diff -pruN 3.4.1-6/alsaMixer/src/applet-backend-alsamixer.c 3.4.1+git20201022.a0d3415c-1/alsaMixer/src/applet-backend-alsamixer.c
--- 3.4.1-6/alsaMixer/src/applet-backend-alsamixer.c	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/alsaMixer/src/applet-backend-alsamixer.c	2020-10-21 15:04:44.000000000 +0000
@@ -31,6 +31,7 @@ static int mixer_level = 0;
 static struct snd_mixer_selem_regopt mixer_options;
 static gboolean mixer_is_mute (void);
 static int mixer_get_mean_volume (void);
+static int mixer_get_mean_capture_volume (void);
 
 static gchar *_mixer_get_card_id_from_name (const gchar *cName)
 {
@@ -127,8 +128,8 @@ void mixer_stop (void)
 		g_free (cCardID);
 		snd_mixer_close (myData.mixer_handle);
 		myData.mixer_handle = NULL;
-		myData.pControledElement = NULL;
-		myData.pControledElement2 = NULL;
+		myData.playback.pControledElement = NULL;
+		myData.playback2.pControledElement = NULL;
 		
 		g_free (myData.cErrorMessage);
 		myData.cErrorMessage = NULL;
@@ -173,25 +174,25 @@ GList *mixer_get_elements_list (void)
 
 
 
-static snd_mixer_elem_t *_mixer_get_element_by_name (const gchar *cName)
+static snd_mixer_elem_t *_mixer_get_element_by_name (const gchar *cName, gboolean bOutput)
 {
 	if (myData.mixer_handle == NULL)
 		return NULL;
 	
-	if (cName != NULL)
+	snd_mixer_elem_t *elem;
+	for (elem = snd_mixer_first_elem(myData.mixer_handle); elem; elem = snd_mixer_elem_next(elem))
 	{
-		snd_mixer_elem_t *elem;
-		for (elem = snd_mixer_first_elem(myData.mixer_handle); elem; elem = snd_mixer_elem_next(elem))
+		if (!cName || strcmp (cName, snd_mixer_selem_get_name (elem)) == 0)  // element name matches
 		{
-			if (strcmp (cName, snd_mixer_selem_get_name (elem)) == 0)
+			if (bOutput && snd_mixer_selem_has_playback_volume(elem))  // output matches
+				return elem;
+			if (!bOutput && snd_mixer_selem_has_capture_volume(elem))  // input matches
 				return elem;
 		}
 	}
 	
-	cd_debug ("no channel matches '%s', we take the first available channel by default", cName);
+	cd_warning ("no channel matches '%s', we take the first available channel by default", cName);
 	return snd_mixer_first_elem(myData.mixer_handle);
-	/**myData.cErrorMessage = g_strdup_printf (D_("I couldn't find any audio channel named '%s'\nYou should try to open the configuration panel of the applet,\n and select the proper audio channel you want to control."), cName);
-	return NULL;*/
 }
 
 
@@ -200,14 +201,24 @@ static int mixer_element_update_with_eve
 	CD_APPLET_ENTER;
 	cd_debug ("%s (%d)", __func__, mask);
 	
-	
 	if (mask != SND_CTL_EVENT_MASK_REMOVE && (mask & SND_CTL_EVENT_MASK_VALUE))  // filter calls that can occur when we really don't want, like when closing the applet.
 	{
-		myData.iCurrentVolume = mixer_get_mean_volume ();
-		myData.bIsMute = mixer_is_mute ();
-		cd_debug (" iCurrentVolume <- %d bIsMute <- %d", myData.iCurrentVolume, myData.bIsMute);
-		
-		cd_update_icon ();
+		if (elem == myData.playback.pControledElement)
+		{
+			myData.playback.iCurrentVolume = mixer_get_mean_volume ();
+			myData.bIsMute = mixer_is_mute ();
+			cd_debug (" iCurrentVolume <- %d bIsMute <- %d", myData.playback.iCurrentVolume, myData.bIsMute);
+			
+			cd_update_icon ();
+		}
+		else if (elem == myData.capture.pControledElement)
+		{
+			myData.capture.iCurrentVolume = mixer_get_mean_capture_volume ();
+			if (myData.pCaptureScale)
+			{
+				cd_mixer_set_volume_with_no_callback (myData.pCaptureScale, myData.capture.iCurrentVolume);
+			}
+		}
 	}
 	
 	CD_APPLET_LEAVE(0);
@@ -215,58 +226,70 @@ static int mixer_element_update_with_eve
 
 static void mixer_get_controlled_element (void)
 {
-	myData.pControledElement = _mixer_get_element_by_name (myConfig.cMixerElementName);
-	if (myData.pControledElement != NULL)
+	myData.playback.pControledElement = _mixer_get_element_by_name (myConfig.cMixerElementName, TRUE);
+	if (myData.playback.pControledElement != NULL)
 	{
-		myData.bHasMuteSwitch = snd_mixer_selem_has_playback_switch (myData.pControledElement);
+		myData.playback.bHasMuteSwitch = snd_mixer_selem_has_playback_switch (myData.playback.pControledElement);
+		snd_mixer_selem_get_playback_volume_range (myData.playback.pControledElement, &myData.playback.iVolumeMin, &myData.playback.iVolumeMax);
+		cd_debug ("volume range : %d - %d", myData.playback.iVolumeMin, myData.playback.iVolumeMax);
 		
-		snd_mixer_selem_get_playback_volume_range (myData.pControledElement, &myData.iVolumeMin, &myData.iVolumeMax);
-		cd_debug ("volume range : %d - %d", myData.iVolumeMin, myData.iVolumeMax);
-		
-		snd_mixer_elem_set_callback (myData.pControledElement, mixer_element_update_with_event);
+		snd_mixer_elem_set_callback (myData.playback.pControledElement, mixer_element_update_with_event);
 	}
 	if (myConfig.cMixerElementName2 != NULL)
 	{
-		myData.pControledElement2 = _mixer_get_element_by_name (myConfig.cMixerElementName2);
+		myData.playback2.pControledElement = _mixer_get_element_by_name (myConfig.cMixerElementName2, TRUE);
+		myData.playback2.bHasMuteSwitch = myData.playback.bHasMuteSwitch;
+		myData.playback2.iVolumeMin = myData.playback.iVolumeMin;
+		myData.playback2.iVolumeMax = myData.playback.iVolumeMax;  // no need to set a callback, we'll control the 2nd element based on the first one
+	}
+	myData.capture.pControledElement = _mixer_get_element_by_name (myConfig.cCaptureMixerElementName, FALSE);
+	if (myData.capture.pControledElement != NULL)
+	{
+		myData.capture.bHasMuteSwitch = snd_mixer_selem_has_capture_switch (myData.capture.pControledElement);
+		snd_mixer_selem_get_capture_volume_range (myData.capture.pControledElement, &myData.capture.iVolumeMin, &myData.capture.iVolumeMax);
+		cd_debug ("capture volume range : %d - %d", myData.capture.iVolumeMin, myData.capture.iVolumeMax);
+		
+		snd_mixer_elem_set_callback (myData.capture.pControledElement, mixer_element_update_with_event);
 	}
+	
 }
 
 static int mixer_get_mean_volume (void)
 {
-	g_return_val_if_fail (myData.pControledElement != NULL, 0);
+	g_return_val_if_fail (myData.playback.pControledElement != NULL, 0);
 	long iVolumeLeft=0, iVolumeRight=0;
-	gboolean bHasLeft = snd_mixer_selem_has_playback_channel (myData.pControledElement, SND_MIXER_SCHN_FRONT_LEFT);
-	gboolean bHasRight = snd_mixer_selem_has_playback_channel (myData.pControledElement, SND_MIXER_SCHN_FRONT_RIGHT);
-	g_return_val_if_fail (bHasLeft || bHasRight, 0);
+	gboolean bHasLeft = snd_mixer_selem_has_playback_channel (myData.playback.pControledElement, SND_MIXER_SCHN_FRONT_LEFT);
+	gboolean bHasRight = snd_mixer_selem_has_playback_channel (myData.playback.pControledElement, SND_MIXER_SCHN_FRONT_RIGHT);
+	g_return_val_if_fail (bHasLeft || bHasRight, 0);  // Note: in case of a mono, Front_Left will be the equivalent channel
 	
 	if (bHasLeft)
-		snd_mixer_selem_get_playback_volume (myData.pControledElement, SND_MIXER_SCHN_FRONT_LEFT, &iVolumeLeft);
+		snd_mixer_selem_get_playback_volume (myData.playback.pControledElement, SND_MIXER_SCHN_FRONT_LEFT, &iVolumeLeft);
 	if (bHasRight)
-		snd_mixer_selem_get_playback_volume (myData.pControledElement, SND_MIXER_SCHN_FRONT_RIGHT, &iVolumeRight);
+		snd_mixer_selem_get_playback_volume (myData.playback.pControledElement, SND_MIXER_SCHN_FRONT_RIGHT, &iVolumeRight);
 	cd_debug ("volume : %d;%d", iVolumeLeft, iVolumeRight);
 	
 	int iMeanVolume = (iVolumeLeft + iVolumeRight) / (bHasLeft + bHasRight);
 	
-	cd_debug ("myData.iVolumeMin : %d ; myData.iVolumeMax : %d ; iMeanVolume : %d", myData.iVolumeMin, myData.iVolumeMax, iMeanVolume);
-	return (100. * (iMeanVolume - myData.iVolumeMin) / (myData.iVolumeMax - myData.iVolumeMin));
+	cd_debug ("myData.playback.iVolumeMin : %d ; myData.playback.iVolumeMax : %d ; iMeanVolume : %d", myData.playback.iVolumeMin, myData.playback.iVolumeMax, iMeanVolume);
+	return (100. * (iMeanVolume - myData.playback.iVolumeMin) / (myData.playback.iVolumeMax - myData.playback.iVolumeMin));
 }
 
 static void _set_mute (gboolean bMute)
 {
-	snd_mixer_selem_set_playback_switch_all (myData.pControledElement, !bMute);
-	if (myData.pControledElement2 != NULL)
-		snd_mixer_selem_set_playback_switch_all (myData.pControledElement2, !bMute);
+	snd_mixer_selem_set_playback_switch_all (myData.playback.pControledElement, !bMute);
+	if (myData.playback2.pControledElement != NULL)
+		snd_mixer_selem_set_playback_switch_all (myData.playback2.pControledElement, !bMute);
 	myData.bIsMute = bMute;
 }
 static void mixer_set_volume (int iNewVolume)
 {
-	g_return_if_fail (myData.pControledElement != NULL);
+	g_return_if_fail (myData.playback.pControledElement != NULL);
 	cd_debug ("%s (%d)", __func__, iNewVolume);
-	int iVolume = ceil (myData.iVolumeMin + (myData.iVolumeMax - myData.iVolumeMin) * iNewVolume / 100.);
-	snd_mixer_selem_set_playback_volume_all (myData.pControledElement, iVolume);
-	if (myData.pControledElement2 != NULL)
-		snd_mixer_selem_set_playback_volume_all (myData.pControledElement2, iVolume);
-	myData.iCurrentVolume = iNewVolume;
+	int iVolume = ceil (myData.playback.iVolumeMin + (myData.playback.iVolumeMax - myData.playback.iVolumeMin) * iNewVolume / 100.);
+	snd_mixer_selem_set_playback_volume_all (myData.playback.pControledElement, iVolume);
+	if (myData.playback2.pControledElement != NULL)
+		snd_mixer_selem_set_playback_volume_all (myData.playback2.pControledElement, iVolume);
+	myData.playback.iCurrentVolume = iNewVolume;
 	if (myData.bIsMute)
 	{
 		_set_mute (FALSE);
@@ -274,15 +297,43 @@ static void mixer_set_volume (int iNewVo
 	cd_update_icon ();  // on ne recoit pas d'evenements pour nos actions.
 }
 
+static int mixer_get_mean_capture_volume (void)
+{
+	g_return_val_if_fail (myData.capture.pControledElement != NULL, 0);
+	long iVolumeLeft=0, iVolumeRight=0;
+	gboolean bHasLeft = snd_mixer_selem_has_capture_channel (myData.capture.pControledElement, SND_MIXER_SCHN_FRONT_LEFT);
+	gboolean bHasRight = snd_mixer_selem_has_capture_channel (myData.capture.pControledElement, SND_MIXER_SCHN_FRONT_RIGHT);
+	g_return_val_if_fail (bHasLeft || bHasRight, 0);
+	
+	if (bHasLeft)
+		snd_mixer_selem_get_capture_volume (myData.capture.pControledElement, SND_MIXER_SCHN_FRONT_LEFT, &iVolumeLeft);
+	if (bHasRight)
+		snd_mixer_selem_get_capture_volume (myData.capture.pControledElement, SND_MIXER_SCHN_FRONT_RIGHT, &iVolumeRight);
+	cd_debug ("volume : %d;%d", iVolumeLeft, iVolumeRight);
+	
+	int iMeanVolume = (iVolumeLeft + iVolumeRight) / (bHasLeft + bHasRight);
+	
+	cd_debug ("myData.capture.iVolumeMin : %d ; myData.capture.iVolumeMax : %d ; iMeanVolume : %d", myData.capture.iVolumeMin, myData.capture.iVolumeMax, iMeanVolume);
+	return (100. * (iMeanVolume - myData.capture.iVolumeMin) / (myData.capture.iVolumeMax - myData.capture.iVolumeMin));
+}
+
+static void mixer_set_capture_volume (int iNewVolume)
+{
+	g_return_if_fail (myData.capture.pControledElement != NULL);
+	int iVolume = ceil (myData.capture.iVolumeMin + (myData.capture.iVolumeMax - myData.capture.iVolumeMin) * iNewVolume / 100.);
+	snd_mixer_selem_set_capture_volume_all (myData.capture.pControledElement, iVolume);
+	myData.capture.iCurrentVolume = iNewVolume;
+}
+
 static gboolean mixer_is_mute (void)
 {
 	cd_debug ("");
-	g_return_val_if_fail (myData.pControledElement != NULL, FALSE);
-	if (snd_mixer_selem_has_playback_switch (myData.pControledElement))
+	g_return_val_if_fail (myData.playback.pControledElement != NULL, FALSE);
+	if (snd_mixer_selem_has_playback_switch (myData.playback.pControledElement))
 	{
 		int iSwitchLeft, iSwitchRight;
-		snd_mixer_selem_get_playback_switch (myData.pControledElement, SND_MIXER_SCHN_FRONT_LEFT, &iSwitchLeft);
-		snd_mixer_selem_get_playback_switch (myData.pControledElement, SND_MIXER_SCHN_FRONT_RIGHT, &iSwitchRight);
+		snd_mixer_selem_get_playback_switch (myData.playback.pControledElement, SND_MIXER_SCHN_FRONT_LEFT, &iSwitchLeft);
+		snd_mixer_selem_get_playback_switch (myData.playback.pControledElement, SND_MIXER_SCHN_FRONT_RIGHT, &iSwitchRight);
 		cd_debug ("%d;%d", iSwitchLeft, iSwitchRight);
 		return (iSwitchLeft == 0 && iSwitchRight == 0);
 	}
@@ -292,7 +343,7 @@ static gboolean mixer_is_mute (void)
 
 static void mixer_switch_mute (void)
 {
-	g_return_if_fail (myData.pControledElement != NULL);
+	g_return_if_fail (myData.playback.pControledElement != NULL);
 	gboolean bIsMute = mixer_is_mute ();
 	_set_mute (! bIsMute);
 	cd_update_icon ();  // on ne recoit pas d'evenements pour nos actions.
@@ -303,6 +354,7 @@ static void mixer_switch_mute (void)
 static void _on_dialog_destroyed (GldiModuleInstance *myApplet)
 {
 	myData.pDialog = NULL;
+	myData.pPlaybackScale = myData.pCaptureScale = NULL;
 }
 static void mixer_show_hide_dialog (void)
 {
@@ -375,13 +427,13 @@ static void cd_mixer_reload_alsa (void)
 	mixer_init (myConfig.card_id);
 	mixer_get_controlled_element ();
 	
-	if (myData.pControledElement == NULL)
+	if (myData.playback.pControledElement == NULL)
 	{
 		CD_APPLET_SET_USER_IMAGE_ON_MY_ICON (myConfig.cBrokenIcon, "broken.svg");
 	}
 	else
 	{
-		mixer_element_update_with_event (myData.pControledElement, 1);  // 1 => get the current state (card may have changed).
+		mixer_element_update_with_event (myData.playback.pControledElement, 1);  // 1 => get the current state (card may have changed).
 		
 		myData.iSidCheckVolume = g_timeout_add (1000, (GSourceFunc) mixer_check_events, (gpointer) NULL);
 	}
@@ -396,7 +448,7 @@ void cd_mixer_init_alsa (void)
 	mixer_get_controlled_element ();
 	
 	// update the icon
-	if (myData.pControledElement == NULL)  // no luck
+	if (myData.playback.pControledElement == NULL)  // no luck
 	{
 		CD_APPLET_SET_USER_IMAGE_ON_MY_ICON (myConfig.cBrokenIcon, "broken.svg");
 	}
@@ -405,6 +457,8 @@ void cd_mixer_init_alsa (void)
 		// set the interface
 		myData.ctl.get_volume = mixer_get_mean_volume;
 		myData.ctl.set_volume = mixer_set_volume;
+		myData.ctl.get_capture_volume = mixer_get_mean_capture_volume;
+		myData.ctl.set_capture_volume = mixer_set_capture_volume;
 		myData.ctl.toggle_mute = mixer_switch_mute;
 		myData.ctl.show_hide = mixer_show_hide_dialog;
 		myData.ctl.stop = cd_mixer_stop_alsa;
@@ -414,13 +468,13 @@ void cd_mixer_init_alsa (void)
 		if (myDesklet)
 		{
 			GtkWidget *box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-			myData.pScale = mixer_build_widget (FALSE);
-			gtk_box_pack_end (GTK_BOX (box), myData.pScale, FALSE, FALSE, 0);
+			myData.pControlWidget = mixer_build_widget (FALSE);
+			gtk_box_pack_end (GTK_BOX (box), myData.pControlWidget, FALSE, FALSE, 0);
 			gtk_container_add (GTK_CONTAINER (myDesklet->container.pWidget), box);
 			gtk_widget_show_all (box);
 			
 			if (myConfig.bHideScaleOnLeave && ! myDesklet->container.bInside)
-				gtk_widget_hide (myData.pScale);
+				gtk_widget_hide (myData.pControlWidget);
 		}
 		else if (myIcon->cName == NULL)  // in dock, set the label
 		{
@@ -428,7 +482,7 @@ void cd_mixer_init_alsa (void)
 		}
 		
 		// trigger the callback to update the icon
-		mixer_element_update_with_event (myData.pControledElement, 1);  // 1 => get the current state.
+		mixer_element_update_with_event (myData.playback.pControledElement, 1);  // 1 => get the current state.
 		myData.iSidCheckVolume = g_timeout_add (1000, (GSourceFunc) mixer_check_events, (gpointer) NULL);
 	}
 }
diff -pruN 3.4.1-6/alsaMixer/src/applet-config.c 3.4.1+git20201022.a0d3415c-1/alsaMixer/src/applet-config.c
--- 3.4.1-6/alsaMixer/src/applet-config.c	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/alsaMixer/src/applet-config.c	2020-10-21 15:04:44.000000000 +0000
@@ -103,10 +103,10 @@ CD_APPLET_RESET_CONFIG_END
 
 
 CD_APPLET_RESET_DATA_BEGIN
-	if (myData.pScale != NULL)
+	if (myData.pControlWidget != NULL)
 	{
-		gtk_widget_destroy (myData.pScale);
-		myData.pScale = NULL;
+		gtk_widget_destroy (myData.pControlWidget);
+		myData.pControlWidget = myData.pPlaybackScale = myData.pCaptureScale = NULL;
 	}
 	gldi_object_unref (GLDI_OBJECT(myData.pDialog));
 CD_APPLET_RESET_DATA_END
diff -pruN 3.4.1-6/alsaMixer/src/applet-draw.c 3.4.1+git20201022.a0d3415c-1/alsaMixer/src/applet-draw.c
--- 3.4.1-6/alsaMixer/src/applet-draw.c	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/alsaMixer/src/applet-draw.c	2020-10-21 15:04:44.000000000 +0000
@@ -34,11 +34,11 @@ void cd_update_icon (void)
 	switch (myConfig.iVolumeDisplay)
 	{
 		case VOLUME_ON_LABEL :
-			CD_APPLET_SET_NAME_FOR_MY_ICON_PRINTF ("%s: %d%%", myData.mixer_card_name?myData.mixer_card_name:D_("Volume"), myData.iCurrentVolume);
+			CD_APPLET_SET_NAME_FOR_MY_ICON_PRINTF ("%s: %d%%", myData.mixer_card_name?myData.mixer_card_name:D_("Volume"), myData.playback.iCurrentVolume);
 		break;
 		
 		case VOLUME_ON_ICON :
-			CD_APPLET_SET_QUICK_INFO_ON_MY_ICON_PRINTF ("%d%%", myData.iCurrentVolume);
+			CD_APPLET_SET_QUICK_INFO_ON_MY_ICON_PRINTF ("%d%%", myData.playback.iCurrentVolume);
 			bNeedRedraw = TRUE;
 		break;
 		
@@ -74,7 +74,7 @@ void cd_update_icon (void)
 			if (myData.bIsMute)
 				fPercent = CAIRO_DATA_RENDERER_UNDEF_VALUE;
 			else
-				fPercent = (double) myData.iCurrentVolume / 100.;
+				fPercent = (double) myData.playback.iCurrentVolume / 100.;
 			CD_APPLET_RENDER_NEW_DATA_ON_MY_ICON (&fPercent);
 			bNeedRedraw = FALSE;
 		}
@@ -87,8 +87,8 @@ void cd_update_icon (void)
 	if (bNeedRedraw)
 		CD_APPLET_REDRAW_MY_ICON;
 	
-	if (myData.pScale)
+	if (myData.pPlaybackScale)
 	{
-		cd_mixer_set_volume_with_no_callback (myData.pScale, myData.iCurrentVolume);
+		cd_mixer_set_volume_with_no_callback (myData.pPlaybackScale, myData.playback.iCurrentVolume);
 	}
 }
diff -pruN 3.4.1-6/alsaMixer/src/applet-generic.c 3.4.1+git20201022.a0d3415c-1/alsaMixer/src/applet-generic.c
--- 3.4.1-6/alsaMixer/src/applet-generic.c	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/alsaMixer/src/applet-generic.c	2020-10-21 15:04:44.000000000 +0000
@@ -45,6 +45,19 @@ void cd_set_volume (int iVolume)
 		myData.ctl.set_volume (iVolume);
 }
 
+int cd_get_capture_volume (void)
+{
+	if (myData.ctl.get_capture_volume)
+		return myData.ctl.get_capture_volume ();
+	return 0;
+}
+
+void cd_set_capture_volume (int iVolume)
+{
+	if (myData.ctl.set_capture_volume)
+		myData.ctl.set_capture_volume (iVolume);
+}
+
 void cd_toggle_mute (void)
 {
 	if (myData.ctl.toggle_mute)
@@ -90,22 +103,68 @@ static void on_change_volume (GtkRange *
 	cd_set_volume (iNewVolume);
 	CD_APPLET_LEAVE();
 }
+static void on_change_capture_volume (GtkRange *range, gpointer data)
+{
+	CD_APPLET_ENTER;
+	int iNewVolume = (int) gtk_range_get_value (GTK_RANGE (range));
+	cd_debug ("%s (%d)", __func__, iNewVolume);
+	cd_set_capture_volume (iNewVolume);
+	CD_APPLET_LEAVE();
+}
 GtkWidget *mixer_build_widget (gboolean bHorizontal)
 {
-	g_return_val_if_fail (myData.pControledElement != NULL, NULL);
+	g_return_val_if_fail (myData.playback.pControledElement != NULL, NULL);
+	// build the playback volume scale
 	GtkWidget *pScale = gtk_scale_new_with_range (bHorizontal ? GTK_ORIENTATION_HORIZONTAL : GTK_ORIENTATION_VERTICAL, 0., 100., .5*myConfig.iScrollVariation);
 	if (! bHorizontal)
 		gtk_range_set_inverted (GTK_RANGE (pScale), TRUE);  // de bas en haut.
 	
-	myData.iCurrentVolume = cd_get_volume ();
-	gtk_range_set_value (GTK_RANGE (pScale), myData.iCurrentVolume);
+	myData.playback.iCurrentVolume = cd_get_volume ();
+	gtk_range_set_value (GTK_RANGE (pScale), myData.playback.iCurrentVolume);
+	gtk_range_set_increments(GTK_RANGE (pScale), 5, 5);
 	
 	g_signal_connect (G_OBJECT (pScale),
 		"value-changed",
 		G_CALLBACK (on_change_volume),
 		NULL);
 	
-	gldi_dialog_set_widget_text_color (pScale);
+	myData.pPlaybackScale = pScale;
+	
+	// build the capture volume scale
+	if (myData.capture.pControledElement != NULL)
+	{
+		GtkWidget *pScale2 = gtk_scale_new_with_range (bHorizontal ? GTK_ORIENTATION_HORIZONTAL : GTK_ORIENTATION_VERTICAL, 0., 100., .5*myConfig.iScrollVariation);
+		if (! bHorizontal)
+			gtk_range_set_inverted (GTK_RANGE (pScale2), TRUE);  // de bas en haut.
+		
+		myData.capture.iCurrentVolume = cd_get_capture_volume ();
+		gtk_range_set_value (GTK_RANGE (pScale2), myData.capture.iCurrentVolume);
+		gtk_range_set_increments(GTK_RANGE (pScale2), 5, 5);
+		
+		g_signal_connect (G_OBJECT (pScale2),
+			"value-changed",
+			G_CALLBACK (on_change_capture_volume),
+			NULL);
+		
+		myData.pCaptureScale = pScale2;
+			
+		// add both scales with some icons into a box
+		GtkWidget *box = gtk_box_new (bHorizontal ? GTK_ORIENTATION_VERTICAL : GTK_ORIENTATION_HORIZONTAL, 0);
+		
+		GtkWidget *hbox = gtk_box_new (bHorizontal ? GTK_ORIENTATION_HORIZONTAL : GTK_ORIENTATION_VERTICAL, 0);
+		GtkWidget *icon = gtk_image_new_from_icon_name ("audio-speakers", GTK_ICON_SIZE_LARGE_TOOLBAR);
+		gtk_box_pack_start (GTK_BOX (hbox), icon, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (hbox), pScale, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 0);
+		
+		hbox = gtk_box_new (bHorizontal ? GTK_ORIENTATION_HORIZONTAL : GTK_ORIENTATION_VERTICAL, 0);
+		icon = gtk_image_new_from_icon_name ("audio-input-microphone", GTK_ICON_SIZE_LARGE_TOOLBAR);
+		gtk_box_pack_start (GTK_BOX (hbox), icon, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (hbox), pScale2, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 0);
+		return box;
+	}
+	
 	return pScale;
 }
 
@@ -115,8 +174,14 @@ void cd_mixer_set_volume_with_no_callbac
 	g_signal_handlers_block_matched (GTK_WIDGET(pScale),
 		G_SIGNAL_MATCH_FUNC,
 		0, 0, NULL, (void*)on_change_volume, NULL);
+	g_signal_handlers_block_matched (GTK_WIDGET(pScale),
+		G_SIGNAL_MATCH_FUNC,
+		0, 0, NULL, (void*)on_change_capture_volume, NULL);
 	gtk_range_set_value (GTK_RANGE (pScale), (double) iVolume);
 	g_signal_handlers_unblock_matched (GTK_WIDGET(pScale),
 		G_SIGNAL_MATCH_FUNC,
 		0, 0, NULL, (void*)on_change_volume, NULL);
+	g_signal_handlers_unblock_matched (GTK_WIDGET(pScale),
+		G_SIGNAL_MATCH_FUNC,
+		0, 0, NULL, (void*)on_change_capture_volume, NULL);
 }
diff -pruN 3.4.1-6/alsaMixer/src/applet-generic.h 3.4.1+git20201022.a0d3415c-1/alsaMixer/src/applet-generic.h
--- 3.4.1-6/alsaMixer/src/applet-generic.h	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/alsaMixer/src/applet-generic.h	2020-10-21 15:04:44.000000000 +0000
@@ -27,6 +27,10 @@ int cd_get_volume (void);
 
 void cd_set_volume (int iVolume);
 
+int cd_get_capture_volume (void);
+
+void cd_set_capture_volume (int iVolume);
+
 void cd_toggle_mute (void);
 
 void cd_show_hide (void);
diff -pruN 3.4.1-6/alsaMixer/src/applet-init.c 3.4.1+git20201022.a0d3415c-1/alsaMixer/src/applet-init.c
--- 3.4.1-6/alsaMixer/src/applet-init.c	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/alsaMixer/src/applet-init.c	2020-10-21 15:04:44.000000000 +0000
@@ -27,7 +27,7 @@
 
 
 CD_APPLET_DEFINE_BEGIN ("AlsaMixer",
-	2, 0, 0,
+	2, 1, 0,
 	CAIRO_DOCK_CATEGORY_APPLET_SYSTEM,
 	N_("This applet lets you control the sound volume from the dock.\n"
 	"Scroll up/down on the icon to increase/decrease the volume.\n"
@@ -46,9 +46,9 @@ static gboolean _cd_mixer_on_enter (GtkW
 	GdkEventCrossing* pEvent,
 	gpointer data)
 {
-	if (myData.pScale && myDesklet && myDesklet->container.iHeight > 64)
+	if (myData.pControlWidget && myDesklet && myDesklet->container.iHeight > 64)
 	{
-		gtk_widget_show (myData.pScale);
+		gtk_widget_show (myData.pControlWidget);
 	}
 	return GLDI_NOTIFICATION_LET_PASS;
 }
@@ -56,10 +56,12 @@ gboolean _cd_mixer_on_leave (GtkWidget*
 	GdkEventCrossing* pEvent,
 	gpointer data)
 {
-	if (myData.pScale && myDesklet && myDesklet->container.iHeight > 64)
+	if (myData.pControlWidget && myDesklet && myDesklet->container.iHeight > 64)
 	{
 		if (! myDesklet->container.bInside)
-			gtk_widget_hide (myData.pScale);
+		{
+			gtk_widget_hide (myData.pControlWidget);
+		}
 	}
 	return GLDI_NOTIFICATION_LET_PASS;
 }
@@ -201,12 +203,12 @@ CD_APPLET_RELOAD_BEGIN
 				myData.pDialog = NULL;
 
 				GtkWidget *box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-				myData.pScale = mixer_build_widget (FALSE);
-				gtk_box_pack_end (GTK_BOX (box), myData.pScale, FALSE, FALSE, 0);
+				myData.pControlWidget = mixer_build_widget (FALSE);
+				gtk_box_pack_end (GTK_BOX (box), myData.pControlWidget, FALSE, FALSE, 0);
 				gtk_widget_show_all (box);
 				gtk_container_add (GTK_CONTAINER (myDesklet->container.pWidget), box);
 				if (myConfig.bHideScaleOnLeave && ! myDesklet->container.bInside)
-					gtk_widget_hide (myData.pScale);
+					gtk_widget_hide (myData.pControlWidget);
 			}
 			
 			gulong iOnEnterCallbackID = g_signal_handler_find (myDesklet->container.pWidget,
@@ -242,10 +244,10 @@ CD_APPLET_RELOAD_BEGIN
 		}
 		else
 		{
-			if (CD_APPLET_MY_CONTAINER_TYPE_CHANGED && myData.pScale)
+			if (CD_APPLET_MY_CONTAINER_TYPE_CHANGED && myData.pControlWidget)
 			{
-				gtk_widget_destroy (myData.pScale);
-				myData.pScale = NULL;
+				gtk_widget_destroy (myData.pControlWidget);
+				myData.pControlWidget = myData.pPlaybackScale = myData.pCaptureScale = NULL;
 			}
 			
 			if (myIcon->cName == NULL)
@@ -258,7 +260,7 @@ CD_APPLET_RELOAD_BEGIN
 	{
 		///\_______________ On redessine notre icone.
 		if (myDesklet && myDesklet->container.iHeight <= 64)
-			gtk_widget_hide (myData.pScale);
+			gtk_widget_hide (myData.pControlWidget);
 		
 		/**if (myConfig.iVolumeEffect != VOLUME_EFFECT_NONE)
 			CD_APPLET_RELOAD_MY_DATA_RENDERER (NULL);
diff -pruN 3.4.1-6/alsaMixer/src/applet-struct.h 3.4.1+git20201022.a0d3415c-1/alsaMixer/src/applet-struct.h
--- 3.4.1-6/alsaMixer/src/applet-struct.h	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/alsaMixer/src/applet-struct.h	2020-10-21 15:04:44.000000000 +0000
@@ -22,7 +22,6 @@
 
 #include <sys/types.h>
 #include <alsa/asoundlib.h>
-#define _STRUCT_TIMEVAL
 #include <cairo-dock.h>
 
 #ifdef INDICATOR_SOUNDMENU_WITH_IND3
@@ -53,6 +52,7 @@ struct _AppletConfig {
 	gchar *card_id;
 	gchar *cMixerElementName;
 	gchar *cMixerElementName2;
+	gchar *cCaptureMixerElementName;
 	gchar *cShowAdvancedMixerCommand;
 	// display
 	VolumeTypeDisplay iVolumeDisplay;
@@ -75,12 +75,21 @@ struct _AppletConfig {
 typedef struct {
 	int (*get_volume) (void);
 	void (*set_volume) (int iVolume);
+	int (*get_capture_volume) (void);
+	void (*set_capture_volume) (int iVolume);
 	void (*toggle_mute) (void);
 	void (*show_hide) (void);
 	void (*stop) (void);
 	void (*reload) (void);
 	} CDSoundCtl;
 
+typedef struct {
+	snd_mixer_elem_t *pControledElement;  // mixer element
+	long iVolumeMin, iVolumeMax;  // volumes min et max en unites de la carte son.
+	gboolean bHasMuteSwitch;
+	int iCurrentVolume;  // current volume in [0-100]
+	} AlsaElem;
+
 struct _AppletData {
 	// generic interface
 	CDSoundCtl ctl;
@@ -89,14 +98,11 @@ struct _AppletData {
 	gchar *mixer_card_name;
 	gchar *mixer_device_name;
 	gchar *cErrorMessage;
-	snd_mixer_elem_t *pControledElement;
-	snd_mixer_elem_t *pControledElement2;  // des fois un element ne controle qu'une sortie (droite ou gauche).
-	snd_mixer_selem_id_t *pControledID;
-	gboolean bHasMuteSwitch;
-	long iVolumeMin, iVolumeMax;  // volumes min et max en unites de la carte son.
+	AlsaElem playback;
+	AlsaElem playback2;  // des fois un element ne controle qu'une sortie (droite ou gauche).
+	AlsaElem capture;
 	guint iSidCheckVolume;
 	CairoDialog *pDialog;
-	int iCurrentVolume;  // current volume in [0-100]
 	// sound service data
 	#ifdef INDICATOR_SOUNDMENU_WITH_IND3
 	IndicatorObject *pIndicator;
@@ -112,7 +118,9 @@ struct _AppletData {
 	// other
 	gboolean bIsMute;
 	gint bMuteImage;  // 1 if the "mute" image is currently displayed, 0 if the normal icon is set, -1 if no image is set
-	GtkWidget *pScale;
+	GtkWidget *pControlWidget;
+	GtkWidget *pPlaybackScale;
+	GtkWidget *pCaptureScale;
 	GldiShortkey *cKeyBinding;
 	} ;
 
diff -pruN 3.4.1-6/Animated-icons/data/misc/box_with_spring_nicu_buc_01.svg 3.4.1+git20201022.a0d3415c-1/Animated-icons/data/misc/box_with_spring_nicu_buc_01.svg
--- 3.4.1-6/Animated-icons/data/misc/box_with_spring_nicu_buc_01.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Animated-icons/data/misc/box_with_spring_nicu_buc_01.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,134 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) --><svg height="128.00000px" id="svg1" inkscape:export-filename="/home/nicu/Desktop/released.png" inkscape:export-xdpi="72.000000" inkscape:export-ydpi="72.000000" inkscape:version="0.42" sodipodi:docbase="/home/nicu/Desktop/hats" sodipodi:docname="box_with_spring.svg" sodipodi:version="0.32" version="1.0" width="128.00000px" x="0.0000000" xmlns="http://www.w3.org/2000/svg" xmlns:cc="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:sodipodi="http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:svg="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" y="0.0000000">
+  <metadata>
+    <rdf:RDF xmlns:cc="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
+      <cc:Work rdf:about="">
+        <dc:title>box with spring</dc:title>
+        <dc:description></dc:description>
+        <dc:subject>
+          <rdf:Bag>
+            <rdf:li>fun</rdf:li>
+          </rdf:Bag>
+        </dc:subject>
+        <dc:publisher>
+          <cc:Agent rdf:about="http://www.openclipart.org/">
+            <dc:title>Open Clip Art Library</dc:title>
+          </cc:Agent>
+        </dc:publisher>
+        <dc:creator>
+          <cc:Agent>
+            <dc:title>Nicu Buculei</dc:title>
+          </cc:Agent>
+        </dc:creator>
+        <dc:rights>
+          <cc:Agent>
+            <dc:title>Nicu Buculei</dc:title>
+          </cc:Agent>
+        </dc:rights>
+        <dc:date></dc:date>
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
+        <cc:license rdf:resource="http://web.resource.org/cc/PublicDomain"/>
+        <dc:language>en</dc:language>
+      </cc:Work>
+      <cc:License rdf:about="http://web.resource.org/cc/PublicDomain">
+        <cc:permits rdf:resource="http://web.resource.org/cc/Reproduction"/>
+        <cc:permits rdf:resource="http://web.resource.org/cc/Distribution"/>
+        <cc:permits rdf:resource="http://web.resource.org/cc/DerivativeWorks"/>
+      </cc:License>
+    </rdf:RDF>
+  </metadata>
+  <defs id="defs3">
+    <linearGradient id="linearGradient1855" inkscape:collect="always">
+      <stop id="stop1856" offset="0" style="stop-color:#000000;stop-opacity:1;"/>
+      <stop id="stop1857" offset="1" style="stop-color:#000000;stop-opacity:0;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient5295">
+      <stop id="stop5296" offset="0.0000000" style="stop-color:#00aa00;stop-opacity:1.0000000;"/>
+      <stop id="stop5297" offset="1.0000000" style="stop-color:#00cd00;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2569">
+      <stop id="stop2570" offset="0.0000000" style="stop-color:#c27c00;stop-opacity:1.0000000;"/>
+      <stop id="stop2571" offset="1.0000000" style="stop-color:#a66600;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1812">
+      <stop id="stop1813" offset="0.0000000" style="stop-color:#404040;stop-opacity:1.0000000;"/>
+      <stop id="stop1814" offset="1.0000000" style="stop-color:#767974;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1794">
+      <stop id="stop1795" offset="0.0000000" style="stop-color:#989b9d;stop-opacity:1.0000000;"/>
+      <stop id="stop1796" offset="1.0000000" style="stop-color:#d5d3d0;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1790">
+      <stop id="stop1791" offset="0.0000000" style="stop-color:#c29400;stop-opacity:1.0000000;"/>
+      <stop id="stop1792" offset="1.0000000" style="stop-color:#be7600;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1778">
+      <stop id="stop1779" offset="0.0000000" style="stop-color:#c29400;stop-opacity:1.0000000;"/>
+      <stop id="stop1780" offset="1.0000000" style="stop-color:#c2b01f;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1770">
+      <stop id="stop1771" offset="0.0000000" style="stop-color:#c29b00;stop-opacity:1.0000000;"/>
+      <stop id="stop1772" offset="1.0000000" style="stop-color:#c2b600;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient gradientTransform="scale(0.976314,1.024260)" gradientUnits="userSpaceOnUse" id="linearGradient1815" inkscape:collect="always" x1="-48.544033" x2="-358.47437" xlink:href="#linearGradient1812" y1="377.75958" y2="305.25934"/>
+    <linearGradient gradientTransform="scale(3.700101,0.270263)" gradientUnits="userSpaceOnUse" id="linearGradient3389" inkscape:collect="always" x1="28.696781" x2="28.946466" xlink:href="#linearGradient5295" y1="1726.5381" y2="1704.1497"/>
+    <linearGradient gradientTransform="scale(0.976314,1.024260)" gradientUnits="userSpaceOnUse" id="linearGradient1587" inkscape:collect="always" x1="-193.15984" x2="-140.77626" xlink:href="#linearGradient1812" y1="398.25125" y2="520.96924"/>
+    <linearGradient gradientTransform="scale(0.976314,1.024260)" gradientUnits="userSpaceOnUse" id="linearGradient1589" inkscape:collect="always" x1="-186.59181" x2="-116.74704" xlink:href="#linearGradient1812" y1="326.43738" y2="420.05731"/>
+    <linearGradient gradientTransform="scale(0.976314,1.024260)" gradientUnits="userSpaceOnUse" id="linearGradient1591" inkscape:collect="always" x1="-131.43706" x2="-89.798820" xlink:href="#linearGradient1812" y1="255.32832" y2="360.33447"/>
+    <linearGradient gradientTransform="scale(0.976314,1.024260)" gradientUnits="userSpaceOnUse" id="linearGradient1593" inkscape:collect="always" x1="-212.16812" x2="-114.92285" xlink:href="#linearGradient1812" y1="154.25601" y2="301.00696"/>
+    <radialGradient cx="190.61931" cy="736.56592" fx="190.61931" fy="736.56592" gradientTransform="scale(1.982798,0.504338)" gradientUnits="userSpaceOnUse" id="radialGradient1601" inkscape:collect="always" r="103.85657" xlink:href="#linearGradient1794"/>
+    <linearGradient gradientTransform="scale(2.137332,0.467873)" gradientUnits="userSpaceOnUse" id="linearGradient1603" inkscape:collect="always" x1="188.37379" x2="276.59924" xlink:href="#linearGradient1794" y1="563.35138" y2="393.83224"/>
+    <radialGradient cx="220.48315" cy="488.00928" fx="220.48315" fy="488.00928" gradientTransform="scale(2.137331,0.467873)" gradientUnits="userSpaceOnUse" id="radialGradient1605" inkscape:collect="always" r="80.723335" xlink:href="#linearGradient1855"/>
+    <linearGradient gradientTransform="matrix(0.501847,0.000000,0.000000,0.647652,58.62980,-33.53691)" gradientUnits="userSpaceOnUse" id="linearGradient1630" inkscape:collect="always" x1="782.53198" x2="700.44714" xlink:href="#linearGradient1778" y1="490.17572" y2="644.74353"/>
+    <linearGradient gradientTransform="matrix(0.987455,0.000000,0.000000,0.329151,58.62980,-33.53691)" gradientUnits="userSpaceOnUse" id="linearGradient1634" inkscape:collect="always" x1="152.44762" x2="249.39693" xlink:href="#linearGradient1770" y1="1371.7654" y2="1249.2849"/>
+    <linearGradient gradientTransform="matrix(0.288427,0.000000,0.000000,1.126879,58.62980,-33.53691)" gradientUnits="userSpaceOnUse" id="linearGradient1638" inkscape:collect="always" x1="1021.5574" x2="1364.4189" xlink:href="#linearGradient1778" y1="458.66159" y2="353.86533"/>
+    <linearGradient gradientTransform="matrix(0.562161,0.000000,0.000000,0.578166,58.62980,-33.53691)" gradientUnits="userSpaceOnUse" id="linearGradient1647" inkscape:collect="always" x1="177.96225" x2="430.68698" xlink:href="#linearGradient1770" y1="963.03784" y2="698.14783"/>
+    <linearGradient gradientTransform="matrix(0.535281,0.000000,0.000000,0.607201,58.62980,-33.53691)" gradientUnits="userSpaceOnUse" id="linearGradient1650" inkscape:collect="always" x1="592.96381" x2="382.89490" xlink:href="#linearGradient2569" y1="704.61902" y2="476.01773"/>
+    <linearGradient gradientTransform="matrix(0.353250,0.000000,0.000000,0.920092,58.62980,-33.53691)" gradientUnits="userSpaceOnUse" id="linearGradient1653" inkscape:collect="always" x1="429.18546" x2="303.49216" xlink:href="#linearGradient1790" y1="586.39734" y2="364.97208"/>
+    <linearGradient gradientTransform="matrix(2.158394,0.000000,0.000000,0.150586,58.62980,-33.53691)" gradientUnits="userSpaceOnUse" id="linearGradient1656" inkscape:collect="always" x1="161.98236" x2="158.20120" xlink:href="#linearGradient1778" y1="1921.3303" y2="1946.7587"/>
+    <linearGradient gradientTransform="matrix(2.158394,0.000000,0.000000,0.150586,58.62980,-33.53691)" gradientUnits="userSpaceOnUse" id="linearGradient2409" inkscape:collect="always" x1="161.98236" x2="158.20120" xlink:href="#linearGradient1778" y1="1921.3303" y2="1946.7587"/>
+    <linearGradient gradientTransform="matrix(0.353250,0.000000,0.000000,0.920092,58.62980,-33.53691)" gradientUnits="userSpaceOnUse" id="linearGradient2411" inkscape:collect="always" x1="429.18546" x2="303.49216" xlink:href="#linearGradient1790" y1="586.39734" y2="364.97208"/>
+    <linearGradient gradientTransform="matrix(0.535281,0.000000,0.000000,0.607201,58.62980,-33.53691)" gradientUnits="userSpaceOnUse" id="linearGradient2413" inkscape:collect="always" x1="592.96381" x2="382.89490" xlink:href="#linearGradient2569" y1="704.61902" y2="476.01773"/>
+    <linearGradient gradientTransform="matrix(0.562161,0.000000,0.000000,0.578166,58.62980,-33.53691)" gradientUnits="userSpaceOnUse" id="linearGradient2415" inkscape:collect="always" x1="177.96225" x2="430.68698" xlink:href="#linearGradient1770" y1="963.03784" y2="698.14783"/>
+    <linearGradient gradientTransform="scale(0.976314,1.024260)" gradientUnits="userSpaceOnUse" id="linearGradient2417" inkscape:collect="always" x1="-193.15984" x2="-140.77626" xlink:href="#linearGradient1812" y1="398.25125" y2="520.96924"/>
+    <linearGradient gradientTransform="scale(0.976314,1.024260)" gradientUnits="userSpaceOnUse" id="linearGradient2419" inkscape:collect="always" x1="-186.59181" x2="-116.74704" xlink:href="#linearGradient1812" y1="326.43738" y2="420.05731"/>
+    <linearGradient gradientTransform="scale(0.976314,1.024260)" gradientUnits="userSpaceOnUse" id="linearGradient2421" inkscape:collect="always" x1="-131.43706" x2="-89.798820" xlink:href="#linearGradient1812" y1="255.32832" y2="360.33447"/>
+    <linearGradient gradientTransform="scale(0.976314,1.024260)" gradientUnits="userSpaceOnUse" id="linearGradient2423" inkscape:collect="always" x1="-212.16812" x2="-114.92285" xlink:href="#linearGradient1812" y1="154.25601" y2="301.00696"/>
+    <linearGradient gradientTransform="matrix(0.288427,0.000000,0.000000,1.126879,58.62980,-33.53691)" gradientUnits="userSpaceOnUse" id="linearGradient2425" inkscape:collect="always" x1="1021.5574" x2="1364.4189" xlink:href="#linearGradient1778" y1="458.66159" y2="353.86533"/>
+    <linearGradient gradientTransform="matrix(0.987455,0.000000,0.000000,0.329151,58.62980,-33.53691)" gradientUnits="userSpaceOnUse" id="linearGradient2427" inkscape:collect="always" x1="152.44762" x2="249.39693" xlink:href="#linearGradient1770" y1="1371.7654" y2="1249.2849"/>
+    <linearGradient gradientTransform="matrix(0.501847,0.000000,0.000000,0.647652,58.62980,-33.53691)" gradientUnits="userSpaceOnUse" id="linearGradient2429" inkscape:collect="always" x1="782.53198" x2="700.44714" xlink:href="#linearGradient1778" y1="490.17572" y2="644.74353"/>
+    <radialGradient cx="190.61931" cy="736.56592" fx="190.61931" fy="736.56592" gradientTransform="scale(1.982798,0.504338)" gradientUnits="userSpaceOnUse" id="radialGradient2431" inkscape:collect="always" r="103.85657" xlink:href="#linearGradient1794"/>
+    <linearGradient gradientTransform="scale(2.137332,0.467873)" gradientUnits="userSpaceOnUse" id="linearGradient2433" inkscape:collect="always" x1="188.37379" x2="276.59924" xlink:href="#linearGradient1794" y1="563.35138" y2="393.83224"/>
+    <radialGradient cx="220.48315" cy="488.00928" fx="220.48315" fy="488.00928" gradientTransform="scale(2.137331,0.467873)" gradientUnits="userSpaceOnUse" id="radialGradient2435" inkscape:collect="always" r="80.723335" xlink:href="#linearGradient1855"/>
+  </defs>
+  <sodipodi:namedview bordercolor="#666666" borderopacity="1.0" id="base" inkscape:current-layer="layer1" inkscape:cx="64.000000" inkscape:cy="64.000000" inkscape:guide-bbox="true" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:window-height="793" inkscape:window-width="1152" inkscape:window-x="0" inkscape:window-y="25" inkscape:zoom="1.0000000" pagecolor="#ffffff" showguides="true"/>
+  <g id="layer3" inkscape:groupmode="layer" inkscape:label="paper" style="display:block"/>
+  <g id="layer4" inkscape:groupmode="layer" inkscape:label="text" style="display:block"/>
+  <g id="layer1" inkscape:groupmode="layer" inkscape:label="box" style="display:block">
+    <g id="g2386" transform="matrix(0.287026,0.000000,0.000000,0.287026,-12.66025,-32.07695)">
+      <path d="M 248.93095,250.08859 C 249.48797,251.49226 196.98393,264.62981 173.76209,270.79382 C 136.65602,302.01634 54.291960,369.85285 56.213760,369.36229 C 81.847000,361.28188 118.62814,348.95494 144.26138,340.87453 C 129.67431,368.94850 113.46267,397.87927 98.896140,425.96383 C 114.54442,425.99952 132.34647,424.62493 147.99473,424.67047 C 148.38332,462.56320 147.34196,501.33306 147.55310,539.22717 C 213.26392,539.22717 279.53687,539.78930 345.24770,539.78930 C 344.76228,535.33376 395.44979,468.22683 417.58008,437.38565 C 417.58008,415.34743 419.26647,391.06070 419.26647,369.02248 C 437.28478,340.60654 454.73663,312.18783 472.75764,283.77360 C 463.02154,277.88905 450.18978,271.70444 440.45100,265.82430 C 450.86121,265.77335 466.70442,267.39326 477.05420,266.83970 C 481.33026,265.86705 417.98732,252.03186 414.57308,250.07956 C 363.69688,249.54322 244.37165,247.98557 248.93095,250.08859 z " id="path1831" sodipodi:nodetypes="ccccccccccccccc" style="fill:#000000;fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:2.5000000;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000"/>
+      <path d="M 253.18823,250.42650 L 290.62865,263.19027 L 472.72528,265.74304 L 416.56463,252.12834 L 253.18823,250.42650 z " id="path1690" sodipodi:nodetypes="ccccc" style="fill:url(#linearGradient2409);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:2.5000000;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000"/>
+      <path d="M 147.67431,337.22021 L 150.22707,537.18613 L 257.44283,441.03230 L 258.67717,250.29870 L 147.67431,337.22021 z " id="path1063" sodipodi:nodetypes="ccccc" style="fill:url(#linearGradient2411);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:2.5000000;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000"/>
+      <path d="M 256.59191,251.53525 L 416.56463,253.09450 L 414.86280,433.11607 L 255.74099,433.96699 L 256.59191,251.53525 z " id="path1064" sodipodi:nodetypes="ccccc" style="fill:url(#linearGradient2413);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:2.5000000;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000"/>
+      <path d="M 148.52523,339.31882 L 344.23654,336.56152 L 344.23654,537.84506 L 149.37615,537.84506 L 148.52523,339.31882 z " id="path1061" sodipodi:nodetypes="ccccc" style="fill:url(#linearGradient2415);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:2.5000000;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000"/>
+      <path d="M 147.09674,338.90660 L 257.99723,251.27741 L 174.05280,272.55038 L 63.433360,365.30053 L 147.09674,338.90660 z " id="path1689" sodipodi:nodetypes="ccccc" style="fill:#c29b00;fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:2.5000000;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000"/>
+      <g id="g1718" style="fill:url(#linearGradient1815);fill-opacity:1.0000000;stroke:#000000;stroke-width:5.2754922;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000" transform="matrix(0.453076,0.000000,0.000000,0.495659,367.9590,125.4119)">
+        <path d="M -344.29789,384.52636 C -366.99173,403.58918 -375.71819,423.69550 -373.06155,444.16724 C -370.40491,464.63898 -356.11503,482.71349 -335.21780,497.51099 C -293.42333,527.10599 -223.58984,545.11008 -149.12405,540.72974 L -148.93655,540.72974 L -148.78030,540.69849 C -90.162127,534.57421 -56.189210,517.91230 -37.936550,498.94849 C -19.683888,479.98468 -17.290814,458.81462 -24.530300,445.54224 L -24.749050,445.13599 L -24.999050,444.72974 C -43.078778,419.61900 -80.419696,412.07721 -117.21780,409.22974 C -154.01590,406.38227 -191.45297,409.01099 -209.65530,409.01099 C -228.76673,409.01099 -254.08246,410.48414 -280.39696,416.50526 C -306.71146,422.52638 -332.22787,438.30777 -352.60376,457.24954 L -345.17722,468.09017 C -332.59227,455.35318 -303.98466,436.04663 -279.65530,430.47974 C -255.32594,424.91285 -228.31218,424.01099 -209.65530,424.01099 C -190.08933,424.01099 -153.67906,421.46655 -118.37405,424.19849 C -83.333321,426.90998 -50.555666,435.59567 -37.530300,453.13599 C -34.630594,458.99705 -34.253372,473.48179 -48.749049,488.54224 C -63.511988,503.88036 -93.827278,519.83775 -149.99905,525.76099 C -150.05126,525.76406 -150.10309,525.75794 -150.15530,525.76099 C -221.55448,529.92878 -288.98423,511.90105 -326.56155,485.29224 C -345.36395,471.97811 -356.28310,456.89754 -358.18655,442.22974 C -360.09000,427.56194 -355.67640,413.50875 -335.45171,396.52001 L -344.29789,384.52636 z " id="path1717" sodipodi:nodetypes="cccccccccccccccccccccccccc" style="fill:url(#linearGradient2417);fill-rule:evenodd;stroke-linecap:butt;stroke-linejoin:miter"/>
+        <path d="M -325.27318,296.09912 C -347.96702,315.16194 -357.50354,338.47697 -354.84690,358.94871 C -352.19026,379.42045 -337.90038,397.49496 -317.00315,412.29246 C -275.20868,441.88746 -205.37519,459.89155 -130.90940,455.51121 L -130.72190,455.51121 L -130.56565,455.47996 C -71.947479,449.35568 -37.974562,432.69377 -19.721901,413.72996 C -1.4692400,394.76615 0.92383398,373.59609 -6.3156510,360.32371 L -6.5344010,359.91746 L -6.7844010,359.51121 C -24.864130,334.40047 -62.205048,326.85868 -99.003151,324.01121 C -135.80125,321.16374 -173.23832,323.79246 -191.44065,323.79246 C -210.55208,323.79246 -235.86781,325.26561 -262.18231,331.28673 C -288.49681,337.30785 -314.55327,353.08924 -334.92916,372.03101 C -332.45364,376.87868 -330.24815,379.75175 -327.23259,382.87164 C -314.64764,370.13465 -285.77001,350.82810 -261.44065,345.26121 C -237.11129,339.69432 -210.09753,338.79246 -191.44065,338.79246 C -171.87468,338.79246 -135.46441,336.24802 -100.15940,338.97996 C -65.118673,341.69145 -32.341018,350.37714 -19.315651,367.91746 C -16.415945,373.77852 -16.038723,388.26326 -30.534401,403.32371 C -45.297340,418.66183 -75.612630,434.61922 -131.78440,440.54246 C -131.83661,440.54553 -131.88844,440.53941 -131.94065,440.54246 C -203.33983,444.71025 -270.76958,426.68252 -308.34690,400.07371 C -327.14930,386.75958 -338.06845,371.67901 -339.97190,357.01121 C -341.87535,342.34341 -337.46175,324.58786 -317.23706,307.59912 L -325.27318,296.09912 z " id="path1715" sodipodi:nodetypes="cccccccccccccccccccccccccc" style="fill:url(#linearGradient2419);fill-rule:evenodd;stroke-linecap:butt;stroke-linejoin:miter"/>
+        <path d="M -305.25000,212.28125 C -327.94384,231.34407 -337.75039,252.68451 -335.09375,273.15625 C -332.43711,293.62799 -318.14723,311.70250 -297.25000,326.50000 C -255.45553,356.09500 -185.62204,374.09909 -111.15625,369.71875 L -110.96875,369.71875 L -110.81250,369.68750 C -52.194328,363.56322 -18.221411,346.90131 0.031250000,327.93750 C 18.283911,308.97369 20.676985,287.80363 13.437500,274.53125 L 13.218750,274.12500 L 12.968750,273.71875 C -5.1109788,248.60801 -42.451897,241.06622 -79.250000,238.21875 C -116.04810,235.37128 -153.48517,238.00000 -171.68750,238.00000 C -190.79893,238.00000 -216.11466,239.47315 -242.42916,245.49427 C -268.74366,251.51539 -294.69070,267.61701 -315.06659,286.55878 C -312.80756,290.31240 -310.00849,294.80650 -307.47944,297.07918 C -294.89449,284.34219 -266.01686,265.03564 -241.68750,259.46875 C -217.35814,253.90186 -190.34438,253.00000 -171.68750,253.00000 C -152.12153,253.00000 -115.71126,250.45556 -80.406250,253.18750 C -45.365522,255.89899 -12.587867,264.58468 0.43750000,282.12500 C 3.3372059,287.98606 3.7144279,302.47080 -10.781250,317.53125 C -25.544189,332.86937 -55.859479,348.82676 -112.03125,354.75000 C -112.08346,354.75307 -112.13529,354.74695 -112.18750,354.75000 C -183.58668,358.91779 -251.01643,340.89006 -288.59375,314.28125 C -307.39615,300.96712 -318.31530,285.88655 -320.21875,271.21875 C -322.12220,256.55095 -315.81844,240.76999 -295.59375,223.78125 L -305.25000,212.28125 z " id="path1700" sodipodi:nodetypes="cccccccccccccccccccccccccc" style="fill:url(#linearGradient2421);fill-rule:evenodd;stroke-linecap:butt;stroke-linejoin:miter"/>
+        <path d="M -300.28082,137.71789 C -306.42374,140.23899 -327.58051,125.12766 -320.71363,134.66717 C -358.36143,178.99769 -289.92030,243.51471 -243.03289,273.02257 C -205.28789,294.51671 -159.94007,295.36310 -117.81523,291.13127 C -82.523115,287.20883 -46.878496,279.77251 -15.177919,263.26506 C -0.13785372,254.06781 14.385084,238.47695 13.494128,219.72901 C 10.804388,200.01218 -8.4540789,188.95418 -24.839939,181.36255 C -75.518968,157.92773 -133.65492,159.96680 -187.84185,169.03649 C -222.44994,175.16972 -261.99080,186.56546 -292.68174,203.78959 C -292.07216,204.48978 -284.05820,215.48397 -283.81507,215.48637 C -225.45624,186.27215 -144.40489,170.71748 -80.007852,180.06044 C -53.414772,184.53549 -26.505092,193.63782 -5.9643361,211.62282 C 3.6638018,222.05572 -4.4163624,235.94234 -13.548946,243.37168 C -30.354075,257.60292 -52.608719,262.67198 -73.368920,268.28299 C -119.22395,279.17231 -168.26669,282.82669 -214.02896,269.61422 C -248.97502,258.11344 -274.88312,229.55960 -295.13976,200.04627 C -309.10291,179.03453 -325.47177,168.30723 -300.28082,137.71789 z " id="path1699" sodipodi:nodetypes="ccccccccccccccccc" style="fill:url(#linearGradient2423);fill-rule:evenodd;stroke-linecap:butt;stroke-linejoin:miter"/>
+      </g>
+      <path d="M 344.23654,336.36929 L 416.56463,251.27741 L 416.56463,435.07586 L 343.38562,537.18613 L 344.23654,336.36929 z " id="path1062" sodipodi:nodetypes="ccccc" style="fill:url(#linearGradient2425);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:2.5000000;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000"/>
+      <path d="M 146.78080,338.71264 L 102.53305,423.80451 L 371.28430,427.46925 L 346.60760,338.78700 L 146.78080,338.71264 z " id="path1233" sodipodi:nodetypes="ccccc" style="fill:#7c4900;fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:2.5000000;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000"/>
+      <path d="M 146.82340,338.92205 L 102.57562,424.01392 L 368.06226,424.86484 L 343.38562,336.36929 L 146.82340,338.92205 z " id="path1687" sodipodi:nodetypes="ccccc" style="fill:url(#linearGradient2427);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:2.5000000;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000"/>
+      <path d="M 346.68250,344.55659 L 416.57020,251.26463 L 470.17810,283.59955 L 387.63900,419.23106 L 346.68250,344.55659 z " id="path1860" sodipodi:nodetypes="ccccc" style="fill:#7c4900;fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:2.5000000;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000"/>
+      <path d="M 344.23654,337.22021 L 416.56463,252.12834 L 470.17251,284.46325 L 387.63340,414.65382 L 344.23654,337.22021 z " id="path1688" style="fill:url(#linearGradient2429);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:2.5000000;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000"/>
+      <path d="M 267.59203,150.89285 C 242.87093,152.66228 217.56148,154.22147 194.24289,163.28158 C 188.27727,165.62222 181.68533,169.77952 182.79529,177.25496 C 183.57189,182.14721 182.62157,186.70390 187.12783,189.69319 C 194.49312,195.69092 204.55511,199.15154 213.57686,201.39161 C 246.92330,208.79902 281.39427,208.34615 315.40541,206.94396 C 337.56804,205.55753 359.30268,203.79145 380.43603,196.65016 C 386.59297,194.53144 393.29008,192.83319 396.02023,186.60187 C 396.86887,182.00247 397.25294,176.22485 395.70229,171.95832 C 390.00549,163.58644 379.29214,161.56045 370.21771,158.81880 C 336.73104,150.59772 301.89136,150.04315 267.59203,150.89285 z " id="path2498" sodipodi:nodetypes="ccccccccccc" style="fill:#000000;fill-opacity:1.0000000;stroke:none;stroke-width:2.5000000;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000"/>
+      <g id="g2494" transform="matrix(0.570107,0.000000,0.000000,0.570107,58.62980,-33.53691)">
+        <path d="M 401.71875,327.03125 C 299.96028,327.03125 217.37500,345.09952 217.37500,367.37500 C 215.38308,372.02307 218.71875,378.95563 218.71875,380.93750 C 218.71875,403.21299 301.30403,421.31250 403.06250,421.31250 C 504.82097,421.31250 587.40623,403.21300 587.40625,380.93750 C 587.40625,378.28646 586.06250,369.35472 586.06250,367.37500 C 586.06250,345.09951 503.47723,327.03124 401.71875,327.03125 z " id="path1697" sodipodi:nodetypes="ccccccc" style="fill:url(#radialGradient2431);fill-opacity:1.0000000;stroke:none;stroke-width:2.5000000;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000" transform="translate(3.944035,2.842171e-14)"/>
+        <path d="M 643.77785 228.32654 A 172.53246 37.768299 0 1 1  298.71294,228.32654 A 172.53246 37.768299 0 1 1  643.77785 228.32654 z" id="path1759" sodipodi:cx="471.24539" sodipodi:cy="228.32654" sodipodi:rx="172.53246" sodipodi:ry="37.768299" sodipodi:type="arc" style="fill:url(#linearGradient2433);fill-opacity:1.0000000;stroke:none;stroke-width:2.5000000;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000" transform="matrix(1.068466,0.000000,0.000000,1.068466,-99.06136,123.3834)"/>
+      </g>
+    </g>
+  </g>
+</svg>
Binary files 3.4.1-6/Animated-icons/data/misc/halo.ini.png and 3.4.1+git20201022.a0d3415c-1/Animated-icons/data/misc/halo.ini.png differ
diff -pruN 3.4.1-6/Animated-icons/data/misc/halo.svg 3.4.1+git20201022.a0d3415c-1/Animated-icons/data/misc/halo.svg
--- 3.4.1-6/Animated-icons/data/misc/halo.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Animated-icons/data/misc/halo.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,90 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="128"
+   height="128"
+   id="svg2"
+   sodipodi:version="0.32"
+   inkscape:version="0.46"
+   version="1.0"
+   sodipodi:docname="halo.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <defs
+     id="defs4">
+    <linearGradient
+       id="linearGradient3165">
+      <stop
+         style="stop-color:#87f3fc;stop-opacity:0;"
+         offset="0"
+         id="stop3167" />
+      <stop
+         style="stop-color:#70a7fb;stop-opacity:1;"
+         offset="1"
+         id="stop3169" />
+    </linearGradient>
+    <inkscape:perspective
+       sodipodi:type="inkscape:persp3d"
+       inkscape:vp_x="0 : 526.18109 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_z="744.09448 : 526.18109 : 1"
+       inkscape:persp3d-origin="372.04724 : 350.78739 : 1"
+       id="perspective10" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3165"
+       id="linearGradient3171"
+       x1="1.5203052"
+       y1="526.07056"
+       x2="40.9086"
+       y2="526.07056"
+       gradientUnits="userSpaceOnUse"
+       spreadMethod="reflect"
+       gradientTransform="matrix(0.1740749,0,0,0.1210281,-0.7791102,0.8934343)" />
+  </defs>
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="1.979899"
+     inkscape:cx="173.16522"
+     inkscape:cy="50.956566"
+     inkscape:document-units="px"
+     inkscape:current-layer="layer1"
+     showgrid="false"
+     inkscape:window-width="1279"
+     inkscape:window-height="905"
+     inkscape:window-x="1"
+     inkscape:window-y="29" />
+  <metadata
+     id="metadata7">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:label="Calque 1"
+     inkscape:groupmode="layer"
+     id="layer1">
+    <path
+       style="fill:url(#linearGradient3171);fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:0;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;stroke-miterlimit:4;stroke-dasharray:none;opacity:1"
+       d="M -0.427426,128.25881 C -0.427426,128.25881 11.814507,1.2067436 64.634146,0.86719915 C 115.93088,0.53744457 128.28899,127.76978 128.28899,127.76978"
+       id="path2383"
+       sodipodi:nodetypes="csc" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/Animated-icons/data/misc/icon_old.svg 3.4.1+git20201022.a0d3415c-1/Animated-icons/data/misc/icon_old.svg
--- 3.4.1-6/Animated-icons/data/misc/icon_old.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Animated-icons/data/misc/icon_old.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,812 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   height="128.00000px"
+   id="svg1"
+   inkscape:export-filename="/home/nicu/Desktop/released.png"
+   inkscape:export-xdpi="72.000000"
+   inkscape:export-ydpi="72.000000"
+   inkscape:version="0.46"
+   sodipodi:docbase="/home/nicu/Desktop/hats"
+   sodipodi:docname="icon.svg"
+   sodipodi:version="0.32"
+   version="1.0"
+   width="128.00000px"
+   x="0.0000000"
+   y="0.0000000"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <metadata
+     id="metadata3">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:title>box with spring</dc:title>
+        <dc:description />
+        <dc:subject>
+          <rdf:Bag>
+            <rdf:li>fun</rdf:li>
+          </rdf:Bag>
+        </dc:subject>
+        <dc:publisher>
+          <cc:Agent
+             rdf:about="http://www.openclipart.org/">
+            <dc:title>Open Clip Art Library</dc:title>
+          </cc:Agent>
+        </dc:publisher>
+        <dc:creator>
+          <cc:Agent>
+            <dc:title>Nicu Buculei</dc:title>
+          </cc:Agent>
+        </dc:creator>
+        <dc:rights>
+          <cc:Agent>
+            <dc:title>Nicu Buculei</dc:title>
+          </cc:Agent>
+        </dc:rights>
+        <dc:date />
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <cc:license
+           rdf:resource="http://web.resource.org/cc/PublicDomain" />
+        <dc:language>en</dc:language>
+      </cc:Work>
+      <cc:License
+         rdf:about="http://web.resource.org/cc/PublicDomain">
+        <cc:permits
+           rdf:resource="http://web.resource.org/cc/Reproduction" />
+        <cc:permits
+           rdf:resource="http://web.resource.org/cc/Distribution" />
+        <cc:permits
+           rdf:resource="http://web.resource.org/cc/DerivativeWorks" />
+      </cc:License>
+    </rdf:RDF>
+  </metadata>
+  <defs
+     id="defs3">
+    <inkscape:perspective
+       sodipodi:type="inkscape:persp3d"
+       inkscape:vp_x="0 : 64 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_z="128 : 64 : 1"
+       inkscape:persp3d-origin="64 : 42.666667 : 1"
+       id="perspective85" />
+    <linearGradient
+       id="linearGradient1855"
+       inkscape:collect="always">
+      <stop
+         id="stop1856"
+         offset="0"
+         style="stop-color:#000000;stop-opacity:1;" />
+      <stop
+         id="stop1857"
+         offset="1"
+         style="stop-color:#000000;stop-opacity:0;" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5295">
+      <stop
+         id="stop5296"
+         offset="0.0000000"
+         style="stop-color:#00aa00;stop-opacity:1.0000000;" />
+      <stop
+         id="stop5297"
+         offset="1.0000000"
+         style="stop-color:#00cd00;stop-opacity:1.0000000;" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient2569">
+      <stop
+         id="stop2570"
+         offset="0"
+         style="stop-color:#e8990b;stop-opacity:1;" />
+      <stop
+         id="stop2571"
+         offset="1.0000000"
+         style="stop-color:#a66600;stop-opacity:1.0000000;" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1812">
+      <stop
+         id="stop1813"
+         offset="0.0000000"
+         style="stop-color:#404040;stop-opacity:1.0000000;" />
+      <stop
+         id="stop1814"
+         offset="1.0000000"
+         style="stop-color:#767974;stop-opacity:1.0000000;" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1794">
+      <stop
+         id="stop1795"
+         offset="0.0000000"
+         style="stop-color:#989b9d;stop-opacity:1.0000000;" />
+      <stop
+         id="stop1796"
+         offset="1.0000000"
+         style="stop-color:#d5d3d0;stop-opacity:1.0000000;" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1790">
+      <stop
+         id="stop1791"
+         offset="0.0000000"
+         style="stop-color:#c29400;stop-opacity:1.0000000;" />
+      <stop
+         id="stop1792"
+         offset="1.0000000"
+         style="stop-color:#be7600;stop-opacity:1.0000000;" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1778">
+      <stop
+         id="stop1779"
+         offset="0.0000000"
+         style="stop-color:#c29400;stop-opacity:1.0000000;" />
+      <stop
+         id="stop1780"
+         offset="1.0000000"
+         style="stop-color:#c2b01f;stop-opacity:1.0000000;" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1770">
+      <stop
+         id="stop1771"
+         offset="0.0000000"
+         style="stop-color:#c29b00;stop-opacity:1.0000000;" />
+      <stop
+         id="stop1772"
+         offset="1.0000000"
+         style="stop-color:#c2b600;stop-opacity:1.0000000;" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="scale(0.976314,1.02426)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient1815"
+       inkscape:collect="always"
+       x1="-48.544033"
+       x2="-358.47437"
+       xlink:href="#linearGradient1812"
+       y1="377.75958"
+       y2="305.25934" />
+    <linearGradient
+       gradientTransform="scale(3.700101,0.270263)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient3389"
+       inkscape:collect="always"
+       x1="28.696781"
+       x2="28.946466"
+       xlink:href="#linearGradient5295"
+       y1="1726.5381"
+       y2="1704.1497" />
+    <linearGradient
+       gradientTransform="scale(0.976314,1.024260)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient1587"
+       inkscape:collect="always"
+       x1="-193.15984"
+       x2="-140.77626"
+       xlink:href="#linearGradient1812"
+       y1="398.25125"
+       y2="520.96924" />
+    <linearGradient
+       gradientTransform="scale(0.976314,1.024260)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient1589"
+       inkscape:collect="always"
+       x1="-186.59181"
+       x2="-116.74704"
+       xlink:href="#linearGradient1812"
+       y1="326.43738"
+       y2="420.05731" />
+    <linearGradient
+       gradientTransform="scale(0.976314,1.024260)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient1591"
+       inkscape:collect="always"
+       x1="-131.43706"
+       x2="-89.798820"
+       xlink:href="#linearGradient1812"
+       y1="255.32832"
+       y2="360.33447" />
+    <linearGradient
+       gradientTransform="scale(0.976314,1.024260)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient1593"
+       inkscape:collect="always"
+       x1="-212.16812"
+       x2="-114.92285"
+       xlink:href="#linearGradient1812"
+       y1="154.25601"
+       y2="301.00696" />
+    <radialGradient
+       cx="190.61931"
+       cy="736.56592"
+       fx="190.61931"
+       fy="736.56592"
+       gradientTransform="scale(1.982798,0.504338)"
+       gradientUnits="userSpaceOnUse"
+       id="radialGradient1601"
+       inkscape:collect="always"
+       r="103.85657"
+       xlink:href="#linearGradient1794" />
+    <linearGradient
+       gradientTransform="scale(2.137332,0.467873)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient1603"
+       inkscape:collect="always"
+       x1="188.37379"
+       x2="276.59924"
+       xlink:href="#linearGradient1794"
+       y1="563.35138"
+       y2="393.83224" />
+    <radialGradient
+       cx="220.48315"
+       cy="488.00928"
+       fx="220.48315"
+       fy="488.00928"
+       gradientTransform="scale(2.137331,0.467873)"
+       gradientUnits="userSpaceOnUse"
+       id="radialGradient1605"
+       inkscape:collect="always"
+       r="80.723335"
+       xlink:href="#linearGradient1855" />
+    <linearGradient
+       gradientTransform="matrix(0.501847,0.000000,0.000000,0.647652,58.62980,-33.53691)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient1630"
+       inkscape:collect="always"
+       x1="782.53198"
+       x2="700.44714"
+       xlink:href="#linearGradient1778"
+       y1="490.17572"
+       y2="644.74353" />
+    <linearGradient
+       gradientTransform="matrix(0.987455,0.000000,0.000000,0.329151,58.62980,-33.53691)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient1634"
+       inkscape:collect="always"
+       x1="152.44762"
+       x2="249.39693"
+       xlink:href="#linearGradient1770"
+       y1="1371.7654"
+       y2="1249.2849" />
+    <linearGradient
+       gradientTransform="matrix(0.288427,0.000000,0.000000,1.126879,58.62980,-33.53691)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient1638"
+       inkscape:collect="always"
+       x1="1021.5574"
+       x2="1364.4189"
+       xlink:href="#linearGradient1778"
+       y1="458.66159"
+       y2="353.86533" />
+    <linearGradient
+       gradientTransform="matrix(0.562161,0.000000,0.000000,0.578166,58.62980,-33.53691)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient1647"
+       inkscape:collect="always"
+       x1="177.96225"
+       x2="430.68698"
+       xlink:href="#linearGradient1770"
+       y1="963.03784"
+       y2="698.14783" />
+    <linearGradient
+       gradientTransform="matrix(0.535281,0.000000,0.000000,0.607201,58.62980,-33.53691)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient1650"
+       inkscape:collect="always"
+       x1="592.96381"
+       x2="382.89490"
+       xlink:href="#linearGradient2569"
+       y1="704.61902"
+       y2="476.01773" />
+    <linearGradient
+       gradientTransform="matrix(0.353250,0.000000,0.000000,0.920092,58.62980,-33.53691)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient1653"
+       inkscape:collect="always"
+       x1="429.18546"
+       x2="303.49216"
+       xlink:href="#linearGradient1790"
+       y1="586.39734"
+       y2="364.97208" />
+    <linearGradient
+       gradientTransform="matrix(2.158394,0.000000,0.000000,0.150586,58.62980,-33.53691)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient1656"
+       inkscape:collect="always"
+       x1="161.98236"
+       x2="158.20120"
+       xlink:href="#linearGradient1778"
+       y1="1921.3303"
+       y2="1946.7587" />
+    <linearGradient
+       gradientTransform="matrix(2.158394,0,0,0.150586,58.6298,-33.53691)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient2409"
+       inkscape:collect="always"
+       x1="161.98236"
+       x2="158.20120"
+       xlink:href="#linearGradient1778"
+       y1="1921.3303"
+       y2="1946.7587" />
+    <linearGradient
+       gradientTransform="matrix(0.35325,0,0,0.920092,58.6298,-33.53691)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient2411"
+       inkscape:collect="always"
+       x1="429.18546"
+       x2="303.49216"
+       xlink:href="#linearGradient1790"
+       y1="586.39734"
+       y2="364.97208" />
+    <linearGradient
+       gradientTransform="matrix(0.535281,0,0,0.607201,58.6298,-33.53691)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient2413"
+       inkscape:collect="always"
+       x1="592.96381"
+       x2="382.89490"
+       xlink:href="#linearGradient2569"
+       y1="704.61902"
+       y2="476.01773" />
+    <linearGradient
+       gradientTransform="matrix(0.562161,0,0,0.578166,58.6298,-33.53691)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient2415"
+       inkscape:collect="always"
+       x1="177.96225"
+       x2="430.68698"
+       xlink:href="#linearGradient1770"
+       y1="963.03784"
+       y2="698.14783" />
+    <linearGradient
+       gradientTransform="scale(0.976314,1.02426)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient2417"
+       inkscape:collect="always"
+       x1="-193.15984"
+       x2="-140.77626"
+       xlink:href="#linearGradient1812"
+       y1="398.25125"
+       y2="520.96924" />
+    <linearGradient
+       gradientTransform="scale(0.976314,1.02426)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient2419"
+       inkscape:collect="always"
+       x1="-186.59181"
+       x2="-116.74704"
+       xlink:href="#linearGradient1812"
+       y1="326.43738"
+       y2="420.05731" />
+    <linearGradient
+       gradientTransform="scale(0.976314,1.02426)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient2421"
+       inkscape:collect="always"
+       x1="-131.43706"
+       x2="-89.798820"
+       xlink:href="#linearGradient1812"
+       y1="255.32832"
+       y2="360.33447" />
+    <linearGradient
+       gradientTransform="scale(0.976314,1.02426)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient2423"
+       inkscape:collect="always"
+       x1="-212.16812"
+       x2="-114.92285"
+       xlink:href="#linearGradient1812"
+       y1="154.25601"
+       y2="301.00696" />
+    <linearGradient
+       gradientTransform="matrix(0.288427,0,0,1.126879,58.6298,-33.53691)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient2425"
+       inkscape:collect="always"
+       x1="1021.5574"
+       x2="1364.4189"
+       xlink:href="#linearGradient1778"
+       y1="458.66159"
+       y2="353.86533" />
+    <linearGradient
+       gradientTransform="matrix(0.987455,0,0,0.329151,58.6298,-33.53691)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient2427"
+       inkscape:collect="always"
+       x1="152.44762"
+       x2="249.39693"
+       xlink:href="#linearGradient1770"
+       y1="1371.7654"
+       y2="1249.2849" />
+    <linearGradient
+       gradientTransform="matrix(0.501847,0,0,0.647652,58.6298,-33.53691)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient2429"
+       inkscape:collect="always"
+       x1="782.53198"
+       x2="700.44714"
+       xlink:href="#linearGradient1778"
+       y1="490.17572"
+       y2="644.74353" />
+    <radialGradient
+       cx="190.61931"
+       cy="736.56592"
+       fx="190.61931"
+       fy="736.56592"
+       gradientTransform="scale(1.982798,0.504338)"
+       gradientUnits="userSpaceOnUse"
+       id="radialGradient2431"
+       inkscape:collect="always"
+       r="103.85657"
+       xlink:href="#linearGradient1794" />
+    <linearGradient
+       gradientTransform="scale(2.137332,0.467873)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient2433"
+       inkscape:collect="always"
+       x1="188.37379"
+       x2="276.59924"
+       xlink:href="#linearGradient1794"
+       y1="563.35138"
+       y2="393.83224" />
+    <radialGradient
+       cx="220.48315"
+       cy="488.00928"
+       fx="220.48315"
+       fy="488.00928"
+       gradientTransform="scale(2.137331,0.467873)"
+       gradientUnits="userSpaceOnUse"
+       id="radialGradient2435"
+       inkscape:collect="always"
+       r="80.723335"
+       xlink:href="#linearGradient1855" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1778"
+       id="linearGradient3239"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.1157144,0,0,0.1093439,12.279779,30.811255)"
+       x1="782.53198"
+       y1="490.17572"
+       x2="700.44714"
+       y2="644.74353" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1770"
+       id="linearGradient3243"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.2276845,0,0,5.5570958e-2,12.279779,30.811255)"
+       x1="152.44762"
+       y1="1371.7654"
+       x2="249.39693"
+       y2="1249.2849" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1778"
+       id="linearGradient3247"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(6.6504654e-2,0,0,0.1902523,12.279779,30.811255)"
+       x1="1021.5574"
+       y1="458.66159"
+       x2="1364.4189"
+       y2="353.86533" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1770"
+       id="linearGradient3256"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.1296214,0,0,9.761246e-2,12.279779,30.811255)"
+       x1="177.96225"
+       y1="963.03784"
+       x2="430.68698"
+       y2="698.14783" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient2569"
+       id="linearGradient3259"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.1234236,0,0,0.1025145,12.279779,30.811255)"
+       x1="592.96381"
+       y1="704.61902"
+       x2="382.89490"
+       y2="476.01773" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1790"
+       id="linearGradient3262"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(8.1451352e-2,0,0,0.1553402,12.279779,30.811255)"
+       x1="429.18546"
+       y1="586.39734"
+       x2="303.49216"
+       y2="364.97208" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1778"
+       id="linearGradient3265"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.4976762,0,0,2.5423615e-2,12.279779,30.811255)"
+       x1="161.98236"
+       y1="1921.3303"
+       x2="158.20120"
+       y2="1946.7587" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1794"
+       id="radialGradient3268"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.982798,0.504338)"
+       cx="190.61931"
+       cy="736.56592"
+       fx="190.61931"
+       fy="736.56592"
+       r="103.85657" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1794"
+       id="linearGradient3270"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.137332,0.467873)"
+       x1="188.37379"
+       y1="563.35138"
+       x2="276.59924"
+       y2="393.83224" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1812"
+       id="linearGradient3272"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(0.976314,1.02426)"
+       x1="-193.15984"
+       y1="398.25125"
+       x2="-140.77626"
+       y2="520.96924" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1812"
+       id="linearGradient3274"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(0.976314,1.02426)"
+       x1="-186.59181"
+       y1="326.43738"
+       x2="-116.74704"
+       y2="420.05731" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1812"
+       id="linearGradient3276"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(0.976314,1.02426)"
+       x1="-131.43706"
+       y1="255.32832"
+       x2="-89.798820"
+       y2="360.33447" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1812"
+       id="linearGradient3278"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(0.976314,1.02426)"
+       x1="-212.16812"
+       y1="154.25601"
+       x2="-114.92285"
+       y2="301.00696" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1812"
+       id="linearGradient3280"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(0.976314,1.02426)"
+       x1="-48.544033"
+       y1="377.75958"
+       x2="-358.47437"
+       y2="305.25934" />
+  </defs>
+  <sodipodi:namedview
+     bordercolor="#666666"
+     borderopacity="1.0"
+     id="base"
+     inkscape:current-layer="layer1"
+     inkscape:cx="64"
+     inkscape:cy="62.0681"
+     inkscape:guide-bbox="true"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:window-height="793"
+     inkscape:window-width="1152"
+     inkscape:window-x="10"
+     inkscape:window-y="58"
+     inkscape:zoom="4"
+     pagecolor="#ffffff"
+     showguides="true"
+     showgrid="false" />
+  <g
+     id="layer3"
+     inkscape:groupmode="layer"
+     inkscape:label="paper"
+     style="display:block" />
+  <g
+     id="layer4"
+     inkscape:groupmode="layer"
+     inkscape:label="text"
+     style="display:block" />
+  <g
+     id="layer1"
+     inkscape:groupmode="layer"
+     inkscape:label="box"
+     style="display:block">
+    <path
+       style="fill:#000000;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:2.5;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1"
+       sodipodi:nodetypes="ccccccccccccccc"
+       id="path1831"
+       d="M 56.158862,78.696089 C 56.287298,78.933072 44.181069,81.1511 38.826645,82.191778 C 30.270837,87.463113 11.279573,98.916032 11.722696,98.833211 C 17.633133,97.468985 26.114021,95.387813 32.024458,94.023588 C 28.661015,98.76335 24.922982,103.64777 21.564274,108.38932 C 25.172409,108.39534 29.277153,108.16327 32.885283,108.17096 C 32.974883,114.56843 32.734769,121.11399 32.783454,127.5117 C 47.934863,127.5117 63.215885,127.60661 78.367296,127.60661 C 78.255369,126.85437 89.942747,115.52463 95.04548,110.31768 C 95.04548,106.59694 95.43433,102.49658 95.43433,98.77584 C 99.58894,93.978343 103.61293,89.180378 107.76817,84.383169 C 105.52324,83.389674 102.56453,82.345519 100.31899,81.352768 C 102.71935,81.344166 106.37243,81.617657 108.75885,81.524199 C 109.74481,81.359985 95.13939,79.024173 94.35214,78.694564 C 82.621253,78.604013 55.107591,78.341033 56.158862,78.696089 z" />
+    <path
+       style="fill:url(#linearGradient3265);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:2.5;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1"
+       sodipodi:nodetypes="ccccc"
+       id="path1690"
+       d="M 57.140493,78.753139 L 65.773395,80.908061 L 107.7607,81.339048 L 94.81134,79.040462 L 57.140493,78.753139 z" />
+    <path
+       style="fill:url(#linearGradient3262);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:2.5;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1"
+       sodipodi:nodetypes="ccccc"
+       id="path1063"
+       d="M 32.811402,93.406625 L 33.40001,127.16711 L 58.121506,110.93334 L 58.406116,78.731562 L 32.811402,93.406625 z" />
+    <path
+       style="fill:url(#linearGradient3259);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:2.5;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1"
+       sodipodi:nodetypes="ccccc"
+       id="path1064"
+       d="M 57.925304,78.94033 L 94.81134,79.20358 L 94.418942,109.59684 L 57.729101,109.7405 L 57.925304,78.94033 z" />
+    <path
+       style="fill:url(#linearGradient3256);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:2.5;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1"
+       sodipodi:nodetypes="ccccc"
+       id="path1061"
+       d="M 33.007605,93.760936 L 78.134146,93.295417 L 78.134146,127.27836 L 33.203807,127.27836 L 33.007605,93.760936 z" />
+    <path
+       style="fill:#c29b00;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:2.5;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1"
+       sodipodi:nodetypes="ccccc"
+       id="path1689"
+       d="M 32.678228,93.69134 L 58.249338,78.896799 L 38.893676,82.48834 L 13.38737,98.147459 L 32.678228,93.69134 z" />
+    <g
+       transform="matrix(9.4907248e-2,0,0,0.1054988,83.09913,40.807243)"
+       style="fill:url(#linearGradient3280);fill-opacity:1;stroke:#000000;stroke-width:5.27549219;stroke-miterlimit:4;stroke-opacity:1"
+       id="g1718">
+      <path
+         style="fill:url(#linearGradient3272);fill-rule:evenodd;stroke-linecap:butt;stroke-linejoin:miter"
+         sodipodi:nodetypes="cccccccccccccccccccccccccc"
+         id="path1717"
+         d="M -344.29789,384.52636 C -366.99173,403.58918 -375.71819,423.6955 -373.06155,444.16724 C -370.40491,464.63898 -356.11503,482.71349 -335.2178,497.51099 C -293.42333,527.10599 -223.58984,545.11008 -149.12405,540.72974 L -148.93655,540.72974 L -148.7803,540.69849 C -90.162127,534.57421 -56.18921,517.9123 -37.93655,498.94849 C -19.683888,479.98468 -17.290814,458.81462 -24.5303,445.54224 L -24.74905,445.13599 L -24.99905,444.72974 C -43.078778,419.619 -80.419696,412.07721 -117.2178,409.22974 C -154.0159,406.38227 -191.45297,409.01099 -209.6553,409.01099 C -228.76673,409.01099 -254.08246,410.48414 -280.39696,416.50526 C -306.71146,422.52638 -332.22787,438.30777 -352.60376,457.24954 L -345.17722,468.09017 C -332.59227,455.35318 -303.98466,436.04663 -279.6553,430.47974 C -255.32594,424.91285 -228.31218,424.01099 -209.6553,424.01099 C -190.08933,424.01099 -153.67906,421.46655 -118.37405,424.19849 C -83.333321,426.90998 -50.555666,435.59567 -37.5303,453.13599 C -34.630594,458.99705 -34.253372,473.48179 -48.749049,488.54224 C -63.511988,503.88036 -93.827278,519.83775 -149.99905,525.76099 C -150.05126,525.76406 -150.10309,525.75794 -150.1553,525.76099 C -221.55448,529.92878 -288.98423,511.90105 -326.56155,485.29224 C -345.36395,471.97811 -356.2831,456.89754 -358.18655,442.22974 C -360.09,427.56194 -355.6764,413.50875 -335.45171,396.52001 L -344.29789,384.52636 z" />
+      <path
+         style="fill:url(#linearGradient3274);fill-rule:evenodd;stroke-linecap:butt;stroke-linejoin:miter"
+         sodipodi:nodetypes="cccccccccccccccccccccccccc"
+         id="path1715"
+         d="M -325.27318,296.09912 C -347.96702,315.16194 -357.50354,338.47697 -354.8469,358.94871 C -352.19026,379.42045 -337.90038,397.49496 -317.00315,412.29246 C -275.20868,441.88746 -205.37519,459.89155 -130.9094,455.51121 L -130.7219,455.51121 L -130.56565,455.47996 C -71.947479,449.35568 -37.974562,432.69377 -19.721901,413.72996 C -1.46924,394.76615 0.92383398,373.59609 -6.315651,360.32371 L -6.534401,359.91746 L -6.784401,359.51121 C -24.86413,334.40047 -62.205048,326.85868 -99.003151,324.01121 C -135.80125,321.16374 -173.23832,323.79246 -191.44065,323.79246 C -210.55208,323.79246 -235.86781,325.26561 -262.18231,331.28673 C -288.49681,337.30785 -314.55327,353.08924 -334.92916,372.03101 C -332.45364,376.87868 -330.24815,379.75175 -327.23259,382.87164 C -314.64764,370.13465 -285.77001,350.8281 -261.44065,345.26121 C -237.11129,339.69432 -210.09753,338.79246 -191.44065,338.79246 C -171.87468,338.79246 -135.46441,336.24802 -100.1594,338.97996 C -65.118673,341.69145 -32.341018,350.37714 -19.315651,367.91746 C -16.415945,373.77852 -16.038723,388.26326 -30.534401,403.32371 C -45.29734,418.66183 -75.61263,434.61922 -131.7844,440.54246 C -131.83661,440.54553 -131.88844,440.53941 -131.94065,440.54246 C -203.33983,444.71025 -270.76958,426.68252 -308.3469,400.07371 C -327.1493,386.75958 -338.06845,371.67901 -339.9719,357.01121 C -341.87535,342.34341 -337.46175,324.58786 -317.23706,307.59912 L -325.27318,296.09912 z" />
+      <path
+         style="fill:url(#linearGradient3276);fill-rule:evenodd;stroke-linecap:butt;stroke-linejoin:miter"
+         sodipodi:nodetypes="cccccccccccccccccccccccccc"
+         id="path1700"
+         d="M -305.25,212.28125 C -327.94384,231.34407 -337.75039,252.68451 -335.09375,273.15625 C -332.43711,293.62799 -318.14723,311.7025 -297.25,326.5 C -255.45553,356.095 -185.62204,374.09909 -111.15625,369.71875 L -110.96875,369.71875 L -110.8125,369.6875 C -52.194328,363.56322 -18.221411,346.90131 0.03125,327.9375 C 18.283911,308.97369 20.676985,287.80363 13.4375,274.53125 L 13.21875,274.125 L 12.96875,273.71875 C -5.1109788,248.60801 -42.451897,241.06622 -79.25,238.21875 C -116.0481,235.37128 -153.48517,238 -171.6875,238 C -190.79893,238 -216.11466,239.47315 -242.42916,245.49427 C -268.74366,251.51539 -294.6907,267.61701 -315.06659,286.55878 C -312.80756,290.3124 -310.00849,294.8065 -307.47944,297.07918 C -294.89449,284.34219 -266.01686,265.03564 -241.6875,259.46875 C -217.35814,253.90186 -190.34438,253 -171.6875,253 C -152.12153,253 -115.71126,250.45556 -80.40625,253.1875 C -45.365522,255.89899 -12.587867,264.58468 0.4375,282.125 C 3.3372059,287.98606 3.7144279,302.4708 -10.78125,317.53125 C -25.544189,332.86937 -55.859479,348.82676 -112.03125,354.75 C -112.08346,354.75307 -112.13529,354.74695 -112.1875,354.75 C -183.58668,358.91779 -251.01643,340.89006 -288.59375,314.28125 C -307.39615,300.96712 -318.3153,285.88655 -320.21875,271.21875 C -322.1222,256.55095 -315.81844,240.76999 -295.59375,223.78125 L -305.25,212.28125 z" />
+      <path
+         style="fill:url(#linearGradient3278);fill-rule:evenodd;stroke-linecap:butt;stroke-linejoin:miter"
+         sodipodi:nodetypes="ccccccccccccccccc"
+         id="path1699"
+         d="M -300.28082,137.71789 C -306.42374,140.23899 -327.58051,125.12766 -320.71363,134.66717 C -358.36143,178.99769 -289.9203,243.51471 -243.03289,273.02257 C -205.28789,294.51671 -159.94007,295.3631 -117.81523,291.13127 C -82.523115,287.20883 -46.878496,279.77251 -15.177919,263.26506 C -0.13785372,254.06781 14.385084,238.47695 13.494128,219.72901 C 10.804388,200.01218 -8.4540789,188.95418 -24.839939,181.36255 C -75.518968,157.92773 -133.65492,159.9668 -187.84185,169.03649 C -222.44994,175.16972 -261.9908,186.56546 -292.68174,203.78959 C -292.07216,204.48978 -284.0582,215.48397 -283.81507,215.48637 C -225.45624,186.27215 -144.40489,170.71748 -80.007852,180.06044 C -53.414772,184.53549 -26.505092,193.63782 -5.9643361,211.62282 C 3.6638018,222.05572 -4.4163624,235.94234 -13.548946,243.37168 C -30.354075,257.60292 -52.608719,262.67198 -73.36892,268.28299 C -119.22395,279.17231 -168.26669,282.82669 -214.02896,269.61422 C -248.97502,258.11344 -274.88312,229.5596 -295.13976,200.04627 C -309.10291,179.03453 -325.47177,168.30723 -300.28082,137.71789 z" />
+    </g>
+    <path
+       style="fill:url(#linearGradient3247);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:2.5;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1"
+       sodipodi:nodetypes="ccccc"
+       id="path1062"
+       d="M 78.134146,93.262963 L 94.81134,78.896799 L 94.81134,109.92771 L 77.937943,127.16711 L 78.134146,93.262963 z" />
+    <path
+       style="fill:#7c4900;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:2.5;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1"
+       sodipodi:nodetypes="ccccc"
+       id="path1233"
+       d="M 32.605379,93.658593 L 22.402862,108.02476 L 84.370739,108.64348 L 78.680857,93.671148 L 32.605379,93.658593 z" />
+    <path
+       style="fill:url(#linearGradient3243);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:2.5;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1"
+       sodipodi:nodetypes="ccccc"
+       id="path1687"
+       d="M 32.615202,93.693948 L 22.412678,108.06011 L 83.627811,108.20377 L 77.937943,93.262963 L 32.615202,93.693948 z" />
+    <path
+       style="fill:#7c4900;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:2.5;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1"
+       sodipodi:nodetypes="ccccc"
+       id="path1860"
+       d="M 78.698128,94.645235 L 94.81263,78.894641 L 107.17338,84.353784 L 88.141758,107.25261 L 78.698128,94.645235 z" />
+    <path
+       style="fill:url(#linearGradient3239);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:2.5;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1"
+       id="path1688"
+       d="M 78.134146,93.406625 L 94.81134,79.040462 L 107.1721,84.499604 L 88.140466,106.47983 L 78.134146,93.406625 z" />
+    <path
+       style="fill:#000000;fill-opacity:1;stroke:none;stroke-width:2.5;stroke-miterlimit:4;stroke-opacity:1"
+       sodipodi:nodetypes="ccccccccccc"
+       id="path2498"
+       d="M 66.007532,47.308356 C 60.814963,47.148956 55.502569,46.943324 50.494646,48.035956 C 49.213124,48.319317 47.77369,48.896616 47.894449,50.174314 C 47.983969,51.011421 47.717585,51.760173 48.614842,52.346195 C 50.064829,53.491009 52.116118,54.258994 53.968172,54.802486 C 60.826763,56.664638 68.037286,57.225678 75.165835,57.618565 C 79.818034,57.795082 84.386438,57.89984 88.909143,57.089509 C 90.227345,56.847007 91.652178,56.685202 92.315423,55.68772 C 92.561192,54.929904 92.727401,53.965355 92.466812,53.21917 C 91.400824,51.705926 89.192073,51.167168 87.336471,50.53835 C 80.460679,48.536768 73.188088,47.799486 66.007532,47.308356 z" />
+    <g
+       transform="matrix(0.1191417,1.0538513e-2,-8.4807094e-3,9.5877505e-2,25.081854,12.429262)"
+       id="g2494">
+      <path
+         transform="translate(3.944035,0)"
+         style="fill:url(#radialGradient3268);fill-opacity:1;stroke:none;stroke-width:2.5;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccccc"
+         id="path1697"
+         d="M 401.71875,327.03125 C 299.96028,327.03125 217.375,345.09952 217.375,367.375 C 215.38308,372.02307 218.71875,378.95563 218.71875,380.9375 C 218.71875,403.21299 301.30403,421.3125 403.0625,421.3125 C 504.82097,421.3125 587.40623,403.213 587.40625,380.9375 C 587.40625,378.28646 586.0625,369.35472 586.0625,367.375 C 586.0625,345.09951 503.47723,327.03124 401.71875,327.03125 z" />
+      <path
+         transform="matrix(1.068466,0,0,1.068466,-99.06136,123.3834)"
+         style="fill:url(#linearGradient3270);fill-opacity:1;stroke:none;stroke-width:2.5;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:type="arc"
+         sodipodi:ry="37.768299"
+         sodipodi:rx="172.53246"
+         sodipodi:cy="228.32654"
+         sodipodi:cx="471.24539"
+         id="path1759"
+         d="M 643.77785,228.32654 A 172.53246,37.768299 0 1 1 298.71294,228.32654 A 172.53246,37.768299 0 1 1 643.77785,228.32654 z" />
+    </g>
+    <g
+       id="g4794"
+       transform="matrix(8.4697513e-2,6.8061235e-3,-7.0210596e-3,8.2104663e-2,50.258674,-12.464529)">
+      <path
+         d="M 358.48429,484.82963 C 354.07757,492.4623 320.2476,478.22535 312.19612,481.8101 C 304.14463,485.39486 292.08808,520.0618 283.46723,518.22938 C 274.84638,516.39696 277.93249,479.82329 272.03514,473.27362 C 266.13779,466.72396 229.44189,465.97017 228.52064,457.205 C 227.59938,448.43984 263.33667,440.07302 267.74339,432.44035 C 272.15011,424.80768 261.52735,389.67487 269.57883,386.09012 C 277.63032,382.50537 296.63107,413.90806 305.25192,415.74047 C 313.87277,417.57289 344.00344,396.61341 349.90079,403.16308 C 355.79814,409.71274 331.80396,437.4875 332.72522,446.25266 C 333.64647,455.01783 362.89101,477.19696 358.48429,484.82963 z"
+         id="path3551"
+         inkscape:flatsided="false"
+         inkscape:randomized="0"
+         inkscape:rounded="0.19"
+         sodipodi:arg1="0.52359878"
+         sodipodi:arg2="1.1519173"
+         sodipodi:cx="297.99036"
+         sodipodi:cy="449.90344"
+         sodipodi:r1="69.852379"
+         sodipodi:r2="34.926189"
+         sodipodi:sides="5"
+         sodipodi:type="star"
+         style="fill:#646464;fill-opacity:0.21509435;fill-rule:evenodd;stroke:#54514f;stroke-width:1.25922263;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dashoffset:0;stroke-opacity:0.2"
+         transform="matrix(3.596614,2.121748,-2.060458,3.646575,215.6212,-1858.236)" />
+      <path
+         d="M 358.48429,484.82963 C 354.07757,492.4623 320.2476,478.22535 312.19612,481.8101 C 304.14463,485.39486 292.08808,520.0618 283.46723,518.22938 C 274.84638,516.39696 277.93249,479.82329 272.03514,473.27362 C 266.13779,466.72396 229.44189,465.97017 228.52064,457.205 C 227.59938,448.43984 263.33667,440.07302 267.74339,432.44035 C 272.15011,424.80768 261.52735,389.67487 269.57883,386.09012 C 277.63032,382.50537 296.63107,413.90806 305.25192,415.74047 C 313.87277,417.57289 344.00344,396.61341 349.90079,403.16308 C 355.79814,409.71274 331.80396,437.4875 332.72522,446.25266 C 333.64647,455.01783 362.89101,477.19696 358.48429,484.82963 z"
+         id="path2589"
+         inkscape:flatsided="false"
+         inkscape:randomized="0"
+         inkscape:rounded="0.19"
+         sodipodi:arg1="0.52359878"
+         sodipodi:arg2="1.1519173"
+         sodipodi:cx="297.99036"
+         sodipodi:cy="449.90344"
+         sodipodi:r1="69.852379"
+         sodipodi:r2="34.926189"
+         sodipodi:sides="5"
+         sodipodi:type="star"
+         style="fill:#6685d1;fill-opacity:1;fill-rule:evenodd;stroke:#000084;stroke-width:1.25922263;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dashoffset:0;stroke-opacity:1"
+         transform="matrix(3.445704,1.989378,-1.974003,3.419075,222.0565,-1719.471)" />
+      <path
+         d="M 385.02712,146.43055 C 353.83879,143.06183 318.66785,288.94669 291.5713,304.46956 C 264.47476,319.99238 129.73368,274.20349 117.07891,302.68867 C 104.42412,331.17387 225.98524,406.62781 232.60589,437.19496 C 239.22654,467.76215 163.13247,583.95511 186.49972,604.92869 C 189.2256,607.37533 163.99448,606.36113 191.76308,606.23966 C 171.64252,556.14926 245.71002,471.29856 239.60596,443.11642 C 232.9853,412.54929 115.24161,335.16 127.89641,306.67482 C 140.5512,278.18962 267.60419,325.96707 294.70073,310.44423 C 321.19749,295.26497 349.80435,166.4967 380.22189,164.28323 C 376.55324,158.54061 389.86718,146.95332 385.02712,146.43055 z M 456.1457,322.20538 C 457.17431,323.67833 458.2231,325.08891 459.33877,326.09029 C 478.09128,342.92181 565.41887,339.55362 602.65455,353.33784 C 587.67061,330.74583 493.34529,334.73726 456.1457,322.20538 z M 365.75704,548.04781 C 393.71366,569.08529 431.36764,609.64407 457.66433,623.45757 C 427.5285,601.26368 389.54305,559.99495 365.75704,548.04781 z"
+         id="path1685"
+         sodipodi:nodetypes="cccccccccccccccccc"
+         style="fill:#ffffff;fill-opacity:0.69433965;fill-rule:evenodd;stroke:none;stroke-width:0.53918904;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dashoffset:0;stroke-opacity:1" />
+    </g>
+    <path
+       style="opacity:1;fill:#7d94b7;fill-opacity:1;stroke:#000818;stroke-width:0;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:0"
+       id="path2596"
+       d="M 43.389453,33.099645 C 43.128442,33.372909 42.852517,33.632669 42.60642,33.919439 C 41.830456,34.823646 40.797962,36.217192 40.14421,37.156224 C 39.085179,38.677389 38.207255,40.039935 37.314837,41.669234 C 36.887627,42.449196 36.510926,43.255779 36.108971,44.049052 C 35.785852,44.812555 35.462732,45.576057 35.139612,46.339559 L 32.243177,47.671416 C 32.574925,46.896471 32.906672,46.121526 33.23842,45.346581 C 33.640029,44.546561 34.019156,43.734854 34.443246,42.94652 C 35.876842,40.281636 37.553155,37.70128 39.37182,35.281747 C 39.574491,35.012116 39.798914,34.759543 40.012461,34.498441 L 43.389453,33.099645 z" />
+    <path
+       style="opacity:1;fill:#7d94b7;fill-opacity:1;stroke:#000818;stroke-width:0;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:0"
+       id="path2600"
+       d="M 107.0882,38.673275 C 105.48368,42.271932 103.9602,45.906131 102.43522,49.539119 C 101.39618,52.003624 100.55907,54.542293 99.735884,57.084182 L 96.664769,57.902121 C 97.516518,55.354709 98.380436,52.810658 99.399083,50.323537 C 100.84726,46.776519 102.30252,43.228586 103.54652,39.603746 L 107.0882,38.673275 z" />
+    <path
+       style="opacity:1;fill:#7d94b7;fill-opacity:1;stroke:#000818;stroke-width:0;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:0"
+       id="path2608"
+       d="M 49.826021,46.187527 C 48.307794,48.244894 46.871275,50.360294 45.40237,52.4528 C 43.606268,55.050443 42.008492,57.786129 40.679818,60.651256 C 40.545354,60.956772 40.410889,61.262288 40.276425,61.567804 L 37.073361,63.030809 C 37.221116,62.717444 37.36887,62.404079 37.516625,62.090713 C 38.906357,59.207437 40.531226,56.437935 42.329134,53.790255 C 43.722481,51.767413 45.101391,49.734239 46.434745,47.671324 L 49.826021,46.187527 z" />
+    <path
+       style="opacity:1;fill:#7d94b7;fill-opacity:1;stroke:#000818;stroke-width:0;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:0"
+       id="path2618"
+       d="M 94.598104,64.915804 C 93.682476,66.926598 92.63229,68.87059 91.608999,70.827845 C 91.042406,72.067481 90.339848,73.241701 89.807428,74.497595 C 89.500909,75.220624 89.280283,75.975514 89.080121,76.733016 L 85.825843,78.283622 C 86.433451,76.112618 87.48387,74.232432 88.496837,72.230246 C 89.472515,70.336038 90.523199,68.462536 91.222471,66.443047 L 94.598104,64.915804 z" />
+  </g>
+</svg>
Binary files 3.4.1-6/Animated-icons/data/misc/ray.ini.png and 3.4.1+git20201022.a0d3415c-1/Animated-icons/data/misc/ray.ini.png differ
Binary files 3.4.1-6/Animated-icons/data/misc/spot-front2.png and 3.4.1+git20201022.a0d3415c-1/Animated-icons/data/misc/spot-front2.png differ
Binary files 3.4.1-6/Animated-icons/data/misc/spot.png.ini and 3.4.1+git20201022.a0d3415c-1/Animated-icons/data/misc/spot.png.ini differ
diff -pruN 3.4.1-6/Animated-icons/data/misc/star_sergio_luiz_araujo__01.svg 3.4.1+git20201022.a0d3415c-1/Animated-icons/data/misc/star_sergio_luiz_araujo__01.svg
--- 3.4.1-6/Animated-icons/data/misc/star_sergio_luiz_araujo__01.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Animated-icons/data/misc/star_sergio_luiz_araujo__01.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,52 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 20010904//EN"
+"http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd">
+<!-- Created with Inkscape (http://www.inkscape.org/) --><svg height="297mm" id="svg1" inkscape:version="0.40" sodipodi:docbase="/home/kurumin/smb4k/DETSRV001/Sergio/inkscape" sodipodi:docname="start.svg" sodipodi:version="0.32" width="210mm" xmlns="http://www.w3.org/2000/svg" xmlns:cc="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:xlink="http://www.w3.org/1999/xlink">
+  <metadata>
+    <rdf:RDF xmlns:cc="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
+      <cc:Work rdf:about="">
+        <dc:title>star</dc:title>
+        <dc:description>esta estrela é muito alegre</dc:description>
+        <dc:subject>
+          <rdf:Bag>
+            <rdf:li>icon</rdf:li>
+          </rdf:Bag>
+        </dc:subject>
+        <dc:publisher>
+          <cc:Agent rdf:about="http://www.openclipart.org">
+            <dc:title>Sérgio Luiz Araújo Silva</dc:title>
+          </cc:Agent>
+        </dc:publisher>
+        <dc:creator>
+          <cc:Agent>
+            <dc:title>Sérgio Luiz Araújo Silva</dc:title>
+          </cc:Agent>
+        </dc:creator>
+        <dc:rights>
+          <cc:Agent>
+            <dc:title>Sérgio Luiz Araújo Silva</dc:title>
+          </cc:Agent>
+        </dc:rights>
+        <dc:date></dc:date>
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
+        <cc:license rdf:resource="http://web.resource.org/cc/PublicDomain"/>
+        <dc:language>en</dc:language>
+      </cc:Work>
+      <cc:License rdf:about="http://web.resource.org/cc/PublicDomain">
+        <cc:permits rdf:resource="http://web.resource.org/cc/Reproduction"/>
+        <cc:permits rdf:resource="http://web.resource.org/cc/Distribution"/>
+        <cc:permits rdf:resource="http://web.resource.org/cc/DerivativeWorks"/>
+      </cc:License>
+    </rdf:RDF>
+  </metadata>
+  <defs id="defs3"/>
+  <sodipodi:namedview bordercolor="#666666" borderopacity="1.0" id="base" inkscape:current-layer="layer1" inkscape:cx="295.60615" inkscape:cy="509.77809" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:window-height="693" inkscape:window-width="1016" inkscape:window-x="0" inkscape:window-y="0" inkscape:zoom="0.61664800" pagecolor="#ffffff"/>
+  <g id="layer1" inkscape:groupmode="layer" inkscape:label="Layer 1">
+    <g id="g4794">
+      <path d="M 358.48429,484.82963 C 354.07757,492.46230 320.24760,478.22535 312.19612,481.81010 C 304.14463,485.39486 292.08808,520.06180 283.46723,518.22938 C 274.84638,516.39696 277.93249,479.82329 272.03514,473.27362 C 266.13779,466.72396 229.44189,465.97017 228.52064,457.20500 C 227.59938,448.43984 263.33667,440.07302 267.74339,432.44035 C 272.15011,424.80768 261.52735,389.67487 269.57883,386.09012 C 277.63032,382.50537 296.63107,413.90806 305.25192,415.74047 C 313.87277,417.57289 344.00344,396.61341 349.90079,403.16308 C 355.79814,409.71274 331.80396,437.48750 332.72522,446.25266 C 333.64647,455.01783 362.89101,477.19696 358.48429,484.82963 z " id="path3551" inkscape:flatsided="false" inkscape:randomized="0.0000000" inkscape:rounded="0.19000000" sodipodi:arg1="0.52359878" sodipodi:arg2="1.1519173" sodipodi:cx="297.99036" sodipodi:cy="449.90344" sodipodi:r1="69.852379" sodipodi:r2="34.926189" sodipodi:sides="5" sodipodi:type="star" style="fill:#646464;fill-opacity:0.21509434;fill-rule:evenodd;stroke:#54514f;stroke-width:1.2592226;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4.0000000;stroke-dashoffset:0.0000000;stroke-opacity:0.20000000" transform="matrix(3.596614,2.121748,-2.060458,3.646575,215.6212,-1858.236)"/>
+      <path d="M 358.48429,484.82963 C 354.07757,492.46230 320.24760,478.22535 312.19612,481.81010 C 304.14463,485.39486 292.08808,520.06180 283.46723,518.22938 C 274.84638,516.39696 277.93249,479.82329 272.03514,473.27362 C 266.13779,466.72396 229.44189,465.97017 228.52064,457.20500 C 227.59938,448.43984 263.33667,440.07302 267.74339,432.44035 C 272.15011,424.80768 261.52735,389.67487 269.57883,386.09012 C 277.63032,382.50537 296.63107,413.90806 305.25192,415.74047 C 313.87277,417.57289 344.00344,396.61341 349.90079,403.16308 C 355.79814,409.71274 331.80396,437.48750 332.72522,446.25266 C 333.64647,455.01783 362.89101,477.19696 358.48429,484.82963 z " id="path1061" inkscape:flatsided="false" inkscape:randomized="0.0000000" inkscape:rounded="0.19000000" sodipodi:arg1="0.52359878" sodipodi:arg2="1.1519173" sodipodi:cx="297.99036" sodipodi:cy="449.90344" sodipodi:r1="69.852379" sodipodi:r2="34.926189" sodipodi:sides="5" sodipodi:type="star" style="fill:#6685d1;fill-opacity:1.0000000;fill-rule:evenodd;stroke:#000084;stroke-width:1.2592226;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4.0000000;stroke-dashoffset:0.0000000;stroke-opacity:1.0000000" transform="matrix(3.445704,1.989378,-1.974003,3.419075,222.0565,-1719.471)"/>
+      <path d="M 385.02712,146.43055 C 353.83879,143.06183 318.66785,288.94669 291.57130,304.46956 C 264.47476,319.99238 129.73368,274.20349 117.07891,302.68867 C 104.42412,331.17387 225.98524,406.62781 232.60589,437.19496 C 239.22654,467.76215 163.13247,583.95511 186.49972,604.92869 C 189.22560,607.37533 163.99448,606.36113 191.76308,606.23966 C 171.64252,556.14926 245.71002,471.29856 239.60596,443.11642 C 232.98530,412.54929 115.24161,335.16000 127.89641,306.67482 C 140.55120,278.18962 267.60419,325.96707 294.70073,310.44423 C 321.19749,295.26497 349.80435,166.49670 380.22189,164.28323 C 376.55324,158.54061 389.86718,146.95332 385.02712,146.43055 z M 456.14570,322.20538 C 457.17431,323.67833 458.22310,325.08891 459.33877,326.09029 C 478.09128,342.92181 565.41887,339.55362 602.65455,353.33784 C 587.67061,330.74583 493.34529,334.73726 456.14570,322.20538 z M 365.75704,548.04781 C 393.71366,569.08529 431.36764,609.64407 457.66433,623.45757 C 427.52850,601.26368 389.54305,559.99495 365.75704,548.04781 z " id="path1685" sodipodi:nodetypes="cccccccccccccccccc" style="fill:#ffffff;fill-opacity:0.69433963;fill-rule:evenodd;stroke:none;stroke-width:0.53918904;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4.0000000;stroke-dashoffset:0.0000000;stroke-opacity:1.0000000"/>
+    </g>
+  </g>
+</svg>
diff -pruN 3.4.1-6/Animated-icons/data/misc/stock-star.svg 3.4.1+git20201022.a0d3415c-1/Animated-icons/data/misc/stock-star.svg
--- 3.4.1-6/Animated-icons/data/misc/stock-star.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Animated-icons/data/misc/stock-star.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,97 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 1.0//EN"
+"http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd">
+<!-- Created with Inkscape (http://www.inkscape.org/) --><svg height="24.000000pt" id="svg3261" inkscape:version="0.39cvs" sodipodi:docbase="/home/andy/Desktop" sodipodi:docname="stock-star.svg" sodipodi:version="0.32" width="24.000000pt" xmlns="http://www.w3.org/2000/svg" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:xlink="http://www.w3.org/1999/xlink">
+  <metadata>
+    <rdf:RDF xmlns:cc="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
+      <cc:Work rdf:about="">
+        <dc:title>Etiquette Icons</dc:title>
+        <dc:description></dc:description>
+        <dc:subject>
+          <rdf:Bag>
+            <rdf:li>hash</rdf:li>
+            <rdf:li></rdf:li>
+            <rdf:li>action</rdf:li>
+            <rdf:li>computer</rdf:li>
+            <rdf:li>icons</rdf:li>
+          </rdf:Bag>
+        </dc:subject>
+        <dc:publisher>
+          <cc:Agent rdf:about="http://www.openclipart.org">
+            <dc:title>Andy Fitzsimon</dc:title>
+          </cc:Agent>
+        </dc:publisher>
+        <dc:creator>
+          <cc:Agent>
+            <dc:title>Andy Fitzsimon</dc:title>
+          </cc:Agent>
+        </dc:creator>
+        <dc:rights>
+          <cc:Agent>
+            <dc:title>Andy Fitzsimon</dc:title>
+          </cc:Agent>
+        </dc:rights>
+        <dc:date></dc:date>
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
+        <cc:license rdf:resource="http://web.resource.org/cc/PublicDomain"/>
+        <dc:language>en</dc:language>
+      </cc:Work>
+      <cc:License rdf:about="http://web.resource.org/cc/PublicDomain">
+        <cc:permits rdf:resource="http://web.resource.org/cc/Reproduction"/>
+        <cc:permits rdf:resource="http://web.resource.org/cc/Distribution"/>
+        <cc:permits rdf:resource="http://web.resource.org/cc/DerivativeWorks"/>
+      </cc:License>
+    </rdf:RDF>
+  </metadata>
+  <defs id="defs3263">
+    <linearGradient id="linearGradient4114">
+      <stop id="stop4115" offset="0.0000000" style="stop-color:#e6da1e;stop-opacity:1.0000000;"/>
+      <stop id="stop4116" offset="1.0000000" style="stop-color:#fff99b;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient4111">
+      <stop id="stop4112" offset="0.0000000" style="stop-color:#e6da1e;stop-opacity:1.0000000;"/>
+      <stop id="stop4113" offset="1.0000000" style="stop-color:#7d760f;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient3699">
+      <stop id="stop3700" offset="0.0000000" style="stop-color:#e6da1e;stop-opacity:1.0000000;"/>
+      <stop id="stop3701" offset="1.0000000" style="stop-color:#b5ab17;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2222" x1="0.28441054" x2="0.32513002" xlink:href="#linearGradient4114" y1="0.88272494" y2="0.10505857"/>
+    <linearGradient id="linearGradient2313" x1="-0.0078431377" x2="0.59607846" xlink:href="#linearGradient1513" y1="-1.2448980" y2="0.36054420"/>
+    <linearGradient id="linearGradient2314" x1="-0.45098040" x2="0.47058824" xlink:href="#linearGradient1513" y1="-0.15053764" y2="0.36559141"/>
+    <linearGradient id="linearGradient1516" x1="0.45882353" x2="0.69019610" xlink:href="#linearGradient2122" y1="1.2772278" y2="-0.29702970"/>
+    <linearGradient id="linearGradient2223" x1="-0.18232045" x2="0.68508285" xlink:href="#linearGradient1513" y1="-0.43962848" y2="0.42414862"/>
+    <linearGradient id="linearGradient2122">
+      <stop id="stop2123" offset="0.0000000" style="stop-color:#000000;stop-opacity:0.40784314;"/>
+      <stop id="stop2124" offset="1.0000000" style="stop-color:#000000;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2138" x1="1.3783784" x2="0.58378381" xlink:href="#linearGradient2122" y1="0.25386998" y2="0.13003096"/>
+    <linearGradient id="linearGradient2224" x1="-0.14213198" x2="0.49753696" xlink:href="#linearGradient1513" y1="-0.28792569" y2="0.35603714"/>
+    <linearGradient id="linearGradient1512" x1="0.99512196" x2="0.32682925" xlink:href="#linearGradient1918" y1="0.64396286" y2="0.30030960"/>
+    <linearGradient id="linearGradient2315" x1="0.27843139" x2="0.45098040" xlink:href="#linearGradient1513" y1="-0.063694268" y2="0.61146498"/>
+    <linearGradient id="linearGradient2317">
+      <stop id="stop2318" offset="0.0000000" style="stop-color:#d6d6d6;stop-opacity:1.0000000;"/>
+      <stop id="stop2322" offset="0.25769231" style="stop-color:#eaeaea;stop-opacity:1.0000000;"/>
+      <stop id="stop2320" offset="0.70594490" style="stop-color:#919191;stop-opacity:1.0000000;"/>
+      <stop id="stop2321" offset="0.73347497" style="stop-color:#d2d2d2;stop-opacity:1.0000000;"/>
+      <stop id="stop2319" offset="1.0000000" style="stop-color:#a6a6a6;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2316" x1="0.47450981" x2="0.80392158" xlink:href="#linearGradient2317" y1="0.21771218" y2="0.52029520"/>
+    <linearGradient id="linearGradient1513">
+      <stop id="stop1514" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop1515" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2121" x1="0.41568628" x2="0.59607846" xlink:href="#linearGradient1513" y1="0.27687296" y2="0.44299674"/>
+    <radialGradient cx="0.50000000" cy="0.50000000" fx="0.38431373" fy="0.47619048" id="radialGradient2541" r="0.50000000" xlink:href="#linearGradient1918"/>
+    <linearGradient id="linearGradient1918">
+      <stop id="stop1919" offset="0.0000000" style="stop-color:#000000;stop-opacity:0.31372550;"/>
+      <stop id="stop1921" offset="1.0000000" style="stop-color:#000000;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <radialGradient cx="0.50000000" cy="0.50000000" fx="0.50588238" fy="0.50000000" id="radialGradient1502" r="0.50000000" xlink:href="#linearGradient1918"/>
+    <linearGradient id="linearGradient2312" x1="0.54355544" x2="0.36095273" xlink:href="#linearGradient4111" y1="1.1365328" y2="0.042242367"/>
+  </defs>
+  <sodipodi:namedview bordercolor="#666666" borderopacity="1.0" id="base" inkscape:cx="33.431976" inkscape:cy="6.2199249" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:window-height="471" inkscape:window-width="581" inkscape:window-x="47" inkscape:window-y="265" inkscape:zoom="4.0000000" pagecolor="#ffffff" showborder="true"/>
+  <path d="M 54.438721 37.865574 A 12.562782 12.562782 0 1 0 29.313156,37.865574 A 12.562782 12.562782 0 1 0 54.438721 37.865574 z" id="path1934" sodipodi:cx="41.875938" sodipodi:cy="37.865574" sodipodi:rx="12.562782" sodipodi:ry="12.562782" sodipodi:type="arc" style="fill:url(#radialGradient1502);fill-opacity:1;fill-rule:evenodd;stroke-width:1.0000000pt;" transform="matrix(1.100904,0.000000,0.000000,0.238691,-31.17923,17.75284)"/>
+  <polygon id="polygon3715" inkscape:flatsided="false" points="22.539029,24.475728 15.616353,20.128613 8.2912488,23.756794 10.286377,15.829606 4.5721892,9.9841873 12.727922,9.4320308 16.521464,2.1911819 19.566856,9.7771189 27.625582,11.147447 21.352005,16.387970 22.539029,24.475728 " sodipodi:arg1="0.99289439" sodipodi:arg2="1.6212129" sodipodi:cx="15.909903" sodipodi:cy="14.311068" sodipodi:r1="12.135305" sodipodi:r2="5.8249464" sodipodi:sides="5" sodipodi:type="star" style="fill:url(#linearGradient2222);fill-rule:evenodd;stroke:url(#linearGradient2312);stroke-width:1.0000000pt;" transform="matrix(1.034641,-5.594482e-2,5.594482e-2,1.034641,-2.108377,0.113075)"/>
+</svg>
Binary files 3.4.1-6/Animated-icons/data/misc/texture-chrome2.bmp and 3.4.1+git20201022.a0d3415c-1/Animated-icons/data/misc/texture-chrome2.bmp differ
diff -pruN 3.4.1-6/clock/data/misc/clock.svg 3.4.1+git20201022.a0d3415c-1/clock/data/misc/clock.svg
--- 3.4.1-6/clock/data/misc/clock.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/clock/data/misc/clock.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,233 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   version="1.0"
+   width="48"
+   height="48"
+   id="svg5555">
+  <defs
+     id="defs5557">
+    <linearGradient
+       id="linearGradient3227">
+      <stop
+         id="stop3229"
+         style="stop-color:#4d4d4d;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3231"
+         style="stop-color:#333333;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient8838">
+      <stop
+         id="stop8840"
+         style="stop-color:#000000;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop8842"
+         style="stop-color:#000000;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3334-995-903-143-677-209-356-728">
+      <stop
+         id="stop5026"
+         style="stop-color:#808080;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop5028"
+         style="stop-color:#6d6d6d;stop-opacity:1"
+         offset="0.87326682" />
+      <stop
+         id="stop5030"
+         style="stop-color:#4f5053;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient2480">
+      <stop
+         id="stop2482"
+         style="stop-color:#3d3e40;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2484"
+         style="stop-color:#4e4e4e;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3268">
+      <stop
+         id="stop3270"
+         style="stop-color:#ffffff;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3272"
+         style="stop-color:#d8d8d8;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3996">
+      <stop
+         id="stop3998"
+         style="stop-color:#ffffff;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4000"
+         style="stop-color:#ffffff;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3708">
+      <stop
+         id="stop3710"
+         style="stop-color:#000000;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3712"
+         style="stop-color:#000000;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3301">
+      <stop
+         id="stop3303"
+         style="stop-color:#ffffff;stop-opacity:0"
+         offset="0" />
+      <stop
+         id="stop3309"
+         style="stop-color:#ffffff;stop-opacity:0"
+         offset="0.69999999" />
+      <stop
+         id="stop3305"
+         style="stop-color:#000000;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="24"
+       cy="24"
+       r="17"
+       fx="24"
+       fy="24"
+       id="radialGradient3199"
+       xlink:href="#linearGradient3301"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="29.050154"
+       y1="7.0280032"
+       x2="29.050154"
+       y2="26.493914"
+       id="linearGradient3201"
+       xlink:href="#linearGradient3708"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1,0,0,-1,1e-6,47.999998)" />
+    <linearGradient
+       x1="24.397675"
+       y1="3.6018722"
+       x2="24.397675"
+       y2="26.091318"
+       id="linearGradient3212"
+       xlink:href="#linearGradient3996"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-0.3976755,0.3981273)" />
+    <radialGradient
+       cx="27.411848"
+       cy="12.080106"
+       r="18.000002"
+       fx="27.411848"
+       fy="12.080106"
+       id="radialGradient3215"
+       xlink:href="#linearGradient3268"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.7637903e-8,1.7731075,-2.6591116,2.6451386e-8,59.480381,-17.99927)" />
+    <linearGradient
+       x1="29.050154"
+       y1="7.0280032"
+       x2="29.050154"
+       y2="40.320171"
+       id="linearGradient3217"
+       xlink:href="#linearGradient2480"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.0606061,0,0,1.060606,-1.4545467,-1.4545435)" />
+    <radialGradient
+       cx="24.011986"
+       cy="24.003313"
+       r="21"
+       fx="24.011986"
+       fy="24.003313"
+       id="radialGradient3220"
+       xlink:href="#linearGradient3334-995-903-143-677-209-356-728"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9532054,0,0,0.9532054,1.1236313,1.1232247)" />
+    <linearGradient
+       x1="7.5542169"
+       y1="2.9999976"
+       x2="7.5542169"
+       y2="45.184376"
+       id="linearGradient3222"
+       xlink:href="#linearGradient3227"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       cx="62.625"
+       cy="4.625"
+       r="10.625"
+       fx="62.625"
+       fy="4.625"
+       id="radialGradient3225"
+       xlink:href="#linearGradient8838"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(2.1647059,0,0,0.7529402,-111.56471,36.517647)" />
+  </defs>
+  <path
+     d="m 46.999997,40 c 0,4.418278 -10.297452,8 -23,8 -12.702548,0 -23.0000002,-3.581722 -23.0000002,-8 0,-4.418278 10.2974522,-8 23.0000002,-8 12.702548,0 23,3.581722 23,8 l 0,0 z"
+     id="path8836"
+     style="opacity:0.3;fill:url(#radialGradient3225);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:0.99999988;marker:none;visibility:visible;display:inline;overflow:visible" />
+  <path
+     d="M 44.5,23.999273 C 44.5,35.321475 35.32116,44.5 24.000257,44.5 12.678317,44.5 3.5,35.321371 3.5,23.999273 3.5,12.67759 12.678317,3.499998 24.000257,3.499998 35.32116,3.499998 44.5,12.67759 44.5,23.999273 l 0,0 z"
+     id="path6495"
+     style="fill:url(#radialGradient3220);fill-opacity:1;fill-rule:nonzero;stroke:url(#linearGradient3222);stroke-width:1;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+  <path
+     d="m 41.500001,23.999379 c 0,9.665293 -7.835596,17.500619 -17.49978,17.500619 -9.665072,0 -17.5002223,-7.835415 -17.5002223,-17.500619 0,-9.664851 7.8351503,-17.4993792 17.5002223,-17.4993792 9.664184,0 17.49978,7.8345282 17.49978,17.4993792 l 0,0 0,0 0,0 z"
+     id="path3215"
+     style="fill:url(#radialGradient3215);fill-opacity:1;fill-rule:nonzero;stroke:url(#linearGradient3217);stroke-width:0.99999994;stroke-miterlimit:4;stroke-dasharray:none" />
+  <path
+     d="m 43.5,23.999308 c 0,10.769898 -8.731091,19.50069 -19.499755,19.50069 -10.769651,0 -19.5002455,-8.730891 -19.5002455,-19.50069 0,-10.769404 8.7305945,-19.4993084 19.5002455,-19.4993084 C 34.768909,4.4999996 43.5,13.229904 43.5,23.999308 l 0,0 z"
+     id="path3222"
+     style="opacity:0.4;fill:none;stroke:url(#linearGradient3212);stroke-width:1;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+  <path
+     d="m 9.861727,24.537057 c 2.766321,0 3.11659,-0.07959 3.11659,-0.07959"
+     id="path2291"
+     style="opacity:0.5;fill:none;stroke:#000000;stroke-width:1;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+  <path
+     d="m 35.02168,24.537057 c 2.766323,0 3.116593,-0.07959 3.116593,-0.07959"
+     id="path2296"
+     style="opacity:0.5;fill:none;stroke:#000000;stroke-width:1;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+  <path
+     d="m 23.542531,38.03347 c 0,-2.76632 -0.07959,-3.11659 -0.07959,-3.11659"
+     id="path2306"
+     style="opacity:0.6;fill:none;stroke:#000000;stroke-width:1;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+  <path
+     d="m 23.542531,13.08316 c 0,-2.766358 -0.07959,-3.1166315 -0.07959,-3.1166315"
+     id="path2308"
+     style="opacity:0.4;fill:none;stroke:#000000;stroke-width:1;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+  <path
+     d="M 23.102743,25.536933 33.889942,14.545464"
+     id="path2312"
+     style="fill:none;stroke:#000000;stroke-width:0.89999998;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+  <path
+     d="M 24.75041,25.537057 17.462943,18.249591"
+     id="path2314"
+     style="fill:none;stroke:#000000;stroke-width:0.89999998;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+  <path
+     d="M 24.672058,24.653394 35.645373,21.563613"
+     id="path2316"
+     style="fill:#ff0000;fill-rule:evenodd;stroke:#ff0000;stroke-width:0.89999998;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+  <path
+     d="M 40.5,24.000585 C 40.5,14.887594 33.112152,7.4999999 24.000208,7.4999999 14.887427,7.4999999 7.5,14.887677 7.5,24.000585 7.5,33.113159 14.887427,40.5 24.000208,40.5 33.112152,40.5 40.5,33.113159 40.5,24.000585 l 0,0 z"
+     id="path3215-4"
+     style="opacity:0.2;fill:url(#radialGradient3199);fill-opacity:1;stroke:url(#linearGradient3201);stroke-width:0.99999988;stroke-miterlimit:4;stroke-dasharray:none" />
+</svg>
diff -pruN 3.4.1-6/clock/data/misc/dates.svg 3.4.1+git20201022.a0d3415c-1/clock/data/misc/dates.svg
--- 3.4.1-6/clock/data/misc/dates.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/clock/data/misc/dates.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,389 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   id="svg2"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   width="48"
+   height="48"
+   version="1.0"
+   sodipodi:docbase="/home/arkham/Desktop"
+   sodipodi:docname="dates.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <sodipodi:namedview
+     inkscape:window-height="627"
+     inkscape:window-width="910"
+     inkscape:pageshadow="2"
+     inkscape:pageopacity="0.0"
+     guidetolerance="10.0"
+     gridtolerance="10.0"
+     objecttolerance="10.0"
+     borderopacity="1.0"
+     bordercolor="#666666"
+     pagecolor="#ffffff"
+     id="base"
+     width="48px"
+     height="48px"
+     inkscape:zoom="3.1796875"
+     inkscape:cx="64"
+     inkscape:cy="64"
+     inkscape:window-x="413"
+     inkscape:window-y="183"
+     inkscape:current-layer="svg2" />
+  <metadata
+     id="metadata7">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <defs
+     id="defs5" />
+  <image
+     y="0"
+     x="0"
+     height="48"
+     xlink:href="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAIAAAACACAYAAADDPmHLAAAgAElEQVR4nOy9d5Qk133f+7m3Uuee
+sJM3YNPsYhcANwEEAwIFkrZJkbIog5Rk2XqSbMGyzzt+T8/HgdZ7JH0sS0+yFWzjHZG0KYmSIIqQ
+RVGEqEQKAMUgkNgFiETsLDbvTE/qCZ27qu6974+q6ukZzOzOLmZBQ8e/g8ZOV1VXuL/8/f3uLWGM
+4X/RtUkIIY0xeu3fb3Syv9s38Eaiu975zv4rLy01gZYQQpi/Adojv9s38D87CSEkwJETD/yTtCi+
+NLxr98t3vPkDD0a7xBt+/MTfACG+qSSEkCfe+o797/+Bv//yoYMH+f0/eZKn/uqpYLAv95anHn/k
+GcC8kS3BG16CbyYlvn7X2J67P//oI/zOp38j/Aff/7fMrvFbHe3kfgHucx988ME39Bi+oW/+9SLb
+ZWRkZJTFxbJ4/oXnuOfeo4h04a3794cHHn008gXf7Xu8UfpfArAJclOZ1PadO8jlMubsxBne+qaD
+vOeH3pPac+LO98Mh8ZGPfOR/CcDfREpSPa0C37FdhgaHaTYqotWomw+8/Q5Gx4bfXyj8WaFUKlnf
+7Xu9UbqpAvBGNo2wkgGYUC87jiCVSWHbrpkqlZidXuTo0UMH02ld/MQnFt+wmMBNE4A4gDLJ3zfr
+Oq8HSVcsNRpNPNdDqVC0Gw2qS4scO7Q/u/fO8WPGfFa9UYX9pjLmrne+s3909EQG3tjWwDFyplJZ
+xg98oUJltIBcJsOesUExNjZ6nzhxIvNGzQa2/Kb/JgIn2mKxWqmgAiU9z6W6vIRtS5P2PPKZ4t2F
+M06qt/edm342IYT4qBDyg0J812OHmwIF3/m27znwgR/6+w93ASe/9eZ3/PArTz3+yDNvRAi1sVxd
+aLabi6EKe13X0dVKRcxPTxvn8G4xMDiw18+I/MmTVNf77UdjoX8JxIPAByPgSAP/U4zBlmrk31Tg
+ZHLy3Hy71SjXazXaYWBU6DM7O0vD1+zdM5zvSQeDJ08+pBKtflQIK2H8x8DwkY/wKOgPggbMRwcH
+c//1rrvG/9uJE+/613v3Fr+bz3ZTLMB6wMmffenpBDh54Y1kBeJ7rb7lnnfNzi/M78vne7AtwVJl
+Wcwv19k+MGgfPXLk1j85//RJPvIROfvEEzwc//Sjo6OpXzny5rHMn//ljs8+8MDB/nzP4WImdTjj
+pEdTmdSwF6r855/+678nhPjDQ2C9BMoYo17P57spAuCmMqnebYNcuXzJnJ04wwc+9CGsgcHUNz4f
+vv/MmeKLMXDyP7UAJEHrIXA+KIQK33bf+YXy4lubzbZxLPTiwoIURjM0MCDyxdzxf3706LeG//RL
+Q/8k44735Yu3FTKZW9O79uzIeqntqUw6K10bKRwsS4CBIAyNpUK2edn3AJ8/DOrF15n5sMUCcA3g
+RFx8+pvvLxT+8OFS6Y4qkTn8rlPMaPEgCIAHgQdjRnz2s58Vn/rUp8Rssyn85cbX5hcWfiDlpC66
+OnTT6dyuULVE2vPY59k//ndvP/bjPflsznUdLGEjbYGFRAiD1hiBMaDRKroOwhhcVwwN9D3Q19f3
+fV9LpW7dvn3n8OTk5X9vjJl+vazklgpAEgN0AydKaTNVKpHfNsjRo4cOfjH9B8VPfGJx+eMf38or
+b+rersrohx9+WAA8DDz6wQ9aHzl0aKz08z8/+gPZ7IH+bP6Q1dN/ZHnXjsmdxeLwQqGn+Ie1Fs1a
+QH9vGqu3J+c5Ial0GgcQEtACIQxCCyRGCGkJoxVCCAwGGyG00gz39u06ODz2+3XXRgqB0OYS8AtE
+8dlNtwg3xQUkwEkmk6WiKqLdaJhu4GT6C791/mZJ+NUY/eCDD4rZ2dlVjP7w/v3DU//hF0Z/JOvt
+78nkDmXT6cMZ7N2pYye2Z1KpfmHZeJZEOi6WAEsI+rNFxOIVysvLjI30E7gevhYIIxAmBGOBURAz
+G8CoEAQYY8CAkYJQheQLRXY5jn7R6MBgPCvtfg+RALwuLvKmCEACnNiOsxFw8icPPvhgm9cg4Rsx
+2hhjxEeFePDwZ3n44YfFwwCPPmp9+ODBwb6zZ0fzXmZPLuUdzmUyt2WV2uOduHMs7XiDjutiSYFt
+OTh2lKhIITAILClBCKTRYCQ0GghLMD87j31oH7lMkVb1NDrlohEYHSIFYASG+AYxsfZHZJQBozG2
+yx25rHyhWnGEkHiOc4cQYsgYM/N6uIGbIgDaYrG6UKFY6F0LnIgOcHL8nQGbEIC1jAZ4FLQxxggh
+eDA23wmjz3z4w30/5x0ZnfuTX97942n39lw6d9j7nUf2PnD7HdvTrjfs2A62lDi2iyXBkhJhQNoW
+HazSmIiBCgw6uksLtJEE05e5fOQEptqgvLSEZVk4+RTN4ycQZ15COzYg0UaAiRy+EVHMK2RygVgQ
+tIWx4U3FPn5naVEYKZXjpkb6+kbuEEJ8ieiZ33gCcCPAyQaMNsYY3c1ogM/+s38mP7pjR/EX77hj
+tPRzv7D7R3Lpw0U3fcj5zd8cP37bHWOe44ym3JS0LYltS2xpIYVEGo20bIQwYATCMqANwkRMTpRN
+AFoIiP5DSZAadHme9p69PCuhWW/QqNYxxiClzZX+Hg6N3AuPP45Je6BiUw8dwTIG4sdEGxNdJzTs
+29bDwBUpFoTBtS0yGet7FhZIBOCm0k0RgMnJc/NWOl+u12q9bsozqdAX3cBJf8of3nPyoSsfFA9Z
+sDGj7wPx0VtuKfzsoSOjl3/u53b+cCpzOJvybue///r+40eOj3mOuz3lupZtCVzLxpISC4FlCQQS
+KYlGX4GwNAIBSkUqJTUmiO5XIjAmBCE6KieMiH04GB1ihAQBk3tu4a/++M/QStLwW9TbAVIKvvCF
+L3DbTz3EcE8vLC9jHIkwJj4X0bWljKUgSgKMkIRK4WXzjFm2WTQIJDhO+n5iObwZ/OmmLReAzQAn
+R47feXB2V+7kgQMHxOnTp819IP7ltm3Zf3f77aMXfvb/3fWhdOpQynUOpVz7QOrQ4R2O7YylXdd1
+LAtHWlhSYguJkAILAVIgo1GNuKc0CINWK9ZTaBnjniL6p8uwKmNIalVCiI6mJuoXGoNt2QjX5cmn
+vslieREhLKqLiyxV6rR8H4nFn//pF/j7oURiQOmE15EQSRBGR5eNr220hlBjpORYriCeqy5hI3E9
+61ZgN3DuZscBWyIA3eb7RbCFEOGdb3vHuY2Ak2JK3ndksTIzfOrZvSc871DKdg5bx06MpW1nLO06
+aTdmtGNJBCCRWLaMmAxRNI1GaEHsauOBTRgpk8NW/K5RiFif9Mp9I0gCNRPbahMpapf1NcagTYiT
+9mByiqXlJSzLoTR1mee/fZJT336ehcUFvN4sWDYxGIIwAhMHkEIbjCD6W2mQEiMskBot4GCxgFxa
+Qkt0KpUuDg8PHJmenjvHTY4DrksA1vPTn12TS+9Mp8VAsykXFyvfnF9aejDjpKZSOvDS6dyIUi3S
+nseoY/3DN42O/VjOdfCkxLUsBBqJREgbKTTEJlgowNJoZVbsYbfGJo6aWGOFiZidON74R8lxAhHt
+SwysEJ1on1jR4i6GlXNIgQoNWgXcm83yWKtCFcH0lbM88fhf8J1vvMCg0+Lde3eitepcxwhAa6QU
+sVDoeLtAaIU2PkLYBCpkT08v2y5eoGwcY1kC1869C+b+gJscB2yqLfyjQsiPRj5aPPjggzLJpQEG
+5+bkIaVGs7Y9Jt30Acu2bss67q3atvZUENtHUulMfdsgX3NS/O//5/9Ff2+BT/7q/8dbX3meXsdD
+olYCJU3MQAEShDIgBUkuJYVMlBST6GjHKERaH/MuOk4kroE1x66Y++7xlbKzJ96fCI6FwSCFBGGo
+hQFPTJd4sdWmHEj22hY/unc3RdeK5JbOTYIUUQxgTKT1rTbStjC2g3BsjN/CNwLLCH7h5LfMNy1l
+HOHIyvLytycmTh+72TOQNmUBPgbmifvvt//trbeO5Z9/fkR63j7PcW93LXnYKvTu8jxnLCXt3pRj
+I4UkZUmklMjYl7ZSLl9rhB3gRKXTtPwQZVloFYBlIbWJmJrkymZFgwWAgZAQubaAKUAIiYgzSiGJ
+nW60U7HGSgiJ6AhPlJp1sj/dZVVYid4FGg1YVpQyZmzJ9+3YxfuFZNFXFGwLG01oIrcEccBpAaFB
+ui64NmZuEe+etxJcvIhpNsn+8A9S+W+fwiiFkRa353PiqeUKeAJpOwcdxzkkhHiRSFFviiBsSgB+
+9fiJX0m12u+2+rZtS9n2tpQl8YSFazlYMk6dpEAKicZgicj8CQ1Ig/EDpG0zFwMn+VwfWgiCto/l
+SkwYRJqioKPuXUGYEEkuLVBRRbXLt0fa1WGySngdSUJkCMzKaY2ClWgCoePrSAshTJzWRbFBhAfI
+2CoZtI6wfRGCb4UIJDnLIASRiCgRCZQRaK0QWmLCEGtkEHf/Aep/9Eek+orIag/Bty9T/8IfoRs1
+pJ1CCc14Lo9XrQgQKp3yvL6+oTtnZq68yE10A1etzd8vhC2EsJ1s9u27e/oOjmSy24a8FEXXJW3b
+WDLOW4jyaRWG6FARBAqlFAGadqVKeWQEkU6zEAMnbj6FfM97cXoLhG0fZSIfG2qN0gZlDMpEGhUa
+TaA1oTaEWqGSY7Qh1Aalif/W0b7kdyo6NtSaUGlCYwhVdLzGoLo+IQalQ5RWaK1Rquv3fhsdarQx
++IFPGIQoo1F+QBgEaKVQQYhS8T0FitBEFkPF8YA/eYXal76ESdlUP/dHNL51krDdQrcCnDtPYDAE
+gc9oocg2Y0xoFK5j42Wcd91M5m8oAEnr1oHjxwVg+np7nldGI0WkgVoZQqNRShGqABVGA6ZNpEHR
+AENYb6HGxljcsYNWs0Wj2sAYg21ZPHl2gtR734t0XIJQEWhFoBSB0fhK4YeqIxChNoQq+h5oRagV
+QRhGxysVHR//JlCaQEWMV0bFH9MRjug6kbDoDqMj4QraQXRsGKJaLZQKMbk8SgpUEEZxY+eeIASC
+RBj9ABUGaBOi6jVUux1lKJ5HWG/gHDqIGBiGbI7+n/7nGC+Fc/R2CvfeCykXozWW57DbcZA66p5L
+e94JIHMzewTWFYDE3/z+Sy8NpdPpo8/NlcGAr0O0NhHjw5BAa9pa45vo35ZStJSiqTV+qNEWeHff
+zbeeOcny8hINvxkDJ5Lp0gyPPXuKsJDHmBBlDBodaWEsSEobgkTrjUaZWNONQRsw2qCNRhuNMRqF
+IegwNBIEP9T4xtBWirZSkTCFAX6ria8VQdvHb7TQIcj+PoJmA3v7GLn77sVfrND3ve/FO7CPsNkk
+JErZVBhiMKgwQFVrhEEb46VQ0iZohaTvuRflutBTwLv3boJKHff2o9h79xPMlqk8+SRhvcny7z7K
+1L/8N7Tm5kBptDbcnsoKgxEGjOt5+9PpvkMiopvSSbXuSbdv3/7hvfsOPDd8y55v7Nk3/q2XdPij
+YRiiNTS1oq01gTGx9EfmVROhn5oVxiAlS/UqleVFGvV6Bzhp+m2MgdNnTtNutwGJwcSMB2MUGoMx
+Os7BNVprjFKgo4FKtikVmWdtIjeEARPv08Z0GIXRoCH02+Cl8HbdQrtaI3vXCTLHb6PVaNDzwP3o
+QoFWtUrYbBPaFqXf/wOWTz5LKARaG8IwikJ830c7Dtl3vIOw3SJ95A5y77ifoF7HHhtBFnpoXZyi
+8uWvYByHmY//Kguf/xyh9mk89RTWrh1o16P4T3+K3Lvfi241CI1mZy5DFi2MMNrzUvT0Zd8Ss+Wm
+uIJOEJggTkKIzJ694z81NDSw3UQMNjVhdEtKy1YhEWRiEuSlc2dax+mkFGgMGAshBMsvfYdKpcZy
+pcb01CWe+vqTnHz6m8xOl9gV1LDyvQTCRAFjck4hYqg0zqdjSM104vNIUJLjIwMp0PHxWoCUku4U
+VylF7/Gj1F5+GVyX3rvfTOXMBO2p6dhfh1z57c9glE+AoTV5BemlCFRA/sRdNM+9QnOxjG07CKUR
+kQmKED/XpfL003HzR8j0r30cKSVCegjHwbplB6JeYfBH/iGVr30TK59l4O+8m8u/+EuE8wu0L59F
+S4kKfIZzOXqntZnRQti2xPOcdwH/pTPYW0yrcIBOU+eePY8PDAzeDyYwBtsF8c/6+8m32igh0Cqq
+ckkh43y8wxaElDH0KZBGoAT8YbXCWSnwvBSWbbG4UKU/aPKPRkZJm05G36mdi1jIhBAxNNsN/CQF
+lq4sIRmd5NjkGMvC6ChjMErh9vSgGy2M34zi1iAAIbALBQgCvJERUgODLD/3PLv+wY/gL1dZ+MZX
+GH3/91H+6lepn34Zy0vF9yMja1Sv42TSoA3ZW29D1yrYjs3gB/4us595lOL992IXC8z++iP0/O0H
+aD7/As0XX0KmMuiluah3wAYn34efsnCN5JHz53hSGuNZligvVa68/NILR40x8zcDFl4rABagx8bG
+Pjk8tv0npDSh0NLCEuLHC32M+i0CTQft6pZJIVZwdJIULWaaDbzS9nkl8DGWxYiUHPY8HClRRNoe
+nc900r9V9k4kAhLX6JOqWjewI5KbiW4seq64ABOqKOe3bOxsjvb0NAP33UO7vEB7scytDz3E5T/9
+C3SrTXb3Dmb/7M9JjYyhW03apRJGKaR0sfJpZCxU0pKgQ/refg9WNsvClx9n+0/8KK3SNAt//pcU
+7zxK9elT6KVFRKONlDaEPlYxj8Gi5+63EPpNCNoM/uCHmPv9P6T27EncQh+npi7yyVbLWI5tWo2W
+vHzp4veUy+UnuAl4wFocQABWsxmeNcogsKKSKYJ5rRgxoEWMace5d2IBTOK/MUgtMDHgYjAoLMZT
+HgczabSJnEg7TsuMjC1IDJMmIIrutixGk8RAOoFrEasFMIZuhejebxBa03P8CEvPvkBqdIyRB97B
+xH99GCMkViZN+6UZTn/8vxOUZzFBm/JT38DJpGlemiSzZydWocDA/ffi9A9Q+twfoAKFsARaa4TW
+VL/zMmhNUFvm/K88jGo0kI6N/6dfxikUIJun/0MfYuEvnqD3gXsYOnqcC594mOJ9b6G5sMTC5z7P
+whNfpXnhDMJN4Wuf7aks2WZTtLXQqVSKVCp3H0QCsJXMXyUAYqWKYoVh84LWAbiWwAiMMMyGQcTQ
+KEqLNF2s/Es87B0mGYWOcXaFAm2h0ZF2Gx0LSwQW6dikRowWqK7zxYhutK8jUqIjgCtDEmUGiVsy
+RHFAqBTN6VkMhsblC7zy6d/CoJj5yy9HYiMcQr9J7vbbqX/nZfb86IPoRoPy159i9w9+iAt/8DlU
+O4DZRbQKo0vpxEVJGlOTuH19OH1DCEcw/P73MfPYn7D9Qw8iHJup//GHpEeGwLWpfPObNCfOUJm4
+RO1j/w7TaGLbHv58GXe4H93wCdsBxZRHf6jMpKOFJS28rHc/8O+4CeXh9ZBAp16vLzXbbZ3OZCyl
+lBFGMBP4KGkRmVcRtTN1iifdjOgAq3EfrIlL8hq0iJkUHTFw5Ahzzz4LwP6/9/3s+3s/wPIrr/CN
+n/l/YuAurvbF5zdxp06EywsMesUKiKjWruMxMnHujxFUz55Deh6m3abn8D6Es5fG5GUO/dQ/5dIf
+PYadSZM/cIClZ56hPnEB3axQm7rM8z/786hWi6XnnkcIg1vsRasAIWOh1BrpZtjxwQdpLS0z96Uv
+EfohOvS5/D8+h15eIiiXmfj3z2GEQVgO2V17SR3Yg6rV2flj/xszf/oX5Mb3kRkbpfTJT6N0G8dx
+Gc+kxaQCYQkyqdRhYMwYc3mr44BuAUg4ZyulGioIFwWi3xYSZTRLYUjDtbCUTlDVrh+ZLkbEnTVi
+JTQs7tvH4plXOm7Cyef5/j95DIAn/vn/wewz38bOZskODxPUapGbiBndqZ3HgaBa8z0ZCymT+vvK
+jRjAhC36jh1j6O43c+7RRyneOo6wbBZffImLX/wLqhcu4JcXmX78y2hLMvWXf47teSA0udvuwC32
+UDt3lp0f+LvMfvWrLL/wErbnEvX7CcKgybnf+A1UvYlu+7zyX/4ztpvGdl16jh2l7rlkd+1h7O+8
+i3Of+hQ7fuhBlK+48sjv0K5U0PUG5S8/waLrEJoADejQZ2crQNsWRtvaS6W2bdu27U1CiCu8Kvra
+OgGIOYkAlv2gVTWYfk00sBUVEGZyOFpH+b7WMZMSEkgBPfv2kRkeZvKv/orRe97O23/uZwH4vXvu
+i44S4NeqBLUaTi5HZmgYY55h9plnOfxj0e8TFyNE4gQ0puu5k/hO67h3Twi0prMvqh0QpWnSoXbh
+Au25edrzZc7+1u+g2k0sL8XcU0+R6stjpTyG3/m3aV66hPQy7PuRH+TFX/3P9B25A6TF4gvPMvON
+r1O/cAlhWyhMVH+IDCFWKk/vm+9i4eRJ9rz/+7CyBUp//AW23ft22p9/jKCyxOIrrxDWqpz/zU+j
+6g100+fcf/wlhIqiJAINlkSmPeTAIIfeeje9zz1HTWuTclxS+ew7mZ//Y7Y4DugWgCSzFoAK2moW
+wy0YGQdtgoYlyAEqqcN0tBBAM3LPvdzz8/8BgM+87R7qpenOyTNDg1SmpkFYWNKweOYVBo8eobhv
+LwaolUqdY/uP3EH52W+jdXT+jkXoknsT15BX3JDpZCJaJ/GBQFjQKi+ilcJ4Lqltg9zy3vdw5Ytf
+ZOAd91Ic3c6Z3/5tCrt20SovUjk9wcuf+jT10jRnfuO3EMYgXZvFb51Cei5CWphQIaVEI1B+m+It
+2xk8fie102dYfOklEBbt8jxnf/3XUY0WxvdZ/OY3wbIhiGIpabnY/UVSI6Oktu+kcGA/uR3byQyP
+4Bbz5AYGeNO/+TBf/drXhe25ZJzM2wC51bDwejGABsJW0L5ijL5LSAvCKDhb0IZBE1X+tDCIjiWI
+JKLexcTe/ftZmJjofM8Oj8QCoTFGsHjmDINHj9C7fz8AtS5hyQ6PMGuejTPDFQYn0tlp1DArAWFC
+ifsxcQ3ZhBorm+XAj/4YM3/9VRqlWWwvjTaG0uNfZrIV0p6Z59lf/E9IE2KlC7TLC1gpByvtxvcg
+kI4HaLRWUfyhNQiJ5XksP/8Cy88+B1pRO3cO1fARlgRCBDZONkvmwAHSI2Nk9+2hsGsH+dExskOD
+OPk8diq1cu9ddPeb7xJ/9fWvIRG4ae9W13X3AhNbuVLpei5AAX7Qap3zQ0XatY2yohGfCXwOkkT5
+xJH4yqAvnDnTOVFmeIjyxASLZ87Qu38/g0ePMHPqVCdGqE9HDO/Zv68zWWL2mWcYPHqUzPDQSpbQ
+ZW2Ig0LRDfYkEX/HEiUCoSNQSgh0s8XLv/kb1K5MIoyh/MyziLSH5Xj0vel2bMfDGx1i8PhxLn7u
+8wS1OkbKCERCgFxpNJHSxqDRKkT7AcYPogzFGOxcltTIKN7gENmdOyju2U1ux3ZyQ0N4fX2kCoVX
+MbnzbF2Cro3BsiwOHT6MJQRKK53NZLKFbduOCSHOsIVuYD0BCIGw1WpdCX0f0ikhdZRezYYBRlgk
+fXQRErvaPicM79m/n8tf+SvqpVLnuyGJ5AWLsXVwczmcTAa/XqdWmmbwKAwdPcILmI6Gr1pcJJG9
++IuJg03dGdiVbj6tFFgCwgBHp7nle9/L5De+zv4f+ACpgUHOfPrT7P/+H2Dy619l6eUJll9+BRUG
+GCkQloUwGh0oTKONr1Tk8IXBthzc3j5yu3aRGttOcfduCrfsJDc6QrpvgHR/L9KyVphL4pq6ApVo
+Y+exRAxdCyGw4uP37tnD9rExpqZKxvM88l7mb83D770Whq+l9QRAA0EYhlNtP2j0CJlRtjFWqMWS
+UrQtEc1qIdLE5CETjVycmKB3/3569+0DrVk88wrb772X7Mhw5yLaGBYmVqxFz/59zD777U4ckB0e
+oWffPrIjw/Tu20fv/v3USyVO/ef/snKnSTuXSSBk0dnc7SqMEZhAkdu3j13vfBeLL7/MwnMvYqUm
+aNVqnPql/4RqttHGZ+nsWTA6winCECMsUoUime1jZLePUdi9m8Itt1DYsYPM4DbS27Zhe6vNdyKs
+RqmV5tN4bDpM7mJ2N3V/D8MQ27Y5cOAAk5OTwnFcvGzqLsAxxvibZfC1qCMAcSFIELmAACiFQbiM
+IIOOhrSmNX7GI91qE8Sq2P0IBjqBX3ZkBKCj6b379+NkM/i1OhiDk8t1flebnsEYw+wzz8S/Hebv
+/ManXnWzJ7sEQJgOJBSnnCuVBNOxSnFLYSbNwvMv8o1nnkUHisq5s4TNFtK2CbSOupmyWbKjw6SH
+hyjs2kXv3n307N1DdnSEdG8fTjb7KoZBhAWYuHwdwdPxR0qsWOtlF8NXt5+vn811b7/7zW8Wf/nl
+xxEIUrZ7oKen51bg21sVB6yyALEQJHW5mu83ywIxgiWwhEVbhbSkRU4IQiMwKLIjI+RGRjDA7KlT
+zJ6KmNg7vh8db/OrNdx8jrt/5mc4/8Uvkh0ZYc973gPAzKlnqE9ORtbjdCQsi2fOUCuVWDrzCjOn
+TlGbnlkVYHYGNBlIiFxBUkeIB9doRdj0USqMSsLKIG2L1LY+em69ldz27ZG12ruH/I5R0n0DuD29
+nWxiLVO0WgnAu5ndXXns/t2qItY657saJccfPHgrbsoVOtQqm89aqVT+biHEc2xRHLBeFpC4gXa7
+1ZrURt8WwasKKSQVAQMIkAaMZM9738Md/+gnOPfHf8zMqVOrsEoBtKo1Tv7Kr/KW//vfsuO+e9lx
+372d/TOnTvGVf/WvO1hCu1rld+5+6yrfSBIDJBFhnBbKuOoIUYOGVgp8n6gWHJlZt1gkPTpKZmSE
+4u5d9O4fp3jLTtIDw2T6e5H2+i2ROlSdntTOtaVAyJX2iauZ72ttX4/5ay1CIlS7du1kx9iYuXDx
+Eq7jks557wY+se7FboA2EgAFBE2/fSEMQhzXMUJIIaRgXmn2mCgFVEYzE2v8nve+F79aY3vM4JlT
+pzoMSoRj+3334uZyBLUal578yiqt7vjORL5KKs4AACAASURBVLPX1PWFlFEuH4SYuBtJxNutTJb8
+6BCZoUEKO3dR3LuH4i27yA2PkNnWv8rdrHpQvQJni+R/QiIs+aoy9PXQyZMnATh+/Pirr9l1zvWs
+Bqw8cxiGOI7DoUOHOX/+orA9m2wqexQoGmOWtgIW3qgrWAFBuxFcbAcBnusJbRmkkswEfoTCEY3X
+9NNP8/Jnfo+DP/ghDv7gh4CI+U//8q+sPDQRRvDyZ35vpbS71jx21/uNQYdh1HoVt1+BwPY80tu2
+kRkcIDc2Rs+ePfTs2U1ubIzMwADpvr51H6ab0auudxXzvd73tTQ1NcXExMSqz9TUFAD5fJ7HH3/8
+Vb/pPue1ridji3PXXXeKx774GEYb42W83b29vYeAryfDddWbvAZd1QL4fmMyaLdDWSzYBFFevWg0
+zVB1UDghBN/65V/h25/8b/SOj1MvlSLN7jKXxH5axABN3HQd+2mN9n10GKJV5ECk6+D1FCkMDJIb
+G6Wwcxe9+/aS37mDzMAAmYEBrNh8r9Uoo3XXZbeG0RBp9enTp5menub06dMdLd+IqtUq1WqVfD5/
+zXNvRMl9jY+Pk83kRNtvqVw2Z6Wy+bcLIb7BFsQBG1kATYQHTPthsCyF1a9kaIQRoh4YdCqF4/tR
+C57RIAR+rcZMHMUDEUi0JuIN2+3IjKtoMp+0JE4+T2Z4mOzwELmdO+nZu5fiLbeQGx4iMzCAnU6v
+e4MmmeUbXaDz74346W5KtHhiYoKTJ09SKpU6Wn29NDExsa4b2Cwl2MHIyAg7d+wwE2fOCNuyKGTT
+D5TgF9mCotCrBCDOBBSRFZhtt1qLxuh+gYUlBU0R0nZs0r5PyxIILV8V+Wql0EEQMSkWBDudJjs0
+RHZokOz27fTs3UvP7lvIx+bbKxY7v191P91+OhEoKUHKGP27MT9drVaZmJjg9OnTnDlzhqmpqWtq
+9fXSyZMnb1gAkmdSKqo73Hb7bZyeOC0sy8FLp+4Aho0xpdcaB1xtZpABglarNWOM2ScsEc26kZK6
+ZdErJYRhpNVhjJIBlueR6usjOzhIdmSEnj276dm3l8L27WQGB8kMDKx/sTVpVifKj8332oHZ6Ptm
+6BOf+ASf+MSWBdIbUqkryL0R6hbuO0+cEP/j9//AGKN1OpMd7uvruw0o8RrjgKu5AAX4zZZ/QWn1
+NttxjNZGWNJizvcZajSwi0UK28fIDI9QvGUXvXv3UrhlF9mhyHxbrrvqYTonX5tPs4KUde1Y6TnY
+pKZPTU0xOjp6zYceiUGqm02nT59+zedInnnfvn309PaIWrWus+kMmULhHWJlGZkbpo0EYAUSbjfP
+B76P63pgg1AKfWCc9z70T6Cnh/TgAG42u/5JXpVmiQ6j1+32XWPJNoqYE/Od+OjTp08zMTGxYeS9
+lg4cOHDNY7aCTpw48Zp+3+0G+vv72blrp3nhhZeEZVlk0pn74sNeExp4NReggKBer19qtQLyRSkJ
+I9O87DgUjx7pHHi1NKuDysXbuwGPa+XDG9HExAQPPfTQq7ZXq9VNWYHx8fFNXee10Pj4OD/90z/9
+ms/TPV5H3vQm8fxzL2K5DpmUdxjYbYx5TauIXG26kSLKBGZ8v1W1hEBIYYQUzJWmadTrAHFdXCAt
+K9Ls5NOFe8s134EOft5931vR6rZZv3sjQjA+Ps773vc+fvInf5KPf/zjPPLIIxumeR/96Eev+/zr
+UbeVPHrkKEZotNE6m80Xh4eHj8T1mxt2A+tagK5MIACutPz2koa8NhEcPL9QplqrkclmO1oOG2tw
+d1PH1WizFuBqvnWzkffo6CgTXQ0ra/eNjIxw/PhxxsfHGR0dXVdgPvaxj1GtvnqV+Pe9731bamWS
+cdmzZzfbtm1jaWnZpNMpUpnMO4HPsdUC0H1toN1uNueNMjssYWFsQxgEzM3NMTQ0tGFwthltvlpF
+7Gr0mc98ZsN9GzF1LY2Pj/PEE09w/PhxRkdH2b9/PwcOHGB8fHxT4M3U1BRf+MIX1t33j//xP97U
+PWyGuuOAQqHAnltu4dQzzwrLtsllcm8FxGtpE7uaACSZQNBqNi+FKjjqOK6RIKRlceHCBW677bZr
+3vhGDF4vFtgMPfLII1cFZjYL2vzQD/0QP/mTP7np666lT37yk+tuf9/73repTOR6KRmrY8eOiadP
+ncKVLo7rHXAc51bgxRstD18tBui0hzXb7fMqVJ01eoQQvHL23KYusNb3r32g62H+xMTEhgPffcxm
+6LVAtNVq9XXR/m5KFOa2w7eBQWijVb6YS/UMDJx4LXHAteacRw2irdb5tt8mWXFJSosLFy52bmwj
+Wi/Q6/7N9TD/5MmTPPTQQ+v63LW0WSG4Ufrd3/3ddbcn7uRmUAKG7dmzm5GhYWMweG6KfDb77td0
+3o12xGmFAoLQ96ebjXrbkpYQMtLoufk52u32Vf34Wu2/WiVsI5qamuJjH/vYppkPWwPAXI0ee+yx
+dbd/7/d+7025XjJWYRiSSqXYu3cvxijhuDbZTPYEkLrROOBaQaAmygQm236whGBIh8ZIS4j5+Xmq
+tRqe5236ATYb8E1MTPD000/z5JNP3hA+/1oh2KvRE088sWGccf/999+063bTseNHxTf++q/BwqRT
+6fF0On0b8K0biQM2IwAAS+1We9EoPWTZEmEE7VaLxYUFtvX3bwqm3WzR5l/8i3/BE088samb34i2
+uqjTTRtp//Hjx19TXHEt6p4Kd+vBWxGWEBijsrmM1dMzdDfwLW4gDthMDKABv96oX4kngRhE1Id/
+6dKlVTe43k2v/X4tK7AV+fPNigGq1eqGwnnfffetu30rqDtgNgZ27drF2OiYUWjhuh75YupdcSB4
+3Tn1tQQgqQmE7Xb7gu9HK2M70kZIydlzK5nAetrdgYG7HuBaVmArBCBpxthquppleq24/0a0AqIB
+CMIwRErJm+64XRhlhOs4ZFLZNwG9Jl7N9XrOv5mVpxTg+43WuSDwY4w/Wlb1/PkLwPqAzkaMv5YF
+2Koo+mZYgSeffHLDfTejvrAWQdVxzUVrxV133hn/bXQmm9pZzPbfEf/sugRgMyuFRmCQ35psNlqm
+r19KraL5gDMzM50JDFer5G1me0IbDWQCxyafarXKxz72sQ3P81qaMa52zvVoq6+zuj6ysgBXZ0a2
+Mdx6660MDQ2JhYWyzmSz5Afy9wBPcBMEQAOh1rrUajeWBKLXYIwUUpTL81SrVXp7e6/nmtekH/7h
+HwZgeHiYAwcOrDvA10L8tjoTOHny5IZuZSvLy6v6JrRZpf1gOkvjWZbNbYcPm688+RXheSny6cz3
+CCH+PdcZB1xVALomiihgqt1qLxljegUCy7JotVosLS9vuQBspow6OjpKPp/fkClbjQVcLbPYH89w
+fq3U7e+7zX9nvcSY+Spexvbuu+8Wf/nE43jCIpVL30a0isiV6ykPbyYGSDrAg0azMRNG774zyGjl
+7anJqa4bXV3a3Yry7tXoan53q2OAqwnAVsQtK5q+gp5GPn818zsLYBrDgfED7BjbjjJK5TKFbdu2
+bXtTfLpNu4HNLj+qgaDVbF1UQRSFWpaFlJJz5852DlqL9N1Iv9710LVM71YKwdXO9VoDwG7mJ9+1
+VvEn0fpoXeNQKVSoCPwApRXHTxwXwggy6TS5XO/3XG9dYDMC0IGEa63muWhpVzrLsp07f/5VD/J6
+0bVM7422c6+liYmJq6aVNwIAdddJtDZrND/qpk4Yr3W8GLfWqFDFViDafueJO3FcR9i2RTqfent8
+7k3Dwpu1AAoIg2bzYqvVRgopDNG6+tPT050ZsK83Xcv0bpUFuJog3SjzE+rW+hXNjxifmP5QKbRa
+YX6oQlQYLdjd09PL4VsPCyEF2Uz+ELAXQGxycenrEQAVhuFUu9VsCEsIYYRBSMrlBWq12nUNwFbR
+tdKvrYKEt9L8d5v77vQuWuA61m69wvjE5IdhSKjiTxC92yAMo/cyvO3tbxNoVC6Tym0bHb2unPSa
+AhBHk4aoP3Cq1Wotmfj1LraUVGtVKpXKdQ3CVtLVrMBWpYJb0d+/1twn21eYv9rXK607Jj9UEcMT
+QQjCkCAI498odu7cxfjBceGmPHoLhXdfTxywWQuQCEG10WzMJzUBEc/OmY7X+3k9Iv+1dDUNnJqa
+2hJI+EZjibXjsdbcJ1qvlI6WoY+1XiVaH0Qan3zv1nqVxARKEQQB97z9XunaDplU+i7A3mwccD0C
+oIGw1qxfDlSIlBaWtBBCdppDvht0LRN8s5tDNqK1jF/LfKVCulM7pVfeYqKVJgiDFV8frNb65BO9
+wyH6d/v27Rw9egw35R3cMbznTSKia/L3egXAb9eb5wI/iF7aJEFIcc2i0M2kawnAVgBC1xtLdIM4
+65t71Xn5hEq0PozTuzCImB8zXiVxQPKWliDoaH0Yhh1LoLXmgQceYPeuW+xQhEdi131NZlzPiyMV
+EDabzfPtVot8IS+EiRg+NTUJsGotnNeLriUAZ7qWrrvZdC1zD3Q03phoOTitVjQ6eWmV7rYKsQCY
++G+gw/huF6O1xnVdvv8DH+DA+IGf+eQnP3kZ+NK1mkSuRwA0EPq+f7neaIRD0rJDpZHCYn5hgXq9
+TnaDKWI3k66VCm4VFnA1Wo/x0d8Rfr9i9rsY38XoyM/rzgyrsEurE0aHYRifQ3UEKLEqzWaTVqtF
+vV7Hb/sMDQ9vn19c9IwxSkTvgNiQNiUAa2oCM+1Wc8losw2DkVKKpcVFKtXqd0UAIEoHNzLTN7M7
+qJvW0/i18G4S2Zv4xVuqC/DR3ZF//Hek9ZFwJOdO9rdaLVqtFo1mk4X5MqXpEhfOnzczczPMzsxa
+E6dfnv3wv/pX12wSuV4XoIDZZqO1qLXaZiRYwopmC83NMTI8/Lq7AIgg4asxemJi4qbNB0z8fLc5
+TpifMK6b8Yn2BmHQ2Z8Ecx3tV2qVtkP0kqogCKjX69RqNebm5iiX51kol1Eq5Oy5c8zNzYt0Oq2y
+uZyVyxXuKZfLf32tQPBG3h7uN+v1UqjUfs9xTKi0EFJw4eJFbr/99s6gvJ5CMDw8fNX9U1NTN6lh
+I7IwCfMSc58wNincrPj0JH0zHXMfxKY98fPJuZQKCcMo2KvVaiwtLTE7O8vc3Cwz09NUqxWUUmQy
+GQYGBjhx4gR//Y2nDBKhtSGVzTwghPiPbKEF6KSCjVbjfOD797qugyUlQkjOd9UEvhsW4Go0MTGx
+pR27Ky7/1Rrf8c3GdKBbpZPgbbVmJ/uMidZMCMOQMAzxfZ96vc7s3CyzM7PMTJeYj3svHNsmk8kw
+ODhILpcjm82Sy+VwHCdaOFMLLEuSzaTvAAaMMbNXKw9frwWIVg9rt8+12z65XAFtQoQQXL50GeC7
+UhO4FiR8I1jA+k2usFahjDF85zsvs2/fvlV+HkPHz4dhrN2JD499v45ftxsEAe12m0qlwmys4aXS
+FOX5Ms1mA8/zyOfz9O3cSSaTIZfLkU6nSafTZDIZXNdFSkk+n6dSqwjLWCqTzo709/ffDkTvxtnA
+ElyvAERgUK12sdFoMDCI1Dp6YXK5XKbdbuN53nclDhgdHd0w4r8eAVjbhwdw7NixTowxMjLC/v37
+2bdvH/v27WPv3n0MDw93THknrTO6E9ytZXwYKgLfp9lsUq1WmS6VKE1PMz09xdLiIr7vk06n6ekp
+MjY22tH0VCpFJpMhlUrhOA6e5+G6Lo7jRFZhaFBU47pMJpMhU8jdz4oArEubFoA1mUCp0WpUMBQ0
+ykgpxXy5TLVa3dREkZtBIyMjGwrAtVLB9RpaE1JK88EPfogf//Gf4OjRI6uaM4yJFr4I4iXuQhWu
+uII4j4+sguowvV6vs7y8zFRpiplSpOm1WhWtNel0mm3btpHP58lms+Tz+Q7DPc/Dtu3O367rdj6W
+ZZHJZLj14EHOnj1rjEHYrkMuW7g/rgtsCQ4AK70Bk36rvaSULkgjEVY0fahcLrNt27brPOXW0NVS
+QXh1k+hGTI98+OoCzj33vL0DuZrYtHdelK1WABylNCT+X0UvuA6DgEqlQrlcplQqUZqaYmZmmkaj
+juM4pNNpRkZGOr68p6eHTCZDOp1epeXJJ9nmOA62bWPFC3OkPI+DBw7w2GN/jBEGS0hSaec2YKcx
+5uJGccCNCIAAWrVmY1apcKdtW0YZI6QQXLx06XVbf2ctbQYSPnbsWOf7egLQnc515/JJeRZWUrqE
+8QAqDu5CpfB9f8Wfz84yVSpRmrzCwsKKi8xmswwODpDP5ykUChQKhY6J9zyP6F2BKWzbXsV4KWWH
+8UlXlmVZscBqduzYSSadFo1GA2Gj8tliT//IyBHgIhvEATcSA0TrCNdqF8MwPGE7NlIIhLU6E3i9
+KGFk98pf+Xye8fFxjh07xsjICKOjox3tX63pphPRdyNrYLqg1uSV8RHTowg/Nu1xqTYIQmq1GsvL
+y5RKUx1Nr9WqnVStr6+PQqHQ0fKenh6y2Syu63YCuUTru7XbcZxO+12y1I7WhiDwqVYq1OsNFhcX
+adYbvHT6ZZqtVpSuKYOX8iimc+8CPs8GccCN4AAKCFvN5rl24JPOZqJ3CQvBxU1MGd8KWi9CHx8f
+59d+7dc6K3ysPabztg7WL9JEx6hVGp/4cKNXgrjEFbRabarVKuXyPNOlaaamJpmdnaXVamJZFtls
+lrGxsY6W9/X10dPTQzqd7jDd87zOJ2G8EFHHdTKGWmvarRb1eoNqrcbC/AKV5QqNWqNTEJKWRW9f
+D5OXJ1fe4SQQru2QyWXeEpv/dcvD1yUAXYFg0Gi3z7UaTUSxVyQNoDOzM9eVCWz2mISutaRMYuKT
+QViNzr2663alJr/a1Cevn0lMux/4aK2jAG5pmdJ0ienSNKXpKSrLy4RhSDqdplDIs3PnDgqFAsVi
+kZ6eHorFYofpSeqWmPTErCeps1KKRqNBo95gaWmJhfICy0sVWo0WQagQAlLpFK7rks1lcTwby7ax
+LInrOpw5dyZ6TgHaGGFLC9fzDrmuexD4znqFoesSgK4JiCpstycbjXpbSDyCiJFzc/MsLy8zODi4
+KYZ2b0sYdrUpZN3brha5d2t1N0DTfVzSftXt+5PALmnE8H2farXK/Pw80zPTlCanmJmdwW/7SCk6
+Wl4sFqM8va+P3t7eDpO7/brruti2jR0vcu37PrVajXqtzuLiIosLS1SXa7T9NlpFPZbpdArHdckN
+5fA8B8uO+i+M1oQ6xG+HLC4sEgaKydIVyuUFovUb4verGqMKuVyqr2/4OPAd1nEDN2oBFFBqNppL
+RpshBMa2bRH4ATMzMwwMDFyTmWsZt17+vdFvNxKEbs1e3W+3vplPfqu07jC9VqtRrVQpTZeYmS4x
+NVWiUqmgVBgxubeXYrHYCd76+vrI5XKdyD0J4BINhxVmV6tVlhYWWV6q0qg38IMQoxS245DOpMgX
+smzz+nA8J3YDhjDUBEFAsxG5gUajSbPVImj5NNtNLCkp9OR55plTkfVNRWm4MBglDK7nkcl77wZ+
+e73xv5EYIJkyvlhvtcthGA5JGU1bllJw9uzZzuJRV2P8tWgjgQBWafeKRkfzV9aWSruj+W7Gq9iX
+JxF7uVymNFVierrE3OwsQRhg2zbFYpHdu3fR2xsxulgs0tfX1/HhCcNd10Vrjd9uU6/VWFxYZGlx
+mWq1RrsdgIlehOGmPBzHJl/I43oOjmNjO040508bfN+nslihVq9TrdUI/ZB220cbRSrlYjsOjmuR
+yuQokmOuPM/MzDQTr7zSmaMpkgm8BmHZNvls9k4hhGeMaa8dyxsRgE6TaL1RuxKq8JBnpYwQRggh
+r6sB42pMXm/fat8da29s3oUQnci9uw6fdNlGCFyEtVerVZaWlymVSszOzjI9XaJRbyCloFAoMDo2
+Sm9vbydqT7S8W7uNgcBv06jVmbwyyfJShXqtQRgEaG1wXZdUJkU6naJQzOM6Do5rR1F8jB80Wy3q
+i3VqtTqNeoMgCGm1Wji2jZNysC2bdM6j0JslCEJm52YoXy5z6dJlrkxOUi6XqTcatNotent66evr
+R8bFvwiv0EIbbYSQB9Lp9O3A02vjgBsRAIgEIPBrjXO+75NKpUhe83plaqqzxPm1zPl63zfatmLC
+dQeo6Tbv0e9Wa34YKrTR1Gt1qtUqMzMzTM9MMzczy+LSElKKCH3r76e4Z0/HlydBXDqdjmY4EaF9
+tWqN0mSJaqVGu9kiDENAkMqk8TyHnt4iXsrFcWykjBbTikq9hmazSXlhkVq1TqvZIgjahKHGS3nY
+joXtWHgZl0Jvjkqlwlx5ltnZWS5duszU1BTLlWXq9XokII6DEweSqXSKYk+RVCoVB6xBtJqbFDiO
+LbLZnMpkM9b0/Mxx4GnWxAE3KgBJVfBsq9WiWCx2ZgrNzszQaDTIZDIbRvlrc/FVJ+5idHLMWn++
+EdOTRopWq0WtVosqaTMzzM3NsVAugwDHcejv72dkdITe3t4Ozl4sFmNQJYoHKkvLlCZLtJotfD+I
+3iIqJJ7n4ngO/YP9eKkosBNSgI7dih+ytLhMvdag3qijAkWz2YxejuE6OLZNOuuRs6PxKc/PMTWz
+wNRUiUuXLjI7O0etXqNWq2GMwXEcXCdidrHYQ3+/FQWDyAgochykY5P2UuSLBRw7uobrOKLVbptW
+syXqjRoCmTRurhrwGxWACAvw/cuNegOJJRWR1tfrDSqVCul0elU6tpb5GzE8+fvVkyS7Tf/K9jAM
+8YOAarXK4uIiM9MzzM7OUC4vxKtqefT19XHo8KEO+JJOp7EtC4QgCHzqtTrl2TJBOyBaCE/gpNzo
+LV2pNIViIQJkbIEUAoREG0O71WZxcYl6pU6r7eMHbVqtdozeRf7dSznkilla7Rbl+Xnm5ue5fOUK
+V65cYXFhkVqtRq1eixjtep1/h4ayMeIXYQKRINhYtkMuX6CQz2JJGzflYlsObb9FvVan3qizvLhk
+5hcW8FstFYSBvbxcfa50+fKTMR5w42lgzMCVTEDrUqPVWtRG9aIx0rKElIJSqUR/f39HALqFYK0f
+3yg/T5geIV+alflyUd28Uq2yvLzMbKzh5XKZIAjiKloPBw6Md5lxEEIS+AHV5Qrl2TIqjBa5tiyL
+dDpFKpWm2FPEcSMULplaoePJGo16g2a7RbPexPcD/LZPEPqRCbcjrcylshR78iwvV5iZm2Z6usSl
+S5cpTU9TqUSBXegHuJ6L40YCli8W6O3rw44xfWlZuI6N47ikUmn6eot4mQyOZZPOpMFArVql0Wyx
+VKswOzFjFiuLhO2AarOOCZWQti1saQHYQkp0qD4bs88imuBz4wKQyAErawYshlr1ChExUgjB+QsX
+OXjwYCcWiBi8GpwRQnQaJNYKw0qAF3ZaoOv1OsuVCjMz0yyUFygvLKBiAKZYLLJ3716y2SyOY8cB
+WkCz3qS6XItfUiXwUi7pdIZ8voDrObi2i+1Y0dvQY6jXD0KWl5ajdKvRJIwDM9uxceNc3PVsMlkP
+ZTTzc3OU58tMTk1y+cokc/NzcdtWHSkFruviuR6O6zAwMIAT4/gI2WG063kU8nl6enpIpVOkvDRe
+yiX0A5arFVqNJlPzs2bq0hS1ZgO/2aJaryCQwnEcISwZZRi2ixYhKgyXm4E/p319JtD+16anpv57
+F89W0WuJAaI1A2r1aRWEexzHNYIoEzh//lynzy2JzBPGrm2eTIQDiGa8djN8ucLc3Czz8xHAFAQB
+uVyefD7Hju3bScWvXQ+DMNJuvwoCXNeLULd8Btd18DIRE2S8pkGoQnSoababVMt1GtU6fhhEfflB
+EIM2FrZjk0mlyPfmqNfqzM3PMT8/z+VLl5kqTbG0uEStUafRaOJ5Lp7r4nge2WyOnmIPlh1F/VLK
+yC14Lql0mv7eXnp7enHdyJzbjk2tUmG5WqNWa3D23DlTujJFvd2kUalTbzZwHVc4jt15q0omkyfw
+W2EYBMt+KyyHreBS2/fP+37zcrvdvhwEwWVgHpgDqtGQvzrdulEBSIQgaLTr5/0weKvjudE7hYSg
+ND1NEAQdkw2rNd+sjdZjH175/9s7l9/IseuM/y7fxXqqHuoMAjuGbSDbJMggj1WQPyXIn5d9kFXi
+bJzAcE9WjhG3Wo+SSqpSFYtkkZe8lywyCxalklrTGU/Lk0zcB7gguZGI+s75znfOuSTjHev1PUEQ
+EEURdV03nTTHYTqdUFdNrbzXFaXO2es9ntuh1+/jnLSj06aubsGuDxsz4jhG7iRJmqKLprYWNXid
+g5p2Xcxes4N6GwSs1luWyyVXV1cs75bskoQkSdlXe1zXOUS2w2Q85vTUxrJMOLw5pe0P9Hp9JtMJ
+g14fv9uh1+tT1xXbbUSSxNyvN/zy7Vf13WpJrjPiTUJZlcJxbWFbFmBg2hYDe4AuVKa1DnWp7gtd
+XKS5vKhUsZB5fkNVbQEJ5IA6rOxwndJM61/cE/DJDpCnTSnY6/WoRQNwGGyRWYZlWR80beq6aXYk
+ux1RFLO+XxNGjRhqH26wLBPXaeYJBib7skbU1cPMvOP7jRp3TEzTwrSMw1brCq0L0m2MzDJSKdkX
+JVlbWztNK9bzHXp9n6Is2Gw2bIMt8+s5NzcL1us1UkriXfwAsuO6uJ5Lf9DHtOxm+ikEtuviuQ5+
+p8NgMOB0dkq316XX69P1fbI8Iwx37OKQm9tFffb+jCgISXNJGMZYphCu4wjDtDEM6PZ9ynKPLnWs
+sizMimKhlbrQmb5USt5qredHwOaHc0WT14vDUR/O2+uSF6j/NRxgD+zzPH8vpWQymYiqrkEI4t2O
+PMvxOt7D40xJkhBsAoJtcBhjpjRvG6OJbGos08ISFo7l0R128Dt+syPGd3EdtxFzptGklrJE5wUy
+25FJSa4UKtcURYnXacoz27bwXIv+qEey27EJNqxWK+ZXc+6Wd4RhhJQped4MsBz3kI+HAybT6YMY
+FMLEcWz8ro/vdxlPxkwnE7odn+FwFJ0bsgAACLZJREFUgOk47OKYOIoJwi2/+tV/1u/Pz5BJThhv
+kUmK4zrCcZzmg5eGwcnJEK325b5QkVZJoJSaZ0pd6Dy/1lrfFEWxPAJbHa0W7GOg26+7tF3atllX
+14d3B75E/9/aAQ6VQA1URVHcSiklVe3vqWrDEEKrgvn1HMMwWN7dEUURaSopi+bjzsIQmMLC9Vy6
+fg+/6+G4Lp2O12x07HoIYYCoqcoaXRaEYUSeKVKZHoSZwjKMpm9uNTV2x29YYxME3K223N7ecn19
+zXK5agYvMqWu62YE67jYrsNkNsM2LSzbohYC27RwOx6+10z3prNZUz76XQaDPtUe4iQk2oZczedc
+/Otlfb28QSWKzXbNfl8K1+kIx7UwDAvX9XBdj0LpTOsiKrNsVSh1JaU8V0rdaq1vqqoKD0Af03gb
+wS3YmsdoblcLdEvv9RE+D6B/Hfjf2gEO1t7ErZbZdl9VvolBRTPJ+ref/5wf/dGPmF/NMQ0Tz/MZ
+T8f4PR/Xcen4nUY4uTaGMB66e0VZEKybyFRKo7UmVxrHsrFd8yCmPAajHnmec79eEwQB19fX3Nws
+2GwDZCJJ0h2u00S167j4XZ/RaIhl2RiHHoDrOLieh+93ORkNmb05ZTjoM+gN8Ltd8kwSRhFRGHFx
+flGfnb1v2q9JQhAGmKYpHNcTttWMdUfDIeW+QmsdK6XCQu9uVZ5fZFpfKinvnlH4cZ5ugX6+9jxu
+wjkG+wmwL0X4x0B/LQdobyiWmbzfl+UfmuZhS7gQ/PrX/8WXf/bnnIxOcD0X27IwbRNTGNRCsC/2
+yEwShzFpJqn2NVopqrLC8WxM08Cybfx+h96wSxiGLO/X3K9WXM3nLJdLokMqaZS7+yDORidDprMp
+lmNjAIZh4nge3U6HbrfLdDZjOp7gD3xO+iMs2yRNJGEUcr+856uv/qM+P7sgljFxEBGnCZ7rCtd1
+sCwHwxBMJ1N0ocuiKKJMJoFW5VwpeZHn+bVSalGW5YrHPN0CfkzbbUQrHoOpOlrwAtgvAvEJU7dP
+cQA4CME0za/KsvwTy/brmkIIBGG0JVOSH/zgh82gJJVkMifLMoqyRGWqqa0dG8sxcV0br+M0FL5Z
+s91uublpauvNZk2apuySFEOIppxyXWzH5fS012yfskwEAtO28T2Pjt/k59PplJOTCf1Bj163z76u
+iMOIbbTl4t0F/3x5Ud8uFsS7mDCI2NelcB1HOK6LYTTNl47vkekyK1URZVl0Xyh1KaW8UKpYaJ0v
+DhSe8SjKWrBbUXZ8/hzsmqc5u27f9/spwH5T+1QHqIEyy5MzXWi8jo+owLIslFb84pdvSZOMIAjx
+O51GhdsWvusxOumTSkmwCVhv1lzP5yxub9mGIWkikVn6qMAdB9/vMhyNMG0bE4EwGqdx3Q69bpfR
+eMSb0zcM+n36gwG9bo9E7kjihG245d3Zu/rd2TuC9ZYojdlut9iWJdyWwi2D0XjYjHS1jlWmoqLc
+LVSeX0qtr7SUixdUeAv2sQJvo7wVZq04Owa6gsdc3Z4//KjfAfCtvQoDJLviLJMZo8EJe0MgarAM
+k8vLS/7iyy9xPYcwirhb3rFcLZnP56xWK3a7pGmPlsVBmLUUPmJ2Omt2zxgCyzjU1n6HQa/PdDpl
+PBnT7w0YDQdYlsUuTYmjkLvVkrdvv6rPzt+T7lI2UYBKM2zXEa7jYNkOlmHyZjaj1PtSFSrKpQyU
+Utda5xdZpm6UyhZlWd7xIdhtJB/T+HFUH0c2PBVoD/a/BfZLJj7l/wshbKAL/M1f/tVf/8OPf/Jj
+s53IlbqgLAu6fperq0t2u5Q4jg7DjiayHdt5aNxY5kGFH5oy/oHC35yeMjg5Ydjv0+v32Zd7ojgi
+DmPWwZrzs/N6sbpD7hI22wCqWjQTOxfTsLBMA6hReZkVhYrKsrjXuqVwdau1XlRVFfAI9HOwj/P2
+85KrfnZ8EtXt9bf+gb8Dew0GaJ4UkmlQVfWsFtSGMIRlmVRVxe3dHbrc0+13GY6GDSCGgXXY8ux5
+Hbq+z8l4zGw2ozfoMxoO8Tsd8lwRRSFhGPH+N7+pz96fE2y37KKE7e4ZhRsGk5Mx5b6i1DrWKg8L
+XXydCj/O1S2FH0d1S+kvlVzH68H+L0X1b2OvoQEqYJlnOqiramYaBpWoMQwTw9jTPWydah9w6PV6
+TCYTJuMxfq/LdDwGQ5AmzRj5fnnP26/e1tcXc+I0IQwiMiUbFe44GLaF5Zi8mc6eqfDiQOHZ/EiF
+H1N4zsvdspco/DiyPwDz+wTw/2Sv4QAAZabkjZTyj03LrG3TFpZj8ebkDePJGL/Tpd/vMRwO0KUm
+iVLiXcT88oqf/cvP6tXqnlQmbDchiFo4riMc28W0DHp9n17fRxU6K9U+KvLdqlDqUubyvMiK2/xR
+hR+3Rl+i8ONGyksU/v8e7JfsUx0ADkIwiqL3X3zxxd/+9Cc/pdvz8Ts+qUyJo5g42XFxfl6fnZ+R
+xCnRLmSXpNimJdyOJ2yrefJlMj2h3O/JtY61UmGR6IVU+aVuKHyhtb7hKYXnfJijjym8BfyDcouP
+UPjvk72GA+yBIg7DX4Rh+Pd390tx+e8X9WK1IE80QbShVBq7pXDTwHE8ZtMOWhflvlBRplWQKzVX
+Sp3rPL95gcJbwI9V+G/dSPku6+vvi31SFQAghLBoKoEfnkzG/9TvD76wTAvbsRGGgWlYQEWhiizf
+F1FVlCtd6MtcynOt1G2u9Zyqinga1S+B/VyYvdhIeX5/n8H+uL1WCqiALYh/7Hidv6uqfZCpPC6K
+8lZLfaG1vFJKLbTW13w4t34++Hier6ujI3yD2vqzfXN7DQYQQNsP+INut/unRVEUWusdjyLsOF8f
+C7Pj9uiL40w+U/jv1F7LAQTgAB3AP5w3HZinEf2xCRd8zTjzs/3u7LUcABonsGjAh6fgHkf2A31/
+bJz52b4b+2QHgCdOAE+fPPledsd+n+xVHODJH/we9cE/G/w3aYuY/vdOq5QAAAAASUVORK5CYII=
+"
+     width="48"
+     id="image9" />
+</svg>
diff -pruN 3.4.1-6/clock/src/applet-backend-default.c 3.4.1+git20201022.a0d3415c-1/clock/src/applet-backend-default.c
--- 3.4.1-6/clock/src/applet-backend-default.c	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/clock/src/applet-backend-default.c	2020-10-21 15:04:44.000000000 +0000
@@ -19,7 +19,6 @@
 
 #include <stdlib.h>
 #include <math.h>
-#define __USE_POSIX
 #include <signal.h>
 #include <glib/gstdio.h>
 
diff -pruN 3.4.1-6/clock/src/applet-backend-ical.c 3.4.1+git20201022.a0d3415c-1/clock/src/applet-backend-ical.c
--- 3.4.1-6/clock/src/applet-backend-ical.c	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/clock/src/applet-backend-ical.c	2020-10-21 15:04:44.000000000 +0000
@@ -19,7 +19,6 @@
 
 #include <stdlib.h>
 #include <math.h>
-#define __USE_POSIX
 #include <signal.h>
 #include <glib/gstdio.h>
 
diff -pruN 3.4.1-6/clock/src/applet-calendar.c 3.4.1+git20201022.a0d3415c-1/clock/src/applet-calendar.c
--- 3.4.1-6/clock/src/applet-calendar.c	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/clock/src/applet-calendar.c	2020-10-21 15:04:44.000000000 +0000
@@ -19,7 +19,6 @@
 
 #include <stdlib.h>
 #include <math.h>
-#define __USE_POSIX
 #include <signal.h>
 
 #include "applet-struct.h"
diff -pruN 3.4.1-6/clock/src/applet-draw.c 3.4.1+git20201022.a0d3415c-1/clock/src/applet-draw.c
--- 3.4.1-6/clock/src/applet-draw.c	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/clock/src/applet-draw.c	2020-10-21 15:04:44.000000000 +0000
@@ -18,7 +18,6 @@
 */
 
 #include <stdlib.h>
-#define __USE_POSIX
 #include <time.h>
 #include <signal.h>
 #include <math.h>
diff -pruN 3.4.1-6/clock/src/applet-notifications.c 3.4.1+git20201022.a0d3415c-1/clock/src/applet-notifications.c
--- 3.4.1-6/clock/src/applet-notifications.c	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/clock/src/applet-notifications.c	2020-10-21 15:04:44.000000000 +0000
@@ -19,7 +19,6 @@
 
 #include <stdlib.h>
 #include <math.h>
-#define __USE_POSIX
 #include <signal.h>
 
 #include "applet-struct.h"
diff -pruN 3.4.1-6/clock/src/applet-task-editor.c 3.4.1+git20201022.a0d3415c-1/clock/src/applet-task-editor.c
--- 3.4.1-6/clock/src/applet-task-editor.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/clock/src/applet-task-editor.c	2020-10-21 15:04:44.000000000 +0000
@@ -19,7 +19,6 @@
 
 #include <stdlib.h>
 #include <math.h>
-#define __USE_POSIX
 #include <signal.h>
 
 #include "applet-struct.h"
diff -pruN 3.4.1-6/clock/src/applet-theme.c 3.4.1+git20201022.a0d3415c-1/clock/src/applet-theme.c
--- 3.4.1-6/clock/src/applet-theme.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/clock/src/applet-theme.c	2020-10-21 15:04:44.000000000 +0000
@@ -18,7 +18,6 @@
 */
 
 #include <stdlib.h>
-#define __USE_POSIX
 #include <time.h>
 #include <signal.h>
 
diff -pruN 3.4.1-6/clock/src/applet-timer.c 3.4.1+git20201022.a0d3415c-1/clock/src/applet-timer.c
--- 3.4.1-6/clock/src/applet-timer.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/clock/src/applet-timer.c	2020-10-21 15:04:44.000000000 +0000
@@ -18,7 +18,6 @@
 */
 
 #include <stdlib.h>
-#define __USE_POSIX
 #include <time.h>
 #include <signal.h>
 #include <math.h>
diff -pruN 3.4.1-6/CMakeLists.txt 3.4.1+git20201022.a0d3415c-1/CMakeLists.txt
--- 3.4.1-6/CMakeLists.txt	2015-02-19 16:13:14.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/CMakeLists.txt	2020-10-21 15:04:44.000000000 +0000
@@ -11,9 +11,9 @@ include ("${CMAKE_CURRENT_SOURCE_DIR}/cm
 ########### project ###############
 
 project ("cairo-dock-plugins")
-set (VERSION "3.4.1")
+set (VERSION "3.4.99.alpha1")
 
-add_definitions (-std=c99 -Wall -Werror-implicit-function-declaration) # -Wextra -Wwrite-strings -Wuninitialized -Werror-implicit-function-declaration -Wstrict-prototypes -Wreturn-type -Wparentheses -Warray-bounds)
+add_definitions (-std=gnu99 -Wall -Werror-implicit-function-declaration) # -Wextra -Wwrite-strings -Wuninitialized -Werror-implicit-function-declaration -Wstrict-prototypes -Wreturn-type -Wparentheses -Warray-bounds)
 if (NOT DEFINED CMAKE_BUILD_TYPE)
 	add_definitions (-O3)
 endif()
@@ -573,11 +573,11 @@ if (enable-mono-interface)
 	if (NOT GMCS_EXECUTABLE OR NOT EXISTS ${GMCS_EXECUTABLE})
 		message (STATUS "Could not find Mono compiler gmcs, won't build Mono interface.")
 	else()
-		pkg_check_modules (MONO_PACKAGE glib-sharp-2.0 ndesk-dbus-1.0 ndesk-dbus-glib-1.0)
+		pkg_check_modules (MONO_PACKAGE dbus-sharp-2.0 dbus-sharp-glib-2.0 glib-sharp-2.0)
 		if (NOT MONO_PACKAGE_FOUND)
-			message (STATUS "Could not find glib-sharp-2.0, ndesk-dbus-1.0 or ndesk-dbus-glib-1.0; won't be built Mono interface.")
-			message (WARNING "These modules are required to compile DBus applet with Mono interface: glib-sharp-2.0, ndesk-dbus-1.0 and ndesk-dbus-glib-1.0")
-			set (MODULES_MISSING "${MODULES_MISSING} glib-sharp-2.0 ndesk-dbus-1.0 ndesk-dbus-glib-1.0")
+			message (STATUS "Could not find dbus-sharp-2.0, dbus-sharp-glib-2.0 or glib-sharp-2.0; won't be built Mono interface.")
+			message (WARNING "These modules are required to compile DBus applet with Mono interface: dbus-sharp-2.0, dbus-sharp-glib-2.0 and glib-sharp-2.0")
+			set (MODULES_MISSING "${MODULES_MISSING} dbus-sharp-2.0 dbus-sharp-glib-2.0 glib-sharp-2.0")
 		else()
 			set (MONO_FOUND TRUE)
 			set (with_mono yes)
@@ -1393,13 +1393,23 @@ add_subdirectory (Toons)
 
 ############# WEATHER #################
 message (STATUS "> Weather:")
-set (GETTEXT_WEATHER ${GETTEXT_PLUGINS})
-set (VERSION_WEATHER "1.2.16")
-set (PACKAGE_WEATHER "cd-weather")
-set (weatherdatadir "${pluginsdatadir}/weather")
-set (weatheruserdirname "weather")
-configure_file (${CMAKE_CURRENT_SOURCE_DIR}/weather/data/weather.conf.in ${CMAKE_CURRENT_BINARY_DIR}/weather/data/weather.conf)
-add_subdirectory (weather)
+set (with_weather no)
+set (WEATHER_MODULE openssl)
+pkg_check_modules (WEATHER ${WEATHER_MODULE})
+if (NOT WEATHER_FOUND)
+	message (STATUS "Could not find ${WEATHER_MODULE}; Cairo-Dock won't be built with Weather applet.")
+	message (WARNING "This module is required to compile Weather applet: ${WEATHER_MODULE}")
+	set (MODULES_MISSING "${MODULES_MISSING} ${WEATHER_MODULE}")
+else()
+	set (GETTEXT_WEATHER ${GETTEXT_PLUGINS})
+	set (VERSION_WEATHER "2.1.0")
+	set (PACKAGE_WEATHER "cd-weather")
+	set (weatherdatadir "${pluginsdatadir}/weather")
+	set (weatheruserdirname "weather")
+	configure_file (${CMAKE_CURRENT_SOURCE_DIR}/weather/data/weather.conf.in ${CMAKE_CURRENT_BINARY_DIR}/weather/data/weather.conf)
+	add_subdirectory (weather)
+	set (with_weather yes)
+endif()
 
 ############# WEBLETS #################
 message (STATUS "> Weblets:")
@@ -1506,6 +1516,7 @@ message (STATUS " - with Recent-Events a
 message (STATUS " - with Sound Effects applet:      ${with_sound_effects}")
 message (STATUS " - with Status-Notifier applet:    ${with_status_notifier}")
 message (STATUS " - with Terminal applet:           ${with_terminal}")
+message (STATUS " - with Weather applet:            ${with_weather}")
 message (STATUS " - with Weblets applet:            ${with_weblets}")
 message (STATUS " - with Xgamma applet:             ${with_xgamma}")
 message (STATUS "Add On:")
diff -pruN 3.4.1-6/Composite-Manager/data/misc/composite-off.svg 3.4.1+git20201022.a0d3415c-1/Composite-Manager/data/misc/composite-off.svg
--- 3.4.1-6/Composite-Manager/data/misc/composite-off.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Composite-Manager/data/misc/composite-off.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,50 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg id="svg3082" xmlns="http://www.w3.org/2000/svg" height="48" width="48" version="1.1" xmlns:xlink="http://www.w3.org/1999/xlink">
+ <defs id="defs3084">
+  <linearGradient id="linearGradient5060">
+   <stop id="stop5062" offset="0"/>
+   <stop id="stop5064" style="stop-opacity:0" offset="1"/>
+  </linearGradient>
+  <linearGradient id="linearGradient4168">
+   <stop id="stop4170" style="stop-color:#f8cd70" offset="0"/>
+   <stop id="stop4172" style="stop-color:#cc9110" offset="1"/>
+  </linearGradient>
+  <radialGradient id="radialGradient5537" xlink:href="#linearGradient4168" gradientUnits="userSpaceOnUse" cy="9.9662" cx="40.128" gradientTransform="matrix(1.8725 .0000022096 -.0000022597 1.9134 -42.642 -9.5692)" r="1.0607"/>
+  <radialGradient id="radialGradient5540" xlink:href="#linearGradient4168" gradientUnits="userSpaceOnUse" cy="9.9662" cx="40.128" gradientTransform="matrix(1.8725 .0000022587 -.0000022597 1.8717 -38.642 -9.1541)" r="1.0607"/>
+  <radialGradient id="radialGradient5543" xlink:href="#linearGradient4168" gradientUnits="userSpaceOnUse" cy="9.9662" cx="40.128" gradientTransform="matrix(1.8725 -1.5971e-7 1.5267e-7 1.7884 -34.642 -8.3239)" r="1.0607"/>
+  <linearGradient id="linearGradient5546" y2="40" gradientUnits="userSpaceOnUse" x2="24" gradientTransform="matrix(1.0526 0 0 1.0741 -1.2632 -.96296)" y1="13" x1="24">
+   <stop id="stop6459" style="stop-color:#fff;stop-opacity:.94118" offset="0"/>
+   <stop id="stop6461" style="stop-color:#fff;stop-opacity:.70588" offset="1"/>
+  </linearGradient>
+  <linearGradient id="linearGradient5549" y2="38.927" gradientUnits="userSpaceOnUse" x2="15.935" gradientTransform="matrix(1.3226 0 0 1.2414 -9.0645 -5.2931)" y1="9.0735" x1="16.034">
+   <stop id="stop3317" style="stop-color:#fff" offset="0"/>
+   <stop id="stop3319" style="stop-color:#fff;stop-opacity:0" offset="1"/>
+  </linearGradient>
+  <linearGradient id="linearGradient5552" y2="39.924" gradientUnits="userSpaceOnUse" x2="21.78" gradientTransform="matrix(1.303 0 0 1.2459 -8.5757 -5.7131)" y1="8.5763" x1="21.866">
+   <stop id="stop2783" style="stop-color:#505050" offset="0"/>
+   <stop id="stop6301" style="stop-color:#6e6e6e" offset=".13216"/>
+   <stop id="stop2785" style="stop-color:#8c8c8c" offset="1"/>
+  </linearGradient>
+  <radialGradient id="radialGradient6367" xlink:href="#linearGradient5060" gradientUnits="userSpaceOnUse" cy="486.65" cx="605.71" gradientTransform="matrix(-.062854 0 0 .024706 46.705 31.442)" r="117.14"/>
+  <radialGradient id="radialGradient6370" xlink:href="#linearGradient5060" gradientUnits="userSpaceOnUse" cy="486.65" cx="605.71" gradientTransform="matrix(.062854 0 0 .024706 1.295 31.442)" r="117.14"/>
+  <linearGradient id="linearGradient6381" y2="609.51" gradientUnits="userSpaceOnUse" x2="302.86" gradientTransform="matrix(.062854 0 0 .024706 1.2826 31.442)" y1="366.65" x1="302.86">
+   <stop id="stop5050" style="stop-opacity:0" offset="0"/>
+   <stop id="stop5056" offset=".5"/>
+   <stop id="stop5052" style="stop-opacity:0" offset="1"/>
+  </linearGradient>
+ </defs>
+ <g id="g5519">
+  <g id="g5514">
+   <path id="rect4173" style="opacity:.23613;fill:url(#linearGradient6381)" d="m8.8125 40.5v6h19.5l-5.5938-6h-13.906zm19.406 0 5.5625 6h5.4062v-6h-10.969z"/>
+   <path id="path5058" style="opacity:.23613;fill:url(#radialGradient6370)" d="m39.175 40.5v5.9997c3.2369 0.01129 7.8251-1.3442 7.8251-3.0002s-3.6121-2.9994-7.8251-2.9994z"/>
+   <path id="path5018" style="opacity:.23613;fill:url(#radialGradient6367)" d="m8.8251 40.5v5.9997c-3.2368 0.011-7.8251-1.344-7.8251-3s3.6121-3 7.8251-3z"/>
+  </g>
+  <path id="rect1887" style="stroke:#565853;fill:url(#linearGradient5552)" d="m4.5 5.5c-1.108 0-2 0.892-2 2v34c0 1.108 0.892 2 2 2h21.031l-4.469-4.781 8.626-8.344-18.688-15.375 12.688-9.5h-19.188zm25.812 0-13.312 9.5 18.469 15.281-8.719 8.657 4.25 4.562h12.5c1.108 0 2-0.892 2-2v-34c0-1.108-0.892-2-2-2h-13.188z"/>
+  <path id="rect2779" style="opacity:.2;stroke:url(#linearGradient5549);fill:none" d="m4.5 6.5c-0.554 0-1 0.446-1 1v34c0 0.554 0.446 1 1 1h20.094l-3.532-3.781 8.626-8.344-18.688-15.375 11.344-8.5h-17.844zm24.406 0-11.906 8.5 18.469 15.281-8.719 8.657 3.312 3.562h13.438c0.554 0 1-0.446 1-1v-34c0-0.554-0.446-1-1-1h-14.594z"/>
+  <path id="rect6287" style="fill:url(#linearGradient5546)" d="m5.0625 13c-0.5832 0-1.0625 0.467-1.0625 1.062v26.875c0 0.596 0.4793 1.063 1.0625 1.063h19.062l-3.062-3.281 8.626-8.344-18.688-15.375 2.656-2h-8.5935zm14.75 0l-2.812 2 18.469 15.281-8.719 8.657 2.844 3.062h13.344c0.583 0 1.062-0.467 1.062-1.062v-26.875c0-0.596-0.479-1.063-1.062-1.063h-23.125z"/>
+  <path id="path6289" style="fill:url(#radialGradient5543)" d="m42 9.5c0.000359 0.82832-0.67132 1.5-1.5 1.5s-1.5004-0.67168-1.5-1.5c-0.000359-0.82832 0.67132-1.5 1.5-1.5s1.5004 0.67168 1.5 1.5z"/>
+  <path id="path6291" style="fill:url(#radialGradient5540)" d="m38 9.5c0.000359 0.82832-0.67132 1.5-1.5 1.5s-1.5004-0.67168-1.5-1.5c0-0.8283 0.671-1.5 1.5-1.5s1.5 0.6717 1.5 1.5z"/>
+  <path id="path6293" style="fill:url(#radialGradient5537)" d="m34 9.5c0.000359 0.82832-0.67132 1.5-1.5 1.5s-1.5004-0.67168-1.5-1.5c0-0.8283 0.671-1.5 1.5-1.5s1.5 0.6717 1.5 1.5z"/>
+ </g>
+</svg>
diff -pruN 3.4.1-6/Composite-Manager/data/misc/composite-on.svg 3.4.1+git20201022.a0d3415c-1/Composite-Manager/data/misc/composite-on.svg
--- 3.4.1-6/Composite-Manager/data/misc/composite-on.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Composite-Manager/data/misc/composite-on.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,512 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   version="1.1"
+   width="48"
+   height="48"
+   id="svg3082"
+   inkscape:version="0.48.1 r9760"
+   sodipodi:docname="composite-on.svg">
+  <metadata
+     id="metadata81">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <sodipodi:namedview
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1"
+     objecttolerance="10"
+     gridtolerance="10"
+     guidetolerance="10"
+     inkscape:pageopacity="0"
+     inkscape:pageshadow="2"
+     inkscape:window-width="1164"
+     inkscape:window-height="805"
+     id="namedview79"
+     showgrid="false"
+     inkscape:zoom="3.1979167"
+     inkscape:cx="4.5441968"
+     inkscape:cy="31.171798"
+     inkscape:window-x="7"
+     inkscape:window-y="32"
+     inkscape:window-maximized="0"
+     inkscape:current-layer="svg3082" />
+  <defs
+     id="defs3084">
+    <linearGradient
+       id="linearGradient3315">
+      <stop
+         id="stop3317"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3319"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6457">
+      <stop
+         id="stop6459"
+         style="stop-color:white;stop-opacity:0.94117647"
+         offset="0" />
+      <stop
+         id="stop6461"
+         style="stop-color:white;stop-opacity:0.70588237"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5060">
+      <stop
+         id="stop5062"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop5064"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5048">
+      <stop
+         id="stop5050"
+         style="stop-color:black;stop-opacity:0"
+         offset="0" />
+      <stop
+         id="stop5056"
+         style="stop-color:black;stop-opacity:1"
+         offset="0.5" />
+      <stop
+         id="stop5052"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient2781">
+      <stop
+         id="stop2783"
+         style="stop-color:#505050;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6301"
+         style="stop-color:#6e6e6e;stop-opacity:1"
+         offset="0.13216467" />
+      <stop
+         id="stop2785"
+         style="stop-color:#8c8c8c;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4168">
+      <stop
+         id="stop4170"
+         style="stop-color:#f8cd70;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4172"
+         style="stop-color:#cc9110;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="302.85715"
+       y1="366.64789"
+       x2="302.85715"
+       y2="609.50507"
+       id="linearGradient5557"
+       xlink:href="#linearGradient5048"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(2.774389,0,0,1.969706,-1892.179,-872.8854)" />
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient5559"
+       xlink:href="#linearGradient5060"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(2.774389,0,0,1.969706,-1891.633,-872.8854)" />
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient5561"
+       xlink:href="#linearGradient5060"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-2.774389,0,0,1.969706,112.7623,-872.8854)" />
+    <radialGradient
+       cx="40.128311"
+       cy="9.9661751"
+       r="1.0606601"
+       fx="40.128311"
+       fy="9.9661751"
+       id="radialGradient2875"
+       xlink:href="#linearGradient4168"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.8725485,2.2095674e-6,-2.259713e-6,1.9133827,-42.642185,-9.569197)" />
+    <radialGradient
+       cx="40.128311"
+       cy="9.9661751"
+       r="1.0606601"
+       fx="40.128311"
+       fy="9.9661751"
+       id="radialGradient2878"
+       xlink:href="#linearGradient4168"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.8725485,2.2587334e-6,-2.2597133e-6,1.8717342,-38.642185,-9.154121)" />
+    <radialGradient
+       cx="40.128311"
+       cy="9.9661751"
+       r="1.0606601"
+       fx="40.128311"
+       fy="9.9661751"
+       id="radialGradient2881"
+       xlink:href="#linearGradient4168"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.8725485,-1.5970626e-7,1.5266511e-7,1.788437,-34.642209,-8.32387)" />
+    <linearGradient
+       x1="24"
+       y1="13"
+       x2="24"
+       y2="40"
+       id="linearGradient2884"
+       xlink:href="#linearGradient6457"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.0526316,0,0,1.0740741,-1.2631579,-0.962963)" />
+    <linearGradient
+       x1="16.033964"
+       y1="9.0734701"
+       x2="15.934606"
+       y2="38.926552"
+       id="linearGradient2887"
+       xlink:href="#linearGradient3315"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.3225792,0,0,1.2413775,-9.0644846,-5.2930795)" />
+    <linearGradient
+       x1="21.866402"
+       y1="8.5763302"
+       x2="21.780495"
+       y2="39.923653"
+       id="linearGradient2890"
+       xlink:href="#linearGradient2781"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.3030281,0,0,1.2459013,-8.5757242,-5.713095)" />
+    <linearGradient
+       id="linearGradient7421">
+      <stop
+         id="stop7423"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop7425"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient7381">
+      <stop
+         id="stop7383"
+         style="stop-color:#babdb6;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop7385"
+         style="stop-color:white;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient7444">
+      <stop
+         id="stop7446"
+         style="stop-color:#888a85;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop7448"
+         style="stop-color:#555753;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4434">
+      <stop
+         id="stop4436"
+         style="stop-color:#d3d7cf;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4438"
+         style="stop-color:#babdb6;stop-opacity:1"
+         offset="0.18303643" />
+      <stop
+         id="stop4440"
+         style="stop-color:white;stop-opacity:1"
+         offset="0.31893486" />
+      <stop
+         id="stop4442"
+         style="stop-color:#babdb6;stop-opacity:1"
+         offset="0.87643671" />
+      <stop
+         id="stop4444"
+         style="stop-color:#eeeeec;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6432">
+      <stop
+         id="stop6434"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6436"
+         style="stop-color:black;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="304.76227"
+       y1="64.295265"
+       x2="335.30014"
+       y2="81.926315"
+       id="linearGradient3280"
+       xlink:href="#linearGradient4434"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(55.750001,906.7774)" />
+    <linearGradient
+       x1="324.49731"
+       y1="70.282364"
+       x2="330.06076"
+       y2="99.273735"
+       id="linearGradient3282"
+       xlink:href="#linearGradient7444"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(55.750001,906.7774)" />
+    <linearGradient
+       x1="302.29202"
+       y1="58.442768"
+       x2="308.64914"
+       y2="60.767513"
+       id="linearGradient3284"
+       xlink:href="#linearGradient7381"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(55.750001,906.7774)" />
+    <linearGradient
+       x1="326.60196"
+       y1="75.575363"
+       x2="317.16116"
+       y2="88.006248"
+       id="linearGradient3286"
+       xlink:href="#linearGradient7421"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="340.9343"
+       y1="984.38202"
+       x2="340.9343"
+       y2="986.9292"
+       id="linearGradient2897"
+       xlink:href="#linearGradient6432"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.0742416,0,0,1.1176269,3.4610723,-124.11755)" />
+    <linearGradient
+       x1="20.494"
+       y1="7.044"
+       gradientTransform="matrix(0.41388,0,0,0.41629,-1.7222,-1.7776)"
+       x2="20.494"
+       gradientUnits="userSpaceOnUse"
+       y2="39.78"
+       id="linearGradient2431">
+      <stop
+         offset="0"
+         style="stop-color:#fff"
+         id="stop3402" />
+      <stop
+         offset="1"
+         style="stop-color:#fff;stop-opacity:0"
+         id="stop3404" />
+    </linearGradient>
+    <linearGradient
+       x1="-86.129"
+       y1="2.0691"
+       gradientTransform="matrix(0.42104,-0.10139,0.1008,0.4235,44.055,-5.0894)"
+       x2="-93.088"
+       gradientUnits="userSpaceOnUse"
+       y2="31.138"
+       id="linearGradient2427">
+      <stop
+         offset="0"
+         style="stop-color:#d7e866"
+         id="stop2266" />
+      <stop
+         offset="1"
+         style="stop-color:#8cab2a"
+         id="stop2268" />
+    </linearGradient>
+    <linearGradient
+       x1="20.493999"
+       y1="7.0440001"
+       gradientTransform="matrix(0.41388,0,0,0.41629,-1.7222,-1.7776)"
+       x2="20.493999"
+       gradientUnits="userSpaceOnUse"
+       y2="39.779999"
+       id="linearGradient2431-3">
+      <stop
+         offset="0"
+         style="stop-color:#fff"
+         id="stop3402-1" />
+      <stop
+         offset="1"
+         style="stop-color:#fff;stop-opacity:0"
+         id="stop3404-7" />
+    </linearGradient>
+    <linearGradient
+       y2="39.779999"
+       x2="20.493999"
+       y1="7.0440001"
+       x1="20.493999"
+       gradientTransform="matrix(0.41388,0,0,0.41629,-1.7222,-1.7776)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient3101"
+       xlink:href="#linearGradient2431-3"
+       inkscape:collect="always" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient2431-3"
+       id="linearGradient3153"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.41388,0,0,0.41629,27.98464,-8.1880235)"
+       x1="20.493999"
+       y1="7.0440001"
+       x2="20.493999"
+       y2="39.779999" />
+    <filter
+       inkscape:collect="always"
+       id="filter3923">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="0.37014065"
+         id="feGaussianBlur3925" />
+    </filter>
+    <filter
+       inkscape:collect="always"
+       id="filter3955"
+       x="-0.1586643"
+       width="1.3173286"
+       y="-0.14808364"
+       height="1.2961673">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="0.92535167"
+         id="feGaussianBlur3957" />
+    </filter>
+  </defs>
+  <g
+     transform="matrix(0.02265526,0,0,0.01254292,44.15039,42.390183)"
+     id="g5022"
+     style="opacity:0.58730164;display:inline">
+    <rect
+       width="1339.6335"
+       height="478.35718"
+       x="-1559.2523"
+       y="-150.69685"
+       id="rect4173"
+       style="opacity:0.40206185;fill:url(#linearGradient5557);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+    <path
+       d="m -219.61876,-150.68038 c 0,0 0,478.33079 0,478.33079 142.874166,0.90045 345.40022,-107.16966 345.40014,-239.196175 0,-132.026537 -159.436816,-239.134595 -345.40014,-239.134615 z"
+       id="path5058"
+       style="opacity:0.40206185;fill:url(#radialGradient5559);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+    <path
+       d="m -1559.2523,-150.68038 c 0,0 0,478.33079 0,478.33079 -142.8742,0.90045 -345.4002,-107.16966 -345.4002,-239.196175 0,-132.026537 159.4368,-239.134595 345.4002,-239.134615 z"
+       id="path5018"
+       style="opacity:0.40206185;fill:url(#radialGradient5561);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+  </g>
+  <rect
+     width="42.999969"
+     height="37.999969"
+     rx="2"
+     ry="2"
+     x="2.500015"
+     y="5.5000153"
+     id="rect1887"
+     style="fill:url(#linearGradient2890);fill-opacity:1;stroke:#565853;stroke-width:1.00002992;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+  <rect
+     width="40.999966"
+     height="35.999966"
+     rx="1"
+     ry="1"
+     x="3.5000174"
+     y="6.5000172"
+     id="rect2779"
+     style="opacity:0.2;fill:none;stroke:url(#linearGradient2887);stroke-width:1.00003481;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+  <rect
+     width="40"
+     height="29"
+     rx="1.0526316"
+     ry="1.074074"
+     x="4"
+     y="13"
+     id="rect6287"
+     style="fill:url(#linearGradient2884);fill-opacity:1;stroke:none" />
+  <path
+     d="m 42,9.5 c 3.59e-4,0.828322 -0.671319,1.5 -1.5,1.5 -0.828681,0 -1.500359,-0.671678 -1.5,-1.5 -3.59e-4,-0.8283216 0.671319,-1.4999996 1.5,-1.4999996 0.828681,0 1.500359,0.671678 1.5,1.4999996 l 0,0 z"
+     id="path6289"
+     style="fill:url(#radialGradient2881);fill-opacity:1;stroke:none" />
+  <path
+     d="m 38,9.4999997 c 3.59e-4,0.8283213 -0.671319,1.4999993 -1.5,1.4999993 -0.828681,0 -1.500359,-0.671678 -1.5,-1.4999993 C 34.999641,8.671678 35.671319,8 36.5,8 37.328681,8 38.000359,8.671678 38,9.4999997 l 0,0 z"
+     id="path6291"
+     style="fill:url(#radialGradient2878);fill-opacity:1;stroke:none" />
+  <path
+     d="m 34,9.4999997 c 3.59e-4,0.8283213 -0.671319,1.4999993 -1.5,1.4999993 -0.828681,0 -1.500359,-0.671678 -1.5,-1.4999993 C 30.999641,8.671678 31.671319,8 32.5,8 33.328681,8 34.000359,8.671678 34,9.4999997 l 0,0 z"
+     id="path6293"
+     style="fill:url(#radialGradient2875);fill-opacity:1;stroke:none" />
+  <g
+     transform="matrix(1.1206258,0,0,1.1201656,-326.47085,12.52735)"
+     id="g7440-6"
+     style="opacity:0.48858445;display:inline;enable-background:new" />
+  <g
+     transform="matrix(1.1206258,0,0,1.1201641,-390.24836,-3.560983)"
+     id="g7440-0"
+     style="opacity:0.48858445;display:inline;enable-background:new" />
+  <g
+     transform="matrix(1.1206258,0,0,1.1201641,-388.24836,-7.560983)"
+     id="g7440-03"
+     style="opacity:0.48858445;display:inline;enable-background:new" />
+  <g
+     transform="matrix(1.1811195,0,0,1.1804515,-414.25321,12.547469)"
+     id="g7440-8"
+     style="opacity:0.48858445;display:inline;enable-background:new" />
+  <path
+     d="m 39.910253,25.963735 c -0.232,-0.02365 -0.462,0.09048 -0.581,0.30958 l -5.0718,9.333001 -3.2606,-2.6075 c -0.2904,-0.1597 -0.6528,-0.057 -0.8115,0.2352 l -1.4622,1.8882 c -0.1587,0.29213 -0.05194,0.6565 0.2385,0.81613 0,0 5.9534,4.9457 5.9608,4.9493 0.06807,0.03741 0.13926,0.05624 0.21162,0.06544 0.23638,0.03004 0.47828,-0.08166 0.59979,-0.30532 l 6.8394,-12.586 c 0.1587,-0.29213 0.05194,-0.6565 -0.2385,-0.81613 l -2.194,-1.211801 c -0.073,-0.03986 -0.153,-0.06176 -0.23,-0.06964 z"
+     style="fill:none;stroke:#000000;stroke-width:1.00279998999999997;stroke-linecap:round;stroke-linejoin:round;stroke-opacity:1;filter:url(#filter3955)"
+     id="path1542-9"
+     inkscape:connector-curvature="0" />
+  <g
+     id="layer1"
+     transform="translate(27.589622,25.322468)">
+    <path
+       d="M 12.262,0.50446 C 12.03,0.48081 11.8,0.59494 11.681,0.81404 l -5.0718,9.333 -3.2606,-2.6075 C 3.0582,7.37984 2.6958,7.48254 2.5371,7.77474 l -1.4622,1.8882 c -0.1587,0.29213 -0.051938,0.6565 0.2385,0.81613 0,0 5.9534,4.9457 5.9608,4.9493 0.068071,0.03741 0.13926,0.05624 0.21162,0.06544 0.23638,0.03004 0.47828,-0.08166 0.59979,-0.30532 l 6.8394,-12.586 c 0.1587,-0.29213 0.05194,-0.6565 -0.2385,-0.81613 l -2.194,-1.2118 c -0.073,-0.03986 -0.153,-0.06176 -0.23,-0.06964 z"
+       style="fill:url(#linearGradient2427);stroke:#699536;stroke-width:1.00279999;stroke-linecap:round;stroke-linejoin:round"
+       id="path1542"
+       inkscape:connector-curvature="0" />
+    <path
+       d="M 12.312,1.6562 7,11.469 a 0.15035,0.15035 0 0 1 0,0.031 0.15035,0.15035 0 0 1 -0.03125,0.03125 0.15035,0.15035 0 0 1 -0.03125,0 0.15035,0.15035 0 0 1 -0.03125,0.03125 0.15035,0.15035 0 0 1 -0.03125,0 0.15035,0.15035 0 0 1 -0.03125,0 0.15035,0.15035 0 0 1 -0.03125,-0.03125 0.15035,0.15035 0 0 1 -0.03125,0 l -3.6562,-2.906 c -0.32388,0.40246 -0.60092,0.77792 -0.96875,1.25 0.1123,0.093077 1.303,1.09 2.625,2.1875 0.6912,0.57379 1.3815,1.1568 1.9062,1.5938 0.26235,0.21848 0.4994,0.39983 0.65625,0.53125 0.050142,0.04201 0.088455,0.06296 0.125,0.09375 0.052555,-0.09355 0.10901,-0.18055 0.25,-0.4375 0.19196,-0.34986 0.43971,-0.83698 0.75,-1.4062 0.62059,-1.1385 1.4445,-2.6103 2.25,-4.0938 0.80552,-1.4834 1.5812,-2.9751 2.1875,-4.0938 0.30316,-0.55933 0.56868,-1.0087 0.75,-1.3438 0.14198,-0.26236 0.21072,-0.36449 0.25,-0.4375 -0.055,-0.0314 -0.1,-0.0615 -0.218,-0.125 -0.172,-0.0919 -0.379,-0.1999 -0.594,-0.3126 -0.215,-0.1126 -0.432,-0.2271 -0.594,-0.3124 -0.067,-0.0354 -0.141,-0.0375 -0.188,-0.0626 z"
+       style="opacity:0.4;fill:none;stroke:url(#linearGradient2431);stroke-width:1.00279999;stroke-linecap:round"
+       id="path2429"
+       inkscape:connector-curvature="0" />
+  </g>
+  <g
+     id="layer1-5"
+     transform="translate(33.159654,24.358299)" />
+</svg>
diff -pruN 3.4.1-6/Composite-Manager/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/Composite-Manager/data/misc/icon.svg
--- 3.4.1-6/Composite-Manager/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Composite-Manager/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,408 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   version="1.1"
+   width="48"
+   height="48"
+   id="svg3082">
+  <defs
+     id="defs3084">
+    <linearGradient
+       id="linearGradient3315">
+      <stop
+         id="stop3317"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3319"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6457">
+      <stop
+         id="stop6459"
+         style="stop-color:white;stop-opacity:0.94117647"
+         offset="0" />
+      <stop
+         id="stop6461"
+         style="stop-color:white;stop-opacity:0.70588237"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5060">
+      <stop
+         id="stop5062"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop5064"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5048">
+      <stop
+         id="stop5050"
+         style="stop-color:black;stop-opacity:0"
+         offset="0" />
+      <stop
+         id="stop5056"
+         style="stop-color:black;stop-opacity:1"
+         offset="0.5" />
+      <stop
+         id="stop5052"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient2781">
+      <stop
+         id="stop2783"
+         style="stop-color:#505050;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6301"
+         style="stop-color:#6e6e6e;stop-opacity:1"
+         offset="0.13216467" />
+      <stop
+         id="stop2785"
+         style="stop-color:#8c8c8c;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4168">
+      <stop
+         id="stop4170"
+         style="stop-color:#f8cd70;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4172"
+         style="stop-color:#cc9110;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="302.85715"
+       y1="366.64789"
+       x2="302.85715"
+       y2="609.50507"
+       id="linearGradient5557"
+       xlink:href="#linearGradient5048"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(2.774389,0,0,1.969706,-1892.179,-872.8854)" />
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient5559"
+       xlink:href="#linearGradient5060"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(2.774389,0,0,1.969706,-1891.633,-872.8854)" />
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient5561"
+       xlink:href="#linearGradient5060"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-2.774389,0,0,1.969706,112.7623,-872.8854)" />
+    <radialGradient
+       cx="40.128311"
+       cy="9.9661751"
+       r="1.0606601"
+       fx="40.128311"
+       fy="9.9661751"
+       id="radialGradient2875"
+       xlink:href="#linearGradient4168"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.8725485,2.2095674e-6,-2.259713e-6,1.9133827,-42.642185,-9.569197)" />
+    <radialGradient
+       cx="40.128311"
+       cy="9.9661751"
+       r="1.0606601"
+       fx="40.128311"
+       fy="9.9661751"
+       id="radialGradient2878"
+       xlink:href="#linearGradient4168"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.8725485,2.2587334e-6,-2.2597133e-6,1.8717342,-38.642185,-9.154121)" />
+    <radialGradient
+       cx="40.128311"
+       cy="9.9661751"
+       r="1.0606601"
+       fx="40.128311"
+       fy="9.9661751"
+       id="radialGradient2881"
+       xlink:href="#linearGradient4168"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.8725485,-1.5970626e-7,1.5266511e-7,1.788437,-34.642209,-8.32387)" />
+    <linearGradient
+       x1="24"
+       y1="13"
+       x2="24"
+       y2="40"
+       id="linearGradient2884"
+       xlink:href="#linearGradient6457"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.0526316,0,0,1.0740741,-1.2631579,-0.962963)" />
+    <linearGradient
+       x1="16.033964"
+       y1="9.0734701"
+       x2="15.934606"
+       y2="38.926552"
+       id="linearGradient2887"
+       xlink:href="#linearGradient3315"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.3225792,0,0,1.2413775,-9.0644846,-5.2930795)" />
+    <linearGradient
+       x1="21.866402"
+       y1="8.5763302"
+       x2="21.780495"
+       y2="39.923653"
+       id="linearGradient2890"
+       xlink:href="#linearGradient2781"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.3030281,0,0,1.2459013,-8.5757242,-5.713095)" />
+    <linearGradient
+       id="linearGradient7421">
+      <stop
+         id="stop7423"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop7425"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient7381">
+      <stop
+         id="stop7383"
+         style="stop-color:#babdb6;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop7385"
+         style="stop-color:white;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient7444">
+      <stop
+         id="stop7446"
+         style="stop-color:#888a85;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop7448"
+         style="stop-color:#555753;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4434">
+      <stop
+         id="stop4436"
+         style="stop-color:#d3d7cf;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4438"
+         style="stop-color:#babdb6;stop-opacity:1"
+         offset="0.18303643" />
+      <stop
+         id="stop4440"
+         style="stop-color:white;stop-opacity:1"
+         offset="0.31893486" />
+      <stop
+         id="stop4442"
+         style="stop-color:#babdb6;stop-opacity:1"
+         offset="0.87643671" />
+      <stop
+         id="stop4444"
+         style="stop-color:#eeeeec;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6432">
+      <stop
+         id="stop6434"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6436"
+         style="stop-color:black;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="304.76227"
+       y1="64.295265"
+       x2="335.30014"
+       y2="81.926315"
+       id="linearGradient3280"
+       xlink:href="#linearGradient4434"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(55.750001,906.7774)" />
+    <linearGradient
+       x1="324.49731"
+       y1="70.282364"
+       x2="330.06076"
+       y2="99.273735"
+       id="linearGradient3282"
+       xlink:href="#linearGradient7444"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(55.750001,906.7774)" />
+    <linearGradient
+       x1="302.29202"
+       y1="58.442768"
+       x2="308.64914"
+       y2="60.767513"
+       id="linearGradient3284"
+       xlink:href="#linearGradient7381"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(55.750001,906.7774)" />
+    <linearGradient
+       x1="326.60196"
+       y1="75.575363"
+       x2="317.16116"
+       y2="88.006248"
+       id="linearGradient3286"
+       xlink:href="#linearGradient7421"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="340.9343"
+       y1="984.38202"
+       x2="340.9343"
+       y2="986.9292"
+       id="linearGradient2897"
+       xlink:href="#linearGradient6432"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.0742416,0,0,1.1176269,3.4610723,-124.11755)" />
+    <mask
+       id="mask2893">
+      <rect
+         width="32.495811"
+         height="37.71991"
+         x="344.80136"
+         y="958.0246"
+         id="rect2895"
+         style="fill:url(#linearGradient2897);fill-opacity:1;fill-rule:nonzero;stroke:none;visibility:visible;display:inline" />
+    </mask>
+  </defs>
+  <g
+     transform="matrix(0.02265526,0,0,0.01254292,44.15039,42.390183)"
+     id="g5022"
+     style="opacity:0.58730164;display:inline">
+    <rect
+       width="1339.6335"
+       height="478.35718"
+       x="-1559.2523"
+       y="-150.69685"
+       id="rect4173"
+       style="opacity:0.40206185;fill:url(#linearGradient5557);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+    <path
+       d="m -219.61876,-150.68038 c 0,0 0,478.33079 0,478.33079 142.874166,0.90045 345.40022,-107.16966 345.40014,-239.196175 0,-132.026537 -159.436816,-239.134595 -345.40014,-239.134615 z"
+       id="path5058"
+       style="opacity:0.40206185;fill:url(#radialGradient5559);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+    <path
+       d="m -1559.2523,-150.68038 c 0,0 0,478.33079 0,478.33079 -142.8742,0.90045 -345.4002,-107.16966 -345.4002,-239.196175 0,-132.026537 159.4368,-239.134595 345.4002,-239.134615 z"
+       id="path5018"
+       style="opacity:0.40206185;fill:url(#radialGradient5561);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+  </g>
+  <rect
+     width="42.999969"
+     height="37.999969"
+     rx="2"
+     ry="2"
+     x="2.500015"
+     y="5.5000153"
+     id="rect1887"
+     style="fill:url(#linearGradient2890);fill-opacity:1;stroke:#565853;stroke-width:1.00002992;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+  <rect
+     width="40.999966"
+     height="35.999966"
+     rx="1"
+     ry="1"
+     x="3.5000174"
+     y="6.5000172"
+     id="rect2779"
+     style="opacity:0.2;fill:none;stroke:url(#linearGradient2887);stroke-width:1.00003481;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+  <rect
+     width="40"
+     height="29"
+     rx="1.0526316"
+     ry="1.074074"
+     x="4"
+     y="13"
+     id="rect6287"
+     style="fill:url(#linearGradient2884);fill-opacity:1;stroke:none" />
+  <path
+     d="m 42,9.5 c 3.59e-4,0.828322 -0.671319,1.5 -1.5,1.5 -0.828681,0 -1.500359,-0.671678 -1.5,-1.5 -3.59e-4,-0.8283216 0.671319,-1.4999996 1.5,-1.4999996 0.828681,0 1.500359,0.671678 1.5,1.4999996 l 0,0 z"
+     id="path6289"
+     style="fill:url(#radialGradient2881);fill-opacity:1;stroke:none" />
+  <path
+     d="m 38,9.4999997 c 3.59e-4,0.8283213 -0.671319,1.4999993 -1.5,1.4999993 -0.828681,0 -1.500359,-0.671678 -1.5,-1.4999993 C 34.999641,8.671678 35.671319,8 36.5,8 37.328681,8 38.000359,8.671678 38,9.4999997 l 0,0 z"
+     id="path6291"
+     style="fill:url(#radialGradient2878);fill-opacity:1;stroke:none" />
+  <path
+     d="m 34,9.4999997 c 3.59e-4,0.8283213 -0.671319,1.4999993 -1.5,1.4999993 -0.828681,0 -1.500359,-0.671678 -1.5,-1.4999993 C 30.999641,8.671678 31.671319,8 32.5,8 33.328681,8 34.000359,8.671678 34,9.4999997 l 0,0 z"
+     id="path6293"
+     style="fill:url(#radialGradient2875);fill-opacity:1;stroke:none" />
+  <g
+     transform="matrix(1.1206258,0,0,1.1201656,-326.47085,12.52735)"
+     id="g7440-6"
+     style="opacity:0.48858445;display:inline;enable-background:new" />
+  <path
+     d="m 27.875923,23.513102 c -0.09025,0.02318 -0.155513,0.08148 -0.21875,0.156249 -0.126486,0.149504 -0.161716,0.360745 -0.0625,0.53125 l 2.65625,4.749995 c 0.238303,0.426155 0.134076,0.970676 -0.25,1.531248 -0.387715,0.565884 -1.04961,1.144109 -1.875,1.593749 -0.825555,0.449719 -1.65367,0.695439 -2.34375,0.718749 -0.686006,0.0232 -1.229845,-0.16647 -1.46875,-0.593749 l -2.65625,-4.781245 c -0.07441,-0.132659 -0.223545,-0.232387 -0.375,-0.25 -0.151443,-0.01759 -0.273968,0.04399 -0.375,0.15625 -0.05457,0.05831 -0.106337,0.141159 -0.125,0.218749 -0.513928,2.213522 -0.287301,4.756695 0.6875,6.499994 1.331264,2.380807 4.128746,3.511796 6.84375,3.031247 1.109425,0.373019 2.56827,1.205908 4.3125,2.937496 L 33.62,41.007 l 9.118,0.9 -6.018327,-5.987661 c -1.572378,-1.560969 -2.38986,-2.880847 -2.8125,-3.937496 0.366691,-1.46072 0.209126,-3.026264 -0.5625,-4.406246 -0.9744,-1.742557 -3.020618,-3.279877 -5.1875,-4.031245 -0.09297,-0.034 -0.191002,-0.05443 -0.28125,-0.03125 z"
+     id="path6912-6"
+     style="opacity:0.3;fill:none;stroke:black;stroke-width:2;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0.3612;display:inline;enable-background:new" />
+  <g
+     transform="matrix(1.1811195,0,0,1.1804503,-398.30555,-1107.9241)"
+     mask="url(#mask2893)"
+     id="g6402"
+     style="display:inline">
+    <path
+       d="m 354.90196,961.71351 c -0.0462,0.0494 -0.0794,0.10928 -0.0952,0.17501 -0.43512,1.87515 -0.22941,4.02968 0.59591,5.50649 1.12712,2.01686 3.47459,2.9792 5.77326,2.57211 0.9393,0.316 2.18526,1.01168 3.66202,2.47857 l 18.43588,18.31271 3.47323,-3.45018 -18.43587,-18.31271 c -1.33126,-1.32235 -2.02985,-2.45591 -2.38768,-3.35103 0.31046,-1.23743 0.18398,-2.55857 -0.46932,-3.7276 -0.82498,-1.47618 -2.55608,-2.78144 -4.39068,-3.41795 -0.15743,-0.0576 -0.33081,-0.0136 -0.43789,0.11308 -0.10709,0.12665 -0.1257,0.3083 -0.0417,0.45274 l 2.24619,4.0281 c 0.20176,0.36101 0.0965,0.82534 -0.22868,1.30022 -0.32826,0.47938 -0.87442,0.95837 -1.57324,1.33928 -0.69896,0.38097 -1.3978,0.58999 -1.98206,0.60974 -0.58081,0.0197 -1.03722,-0.1415 -1.23949,-0.50346 l -2.25969,-4.05046 c -0.063,-0.11238 -0.17357,-0.18604 -0.3018,-0.20096 -0.12822,-0.0149 -0.25763,0.0312 -0.34317,0.1263 l -2e-5,0 z"
+       id="path6912"
+       style="fill:url(#linearGradient3280);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient3282);stroke-width:0.84689426;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0.3612;display:inline;enable-background:new" />
+    <path
+       d="m 360.9375,958.8399 c 0.0187,0.007 0.007,0.0312 0,0.0313 l 2.25,4.03125 c 0.30353,0.54308 0.0846,1.18445 -0.28125,1.71875 -0.36949,0.53959 -0.942,1.0624 -1.6875,1.46875 -0.7471,0.40722 -1.53072,0.60279 -2.1875,0.625 -0.65534,0.0222 -1.27047,-0.16491 -1.5625,-0.6875 l -2.25,-4.0625 c -0.0129,-0.002 -0.0334,0.002 -0.0313,0 0.0206,-0.022 0.004,0.016 0,0.0313 -0.41492,1.78813 -0.19972,3.85485 0.5625,5.21875 1.04262,1.86566 3.21941,2.75675 5.375,2.375 2.14547,-0.38402 3.97996,-2.25317 4.4375,-4.03125 0.28891,-1.15158 0.16583,-2.38914 -0.4375,-3.46875 -0.76015,-1.36017 -2.43237,-2.64106 -4.1875,-3.25 l 5e-5,-1e-4 z"
+       id="path7379"
+       style="fill:url(#linearGradient3284);fill-opacity:1;fill-rule:evenodd;stroke:none;display:inline;enable-background:new" />
+    <path
+       d="m 306.3125,53.1875 1.5,2.71875 c 0.42656,0.763203 0.1338,1.581368 -0.28125,2.1875 -0.41934,0.612393 -1.04182,1.156645 -1.84375,1.59375 -0.8053,0.438942 -1.63055,0.693576 -2.375,0.71875 -0.74544,0.02522 -1.56821,-0.220734 -1.96875,-0.9375 l -1.5625,-2.8125 c -0.0666,1.318109 0.0835,2.649454 0.59375,3.5625 0.94047,1.682871 2.92363,2.507367 4.90625,2.15625 0.14514,-0.02867 0.2979,-0.01776 0.4375,0.03125 1.07459,0.361502 2.41864,1.116511 3.96875,2.65625 l 18.4375,18.3125 2.28125,-2.25 -18.4375,-18.3125 c -1.39757,-1.388206 -2.15786,-2.612796 -2.5625,-3.625 -0.061,-0.15828 -0.072,-0.335369 -0.0312,-0.5 0.26287,-1.047793 0.16792,-2.184737 -0.375,-3.15625 -0.49621,-0.887897 -1.54649,-1.701366 -2.6875,-2.34375 l -5e-5,0 z"
+       transform="translate(55.750001,906.7774)"
+       id="path6394"
+       style="fill:none;stroke:url(#linearGradient3286);stroke-width:0.59282601;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0.3612;display:inline;enable-background:new" />
+    <rect
+       width="1.9558058"
+       height="30.75498"
+       rx="0.74745291"
+       ry="1.4931343"
+       x="-428.17471"
+       y="943.14722"
+       transform="matrix(0.7071068,-0.7071068,0.7071068,0.7071068,0,0)"
+       id="rect7166"
+       style="opacity:0.07999998;fill:black;fill-opacity:1;fill-rule:evenodd;stroke:none;display:inline;enable-background:new" />
+    <g
+       transform="translate(55.750001,906.7774)"
+       id="g7440"
+       style="opacity:0.48858445;display:inline;enable-background:new" />
+  </g>
+  <g
+     transform="matrix(1.1206258,0,0,1.1201641,-390.24836,-3.560983)"
+     id="g7440-0"
+     style="opacity:0.48858445;display:inline;enable-background:new" />
+  <g
+     transform="matrix(1.1206258,0,0,1.1201641,-388.24836,-7.560983)"
+     id="g7440-03"
+     style="opacity:0.48858445;display:inline;enable-background:new" />
+  <g
+     transform="matrix(1.1811195,0,0,1.1804515,-414.25321,12.547469)"
+     id="g7440-8"
+     style="opacity:0.48858445;display:inline;enable-background:new" />
+</svg>
diff -pruN 3.4.1-6/Dbus/data/cairo-dock-launcher-API-daemon.py 3.4.1+git20201022.a0d3415c-1/Dbus/data/cairo-dock-launcher-API-daemon.py
--- 3.4.1-6/Dbus/data/cairo-dock-launcher-API-daemon.py	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Dbus/data/cairo-dock-launcher-API-daemon.py	2020-10-21 15:04:44.000000000 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 #
 # This is a part of the Cairo-Dock plug-ins.
 # Copyright : (C) 2012 by Fabrice Rey
@@ -16,17 +16,11 @@
 # http://www.gnu.org/licenses/licenses.html#GPL
 #
 
-from __future__ import print_function
 import sys
 
-try:
-	import glib
-	import gobject
-	g_bMainLoopInGObject = True
-except:
-	from gi.repository import GLib as glib
-	from gi.repository import GObject as gobject
-	g_bMainLoopInGObject = False
+from gi.repository import GLib as glib
+from gi.repository import GObject as gobject
+g_bMainLoopInGObject = False
 
 import re
 from os import popen, getpid
diff -pruN 3.4.1-6/Dbus/demos/demo_mono/demo_mono.cs 3.4.1+git20201022.a0d3415c-1/Dbus/demos/demo_mono/demo_mono.cs
--- 3.4.1-6/Dbus/demos/demo_mono/demo_mono.cs	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Dbus/demos/demo_mono/demo_mono.cs	2020-10-21 15:04:44.000000000 +0000
@@ -138,7 +138,7 @@ public class Applet : CDApplet
 	public override void on_build_menu ()
 	{
 		Console.WriteLine("*** build menu");
-		/// Warning : teh AddMenuItems fails with NDesk-DBus 0.6.0; until this is fixed, use the PopulateMenu method.
+		/// Warning : the AddMenuItems fails with DBus Sharp 0.6.0; until this is fixed, use the PopulateMenu method.
 		/**Dictionary<string, object>[] pItems = new Dictionary<string, object>[] {
 			new Dictionary<string, object>()
 			{
diff -pruN 3.4.1-6/Dbus/demos/demo_ruby/demo_ruby 3.4.1+git20201022.a0d3415c-1/Dbus/demos/demo_ruby/demo_ruby
--- 3.4.1-6/Dbus/demos/demo_ruby/demo_ruby	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Dbus/demos/demo_ruby/demo_ruby	2020-10-21 15:04:44.000000000 +0000
@@ -105,7 +105,7 @@ class Applet < CDApplet
 	end
 	def reload
 		p "[+] our module was reloaded, welcome back!"
-		self.icon.AddDataRenderer("gauge", 1, myApplet.config['theme'])
+		self.icon.AddDataRenderer("gauge", 1, self.configuration['theme'])
 		self.icon.RenderValues([Float(self.counter)/self.configuration['max_value']])
 		self.sub_icons.RemoveSubIcon("any")
 		self.sub_icons.AddSubIcons(["icon 1", "firefox-3.0", "id1", "icon 2", "natilus", "id2", "icon 3", "thunderbird", "id3"]) 
diff -pruN 3.4.1-6/Dbus/interfaces/mono/CDApplet.cs 3.4.1+git20201022.a0d3415c-1/Dbus/interfaces/mono/CDApplet.cs
--- 3.4.1-6/Dbus/interfaces/mono/CDApplet.cs	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Dbus/interfaces/mono/CDApplet.cs	2020-10-21 15:04:44.000000000 +0000
@@ -21,7 +21,7 @@
 // Make your own class derive from a CDApplet, and override the functions you need (the ones which don't start with an underscore).
 
 // Compile it with the following command, then rename 'demo_mono.exe' to 'demo_mono'.
-// gmcs /target:library CDApplet.cs ISubApplet.cs IApplet.cs -pkg:glib-sharp-2.0 -pkg:ndesk-dbus-1.0 -pkg:ndesk-dbus-glib-1.0
+// gmcs /target:library CDApplet.cs ISubApplet.cs IApplet.cs -pkg:dbus-sharp-2.0 -pkg:dbus-sharp-glib-2.0 -pkg:glib-sharp-2.0
   //////////////////////////
  ////// dependancies //////
 //////////////////////////
@@ -29,7 +29,7 @@ using System;  // Environment
 using System.IO;  // Path, Directory
 using System.Reflection;
 using GLib;
-using NDesk.DBus;
+using DBus;
 using CairoDock.Applet;
 
 //namespace CairoDock.Applet
@@ -258,8 +258,8 @@ public class CDApplet
 	
 	private void _connect_to_dock ()
 	{
-		NDesk.DBus.BusG.Init();
-		NDesk.DBus.Bus bus = NDesk.DBus.Bus.Session;
+		DBus.BusG.Init();
+		DBus.Bus bus = DBus.Bus.Session;
 		this.icon = bus.GetObject<IApplet> ("org.cairodock.CairoDock", new ObjectPath (this.cBusPath));
 		this.icon.on_click 			+= new OnClickEvent (on_click);
 		this.icon.on_middle_click 	+= new OnMiddleClickEvent (on_middle_click);
diff -pruN 3.4.1-6/Dbus/interfaces/mono/CMakeLists.txt 3.4.1+git20201022.a0d3415c-1/Dbus/interfaces/mono/CMakeLists.txt
--- 3.4.1-6/Dbus/interfaces/mono/CMakeLists.txt	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Dbus/interfaces/mono/CMakeLists.txt	2020-10-21 15:04:44.000000000 +0000
@@ -3,7 +3,7 @@
 
 execute_process(COMMAND ${GMCS_EXECUTABLE}
 	-target:library
-	-pkg:glib-sharp-2.0 -pkg:ndesk-dbus-1.0 -pkg:ndesk-dbus-glib-1.0
+	-pkg:dbus-sharp-2.0 -pkg:dbus-sharp-glib-2.0 -pkg:glib-sharp-2.0
 	-out:${CMAKE_CURRENT_BINARY_DIR}/CDApplet.dll
 	${CMAKE_CURRENT_SOURCE_DIR}/CDApplet.cs ${CMAKE_CURRENT_SOURCE_DIR}/ISubApplet.cs ${CMAKE_CURRENT_SOURCE_DIR}/IApplet.cs)
 ### find how to register to GAC ...
diff -pruN 3.4.1-6/Dbus/interfaces/mono/IApplet.cs 3.4.1+git20201022.a0d3415c-1/Dbus/interfaces/mono/IApplet.cs
--- 3.4.1-6/Dbus/interfaces/mono/IApplet.cs	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Dbus/interfaces/mono/IApplet.cs	2020-10-21 15:04:44.000000000 +0000
@@ -1,6 +1,6 @@
 using System;
 using System.Collections.Generic;  // Dictionnary
-using NDesk.DBus;
+using DBus;
 
 namespace CairoDock.Applet
 {
@@ -27,7 +27,7 @@ namespace CairoDock.Applet
 		Left
 	}
 
-	[NDesk.DBus.Interface("org.cairodock.CairoDock.applet")]
+	[DBus.Interface("org.cairodock.CairoDock.applet")]
 	public interface IApplet
 	{
 		object Get(string cProperty);
diff -pruN 3.4.1-6/Dbus/interfaces/mono/ISubApplet.cs 3.4.1+git20201022.a0d3415c-1/Dbus/interfaces/mono/ISubApplet.cs
--- 3.4.1-6/Dbus/interfaces/mono/ISubApplet.cs	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Dbus/interfaces/mono/ISubApplet.cs	2020-10-21 15:04:44.000000000 +0000
@@ -1,6 +1,6 @@
 using System;
 using System.Collections.Generic;  // Dictionnary
-using NDesk.DBus;
+using DBus;
 
 namespace CairoDock.Applet
 {
diff -pruN 3.4.1-6/Dbus/interfaces/python/CDApplet.py 3.4.1+git20201022.a0d3415c-1/Dbus/interfaces/python/CDApplet.py
--- 3.4.1-6/Dbus/interfaces/python/CDApplet.py	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Dbus/interfaces/python/CDApplet.py	2020-10-21 15:04:44.000000000 +0000
@@ -19,30 +19,23 @@
 ####################
 ### dependancies ###
 ####################
-from __future__ import print_function
 import sys
 import os.path
 
-try:
-	import glib
-	import gobject
-	g_bMainLoopInGObject = True
-except:
-	from gi.repository import GLib as glib
-	from gi.repository import GObject as gobject
-	g_bMainLoopInGObject = False
+from gi.repository import GLib as glib
+from gi.repository import GObject as gobject
+g_bMainLoopInGObject = False
 
 import gettext
 import dbus
 from dbus.mainloop.glib import DBusGMainLoop
-try:
-	import ConfigParser # python 2
-except:
-	import configparser # python 3
+import configparser
 
 # Enabling threading support (only for GLib < 2.32)
 if glib.glib_version[0] < 2 or (glib.glib_version[0] == 2 and glib.glib_version[1] < 32):
 	gobject.threads_init()
+else:
+	glib.threads_init()
 
 # enable dbus thread support
 dbus.mainloop.glib.threads_init()
diff -pruN 3.4.1-6/Dbus/misc/launcher-test.py 3.4.1+git20201022.a0d3415c-1/Dbus/misc/launcher-test.py
--- 3.4.1-6/Dbus/misc/launcher-test.py	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Dbus/misc/launcher-test.py	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,91 @@
+#!/usr/bin/env python3
+# A simple test case.
+
+from gi.repository import Unity, Gio, GObject, Dbusmenu
+
+loop = GObject.MainLoop()
+
+# Pretend to be Firefox for the sake of the example
+
+launcher = Unity.LauncherEntry.get_for_desktop_id ("firefox.desktop")
+
+# Show a count of 123 on the icon
+
+launcher.set_property("count", 123)
+
+launcher.set_property("count_visible", True)
+
+# Set progress to 40%
+
+launcher.set_property("progress", 0.40)
+
+launcher.set_property("progress_visible", True)
+
+
+#launcher.set_property("emblem", "play")
+
+#launcher.set_property("emblem_visible", True)
+
+
+# We also want a quicklist
+
+def on_item_selected(self, menuitem, index):
+	print("selected",index)
+	
+ql = Dbusmenu.Menuitem.new ()
+
+item1 = Dbusmenu.Menuitem.new ()
+
+item1.property_set (Dbusmenu.MENUITEM_PROP_LABEL, "Item 1")
+
+item1.property_set_bool (Dbusmenu.MENUITEM_PROP_VISIBLE, True)
+
+item1.connect ("item-activated", on_item_selected, 1)
+
+item2 = Dbusmenu.Menuitem.new ()
+
+item2.property_set (Dbusmenu.MENUITEM_PROP_LABEL, "Item 2")
+
+item2.property_set_bool (Dbusmenu.MENUITEM_PROP_VISIBLE, True)
+
+item2.connect ("item-activated", on_item_selected, 2)
+
+ql.child_append (item1)
+
+ql.child_append (item2)
+
+launcher.set_property("quicklist", ql)
+
+n = 3
+prev_item = item2
+
+def update_urgency():
+	global prev_item, n
+	if launcher.get_property("urgent"):
+		print("Removing urgent flag")
+		launcher.set_property("urgent", False)
+	else:
+		print("setting urgent flag")
+		launcher.set_property("urgent", True)
+
+	if prev_item == None:
+		item = Dbusmenu.Menuitem.new ()
+		
+		item.property_set (Dbusmenu.MENUITEM_PROP_LABEL, "Item "+str(n))
+		
+		item.property_set_bool (Dbusmenu.MENUITEM_PROP_VISIBLE, True)
+		
+		item.connect ("item-activated", on_item_selected, n)
+		ql.child_append (item)
+		prev_item = item
+	else:
+		ql.child_delete (prev_item)
+		prev_item = None
+		item1.property_set (Dbusmenu.MENUITEM_PROP_LABEL, "Item 1  (%d)"%n)
+		n = n+1
+	
+	return True
+
+GObject.timeout_add_seconds(4, update_urgency)
+
+loop.run()
diff -pruN 3.4.1-6/Dbus/misc/make_dbus_header.sh 3.4.1+git20201022.a0d3415c-1/Dbus/misc/make_dbus_header.sh
--- 3.4.1-6/Dbus/misc/make_dbus_header.sh	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Dbus/misc/make_dbus_header.sh	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,10 @@
+#!/bin/bash
+#Auteur : necropotame
+#Contact : adrien.pilleboue@gmail.com
+#Version : 2008-03-12
+
+dbus-binding-tool --mode=glib-server --prefix=cd_dbus_main ./src/dbus_introspectable.xml > ./src/dbus-main-spec.h
+
+dbus-binding-tool --mode=glib-server --prefix=cd_dbus_applet ./src/dbus_applet_introspectable.xml > ./src/dbus-applet-spec.h
+
+dbus-binding-tool --mode=glib-server --prefix=cd_dbus_sub_applet ./src/dbus_sub_applet_introspectable.xml > ./src/dbus-sub-applet-spec.h
diff -pruN 3.4.1-6/Dbus/src/applet-dbus.c 3.4.1+git20201022.a0d3415c-1/Dbus/src/applet-dbus.c
--- 3.4.1-6/Dbus/src/applet-dbus.c	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Dbus/src/applet-dbus.c	2020-10-21 15:04:44.000000000 +0000
@@ -35,7 +35,6 @@ dbus-send --session --dest=org.cairodock
 
 #include <fcntl.h>  // O_RDONLY
 #include <unistd.h>  // open, read, close
-#define __USE_POSIX
 #include <signal.h>  // kill
 #include <glib.h>
 #include <glib/gstdio.h>
diff -pruN 3.4.1-6/debian/cairo-dock-alsamixer-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-alsamixer-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-alsamixer-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-alsamixer-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-alsamixer-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-alsamixer-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-alsamixer-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-animated-icons-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-animated-icons-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-animated-icons-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-animated-icons-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-animated-icons-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-animated-icons-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-animated-icons-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-cairo-penguin-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-cairo-penguin-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-cairo-penguin-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-cairo-penguin-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-cairo-penguin-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-cairo-penguin-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-cairo-penguin-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-clipper-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-clipper-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-clipper-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-clipper-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-clipper-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-clipper-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-clipper-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-clock-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-clock-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-clock-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-clock-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-clock-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-clock-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-clock-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-compiz-icon-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-compiz-icon-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-compiz-icon-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-compiz-icon-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-compiz-icon-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-compiz-icon-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-compiz-icon-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-dbus-plug-in-interface-vala.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-dbus-plug-in-interface-vala.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-dbus-plug-in-interface-vala.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-dbus-plug-in-interface-vala.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,4 +1,3 @@
 cairo-dock-dbus-plug-in-interface-vala: package-name-doesnt-match-sonames libCDApplet1
 cairo-dock-dbus-plug-in-interface-vala: non-dev-pkg-with-shlib-symlink usr/lib/x86_64-linux-gnu/libCDApplet.so.1.0.0 usr/lib/*/libCDApplet.so
 cairo-dock-dbus-plug-in-interface-vala: shlib-without-versioned-soname usr/lib/*/libCDApplet.so libCDApplet.so
-cairo-dock-dbus-plug-in-interface-vala: postinst-must-call-ldconfig usr/lib/*/libCDApplet.so
diff -pruN 3.4.1-6/debian/cairo-dock-dbus-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-dbus-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-dbus-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-dbus-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-dbus-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-dbus-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-dbus-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-desklet-rendering-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-desklet-rendering-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-desklet-rendering-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-desklet-rendering-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-desklet-rendering-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-desklet-rendering-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-desklet-rendering-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-dialog-rendering-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-dialog-rendering-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-dialog-rendering-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-dialog-rendering-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-dialog-rendering-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-dialog-rendering-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-dialog-rendering-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-dnd2share-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-dnd2share-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-dnd2share-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-dnd2share-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-dnd2share-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-dnd2share-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-dnd2share-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-drop-indicator-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-drop-indicator-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-drop-indicator-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-drop-indicator-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-drop-indicator-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-drop-indicator-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-drop-indicator-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-dustbin-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-dustbin-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-dustbin-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-dustbin-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-dustbin-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-dustbin-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-dustbin-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-folders-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-folders-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-folders-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-folders-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-folders-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-folders-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-folders-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-gmenu-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-gmenu-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-gmenu-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-gmenu-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-gmenu-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-gmenu-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-gmenu-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-gnome-integration-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-gnome-integration-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-gnome-integration-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-gnome-integration-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-gnome-integration-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-gnome-integration-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-gnome-integration-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-icon-effect-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-icon-effect-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-icon-effect-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-icon-effect-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-icon-effect-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-icon-effect-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-icon-effect-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-illusion-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-illusion-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-illusion-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-illusion-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-illusion-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-illusion-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-illusion-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-impulse-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-impulse-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-impulse-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-impulse-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-impulse-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-impulse-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-impulse-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-kde-integration-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-kde-integration-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-kde-integration-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-kde-integration-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-kde-integration-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-kde-integration-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-kde-integration-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-keyboard-indicator-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-keyboard-indicator-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-keyboard-indicator-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-keyboard-indicator-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-keyboard-indicator-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-keyboard-indicator-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-keyboard-indicator-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-logout-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-logout-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-logout-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-logout-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-logout-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-logout-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-logout-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-mail-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-mail-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-mail-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-mail-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-mail-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-mail-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-mail-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-messaging-menu-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-messaging-menu-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-messaging-menu-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-messaging-menu-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-messaging-menu-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-messaging-menu-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-messaging-menu-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-motion-blur-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-motion-blur-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-motion-blur-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-motion-blur-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-motion-blur-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-motion-blur-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-motion-blur-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-musicplayer-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-musicplayer-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-musicplayer-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-musicplayer-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-musicplayer-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-musicplayer-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-musicplayer-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-netspeed-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-netspeed-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-netspeed-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-netspeed-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-netspeed-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-netspeed-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-netspeed-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-network-monitor-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-network-monitor-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-network-monitor-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-network-monitor-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-network-monitor-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-network-monitor-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-network-monitor-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-nvidia-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-nvidia-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-nvidia-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-nvidia-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-nvidia-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-nvidia-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-nvidia-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-powermanager-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-powermanager-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-powermanager-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-powermanager-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-powermanager-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-powermanager-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-powermanager-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-quick-browser-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-quick-browser-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-quick-browser-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-quick-browser-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-quick-browser-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-quick-browser-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-quick-browser-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-recent-events-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-recent-events-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-recent-events-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-recent-events-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-recent-events-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-recent-events-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-recent-events-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-remote-control-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-remote-control-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-remote-control-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-remote-control-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-remote-control-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-remote-control-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-remote-control-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-rendering-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-rendering-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-rendering-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-rendering-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-rendering-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-rendering-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-rendering-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-rssreader-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-rssreader-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-rssreader-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-rssreader-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-rssreader-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-rssreader-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-rssreader-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-scooby-do-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-scooby-do-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-scooby-do-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-scooby-do-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-scooby-do-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-scooby-do-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-scooby-do-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-shortcuts-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-shortcuts-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-shortcuts-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-shortcuts-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-shortcuts-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-shortcuts-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-shortcuts-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-showdesklets-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-showdesklets-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-showdesklets-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-showdesklets-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-showdesklets-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-showdesklets-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-showdesklets-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-showdesktop-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-showdesktop-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-showdesktop-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-showdesktop-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-showdesktop-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-showdesktop-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-showdesktop-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-showmouse-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-showmouse-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-showmouse-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-showmouse-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-showmouse-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-showmouse-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-showmouse-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-slider-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-slider-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-slider-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-slider-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-slider-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-slider-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-slider-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-stack-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-stack-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-stack-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-stack-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-stack-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-stack-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-stack-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-switcher-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-switcher-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-switcher-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-switcher-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-switcher-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-switcher-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-switcher-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-system-monitor-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-system-monitor-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-system-monitor-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-system-monitor-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-system-monitor-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-system-monitor-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-system-monitor-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-systray-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-systray-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-systray-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-systray-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-systray-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-systray-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-systray-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-terminal-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-terminal-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-terminal-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-terminal-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-terminal-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-terminal-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-terminal-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-tomboy-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-tomboy-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-tomboy-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-tomboy-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-tomboy-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-tomboy-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-tomboy-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-toons-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-toons-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-toons-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-toons-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-toons-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-toons-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-toons-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-weather-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-weather-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-weather-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-weather-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-weather-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-weather-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-weather-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-weblets-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-weblets-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-weblets-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-weblets-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-weblets-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-weblets-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-weblets-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-wifi-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-wifi-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-wifi-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-wifi-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-wifi-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-wifi-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-wifi-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-xfce-integration-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-xfce-integration-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-xfce-integration-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-xfce-integration-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-xfce-integration-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-xfce-integration-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-xfce-integration-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/cairo-dock-xgamma-plug-in.lintian-overrides 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-xgamma-plug-in.lintian-overrides
--- 3.4.1-6/debian/cairo-dock-xgamma-plug-in.lintian-overrides	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/cairo-dock-xgamma-plug-in.lintian-overrides	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1 @@
-cairo-dock-xgamma-plug-in: postinst-has-useless-call-to-ldconfig
-cairo-dock-xgamma-plug-in: postrm-has-useless-call-to-ldconfig
 cairo-dock-xgamma-plug-in: pkg-has-shlibs-control-file-but-no-actual-shared-libs
diff -pruN 3.4.1-6/debian/changelog 3.4.1+git20201022.a0d3415c-1/debian/changelog
--- 3.4.1-6/debian/changelog	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/changelog	2021-01-02 15:32:07.000000000 +0000
@@ -1,3 +1,22 @@
+cairo-dock-plug-ins (3.4.1+git20201022.a0d3415c-1) unstable; urgency=medium
+
+  * Snapshot, taken from the master (20201022). (Closes: #966901)
+  * Update d/control.
+    * Add libssl-dev to B-D.
+    * Switch from libsensors4-dev to libsensors-dev in B-D (Closes: #917433)
+    * Use libayatana-ido3-dev instead of libayatana-ido3-0.4-dev.
+      (Closes: #907375)
+    * Use libayatana-indicator3-dev instead of libindicator3-dev.
+      (Closes: #956760)
+  * Update d/*.lintian-overrides.
+    * Drop malformed-override Unknown tag.
+  * Update d/copyright
+    * Switch copyright in https mode.
+    * Fix lintian warning: source: globbing-patterns-out-of-order.
+  * Bump d/compat to 10.
+
+ -- Nobuhiro Iwamatsu <iwamatsu@debian.org>  Sun, 03 Jan 2021 00:32:07 +0900
+
 cairo-dock-plug-ins (3.4.1-6) unstable; urgency=medium
 
   * Drop python2 support of cairo-dock-plug-ins (Closes: #936263)
diff -pruN 3.4.1-6/debian/compat 3.4.1+git20201022.a0d3415c-1/debian/compat
--- 3.4.1-6/debian/compat	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/compat	2021-01-02 15:32:07.000000000 +0000
@@ -1 +1 @@
-9
+10
diff -pruN 3.4.1-6/debian/control 3.4.1+git20201022.a0d3415c-1/debian/control
--- 3.4.1-6/debian/control	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/control	2021-01-02 15:32:07.000000000 +0000
@@ -10,6 +10,7 @@ Build-Depends: cdbs, debhelper (>= 9), c
  libasound2-dev [linux-any],
  libcairo2-dev (>= 1.8.0),
  libcurl4-gnutls-dev,
+ libssl-dev,
  libdbus-glib-1-dev,
  libdbusmenu-glib-dev,
  libdbusmenu-gtk3-dev,
@@ -23,14 +24,14 @@ Build-Depends: cdbs, debhelper (>= 9), c
  libgnutls28-dev,
  libgtk-3-dev,
  libical-dev,
- libayatana-ido3-0.4-dev,
- libindicator3-dev,
+ libayatana-ido3-dev,
+ libayatana-indicator3-dev,
  libdbus-glib2.0-cil-dev [amd64 armel armhf i386 mipsel kfreebsd-any ppc64 ppc64el s390x],
  libdbus2.0-cil-dev [amd64 armel armhf i386 mipsel kfreebsd-any ppc64 ppc64el s390x],
  libpango1.0-dev,
  libpulse-dev,
  librsvg2-dev,
- libsensors4-dev,
+ libsensors-dev,
  libupower-glib-dev,
  libvte-2.91-dev,
  libxklavier-dev,
diff -pruN 3.4.1-6/debian/copyright 3.4.1+git20201022.a0d3415c-1/debian/copyright
--- 3.4.1-6/debian/copyright	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/copyright	2021-01-02 15:32:07.000000000 +0000
@@ -1,7 +1,14 @@
-Format: http://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
 Upstream-Name: cairo-dock-plugins
 Source: https://launchpad.net/cairo-dock-plug-ins
 
+Files: *
+Copyright: 2007-2011 Fabrice Rey <fabounet@glx-dock.org>
+Commnet: Icons inspired of the Humanity Icons theme and recolorized by
+         Matthieu Baerts. Copyright: Daniel Fore, Jonian Guveli and
+         K.Vishnoo Charan Reddy. under GPL-2+
+License: GPL-3+
+
 Files: systray/src/cd-tray.c
 Copyright: 2007 Neil Jagdish Patel
 License: LGPL-2+
@@ -103,43 +110,6 @@ Files:  shared-images/*.svg
 Copyright: ccsm icons
 License: GPL-3+
 
-Files:  alsaMixer/*
-    Animated-icons/*
-    Cairo-Penguin/*
-    Clipper/*
-    clock/*
-    desklet-rendering/*
-    dialog-rendering/*
-    drop-indicator/*
-    dustbin/*
-    GMenu/*
-    gnome-integration/*
-    gnome-integration-old/*
-    icon-effect/*
-    illusion/*
-    keyboard-indicator/*
-    logout/*
-    motion-blur/*
-    quick-browser/*
-    rendering/*
-    Scooby-Do/*
-    showDesklets/*
-    show-mouse/*
-    Toons/*
-    weather/*
-    Xgamma/*
-    *Menu/*
-    Folders/*
-    Indicator-applet/*
-    Status-Notifier/*
-    gvfs-integration/*
-    *
-Copyright: 2007-2011 Fabrice Rey <fabounet@glx-dock.org>
-Commnet: Icons inspired of the Humanity Icons theme and recolorized by
-         Matthieu Baerts. Copyright: Daniel Fore, Jonian Guveli and
-         K.Vishnoo Charan Reddy. under GPL-2+
-License: GPL-3+
-
 Files: debian/*
 Copyright: 2009-2012 Nobuhiro Iwamatsu <iwamatsu@debian.org>
            2009-2012 Youhei SASAKI <uwabami@gfd-dennou.org>
diff -pruN 3.4.1-6/debian/patches/0001-Fix-MATCH-as-FreeBSD.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/0001-Fix-MATCH-as-FreeBSD.patch
--- 3.4.1-6/debian/patches/0001-Fix-MATCH-as-FreeBSD.patch	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/0001-Fix-MATCH-as-FreeBSD.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,24 +0,0 @@
-From f72b680550fa3806f81233a4afff83211dc553cd Mon Sep 17 00:00:00 2001
-From: Nobuhiro Iwamatsu <iwamatsu@nigauri.org>
-Date: Fri, 5 Jul 2013 12:15:26 +0900
-Subject: [PATCH] Fix MATCH as FreeBSD
-
-When only MATCH is used, FreeBSD matches kFreeBSD.
-We need ^ in front of "FreeBSD".
-
-Signed-off-by: Nobuhiro Iwamatsu <iwamatsu@nigauri.org>
----
- Dbus/src/CMakeLists.txt |    2 +-
- 1 file changed, 1 insertion(+), 1 deletion(-)
-
---- cairo-dock-plug-ins.orig/Dbus/src/CMakeLists.txt
-+++ cairo-dock-plug-ins/Dbus/src/CMakeLists.txt
-@@ -29,7 +29,7 @@
- add_definitions (-DMY_APPLET_ICON_FILE="icon.svg")
- add_definitions (-DCD_PLUGINS_DIR="${pluginsdir}")
- 
--IF (${CMAKE_SYSTEM_NAME} MATCHES "FreeBSD")
-+IF (${CMAKE_SYSTEM_NAME} MATCHES ^"FreeBSD")
- 	set(kvm "kvm")
- endif()
- 
diff -pruN 3.4.1-6/debian/patches/0001-Fix-typo-about-SystemMonitor-Mail-dnd2share-Stack-GV.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/0001-Fix-typo-about-SystemMonitor-Mail-dnd2share-Stack-GV.patch
--- 3.4.1-6/debian/patches/0001-Fix-typo-about-SystemMonitor-Mail-dnd2share-Stack-GV.patch	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/0001-Fix-typo-about-SystemMonitor-Mail-dnd2share-Stack-GV.patch	2021-01-02 15:32:07.000000000 +0000
@@ -1,21 +1,23 @@
+From b5cde65db6c5e8e82d4463541b62934c1c4b0d0e Mon Sep 17 00:00:00 2001
 From: Youhei SASAKI <uwabami@gfd-dennou.org>
 Date: Mon, 15 Oct 2012 00:17:36 +0900
-Subject: Fix typo about SystemMonitor, Mail, dnd2share, Stack,
+Subject: [PATCH] Fix typo about SystemMonitor, Mail, dnd2share, Stack,
  GVFS-integration
 
 Signed-off-by: Youhei SASAKI <uwabami@gfd-dennou.org>
 ---
- System-Monitor/src/applet-init.c      |    2 +-
- dnd2share/src/applet-backend-custom.c |    2 +-
- gvfs-integration/cairo-dock-gio-vfs.c |    4 ++--
- mail/src/cd-mail-applet-init.c        |    2 +-
- netspeed/src/applet-init.c            |    2 +-
- stack/src/applet-stack.c              |    2 +-
- 6 files changed, 7 insertions(+), 7 deletions(-)
+ System-Monitor/src/applet-init.c      | 2 +-
+ gvfs-integration/cairo-dock-gio-vfs.c | 4 ++--
+ mail/src/cd-mail-applet-init.c        | 2 +-
+ netspeed/src/applet-init.c            | 2 +-
+ stack/src/applet-stack.c              | 2 +-
+ 5 files changed, 6 insertions(+), 6 deletions(-)
 
---- cairo-dock-plug-ins.orig/System-Monitor/src/applet-init.c
-+++ cairo-dock-plug-ins/System-Monitor/src/applet-init.c
-@@ -37,7 +37,7 @@
+diff --git a/System-Monitor/src/applet-init.c b/System-Monitor/src/applet-init.c
+index 28ec04d..ec02dfe 100755
+--- a/System-Monitor/src/applet-init.c
++++ b/System-Monitor/src/applet-init.c
+@@ -37,7 +37,7 @@ CD_APPLET_DEFINITION (N_("System Monitor"),
  	CAIRO_DOCK_CATEGORY_APPLET_SYSTEM,
  	N_("This applet shows you the CPU load, RAM usage, graphic card temperature, etc.\n"
  	"Middle click on the icon to get some valuable info.\n"
@@ -24,9 +26,11 @@ Signed-off-by: Youhei SASAKI <uwabami@gf
  	"You can instanciate this applet several times to show different values each time."),
  	"parAdOxxx_ZeRo and Fabounet")
  
---- cairo-dock-plug-ins.orig/gvfs-integration/cairo-dock-gio-vfs.c
-+++ cairo-dock-plug-ins/gvfs-integration/cairo-dock-gio-vfs.c
-@@ -52,10 +52,10 @@
+diff --git a/gvfs-integration/cairo-dock-gio-vfs.c b/gvfs-integration/cairo-dock-gio-vfs.c
+index 6256c70..07711ca 100644
+--- a/gvfs-integration/cairo-dock-gio-vfs.c
++++ b/gvfs-integration/cairo-dock-gio-vfs.c
+@@ -52,10 +52,10 @@ gboolean cairo_dock_gio_vfs_init (void)
  	if( !cairo_dock_dbus_is_enabled() ||
  	    !cairo_dock_dbus_detect_application (G_VFS_DBUS_DAEMON_NAME) )
  	{
@@ -39,9 +43,11 @@ Signed-off-by: Youhei SASAKI <uwabami@gf
  	
  	
  	if (s_hMonitorHandleTable != NULL)
---- cairo-dock-plug-ins.orig/mail/src/cd-mail-applet-init.c
-+++ cairo-dock-plug-ins/mail/src/cd-mail-applet-init.c
-@@ -35,7 +35,7 @@
+diff --git a/mail/src/cd-mail-applet-init.c b/mail/src/cd-mail-applet-init.c
+index 79a9af7..7738402 100755
+--- a/mail/src/cd-mail-applet-init.c
++++ b/mail/src/cd-mail-applet-init.c
+@@ -35,7 +35,7 @@ CD_APPLET_DEFINE_BEGIN (N_("mail"),
  	CAIRO_DOCK_CATEGORY_APPLET_INTERNET,
  	N_("This applet is very useful to warn you when you get new e-mails\n"
  	"It can check in any kind of mailbox (yahoo, gmail, etc)\n"
@@ -50,9 +56,11 @@ Signed-off-by: Youhei SASAKI <uwabami@gf
  	"Middle-click to refresh all the mailboxes."),
  	"Tofe (Christophe Chapuis) &amp; Fabounet (Fabrice Rey)")
  	CD_APPLET_DEFINE_COMMON_APPLET_INTERFACE
---- cairo-dock-plug-ins.orig/netspeed/src/applet-init.c
-+++ cairo-dock-plug-ins/netspeed/src/applet-init.c
-@@ -30,7 +30,7 @@
+diff --git a/netspeed/src/applet-init.c b/netspeed/src/applet-init.c
+index 45221e8..ba3aa6c 100755
+--- a/netspeed/src/applet-init.c
++++ b/netspeed/src/applet-init.c
+@@ -30,7 +30,7 @@ CD_APPLET_DEFINITION (N_("netspeed"),
  	2, 0, 5,
  	CAIRO_DOCK_CATEGORY_APPLET_INTERNET,
  	N_("This applet shows you the bit rate of your internet connection and some stats about it.\n"
@@ -61,9 +69,11 @@ Signed-off-by: Youhei SASAKI <uwabami@gf
  	"Middle-click to (de)activate the network (needs NetworManager)"),
  	"parAdOxxx_ZeRo");
  
---- cairo-dock-plug-ins.orig/stack/src/applet-stack.c
-+++ cairo-dock-plug-ins/stack/src/applet-stack.c
-@@ -385,7 +385,7 @@
+diff --git a/stack/src/applet-stack.c b/stack/src/applet-stack.c
+index c7582af..a45a818 100755
+--- a/stack/src/applet-stack.c
++++ b/stack/src/applet-stack.c
+@@ -385,7 +385,7 @@ static Icon *_cd_stack_create_new_item (GldiModuleInstance *myApplet, const gcha
  		{
  			g_key_file_free (pKeyFile);
  			g_free (cURI);
@@ -72,3 +82,6 @@ Signed-off-by: Youhei SASAKI <uwabami@gf
  			return NULL;
  		}
  		g_key_file_set_string (pKeyFile, "Desktop Entry", "Content", cURI);
+-- 
+2.30.0.rc2
+
diff -pruN 3.4.1-6/debian/patches/0002-Fix-MATCH-as-FreeBSD.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/0002-Fix-MATCH-as-FreeBSD.patch
--- 3.4.1-6/debian/patches/0002-Fix-MATCH-as-FreeBSD.patch	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/0002-Fix-MATCH-as-FreeBSD.patch	2021-01-02 15:32:07.000000000 +0000
@@ -0,0 +1,29 @@
+From 7cefc6cc27333d098a9d112ef962f01b826edbc6 Mon Sep 17 00:00:00 2001
+From: Nobuhiro Iwamatsu <iwamatsu@nigauri.org>
+Date: Fri, 5 Jul 2013 12:15:26 +0900
+Subject: [PATCH] Fix MATCH as FreeBSD
+
+When only MATCH is used, FreeBSD matches kFreeBSD.
+We need ^ in front of "FreeBSD".
+
+Signed-off-by: Nobuhiro Iwamatsu <iwamatsu@nigauri.org>
+---
+ Dbus/src/CMakeLists.txt | 2 +-
+ 1 file changed, 1 insertion(+), 1 deletion(-)
+
+diff --git a/Dbus/src/CMakeLists.txt b/Dbus/src/CMakeLists.txt
+index 10d5232..4909067 100644
+--- a/Dbus/src/CMakeLists.txt
++++ b/Dbus/src/CMakeLists.txt
+@@ -29,7 +29,7 @@ add_definitions (-DMY_APPLET_DOCK_VERSION="${dock_version}")
+ add_definitions (-DMY_APPLET_ICON_FILE="icon.svg")
+ add_definitions (-DCD_PLUGINS_DIR="${pluginsdir}")
+ 
+-IF (${CMAKE_SYSTEM_NAME} MATCHES "FreeBSD")
++IF (${CMAKE_SYSTEM_NAME} MATCHES ^"FreeBSD")
+ 	set(kvm "kvm")
+ endif()
+ 
+-- 
+2.30.0.rc2
+
diff -pruN 3.4.1-6/debian/patches/0003-Change-ruby-dir-to-vendor.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/0003-Change-ruby-dir-to-vendor.patch
--- 3.4.1-6/debian/patches/0003-Change-ruby-dir-to-vendor.patch	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/0003-Change-ruby-dir-to-vendor.patch	2021-01-02 15:32:07.000000000 +0000
@@ -0,0 +1,37 @@
+From 7e2c10d3a39f5347e0f0f41adb29116bfb61ed66 Mon Sep 17 00:00:00 2001
+From: Nobuhiro Iwamatsu <iwamatsu@debian.org>
+Date: Sat, 2 Jan 2021 21:48:45 +0900
+Subject: [PATCH] Change ruby dir to vendor
+
+Signed-off-by: Nobuhiro Iwamatsu <iwamatsu@debian.org>
+---
+ CMakeLists.txt | 6 +-----
+ 1 file changed, 1 insertion(+), 5 deletions(-)
+
+diff --git a/CMakeLists.txt b/CMakeLists.txt
+index 5f5db1b..5c2c90b 100644
+--- a/CMakeLists.txt
++++ b/CMakeLists.txt
+@@ -545,7 +545,7 @@ if (enable-ruby-interface)
+ 	message (STATUS " * Ruby:")
+ 	# find_package(Ruby) found libs of ruby-dev but we only need a directory where we can install ruby libs.
+ 	find_program (RUBY_EXECUTABLE ruby)
+-	EXECUTE_PROCESS(COMMAND ${RUBY_EXECUTABLE} -r rbconfig -e "print RbConfig::CONFIG['rubylibdir']"
++	EXECUTE_PROCESS(COMMAND ${RUBY_EXECUTABLE} -r rbconfig -e "print RbConfig::CONFIG['vendordir']"
+ 		OUTPUT_VARIABLE RUBY_LIB_DIR)
+ 	message (STATUS "   Ruby library dir: ${RUBY_LIB_DIR}")
+ 	if ("${RUBY_LIB_DIR}" STREQUAL "" OR "${RUBY_LIB_DIR}" STREQUAL "nil")
+@@ -554,10 +554,6 @@ if (enable-ruby-interface)
+ 		set (PROGRAMS_MISSING "${PROGRAMS_MISSING} ruby")
+ 		set (with_ruby no)
+ 	else()
+-		# /usr/lib/ruby/1.8 or /usr/lib/ruby/1.9.1
+-		string (REGEX REPLACE "lib/ruby/[0-9].[0-9]?.+" "" RUBY_LIB_DIR_INSTALL "${RUBY_LIB_DIR}")
+-		string (REGEX REPLACE "${RUBY_LIB_DIR_INSTALL}" "" RUBY_LIB_DIR_INSTALL "${RUBY_LIB_DIR}")
+-		set (RUBY_LIB_DIR "${CMAKE_INSTALL_PREFIX}/${RUBY_LIB_DIR_INSTALL}")
+ 		message (STATUS "   will be installed in: ${RUBY_LIB_DIR}")
+ 		set (RUBY_FOUND "TRUE")
+ 		set (with_ruby yes)
+-- 
+2.30.0.rc2
+
diff -pruN 3.4.1-6/debian/patches/0004-Add-CMake-check-for-vte-2.91-and-fix-VTE_CHECK_VERSI.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/0004-Add-CMake-check-for-vte-2.91-and-fix-VTE_CHECK_VERSI.patch
--- 3.4.1-6/debian/patches/0004-Add-CMake-check-for-vte-2.91-and-fix-VTE_CHECK_VERSI.patch	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/0004-Add-CMake-check-for-vte-2.91-and-fix-VTE_CHECK_VERSI.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,77 +0,0 @@
-From: Maxime Gauduin <alucryd@gmail.com>
-Date: Mon, 20 Oct 2014 11:41:17 +0200
-Subject: Add CMake check for vte-2.91 and fix VTE_CHECK_VERSION number
-
----
- CMakeLists.txt                 |  6 +++++-
- terminal/src/terminal-widget.c | 10 +++++-----
- 2 files changed, 10 insertions(+), 6 deletions(-)
-
-diff --git a/CMakeLists.txt b/CMakeLists.txt
-index 83bb3ec..5adb278 100644
---- a/CMakeLists.txt
-+++ b/CMakeLists.txt
-@@ -1341,9 +1341,13 @@ add_subdirectory (systray)
- message (STATUS "> Terminal:")
- enable_if_not_defined (enable-terminal)
- if (enable-terminal)
--	set (TERMINAL_MODULE vte-2.90)
-+	set (TERMINAL_MODULE vte-2.91)
- 	pkg_check_modules (VTE ${TERMINAL_MODULE})
- 	if (NOT VTE_FOUND)
-+		set (TERMINAL_MODULE vte-2.90)
-+		pkg_check_modules (VTE ${TERMINAL_MODULE})
-+	endif()
-+	if (NOT VTE_FOUND)
- 		message (STATUS "Could not find ${TERMINAL_MODULE}; Cairo-Dock won't be built with terminal applet.")
- 		message (WARNING "This module is required to compile Terminal applet: ${TERMINAL_MODULE}")
- 		set (MODULES_MISSING "${MODULES_MISSING} ${TERMINAL_MODULE}")
-diff --git a/terminal/src/terminal-widget.c b/terminal/src/terminal-widget.c
-index c3f29aa..b8f6fe9 100755
---- a/terminal/src/terminal-widget.c
-+++ b/terminal/src/terminal-widget.c
-@@ -263,7 +263,7 @@ static void _term_apply_settings_on_vterm(GtkWidget *vterm)
- {
- 	g_return_if_fail (vterm != NULL);
- 
--	#if VTE_CHECK_VERSION(2,91,0)
-+	#if VTE_CHECK_VERSION(0,38,0)
- 	vte_terminal_set_colors (VTE_TERMINAL(vterm), &myConfig.forecolor.rgba, &myConfig.backcolor.rgba, NULL, 0);
- 	#else
- 	vte_terminal_set_colors_rgba (VTE_TERMINAL(vterm), &myConfig.forecolor.rgba, &myConfig.backcolor.rgba, NULL, 0);
-@@ -271,7 +271,7 @@ static void _term_apply_settings_on_vterm(GtkWidget *vterm)
- 
- 	if (myConfig.bCustomFont)
- 	{
--		#if VTE_CHECK_VERSION(2,91,0)
-+		#if VTE_CHECK_VERSION(0,38,0)
- 		PangoFontDescription *fd = pango_font_description_from_string(myConfig.cCustomFont);
- 		vte_terminal_set_font (VTE_TERMINAL (vterm), fd);
- 		#else
-@@ -325,7 +325,7 @@ static void _create_terminal (GtkWidget *vterm)
- 	#if (GLIB_MAJOR_VERSION > 2) || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION >= 18)  // VTE_CHECK_VERSION doesn't exist in Hardy.
- 		#if VTE_CHECK_VERSION(0,26,0)
- 		const gchar *argv[] = {g_getenv ("SHELL"), NULL};
--		#if VTE_CHECK_VERSION(2,91,0)
-+		#if VTE_CHECK_VERSION(0,38,0)
- 		vte_terminal_spawn_sync (
- 		#else
- 		vte_terminal_fork_command_full (
-@@ -339,7 +339,7 @@ static void _create_terminal (GtkWidget *vterm)
- 			NULL,  // GSpawnChildSetupFunc child_setup
- 			NULL,  // gpointer child_setup_data
- 			&pid,
--			#if VTE_CHECK_VERSION(2,91,0)
-+			#if VTE_CHECK_VERSION(0,38,0)
- 			NULL, // cancellable
- 			#endif
- 			NULL);
-@@ -565,7 +565,7 @@ void terminal_new_tab(void)
- 	//\_________________ On cree un nouveau terminal.
- 	GtkWidget *vterm = vte_terminal_new();
- 	GTK_WIDGET_GET_CLASS (vterm)->get_accessible = _get_dummy_accessible;  // this is to prevent a bug in libvet2.90; it gives a warning, but it's better than a crash !
--	#if ! VTE_CHECK_VERSION(2,91,0)
-+	#if ! VTE_CHECK_VERSION(0,38,0)
- 	vte_terminal_set_emulation (VTE_TERMINAL(vterm), "xterm");
- 	#endif
- 
diff -pruN 3.4.1-6/debian/patches/0004-Use-correct-C-compiler.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/0004-Use-correct-C-compiler.patch
--- 3.4.1-6/debian/patches/0004-Use-correct-C-compiler.patch	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/0004-Use-correct-C-compiler.patch	2021-01-02 15:32:07.000000000 +0000
@@ -0,0 +1,29 @@
+From e5fd204b3cf7fef03d07c55f1f46637b23d08172 Mon Sep 17 00:00:00 2001
+From: Nobuhiro Iwamatsu <iwamatsu@debian.org>
+Date: Sat, 2 Jan 2021 21:52:57 +0900
+Subject: [PATCH] Use correct C# compiler
+
+Signed-off-by: Nobuhiro Iwamatsu <iwamatsu@debian.org>
+---
+ CMakeLists.txt | 4 ++--
+ 1 file changed, 2 insertions(+), 2 deletions(-)
+
+diff --git a/CMakeLists.txt b/CMakeLists.txt
+index 5c2c90b..3699bb8 100644
+--- a/CMakeLists.txt
++++ b/CMakeLists.txt
+@@ -565,9 +565,9 @@ enable_if_not_defined (enable-mono-interface)
+ if (enable-mono-interface)
+ 	message (STATUS " * Mono:")
+ 	#find_package (Mono)
+-	find_program (GMCS_EXECUTABLE gmcs)
++	find_program (GMCS_EXECUTABLE mcs)
+ 	if (NOT GMCS_EXECUTABLE OR NOT EXISTS ${GMCS_EXECUTABLE})
+-		message (STATUS "Could not find Mono compiler gmcs, won't build Mono interface.")
++		message (STATUS "Could not find Mono compiler mcs, won't build Mono interface.")
+ 	else()
+ 		pkg_check_modules (MONO_PACKAGE dbus-sharp-2.0 dbus-sharp-glib-2.0 glib-sharp-2.0)
+ 		if (NOT MONO_PACKAGE_FOUND)
+-- 
+2.30.0.rc2
+
diff -pruN 3.4.1-6/debian/patches/0005-Drop-python2-support.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/0005-Drop-python2-support.patch
--- 3.4.1-6/debian/patches/0005-Drop-python2-support.patch	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/0005-Drop-python2-support.patch	2021-01-02 15:32:07.000000000 +0000
@@ -0,0 +1,58 @@
+From 175c0cc695624e8557c276753f8e0a9112f7d5a6 Mon Sep 17 00:00:00 2001
+From: Nobuhiro Iwamatsu <iwamatsu@debian.org>
+Date: Sat, 2 Jan 2021 21:56:58 +0900
+Subject: [PATCH] Drop python2 support
+
+Signed-off-by: Nobuhiro Iwamatsu <iwamatsu@debian.org>
+---
+ CMakeLists.txt | 15 +++------------
+ 1 file changed, 3 insertions(+), 12 deletions(-)
+
+diff --git a/CMakeLists.txt b/CMakeLists.txt
+index 3699bb8..e69a19e 100644
+--- a/CMakeLists.txt
++++ b/CMakeLists.txt
+@@ -495,17 +495,12 @@ enable_if_not_defined (enable-python-interface)
+ if (enable-python-interface)
+ 	message (STATUS " * Python:")
+ 	# find python executables
+-	find_program (PYTHON2_EXECUTABLE python2)  # if both python2&3 are installed, usually we will have 'python2' and 'python3' available (one of them being a link to 'python')
+-	if (PYTHON2_EXECUTABLE AND EXISTS ${PYTHON2_EXECUTABLE})
+-		set (PYTHON2_FOUND TRUE)
+-		set (with_python2 yes)
+-	endif()
+ 	find_program (PYTHON3_EXECUTABLE python3)
+ 	if (PYTHON3_EXECUTABLE AND EXISTS ${PYTHON3_EXECUTABLE})
+ 		set (PYTHON3_FOUND TRUE)
+ 		set (with_python3 yes)
+ 	endif()
+-	if (NOT PYTHON2_FOUND OR NOT PYTHON3_FOUND)  # if we didn't find one of them, 
++	if (NOT PYTHON3_FOUND)  # if we didn't find one of them, 
+ 		find_program (PYTHON_EXECUTABLE python)
+ 		if (PYTHON_EXECUTABLE AND EXISTS ${PYTHON_EXECUTABLE})
+ 			EXECUTE_PROCESS(COMMAND ${PYTHON_EXECUTABLE} -c
+@@ -513,11 +508,7 @@ if (enable-python-interface)
+ 				OUTPUT_VARIABLE PYTHON_VERSION)
+ 			STRING (REGEX REPLACE "\\..*" "" PYTHON_VERSION ${PYTHON_VERSION})
+ 			message (STATUS "   Python Version: ${PYTHON_VERSION}")
+-			if ("${PYTHON_VERSION}" STREQUAL "2")
+-				set (PYTHON2_EXECUTABLE ${PYTHON_EXECUTABLE})
+-				set (PYTHON2_FOUND TRUE)
+-				set (with_python2 yes)
+-			elseif ("${PYTHON_VERSION}" STREQUAL "3")
++			if ("${PYTHON_VERSION}" STREQUAL "3")
+ 				set (PYTHON3_EXECUTABLE ${PYTHON_EXECUTABLE})
+ 				set (PYTHON3_FOUND TRUE)
+ 				set (with_python3 yes)
+@@ -526,7 +517,7 @@ if (enable-python-interface)
+ 	endif()
+ 	
+ 	# see if we found anything
+-	if (NOT PYTHON2_FOUND AND NOT PYTHON3_FOUND)
++	if (NOT PYTHON3_FOUND)
+ 		message (STATUS "Could not find Python, won't install Python interface.")
+ 		message (WARNING "This program is required to compile DBus applet with Python interface: python (version 2)")
+ 		set (PROGRAMS_MISSING "${PROGRAMS_MISSING} python")
+-- 
+2.30.0.rc2
+
diff -pruN 3.4.1-6/debian/patches/0005-Use-dbus-sharp-not-unmaintained-NDesk.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/0005-Use-dbus-sharp-not-unmaintained-NDesk.patch
--- 3.4.1-6/debian/patches/0005-Use-dbus-sharp-not-unmaintained-NDesk.patch	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/0005-Use-dbus-sharp-not-unmaintained-NDesk.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,90 +0,0 @@
-Index: cairo-dock-plug-ins-3.4.0/CMakeLists.txt
-===================================================================
---- cairo-dock-plug-ins-3.4.0.orig/CMakeLists.txt
-+++ cairo-dock-plug-ins-3.4.0/CMakeLists.txt
-@@ -569,11 +569,11 @@ if (enable-mono-interface)
- 	if (NOT GMCS_EXECUTABLE OR NOT EXISTS ${GMCS_EXECUTABLE})
- 		message (STATUS "Could not find Mono compiler gmcs, won't build Mono interface.")
- 	else()
--		pkg_check_modules (MONO_PACKAGE glib-sharp-2.0 ndesk-dbus-1.0 ndesk-dbus-glib-1.0)
-+		pkg_check_modules (MONO_PACKAGE glib-sharp-2.0 dbus-sharp-2.0 dbus-sharp-glib-2.0)
- 		if (NOT MONO_PACKAGE_FOUND)
--			message (STATUS "Could not find glib-sharp-2.0, ndesk-dbus-1.0 or ndesk-dbus-glib-1.0; won't be built Mono interface.")
--			message (WARNING "These modules are required to compile DBus applet with Mono interface: glib-sharp-2.0, ndesk-dbus-1.0 and ndesk-dbus-glib-1.0")
--			set (MODULES_MISSING "${MODULES_MISSING} glib-sharp-2.0 ndesk-dbus-1.0 ndesk-dbus-glib-1.0")
-+			message (STATUS "Could not find glib-sharp-2.0, dbus-sharp-2.0 or dbus-sharp-glib-2.0; won't be built Mono interface.")
-+			message (WARNING "These modules are required to compile DBus applet with Mono interface: glib-sharp-2.0, dbus-sharp-2.0 and dbus-sharp-glib-2.0")
-+			set (MODULES_MISSING "${MODULES_MISSING} glib-sharp-2.0 dbus-sharp-2.0 dbus-sharp-glib-2.0")
- 		else()
- 			set (MONO_FOUND TRUE)
- 			set (with_mono yes)
-Index: cairo-dock-plug-ins-3.4.0/Dbus/interfaces/mono/CDApplet.cs
-===================================================================
---- cairo-dock-plug-ins-3.4.0.orig/Dbus/interfaces/mono/CDApplet.cs
-+++ cairo-dock-plug-ins-3.4.0/Dbus/interfaces/mono/CDApplet.cs
-@@ -29,7 +29,7 @@ using System;  // Environment
- using System.IO;  // Path, Directory
- using System.Reflection;
- using GLib;
--using NDesk.DBus;
-+using DBus;
- using CairoDock.Applet;
- 
- //namespace CairoDock.Applet
-@@ -258,8 +258,8 @@ public class CDApplet
- 	
- 	private void _connect_to_dock ()
- 	{
--		NDesk.DBus.BusG.Init();
--		NDesk.DBus.Bus bus = NDesk.DBus.Bus.Session;
-+		DBus.BusG.Init();
-+		DBus.Bus bus = DBus.Bus.Session;
- 		this.icon = bus.GetObject<IApplet> ("org.cairodock.CairoDock", new ObjectPath (this.cBusPath));
- 		this.icon.on_click 			+= new OnClickEvent (on_click);
- 		this.icon.on_middle_click 	+= new OnMiddleClickEvent (on_middle_click);
-Index: cairo-dock-plug-ins-3.4.0/Dbus/interfaces/mono/IApplet.cs
-===================================================================
---- cairo-dock-plug-ins-3.4.0.orig/Dbus/interfaces/mono/IApplet.cs
-+++ cairo-dock-plug-ins-3.4.0/Dbus/interfaces/mono/IApplet.cs
-@@ -1,6 +1,6 @@
- using System;
- using System.Collections.Generic;  // Dictionnary
--using NDesk.DBus;
-+using DBus;
- 
- namespace CairoDock.Applet
- {
-@@ -27,7 +27,7 @@ namespace CairoDock.Applet
- 		Left
- 	}
- 
--	[NDesk.DBus.Interface("org.cairodock.CairoDock.applet")]
-+	[DBus.Interface("org.cairodock.CairoDock.applet")]
- 	public interface IApplet
- 	{
- 		object Get(string cProperty);
-Index: cairo-dock-plug-ins-3.4.0/Dbus/interfaces/mono/ISubApplet.cs
-===================================================================
---- cairo-dock-plug-ins-3.4.0.orig/Dbus/interfaces/mono/ISubApplet.cs
-+++ cairo-dock-plug-ins-3.4.0/Dbus/interfaces/mono/ISubApplet.cs
-@@ -1,6 +1,6 @@
- using System;
- using System.Collections.Generic;  // Dictionnary
--using NDesk.DBus;
-+using DBus;
- 
- namespace CairoDock.Applet
- {
-Index: cairo-dock-plug-ins-3.4.0/Dbus/interfaces/mono/CMakeLists.txt
-===================================================================
---- cairo-dock-plug-ins-3.4.0.orig/Dbus/interfaces/mono/CMakeLists.txt
-+++ cairo-dock-plug-ins-3.4.0/Dbus/interfaces/mono/CMakeLists.txt
-@@ -3,7 +3,7 @@
- 
- execute_process(COMMAND ${GMCS_EXECUTABLE}
- 	-target:library
--	-pkg:glib-sharp-2.0 -pkg:ndesk-dbus-1.0 -pkg:ndesk-dbus-glib-1.0
-+	-pkg:glib-sharp-2.0 -pkg:dbus-sharp-2.0 -pkg:dbus-sharp-glib-2.0
- 	-out:${CMAKE_CURRENT_BINARY_DIR}/CDApplet.dll
- 	${CMAKE_CURRENT_SOURCE_DIR}/CDApplet.cs ${CMAKE_CURRENT_SOURCE_DIR}/ISubApplet.cs ${CMAKE_CURRENT_SOURCE_DIR}/IApplet.cs)
- ### find how to register to GAC ...
diff -pruN 3.4.1-6/debian/patches/0006-Fix-support-libetpan-pkgconfig.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/0006-Fix-support-libetpan-pkgconfig.patch
--- 3.4.1-6/debian/patches/0006-Fix-support-libetpan-pkgconfig.patch	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/0006-Fix-support-libetpan-pkgconfig.patch	2021-01-02 15:32:07.000000000 +0000
@@ -0,0 +1,37 @@
+From a3adf34bd20f4bea534fcc1fd03fabada1dbd469 Mon Sep 17 00:00:00 2001
+From: Nobuhiro Iwamatsu <iwamatsu@debian.org>
+Date: Sat, 2 Jan 2021 21:58:06 +0900
+Subject: [PATCH] Fix support libetpan pkgconfig
+
+Signed-off-by: Nobuhiro Iwamatsu <iwamatsu@debian.org>
+---
+ CMakeLists.txt | 5 ++---
+ 1 file changed, 2 insertions(+), 3 deletions(-)
+
+diff --git a/CMakeLists.txt b/CMakeLists.txt
+index e69a19e..139f7a4 100644
+--- a/CMakeLists.txt
++++ b/CMakeLists.txt
+@@ -965,9 +965,8 @@ set (with_mail no)
+ # find the compilation flags
+ enable_if_not_defined (enable-mail)
+ if (enable-mail)
+-	find_program (LIBETPAN_CONFIG_EXECUTABLE libetpan-config)
+ 	execute_process(
+-		COMMAND ${LIBETPAN_CONFIG_EXECUTABLE} --cflags
++		COMMAND pkg-config libetpan --cflags
+ 		OUTPUT_VARIABLE MAIL_PACKAGE_CFLAGS)
+ 	if (NOT "${MAIL_PACKAGE_CFLAGS}" STREQUAL "" AND NOT "${MAIL_PACKAGE_CFLAGS}" STREQUAL "\n") # if there is a problem with the previous, we don't want to have a lot of errors
+ 		STRING (REGEX REPLACE "\n" "" TMP_VARIABLE "${MAIL_PACKAGE_CFLAGS}") # to not skip the last option
+@@ -980,7 +979,7 @@ if (enable-mail)
+ 	endif()
+ 	# find the link flags
+ 	execute_process(
+-		COMMAND ${LIBETPAN_CONFIG_EXECUTABLE} --libs
++		COMMAND pkg-config libetpan --libs
+ 		OUTPUT_VARIABLE MAIL_PACKAGE_LIBS)
+ 	if (NOT "${MAIL_PACKAGE_LIBS}" STREQUAL "")
+ 		STRING (REGEX REPLACE "\n" "" MAIL_PACKAGE_LIBS "${MAIL_PACKAGE_LIBS}")
+-- 
+2.30.0.rc2
+
diff -pruN 3.4.1-6/debian/patches/0007-Change-version-to-3.4.1-in-CMakeLists.txt.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/0007-Change-version-to-3.4.1-in-CMakeLists.txt.patch
--- 3.4.1-6/debian/patches/0007-Change-version-to-3.4.1-in-CMakeLists.txt.patch	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/0007-Change-version-to-3.4.1-in-CMakeLists.txt.patch	2021-01-02 15:32:07.000000000 +0000
@@ -0,0 +1,26 @@
+From cbb4bf65fa689415f5b7346f3a69ec5e0d796d6a Mon Sep 17 00:00:00 2001
+From: Nobuhiro Iwamatsu <iwamatsu@debian.org>
+Date: Sat, 2 Jan 2021 22:23:50 +0900
+Subject: [PATCH] Change version to 3.4.1 in CMakeLists.txt
+
+Signed-off-by: Nobuhiro Iwamatsu <iwamatsu@debian.org>
+---
+ CMakeLists.txt | 2 +-
+ 1 file changed, 1 insertion(+), 1 deletion(-)
+
+diff --git a/CMakeLists.txt b/CMakeLists.txt
+index 5f5db1b..b3a3a23 100644
+--- a/CMakeLists.txt
++++ b/CMakeLists.txt
+@@ -11,7 +11,7 @@ include ("${CMAKE_CURRENT_SOURCE_DIR}/cmake_modules/GNUInstallDirs.cmake")
+ ########### project ###############
+ 
+ project ("cairo-dock-plugins")
+-set (VERSION "3.4.99.alpha1")
++set (VERSION "3.4.1")
+ 
+ add_definitions (-std=gnu99 -Wall -Werror-implicit-function-declaration) # -Wextra -Wwrite-strings -Wuninitialized -Werror-implicit-function-declaration -Wstrict-prototypes -Wreturn-type -Wparentheses -Warray-bounds)
+ if (NOT DEFINED CMAKE_BUILD_TYPE)
+-- 
+2.30.0.rc2
+
diff -pruN 3.4.1-6/debian/patches/0008-weather-Use-unsigned-int.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/0008-weather-Use-unsigned-int.patch
--- 3.4.1-6/debian/patches/0008-weather-Use-unsigned-int.patch	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/0008-weather-Use-unsigned-int.patch	2021-01-02 15:32:07.000000000 +0000
@@ -0,0 +1,26 @@
+From 1c48cff70d534e8ef416a876cc382ebe0f60920c Mon Sep 17 00:00:00 2001
+From: Nobuhiro Iwamatsu <iwamatsu@debian.org>
+Date: Sat, 2 Jan 2021 23:37:44 +0900
+Subject: [PATCH] weather: Use unsigned int
+
+Signed-off-by: Nobuhiro Iwamatsu <iwamatsu@debian.org>
+---
+ weather/src/applet-read-data.c | 2 +-
+ 1 file changed, 1 insertion(+), 1 deletion(-)
+
+diff --git a/weather/src/applet-read-data.c b/weather/src/applet-read-data.c
+index 2fb828d..8621da3 100755
+--- a/weather/src/applet-read-data.c
++++ b/weather/src/applet-read-data.c
+@@ -359,7 +359,7 @@ static guchar *_hmac_sha1_base64(const gchar *key, const gchar *data)
+ 	size_t key_len = strlen(++key);
+ 	size_t data_len = strlen(data);
+ 	uint8_t md[64];  // SHA1_Message_Block_Size = 64 bytes
+-	uint md_len=64;
++	unsigned int md_len=64;
+ 	if (!HMAC(EVP_sha1(), key, key_len, (guchar*)data, data_len, md, &md_len))  // data is URL-encoded, so is actually a guchar*
+ 	{
+ 		//#include <openssl/err.h>
+-- 
+2.30.0.rc2
+
diff -pruN 3.4.1-6/debian/patches/0009-Swith-use-libido3-0.1-to-libayatana-ido3-0.4.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/0009-Swith-use-libido3-0.1-to-libayatana-ido3-0.4.patch
--- 3.4.1-6/debian/patches/0009-Swith-use-libido3-0.1-to-libayatana-ido3-0.4.patch	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/0009-Swith-use-libido3-0.1-to-libayatana-ido3-0.4.patch	2021-01-02 15:32:07.000000000 +0000
@@ -0,0 +1,26 @@
+From 97f4b3baeed5e821f599f60c18ed1d23bbeb964c Mon Sep 17 00:00:00 2001
+From: Nobuhiro Iwamatsu <iwamatsu@debian.org>
+Date: Sun, 3 Jan 2021 01:07:32 +0900
+Subject: [PATCH] Swith use libido3-0.1 to libayatana-ido3-0.4
+
+Signed-off-by: Nobuhiro Iwamatsu <iwamatsu@debian.org>
+---
+ CMakeLists.txt | 2 +-
+ 1 file changed, 1 insertion(+), 1 deletion(-)
+
+diff --git a/CMakeLists.txt b/CMakeLists.txt
+index 5f5db1b..08e0d9e 100644
+--- a/CMakeLists.txt
++++ b/CMakeLists.txt
+@@ -210,7 +210,7 @@ endif()
+ ## libido
+ enable_if_not_defined (enable-libido-support)
+ if (enable-libido-support)
+-	set (IDO_MODULE libido3-0.1)
++	set (IDO_MODULE libayatana-ido3-0.4)
+ 	pkg_check_modules (IDO ${IDO_MODULE})
+ 	if (IDO_FOUND)
+ 		STRING (REGEX REPLACE "\\..*" "" IDO_MAJOR "${IDO_VERSION}")
+-- 
+2.30.0.rc2
+
diff -pruN 3.4.1-6/debian/patches/0010-Change-pkg-config-from-indicator3-0.4-to-ayatana-ind.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/0010-Change-pkg-config-from-indicator3-0.4-to-ayatana-ind.patch
--- 3.4.1-6/debian/patches/0010-Change-pkg-config-from-indicator3-0.4-to-ayatana-ind.patch	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/0010-Change-pkg-config-from-indicator3-0.4-to-ayatana-ind.patch	2021-01-02 15:32:07.000000000 +0000
@@ -0,0 +1,85 @@
+From 8e9b69c228433d224c8d601d6e4e77934944d7a3 Mon Sep 17 00:00:00 2001
+From: Nobuhiro Iwamatsu <iwamatsu@debian.org>
+Date: Sun, 3 Jan 2021 01:22:12 +0900
+Subject: [PATCH] Change pkg-config from indicator3-0.4 to
+ ayatana-indicator3-0.4
+
+Signed-off-by: Nobuhiro Iwamatsu <iwamatsu@debian.org>
+---
+ CMakeLists.txt                              | 6 +++---
+ Indicator-applet/indicator-applet.h         | 4 ++--
+ Indicator-applet3/indicator-applet3-utils.h | 2 +-
+ Indicator-applet3/indicator-applet3.h       | 2 +-
+ 4 files changed, 7 insertions(+), 7 deletions(-)
+
+diff --git a/CMakeLists.txt b/CMakeLists.txt
+index 5f5db1b..55ee45b 100644
+--- a/CMakeLists.txt
++++ b/CMakeLists.txt
+@@ -197,7 +197,7 @@ endif()
+ ## Indicator
+ enable_if_not_defined (enable-indicator-support)
+ if (enable-indicator-support)
+-	set (INDICATOR_APPLET_MODULE indicator3-0.4)
++	set (INDICATOR_APPLET_MODULE ayatana-indicator3-0.4)
+ 	pkg_check_modules (INDICATOR_APPLET ${INDICATOR_APPLET_MODULE})
+ 	if (INDICATOR_APPLET_FOUND)
+ 		set (INDICATOR_NEW_VERSION TRUE)  # oneiric and newer
+@@ -264,10 +264,10 @@ if (INDICATOR_APPLET_FOUND)
+ 
+ 	if (INDICATOR_NEW_VERSION)  # oneiric and newer
+ 		execute_process(
+-			COMMAND pkg-config --variable=iconsdir indicator3-0.4
++			COMMAND pkg-config --variable=iconsdir ayatana-indicator3-0.4
+ 			OUTPUT_VARIABLE INDICATORICONSDIR)
+ 		execute_process(
+-			COMMAND pkg-config --variable=indicatordir indicator3-0.4
++			COMMAND pkg-config --variable=indicatordir ayatana-indicator3-0.4
+ 			OUTPUT_VARIABLE INDICATORDIR)
+ 		STRING (REGEX REPLACE "\n" "" INDICATORDIR ${INDICATORDIR})
+ 		set (with_indicator3 yes)
+diff --git a/Indicator-applet/indicator-applet.h b/Indicator-applet/indicator-applet.h
+index 52a3d4e..deebaec 100755
+--- a/Indicator-applet/indicator-applet.h
++++ b/Indicator-applet/indicator-applet.h
+@@ -23,9 +23,9 @@
+ 
+ #include <cairo-dock.h>
+ 
+-#include <libindicator/indicator.h>
++#include <libayatana-indicator/indicator.h>
+ ///#include <libindicator/indicator-object.h>
+-#include <libindicator/indicator-service-manager.h>
++#include <libayatana-indicator/indicator-service-manager.h>
+ 
+ #include <libdbusmenu-gtk/menuitem.h>
+ #include <libdbusmenu-gtk/menu.h>
+diff --git a/Indicator-applet3/indicator-applet3-utils.h b/Indicator-applet3/indicator-applet3-utils.h
+index 81bc89b..07e803a 100644
+--- a/Indicator-applet3/indicator-applet3-utils.h
++++ b/Indicator-applet3/indicator-applet3-utils.h
+@@ -22,7 +22,7 @@
+ 
+ #include <gtk/gtk.h>
+ #include <cairo-dock.h>
+-#include <libindicator/indicator-object.h>
++#include <libayatana-indicator/indicator-object.h>
+ 
+ /**
+  * Use the image of a GtkImage to draw a Cairo-Dock Icon
+diff --git a/Indicator-applet3/indicator-applet3.h b/Indicator-applet3/indicator-applet3.h
+index 3157370..af29b75 100644
+--- a/Indicator-applet3/indicator-applet3.h
++++ b/Indicator-applet3/indicator-applet3.h
+@@ -22,7 +22,7 @@
+ 
+ #include <glib.h>
+ #include <gtk/gtk.h>
+-#include <libindicator/indicator-object.h>
++#include <libayatana-indicator/indicator-object.h>
+ 
+ #define INDICATOR_SERVICE_DIR "/usr/share/unity/indicators"
+ 
+-- 
+2.30.0.rc2
+
diff -pruN 3.4.1-6/debian/patches/remove_python2_support.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/remove_python2_support.patch
--- 3.4.1-6/debian/patches/remove_python2_support.patch	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/remove_python2_support.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,45 +0,0 @@
-diff --git a/CMakeLists.txt b/CMakeLists.txt
-index 639fdc7..6caa130 100644
---- a/CMakeLists.txt
-+++ b/CMakeLists.txt
-@@ -495,17 +495,12 @@ enable_if_not_defined (enable-python-interface)
- if (enable-python-interface)
- 	message (STATUS " * Python:")
- 	# find python executables
--	find_program (PYTHON2_EXECUTABLE python2)  # if both python2&3 are installed, usually we will have 'python2' and 'python3' available (one of them being a link to 'python')
--	if (PYTHON2_EXECUTABLE AND EXISTS ${PYTHON2_EXECUTABLE})
--		set (PYTHON2_FOUND TRUE)
--		set (with_python2 yes)
--	endif()
- 	find_program (PYTHON3_EXECUTABLE python3)
- 	if (PYTHON3_EXECUTABLE AND EXISTS ${PYTHON3_EXECUTABLE})
- 		set (PYTHON3_FOUND TRUE)
- 		set (with_python3 yes)
- 	endif()
--	if (NOT PYTHON2_FOUND OR NOT PYTHON3_FOUND)  # if we didn't find one of them, 
-+	if (NOT PYTHON3_FOUND)  # if we didn't find one of them, 
- 		find_program (PYTHON_EXECUTABLE python)
- 		if (PYTHON_EXECUTABLE AND EXISTS ${PYTHON_EXECUTABLE})
- 			EXECUTE_PROCESS(COMMAND ${PYTHON_EXECUTABLE} -c
-@@ -513,11 +508,7 @@ if (enable-python-interface)
- 				OUTPUT_VARIABLE PYTHON_VERSION)
- 			STRING (REGEX REPLACE "\\..*" "" PYTHON_VERSION ${PYTHON_VERSION})
- 			message (STATUS "   Python Version: ${PYTHON_VERSION}")
--			if ("${PYTHON_VERSION}" STREQUAL "2")
--				set (PYTHON2_EXECUTABLE ${PYTHON_EXECUTABLE})
--				set (PYTHON2_FOUND TRUE)
--				set (with_python2 yes)
--			elseif ("${PYTHON_VERSION}" STREQUAL "3")
-+			if ("${PYTHON_VERSION}" STREQUAL "3")
- 				set (PYTHON3_EXECUTABLE ${PYTHON_EXECUTABLE})
- 				set (PYTHON3_FOUND TRUE)
- 				set (with_python3 yes)
-@@ -526,7 +517,7 @@ if (enable-python-interface)
- 	endif()
- 	
- 	# see if we found anything
--	if (NOT PYTHON2_FOUND AND NOT PYTHON3_FOUND)
-+	if (NOT PYTHON3_FOUND)
- 		message (STATUS "Could not find Python, won't install Python interface.")
- 		message (WARNING "This program is required to compile DBus applet with Python interface: python (version 2)")
- 		set (PROGRAMS_MISSING "${PROGRAMS_MISSING} python")
diff -pruN 3.4.1-6/debian/patches/ruby-vendor-dir.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/ruby-vendor-dir.patch
--- 3.4.1-6/debian/patches/ruby-vendor-dir.patch	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/ruby-vendor-dir.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,24 +0,0 @@
-Index: cairo-dock-plug-ins-3.3.2/CMakeLists.txt
-===================================================================
---- cairo-dock-plug-ins-3.3.2.orig/CMakeLists.txt	2013-10-29 11:27:30.000000000 +0100
-+++ cairo-dock-plug-ins-3.3.2/CMakeLists.txt	2014-04-26 18:06:15.528495946 +0200
-@@ -533,7 +533,7 @@ if (enable-ruby-interface)
- 	message (STATUS " * Ruby:")
- 	# find_package(Ruby) found libs of ruby-dev but we only need a directory where we can install ruby libs.
- 	find_program (RUBY_EXECUTABLE ruby)
--	EXECUTE_PROCESS(COMMAND ${RUBY_EXECUTABLE} -r rbconfig -e "print RbConfig::CONFIG['rubylibdir']"
-+	EXECUTE_PROCESS(COMMAND ${RUBY_EXECUTABLE} -r rbconfig -e "print RbConfig::CONFIG['vendordir']"
- 		OUTPUT_VARIABLE RUBY_LIB_DIR)
- 	message (STATUS "   Ruby library dir: ${RUBY_LIB_DIR}")
- 	if ("${RUBY_LIB_DIR}" STREQUAL "" OR "${RUBY_LIB_DIR}" STREQUAL "nil")
-@@ -542,10 +542,6 @@ if (enable-ruby-interface)
- 		set (PROGRAMS_MISSING "${PROGRAMS_MISSING} ruby")
- 		set (with_ruby no)
- 	else()
--		# /usr/lib/ruby/1.8 or /usr/lib/ruby/1.9.1
--		string (REGEX REPLACE "lib/ruby/[0-9].[0-9]?.+" "" RUBY_LIB_DIR_INSTALL "${RUBY_LIB_DIR}")
--		string (REGEX REPLACE "${RUBY_LIB_DIR_INSTALL}" "" RUBY_LIB_DIR_INSTALL "${RUBY_LIB_DIR}")
--		set (RUBY_LIB_DIR "${CMAKE_INSTALL_PREFIX}/${RUBY_LIB_DIR_INSTALL}")
- 		message (STATUS "   will be installed in: ${RUBY_LIB_DIR}")
- 		set (RUBY_FOUND "TRUE")
- 		set (with_ruby yes)
diff -pruN 3.4.1-6/debian/patches/series 3.4.1+git20201022.a0d3415c-1/debian/patches/series
--- 3.4.1-6/debian/patches/series	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/series	2021-01-02 15:32:07.000000000 +0000
@@ -1,9 +1,10 @@
 0001-Fix-typo-about-SystemMonitor-Mail-dnd2share-Stack-GV.patch
-0001-Fix-MATCH-as-FreeBSD.patch
-ruby-vendor-dir.patch
-# 0004-Add-CMake-check-for-vte-2.91-and-fix-VTE_CHECK_VERSI.patch
-0005-Use-dbus-sharp-not-unmaintained-NDesk.patch
-use_correct_csharp_compiler.patch
-weather-url.patch
-remove_python2_support.patch
-support_libetpan_pkgconfig.patch
+0002-Fix-MATCH-as-FreeBSD.patch
+0003-Change-ruby-dir-to-vendor.patch
+0004-Use-correct-C-compiler.patch
+0005-Drop-python2-support.patch
+0006-Fix-support-libetpan-pkgconfig.patch
+0007-Change-version-to-3.4.1-in-CMakeLists.txt.patch
+0008-weather-Use-unsigned-int.patch
+0009-Swith-use-libido3-0.1-to-libayatana-ido3-0.4.patch
+0010-Change-pkg-config-from-indicator3-0.4-to-ayatana-ind.patch
diff -pruN 3.4.1-6/debian/patches/support_libetpan_pkgconfig.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/support_libetpan_pkgconfig.patch
--- 3.4.1-6/debian/patches/support_libetpan_pkgconfig.patch	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/support_libetpan_pkgconfig.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,24 +0,0 @@
-diff --git a/CMakeLists.txt b/CMakeLists.txt
-index 639fdc7..718545c 100644
---- a/CMakeLists.txt
-+++ b/CMakeLists.txt
-@@ -978,9 +978,8 @@ set (with_mail no)
- # find the compilation flags
- enable_if_not_defined (enable-mail)
- if (enable-mail)
--	find_program (LIBETPAN_CONFIG_EXECUTABLE libetpan-config)
- 	execute_process(
--		COMMAND ${LIBETPAN_CONFIG_EXECUTABLE} --cflags
-+		COMMAND pkg-config libetpan --cflags
- 		OUTPUT_VARIABLE MAIL_PACKAGE_CFLAGS)
- 	if (NOT "${MAIL_PACKAGE_CFLAGS}" STREQUAL "" AND NOT "${MAIL_PACKAGE_CFLAGS}" STREQUAL "\n") # if there is a problem with the previous, we don't want to have a lot of errors
- 		STRING (REGEX REPLACE "\n" "" TMP_VARIABLE "${MAIL_PACKAGE_CFLAGS}") # to not skip the last option
-@@ -993,7 +992,7 @@ if (enable-mail)
- 	endif()
- 	# find the link flags
- 	execute_process(
--		COMMAND ${LIBETPAN_CONFIG_EXECUTABLE} --libs
-+		COMMAND pkg-config libetpan --libs
- 		OUTPUT_VARIABLE MAIL_PACKAGE_LIBS)
- 	if (NOT "${MAIL_PACKAGE_LIBS}" STREQUAL "")
- 		STRING (REGEX REPLACE "\n" "" MAIL_PACKAGE_LIBS "${MAIL_PACKAGE_LIBS}")
diff -pruN 3.4.1-6/debian/patches/use_correct_csharp_compiler.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/use_correct_csharp_compiler.patch
--- 3.4.1-6/debian/patches/use_correct_csharp_compiler.patch	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/use_correct_csharp_compiler.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-Index: cairo-dock-plug-ins-3.4.0/CMakeLists.txt
-===================================================================
---- cairo-dock-plug-ins-3.4.0.orig/CMakeLists.txt
-+++ cairo-dock-plug-ins-3.4.0/CMakeLists.txt
-@@ -565,9 +565,9 @@ enable_if_not_defined (enable-mono-inter
- if (enable-mono-interface)
- 	message (STATUS " * Mono:")
- 	#find_package (Mono)
--	find_program (GMCS_EXECUTABLE gmcs)
-+	find_program (GMCS_EXECUTABLE mcs)
- 	if (NOT GMCS_EXECUTABLE OR NOT EXISTS ${GMCS_EXECUTABLE})
--		message (STATUS "Could not find Mono compiler gmcs, won't build Mono interface.")
-+		message (STATUS "Could not find Mono compiler mcs, won't build Mono interface.")
- 	else()
- 		pkg_check_modules (MONO_PACKAGE glib-sharp-2.0 dbus-sharp-2.0 dbus-sharp-glib-2.0)
- 		if (NOT MONO_PACKAGE_FOUND)
diff -pruN 3.4.1-6/debian/patches/weather-url.patch 3.4.1+git20201022.a0d3415c-1/debian/patches/weather-url.patch
--- 3.4.1-6/debian/patches/weather-url.patch	2020-04-01 06:56:27.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/debian/patches/weather-url.patch	1970-01-01 00:00:00.000000000 +0000
@@ -1,29 +0,0 @@
-From: Elimar Riesebieter <riesebie@lxtec.de>
-Date: Thu, 26 May 2016 14:39:44 +0200
-Subject: Corrected CD_WEATHER_BASE_URL
-
-
-diff -Naurd a/weather/src/applet-config.c b/weather/src/applet-config.c
---- a/weather/src/applet-config.c	2014-08-18 01:10:45.000000000 +0200
-+++ b/weather/src/applet-config.c	2016-05-26 14:37:35.099729076 +0200
-@@ -174,7 +174,7 @@
- 	gldi_task_discard (myData.pGetLocationTask);
- 	myData.pGetLocationTask = NULL;
- }
--#define CD_WEATHER_BASE_URL "http://xml.weather.com"
-+#define CD_WEATHER_BASE_URL "http://wxdata.weather.com/wxdata"
- static void _cd_weather_search_for_location (GtkEntry *pEntry, GldiModuleInstance *myApplet)
- {
- 	const gchar *cLocationName = gtk_entry_get_text (pEntry);
-diff -Naurd a/weather/src/applet-read-data.c b/weather/src/applet-read-data.c
---- a/weather/src/applet-read-data.c	2014-08-18 01:10:45.000000000 +0200
-+++ b/weather/src/applet-read-data.c	2016-05-26 14:37:22.041744777 +0200
-@@ -30,7 +30,7 @@
- #include "applet-load-icons.h"
- #include "applet-read-data.h"
- 
--#define CD_WEATHER_BASE_URL "http://xml.weather.com"
-+#define CD_WEATHER_BASE_URL "http://wxdata.weather.com/wxdata"
- 
- 
- static xmlDocPtr _cd_weather_open_xml_buffer (const gchar *cData, xmlNodePtr *root_node, const gchar *cRootNodeName, GError **erreur)
Binary files 3.4.1-6/desklet-rendering/data/misc/dark-bg.xcf and 3.4.1+git20201022.a0d3415c-1/desklet-rendering/data/misc/dark-bg.xcf differ
diff -pruN 3.4.1-6/dialog-rendering/src/applet-decorator-comics.c 3.4.1+git20201022.a0d3415c-1/dialog-rendering/src/applet-decorator-comics.c
--- 3.4.1-6/dialog-rendering/src/applet-decorator-comics.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/dialog-rendering/src/applet-decorator-comics.c	2020-10-21 15:04:44.000000000 +0000
@@ -31,10 +31,11 @@
 #define CD_ARROW_HEIGHT 16
 #define CD_ALIGN 0.
 #define CD_RADIUS (myDialogsParam.bUseDefaultColors ? myStyleParam.iCornerRadius : myDialogsParam.iCornerRadius) * 1.5
+#define CD_LINE_WIDTH (myDialogsParam.bUseDefaultColors ? myStyleParam.iLineWidth : myDialogsParam.iLineWidth)
 
 void cd_decorator_set_frame_size_comics (CairoDialog *pDialog)
 {
-	int iMargin = .5 * myDialogsParam.iLineWidth + (1. - sqrt (2) / 2) * CD_RADIUS + _CAIRO_DIALOG_COMICS_MARGIN;  // on laisse qques pixels d'espace en plus tout autour.
+	int iMargin = .5 * CD_LINE_WIDTH + (1. - sqrt (2) / 2) * CD_RADIUS + _CAIRO_DIALOG_COMICS_MARGIN;  // on laisse qques pixels d'espace en plus tout autour.
 	pDialog->iRightMargin = iMargin;
 	pDialog->iLeftMargin = iMargin;
 	pDialog->iTopMargin = iMargin;
@@ -48,7 +49,7 @@ void cd_decorator_set_frame_size_comics
 
 void cd_decorator_draw_decorations_comics (cairo_t *pCairoContext, CairoDialog *pDialog)
 {
-	double fLineWidth = myDialogsParam.iLineWidth;
+	double fLineWidth = CD_LINE_WIDTH;
 	double fRadius = MIN (CD_RADIUS, (pDialog->iBubbleHeight - fLineWidth) / 2);
 	
 	/**double fGapFromDock = pDialog->iMinBottomGap + pDialog->iBottomMargin + fLineWidth/2;
@@ -180,8 +181,8 @@ static void _render_menu (GtkWidget *pMe
 	gdk_window_get_position (gtk_widget_get_window (gtk_widget_get_toplevel(pMenu)), &x, &y);
 	
 	// get drawing params
-	int _ah = ah - myDialogsParam.iLineWidth;  // we want the tip of the arrow (not the middle of the stroke) to reach the border; this is a good approximation
-	double fRadius = CD_RADIUS, fLineWidth = myDialogsParam.iLineWidth;
+	int _ah = ah - CD_LINE_WIDTH;  // we want the tip of the arrow (not the middle of the stroke) to reach the border; this is a good approximation
+	double fRadius = CD_RADIUS, fLineWidth = CD_LINE_WIDTH;
 	double fDockOffsetX = fLineWidth/2;
 	double fDockOffsetY = fLineWidth/2;
 	double fFrameWidth, fFrameHeight;
@@ -383,6 +384,7 @@ static void _render_menu (GtkWidget *pMe
 			gldi_style_colors_set_line_color (pCairoContext);
 		else
 			gldi_color_set_cairo (pCairoContext, &myDialogsParam.fLineColor);
+		cairo_set_line_width (pCairoContext, fLineWidth);
 		cairo_stroke_preserve (pCairoContext);
 	}
 	
diff -pruN 3.4.1-6/dialog-rendering/src/applet-decorator-curly.c 3.4.1+git20201022.a0d3415c-1/dialog-rendering/src/applet-decorator-curly.c
--- 3.4.1-6/dialog-rendering/src/applet-decorator-curly.c	2015-02-19 16:01:14.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/dialog-rendering/src/applet-decorator-curly.c	2020-10-21 15:04:44.000000000 +0000
@@ -27,10 +27,11 @@
 #define CD_ARROW_HEIGHT 12
 #define CD_ALIGN 0.5
 #define CD_RADIUS (myDialogsParam.bUseDefaultColors ? myStyleParam.iCornerRadius : myDialogsParam.iCornerRadius)
+#define CD_LINE_WIDTH (myDialogsParam.bUseDefaultColors ? myStyleParam.iLineWidth : myDialogsParam.iLineWidth)
 
 void cd_decorator_set_frame_size_curly (CairoDialog *pDialog)
 {
-	int iMargin = .5 * myDialogsParam.iLineWidth + (1. - sqrt (2) / 2) * CD_RADIUS;
+	int iMargin = .5 * CD_LINE_WIDTH + (1. - sqrt (2) / 2) * CD_RADIUS;
 	pDialog->iRightMargin = iMargin;
 	pDialog->iLeftMargin = iMargin;
 	pDialog->iTopMargin = iMargin;
@@ -45,7 +46,7 @@ void cd_decorator_set_frame_size_curly (
 
 void cd_decorator_draw_decorations_curly (cairo_t *pCairoContext, CairoDialog *pDialog)
 {
-	double fLineWidth = myDialogsParam.iLineWidth;
+	double fLineWidth = CD_LINE_WIDTH;
 	double fRadius = CD_RADIUS;
 	// double fBottomRadius = 2 * fRadius;
 	double fTipHeight = pDialog->iMinBottomGap + fLineWidth/2;
@@ -175,7 +176,7 @@ static void _render_menu (GtkWidget *pMe
 	int x, y;
 	gdk_window_get_position (gtk_widget_get_window (gtk_widget_get_toplevel(pMenu)), &x, &y);
 	
-	double fRadius = CD_RADIUS, fLineWidth = myDialogsParam.iLineWidth;
+	double fRadius = CD_RADIUS, fLineWidth = CD_LINE_WIDTH;
 	double fDockOffsetX = fRadius + fLineWidth/2;
 	double fDockOffsetY = fLineWidth/2;
 	double fFrameWidth, fFrameHeight;
@@ -372,6 +373,7 @@ static void _render_menu (GtkWidget *pMe
 			gldi_style_colors_set_line_color (pCairoContext);
 		else
 			gldi_color_set_cairo (pCairoContext, &myDialogsParam.fLineColor);
+		cairo_set_line_width (pCairoContext, fLineWidth);
 		cairo_stroke_preserve (pCairoContext);
 	}
 	
diff -pruN 3.4.1-6/dialog-rendering/src/applet-decorator-modern.c 3.4.1+git20201022.a0d3415c-1/dialog-rendering/src/applet-decorator-modern.c
--- 3.4.1-6/dialog-rendering/src/applet-decorator-modern.c	2015-02-19 16:01:14.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/dialog-rendering/src/applet-decorator-modern.c	2020-10-21 15:04:44.000000000 +0000
@@ -27,10 +27,11 @@
 #define CD_ARROW_HEIGHT 20
 #define CD_ALIGN 0.33
 #define CD_RADIUS (myDialogsParam.bUseDefaultColors ? myStyleParam.iCornerRadius : myDialogsParam.iCornerRadius) * 1.5
+#define CD_LINE_WIDTH (myDialogsParam.bUseDefaultColors ? myStyleParam.iLineWidth : myDialogsParam.iLineWidth)
 
 void cd_decorator_set_frame_size_modern (CairoDialog *pDialog)
 {
-	int iMargin = .5 * myDialogsParam.iLineWidth + .5 * CD_RADIUS;
+	int iMargin = .5 * CD_LINE_WIDTH + .5 * CD_RADIUS;
 	pDialog->iRightMargin = iMargin;
 	pDialog->iLeftMargin = iMargin;
 	pDialog->iTopMargin = iMargin;
@@ -45,7 +46,7 @@ void cd_decorator_set_frame_size_modern
 
 void cd_decorator_draw_decorations_modern (cairo_t *pCairoContext, CairoDialog *pDialog)
 {
-	double fLineWidth = myDialogsParam.iLineWidth;
+	double fLineWidth = CD_LINE_WIDTH;
 	double fRadius = MIN (CD_RADIUS, pDialog->iBubbleHeight/2);
 	int sens = (pDialog->container.bDirectionUp ?	1 :	-1);
 	int sens2 = (pDialog->bRight ? 1 :	-1);
@@ -73,7 +74,10 @@ void cd_decorator_draw_decorations_moder
 		- sens2 * fRadius,
 		- sens * fRadius);
 	cairo_close_path (pCairoContext);
-	gldi_style_colors_set_bg_color (pCairoContext);
+	if (myDialogsParam.bUseDefaultColors)
+		gldi_style_colors_set_bg_color_full (pCairoContext, FALSE);
+	else
+		gldi_color_set_cairo_rgb (pCairoContext, &myDialogsParam.fBgColor);
 	///cairo_fill (pCairoContext);
 	cairo_save (pCairoContext);
 	cairo_clip (pCairoContext);
@@ -141,7 +145,7 @@ static void _render_submenu (GtkWidget *
 	gtk_widget_get_allocation (pMenu, &alloc);
 	
 	int w = alloc.width, h = alloc.height;
-	double fRadius = CD_RADIUS, fLineWidth = myDialogsParam.iLineWidth;
+	double fRadius = CD_RADIUS, fLineWidth = CD_LINE_WIDTH;
 	double fFrameWidth, fFrameHeight;
 	fFrameWidth = w - 2*fRadius - fLineWidth;
 	fFrameHeight = h - 2*fRadius - fLineWidth;
@@ -217,7 +221,7 @@ static void _render_menu (GtkWidget *pMe
 	int x, y;
 	gdk_window_get_position (gtk_widget_get_window (gtk_widget_get_toplevel(pMenu)), &x, &y);
 	
-	double fRadius = CD_RADIUS, fLineWidth = myDialogsParam.iLineWidth;
+	double fRadius = CD_RADIUS, fLineWidth = CD_LINE_WIDTH;
 	double fDockOffsetX = fLineWidth/2;
 	double fDockOffsetY = fLineWidth/2;
 	double fFrameWidth, fFrameHeight;
@@ -247,7 +251,10 @@ static void _render_menu (GtkWidget *pMe
 	
 	
 	// set bg color/pattern
-	gldi_style_colors_set_line_color (pCairoContext);
+	if (myDialogsParam.bUseDefaultColors)
+		gldi_style_colors_set_line_color (pCairoContext);
+	else
+		gldi_color_set_cairo (pCairoContext, &myDialogsParam.fLineColor);
 	
 	//\_________________ draw outline
 	if (fLineWidth != 0)
diff -pruN 3.4.1-6/dialog-rendering/src/applet-decorator-tooltip.c 3.4.1+git20201022.a0d3415c-1/dialog-rendering/src/applet-decorator-tooltip.c
--- 3.4.1-6/dialog-rendering/src/applet-decorator-tooltip.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/dialog-rendering/src/applet-decorator-tooltip.c	2020-10-21 15:04:44.000000000 +0000
@@ -29,6 +29,7 @@
 #define CD_ARROW_HEIGHT 8  /// maybe decrease a little if the width or the height is too small ?...
 #define CD_ALIGN 0.5
 #define CD_RADIUS (myDialogsParam.bUseDefaultColors ? myStyleParam.iCornerRadius : myDialogsParam.iCornerRadius)
+#define CD_LINE_WIDTH (myDialogsParam.bUseDefaultColors ? myStyleParam.iLineWidth : myDialogsParam.iLineWidth)
 
 /*
 ic______^___  arrow height + margin
@@ -42,11 +43,11 @@ ic     msg
 
 void cd_decorator_set_frame_size_tooltip (CairoDialog *pDialog)
 {
-	int iMargin = .5 * myDialogsParam.iLineWidth + (1. - sqrt (2) / 2) * CD_RADIUS;
+	int iMargin = .5 * CD_LINE_WIDTH + (1. - sqrt (2) / 2) * CD_RADIUS;
 	int iIconOffset = pDialog->iIconSize / 2;
 	pDialog->iRightMargin = iMargin + _CAIRO_DIALOG_TOOLTIP_MARGIN;
 	pDialog->iLeftMargin = iIconOffset + iMargin + _CAIRO_DIALOG_TOOLTIP_MARGIN;
-	pDialog->iTopMargin = iIconOffset + _CAIRO_DIALOG_TOOLTIP_MARGIN + myDialogsParam.iLineWidth;
+	pDialog->iTopMargin = iIconOffset + _CAIRO_DIALOG_TOOLTIP_MARGIN + CD_LINE_WIDTH;
 	pDialog->iBottomMargin = _CAIRO_DIALOG_TOOLTIP_MARGIN;
 	pDialog->iMinBottomGap = CD_ARROW_HEIGHT;
 	pDialog->iMinFrameWidth = _CAIRO_DIALOG_TOOLTIP_ARROW_WIDTH;
@@ -60,7 +61,7 @@ void cd_decorator_set_frame_size_tooltip
 
 void cd_decorator_draw_decorations_tooltip (cairo_t *pCairoContext, CairoDialog *pDialog)
 {
-	double fLineWidth = myDialogsParam.iLineWidth;
+	double fLineWidth = CD_LINE_WIDTH;
 	double fRadius = CD_RADIUS;
 	double fIconOffset = pDialog->iIconSize / 2;  // myDialogsParam.iDialogIconSize/2
 	
@@ -154,7 +155,7 @@ static void _render_menu (GtkWidget *pMe
 		iAimedX = pParams->iAimedX;
 		iAimedY = pParams->iAimedY;
 	}
-	double fRadius = CD_RADIUS, fLineWidth = myDialogsParam.iLineWidth;
+	double fRadius = CD_RADIUS, fLineWidth = CD_LINE_WIDTH;
 	
 	// draw the outline and set the clip
 	GtkAllocation alloc;
@@ -197,7 +198,7 @@ static void _render_menu (GtkWidget *pMe
 	
 	if (iMarginPosition == 1)  // top arrow
 	{
-		dx = MIN (w - fRadius - 2*aw, MAX (fRadius, iAimedX - x - aw));
+		dx = MIN (fFrameWidth - 2*aw, MAX (fRadius, iAimedX - x - aw));
 		cairo_line_to (pCairoContext, dx, fDockOffsetY);
 		cairo_line_to (pCairoContext, MIN (w, MAX (0, iAimedX - x)), fDockOffsetY - _ah);
 		cairo_line_to (pCairoContext, dx + 2*aw, fDockOffsetY);
@@ -232,7 +233,7 @@ static void _render_menu (GtkWidget *pMe
 	
 	if (iMarginPosition == 0)  // bottom arrow
 	{
-		dx = MIN (w - fRadius - 2*aw, MAX (fRadius, iAimedX - x - aw));
+		dx = MIN (fFrameWidth - 2*aw, MAX (fRadius, iAimedX - x - aw));
 		cairo_line_to (pCairoContext, dx + 2*aw, fDockOffsetY + fFrameHeight);
 		cairo_line_to (pCairoContext, MIN (w, MAX (0, iAimedX - x)), fDockOffsetY + fFrameHeight + _ah);
 		cairo_line_to (pCairoContext, dx, fDockOffsetY + fFrameHeight);
diff -pruN 3.4.1-6/Disks/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/Disks/data/misc/icon.svg
--- 3.4.1-6/Disks/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Disks/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,589 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   version="1.0"
+   width="48"
+   height="48"
+   id="svg3786"
+   inkscape:version="0.48.0 r9654"
+   sodipodi:docname="document-save-as.svg">
+  <metadata
+     id="metadata101">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <sodipodi:namedview
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1"
+     objecttolerance="10"
+     gridtolerance="10"
+     guidetolerance="10"
+     inkscape:pageopacity="0"
+     inkscape:pageshadow="2"
+     inkscape:window-width="723"
+     inkscape:window-height="480"
+     id="namedview99"
+     showgrid="false"
+     inkscape:zoom="2.8854167"
+     inkscape:cx="6.9045149"
+     inkscape:cy="18.678069"
+     inkscape:window-x="935"
+     inkscape:window-y="353"
+     inkscape:window-maximized="0"
+     inkscape:current-layer="svg3786" />
+  <defs
+     id="defs3788">
+    <linearGradient
+       x1="8.5273199"
+       y1="33.332287"
+       x2="57.411129"
+       y2="33.332287"
+       id="linearGradient2901"
+       xlink:href="#linearGradient4222"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,0.798445,-0.7913078,0,44.889795,-5.6111935)" />
+    <linearGradient
+       id="linearGradient4222">
+      <stop
+         id="stop4224"
+         style="stop-color:#ffffff;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4226"
+         style="stop-color:#ffffff;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient2264">
+      <stop
+         id="stop2266"
+         style="stop-color:#8babcb;stop-opacity:1;"
+         offset="0" />
+      <stop
+         id="stop2268"
+         style="stop-color:#426296;stop-opacity:1;"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="28.670898"
+       y1="23.890965"
+       x2="1.3099612"
+       y2="23.890965"
+       id="linearGradient3390"
+       xlink:href="#linearGradient2264"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,-0.6884294,-0.6854408,0,40.375844,29.770525)" />
+    <linearGradient
+       id="linearGradient5048-8">
+      <stop
+         id="stop5050-1"
+         style="stop-color:#000000;stop-opacity:0"
+         offset="0" />
+      <stop
+         id="stop5056-2"
+         style="stop-color:#000000;stop-opacity:1"
+         offset="0.5" />
+      <stop
+         id="stop5052-9"
+         style="stop-color:#000000;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient2939"
+       xlink:href="#linearGradient5060-3"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.04484747,0,0,0.02058824,15.231827,34.839926)" />
+    <linearGradient
+       id="linearGradient5060-3">
+      <stop
+         id="stop5062-9"
+         style="stop-color:#000000;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop5064-0"
+         style="stop-color:#000000;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient2936"
+       xlink:href="#linearGradient5060-3"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.04484747,0,0,0.02058824,32.454077,34.839926)" />
+    <linearGradient
+       x1="29.9375"
+       y1="41"
+       x2="30"
+       y2="49.999996"
+       id="linearGradient2933"
+       xlink:href="#linearGradient2215-8"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.0017502,0,0,0.7596403,-5.2079507,7.3249279)" />
+    <linearGradient
+       id="linearGradient2215-8">
+      <stop
+         id="stop2223-8"
+         style="stop-color:#7a7a7a;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2219-5"
+         style="stop-color:#474747;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="11.734284"
+       cy="8.4900017"
+       r="23.047892"
+       fx="11.734284"
+       fy="8.4900017"
+       id="radialGradient2927"
+       xlink:href="#linearGradient7056-0"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.3767077,0.69719425,-0.46810846,0.92434578,-0.2062097,-0.5500743)" />
+    <linearGradient
+       id="linearGradient7056-0">
+      <stop
+         id="stop7064-9"
+         style="stop-color:#e6e6e6;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop7060-6"
+         style="stop-color:#c8c8c8;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="17.813944"
+       y1="29.796696"
+       x2="18.072828"
+       y2="10.000001"
+       id="linearGradient2929"
+       xlink:href="#linearGradient3484-3"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-0.1570532,1.3884067)" />
+    <linearGradient
+       id="linearGradient3484-3">
+      <stop
+         id="stop3486-8"
+         style="stop-color:#969696;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3488-5"
+         style="stop-color:#b4b4b4;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="141.74666"
+       cy="206.42612"
+       r="78.728165"
+       fx="141.74666"
+       fy="206.42612"
+       id="radialGradient2923"
+       xlink:href="#linearGradient4035"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.35160878,-0.0050244,0.00260227,0.28909275,-27.181393,-22.828984)" />
+    <linearGradient
+       id="linearGradient4035">
+      <stop
+         id="stop4037"
+         style="stop-color:#f5f5f5;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4039"
+         style="stop-color:#e7e7e7;stop-opacity:1"
+         offset="0.47025558" />
+      <stop
+         id="stop4041"
+         style="stop-color:#8c8c8c;stop-opacity:1"
+         offset="0.69348532" />
+      <stop
+         id="stop4043"
+         style="stop-color:#dddddd;stop-opacity:1"
+         offset="0.83542866" />
+      <stop
+         id="stop4045"
+         style="stop-color:#a8a8a8;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="142.62215"
+       cy="191.85428"
+       r="78.728165"
+       fx="142.62215"
+       fy="191.85428"
+       id="radialGradient2920"
+       xlink:href="#linearGradient7609"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.18495239,0,0,-0.13074306,-3.2682255,47.43699)" />
+    <linearGradient
+       id="linearGradient7609">
+      <stop
+         id="stop7611"
+         style="stop-color:#ffffff;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop7677"
+         style="stop-color:#e7e7e7;stop-opacity:1"
+         offset="0.47025558" />
+      <stop
+         id="stop7613"
+         style="stop-color:#8c8c8c;stop-opacity:1"
+         offset="0.67183787" />
+      <stop
+         id="stop7617"
+         style="stop-color:#dddddd;stop-opacity:1"
+         offset="0.83542866" />
+      <stop
+         id="stop7615"
+         style="stop-color:#a8a8a8;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="113.0654"
+       cy="97.587898"
+       r="2.5631001"
+       fx="113.667"
+       fy="98"
+       id="radialGradient2965"
+       xlink:href="#radialGradient4241"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.32948872,0,0,0.34974643,41.805988,2.8823791)" />
+    <radialGradient
+       cx="113.0654"
+       cy="97.587898"
+       r="2.5631001"
+       fx="113.667"
+       fy="98"
+       id="radialGradient4241"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         id="stop4243"
+         style="stop-color:#eeeeee;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4245"
+         style="stop-color:#cecece;stop-opacity:1"
+         offset="0.16" />
+      <stop
+         id="stop4247"
+         style="stop-color:#888888;stop-opacity:1"
+         offset="0.4675" />
+      <stop
+         id="stop4249"
+         style="stop-color:#555555;stop-opacity:1"
+         offset="1" />
+    </radialGradient>
+    <radialGradient
+       cx="113.0654"
+       cy="97.587898"
+       r="2.5631001"
+       fx="113.667"
+       fy="98"
+       id="radialGradient2959"
+       xlink:href="#radialGradient4241"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.22282769,-0.03752228,0.02509892,0.149051,-18.302971,2.9208339)" />
+    <radialGradient
+       cx="113.0654"
+       cy="97.587898"
+       r="2.5631001"
+       fx="113.667"
+       fy="98"
+       id="radialGradient2953"
+       xlink:href="#radialGradient4241"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.22333209,0.03439303,-0.02300572,0.14938839,14.634388,-5.2432873)" />
+    <linearGradient
+       x1="7.0625"
+       y1="35.28125"
+       x2="24.6875"
+       y2="35.28125"
+       id="linearGradient2908"
+       xlink:href="#linearGradient5060-3"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.0212766,0,0,0.89887639,0.6301868,10.175067)" />
+    <linearGradient
+       x1="12.277412"
+       y1="37.205811"
+       x2="12.221823"
+       y2="33.758667"
+       id="linearGradient2905"
+       xlink:href="#linearGradient4236"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.0212766,0,0,0.89887639,-0.1822315,11.366816)" />
+    <linearGradient
+       id="linearGradient4236">
+      <stop
+         id="stop4238"
+         style="stop-color:#eeeeee;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4240"
+         style="stop-color:#eeeeee;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="127.31733"
+       cy="143.82751"
+       r="78.728165"
+       fx="127.31733"
+       fy="143.82751"
+       id="radialGradient2902"
+       xlink:href="#linearGradient4035"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.19054222,-0.02505584,0.00619351,0.10073457,-7.5942276,6.81724)" />
+    <radialGradient
+       cx="113.0654"
+       cy="97.587898"
+       r="2.5631001"
+       fx="113.667"
+       fy="98"
+       id="radialGradient2947"
+       xlink:href="#radialGradient4241"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.32948872,0,0,0.34974643,5.89787,2.8823791)" />
+    <radialGradient
+       cx="24"
+       cy="42"
+       r="21"
+       fx="24"
+       fy="42"
+       id="radialGradient2896"
+       xlink:href="#linearGradient6310-8"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.99999995,-1.0652117e-8,2.7812622e-8,0.35714279,-0.1570521,26.888557)" />
+    <linearGradient
+       id="linearGradient6310-8">
+      <stop
+         id="stop6312-6"
+         style="stop-color:#ffffff;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6314-6"
+         style="stop-color:#ffffff;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="302.85715"
+       y1="366.64789"
+       x2="302.85715"
+       y2="609.50507"
+       id="linearGradient3032"
+       xlink:href="#linearGradient5048-8"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.07635654,0,0,0.02058824,-3.7544815,34.839926)" />
+    <linearGradient
+       x1="21.478369"
+       y1="1.6845057"
+       x2="21.478369"
+       y2="6.5747066"
+       id="linearGradient4307"
+       xlink:href="#linearGradient6451"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(55.030111,1.3948202)" />
+    <linearGradient
+       id="linearGradient6451">
+      <stop
+         id="stop6453"
+         style="stop-color:#eeeeec;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6455"
+         style="stop-color:#ffffff;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <filter
+       inkscape:collect="always"
+       id="filter3965">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="0.26175298"
+         id="feGaussianBlur3967" />
+    </filter>
+    <filter
+       inkscape:collect="always"
+       id="filter4007"
+       x="-0.12088922"
+       width="1.2417784"
+       y="-0.27527539"
+       height="1.5505508">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="0.73290828"
+         id="feGaussianBlur4009" />
+    </filter>
+  </defs>
+  <rect
+     width="36.869301"
+     height="5"
+     x="5.4082794"
+     y="42.388554"
+     id="rect2723-6"
+     style="opacity:0.3;fill:url(#linearGradient3032);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:0.5;marker:none;visibility:visible;display:inline;overflow:visible" />
+  <path
+     d="m 42.259617,42.388728 c 0,0 0,4.999723 0,4.999723 2.30953,0.0094 5.58333,-1.120185 5.58333,-2.500182 0,-1.379997 -2.57726,-2.499541 -5.58333,-2.499541 z"
+     id="path2725-1"
+     style="opacity:0.3;fill:url(#radialGradient2939);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:0.5;marker:none;visibility:visible;display:inline;overflow:visible" />
+  <path
+     d="m 5.426277,42.388728 c 0,0 0,4.999723 0,4.999723 -2.30954,0.0094 -5.5833302,-1.120185 -5.5833302,-2.500182 0,-1.379997 2.5772702,-2.499541 5.5833302,-2.499541 z"
+     id="path2727-1"
+     style="opacity:0.3;fill:url(#radialGradient2936);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+  <path
+     d="m 1.3068005,38.852555 45.0720005,0 -0.901202,6.072 -43.169419,0 -1.0013795,-6.072 z"
+     id="rect6431-5"
+     style="fill:url(#linearGradient2933);fill-opacity:1;fill-rule:evenodd;stroke:#353537;stroke-width:0.9279989;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;display:inline;enable-background:new" />
+  <rect
+     width="45"
+     height="1"
+     x="1.342947"
+     y="38.388409"
+     id="rect6381-9"
+     style="fill:#d2d2d3;fill-opacity:1;fill-rule:evenodd;stroke:none;display:inline;enable-background:new" />
+  <path
+     d="M 46.392947,38.990516 39.583314,13.216178 c -0.192553,-0.733973 -1.2012,-1.329879 -2.049166,-1.329879 l -27.617218,0 c -1.30274,0 -2.049257,0.198573 -2.323959,1.329879 L 1.2929468,38.96542"
+     id="path6345-8"
+     style="fill:url(#radialGradient2927);fill-opacity:1;fill-rule:nonzero;stroke:url(#linearGradient2929);stroke-width:0.99578345;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  <path
+     d="M 45.342949,38.888408 2.342947,38.864357"
+     id="path7046-4"
+     style="opacity:0.4;fill:none;stroke:#ffffff;stroke-width:1;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  <path
+     d="m 40.814344,27.762368 c -0.21768,-1.997975 -1.676509,-3.903122 -4.1004,-5.406472 -0.04876,-0.577862 -0.670055,-7.97019 -0.670055,-7.97019 -0.04762,-0.568265 -0.771749,-0.997153 -1.685016,-0.997153 l -5.731268,0 c -0.919834,0 -1.630882,0.434524 -1.654073,1.010704 -0.10517,2.603206 -3.312025,3.962376 -8.095624,5.198802 -1.67612,0.29034 -6.046005,1.655156 -7.048964,2.254184 -2.952438,1.573605 -4.713226,3.67147 -4.957204,5.910125 -0.22194,2.036069 0.844826,4.073551 3.003866,5.737168 3.160059,2.435045 8.381346,3.889018 13.967237,3.889018 5.5859,0 10.807176,-1.453973 13.967635,-3.889018 1.971903,-1.519149 3.032469,-3.350655 3.032469,-5.207826 0,-0.17636 -0.01031,-0.352992 -0.02866,-0.529342 l 5.7e-5,0 z m -16.971501,8.616336 c -9.303498,0 -16.427483,-4.080325 -15.912079,-8.810179 0.222328,-2.039173 1.854362,-4.216036 4.557022,-5.650539 0.506122,-0.381482 5.077073,-1.865368 6.716838,-2.126087 4.544655,-1.17209 8.700731,-2.693216 8.831026,-5.89884 0.0057,-0.153501 0.267557,-0.275107 0.591955,-0.275107 l 5.730502,0 c 0.33174,0 0.611698,0.127531 0.62484,0.284984 l 0.695941,8.281975 c 2.408816,1.395843 3.86841,3.479309 4.075655,5.383614 0.515781,4.729854 -6.608191,8.810179 -15.9117,8.810179 l 0,0 z"
+     id="path9001"
+     style="fill:url(#radialGradient2923);fill-opacity:1" />
+  <path
+     d="m 23.842716,30.388554 c -3.364964,0 -5.944551,-1.267115 -5.998923,-2.947825 -4.28e-4,-0.01817 -8.46e-4,-0.03604 -8.46e-4,-0.0539 0,-0.608175 0.338098,-1.186584 0.980563,-1.676322 1.086804,-0.827824 2.963209,-1.321951 5.019622,-1.321951 2.055997,0 3.932391,0.494127 5.019195,1.321951 0.661441,0.503521 1.000395,1.101987 0.979728,1.729907 -0.05524,1.68071 -2.634804,2.948137 -5.999339,2.948137 l 0,3e-6 z m 0,-5.059679 c -3.161777,0 -4.77259,1.255831 -4.734647,2.402312 0.03667,1.128624 2.156333,2.030394 4.734647,2.030394 2.578314,0 4.697955,-0.902088 4.734637,-2.030394 0.03749,-1.146798 -1.572872,-2.402312 -4.734637,-2.402312 l 0,0 z"
+     id="path9003"
+     style="fill:url(#radialGradient2920);fill-opacity:1;fill-rule:nonzero;stroke-width:1;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  <path
+     d="m 5.85877,37.007838 c -0.04152,0.595269 -0.663261,1.080716 -1.388137,1.080716 -0.724546,0 -1.273145,-0.485447 -1.22471,-1.080716 0.04811,-0.592121 0.669522,-1.070225 1.387148,-1.070225 0.717957,2.81e-4 1.266555,0.478104 1.225699,1.070225 z"
+     id="path9007"
+     style="fill:#e1e1e1;fill-opacity:1" />
+  <path
+     d="m 5.389906,36.589191 c 0.06623,0.07554 0.142011,0.196558 0.142011,0.357441 0,0.01155 -6.61e-4,0.02308 -0.0013,0.03533 -0.02867,0.410252 -0.514003,0.756851 -1.059637,0.756851 -0.310707,0 -0.594726,-0.113668 -0.759471,-0.304629 -0.07084,-0.08149 -0.151565,-0.216493 -0.137067,-0.396263 0.03328,-0.406755 0.517955,-0.750556 1.058977,-0.750556 0.308401,2.8e-4 0.591431,0.112968 0.756505,0.301831 l 3e-6,0 z"
+     id="path9009"
+     style="fill:url(#radialGradient2965);fill-opacity:1" />
+  <path
+     d="m 8.456482,13.370357 c 0.0708,0.248957 0.526108,0.385035 1.016329,0.302486 0.489999,-0.08251 0.82617,-0.351869 0.750696,-0.600038 -0.07503,-0.246865 -0.52959,-0.379851 -1.014908,-0.298127 -0.485522,0.08188 -0.82224,0.347988 -0.752117,0.595679 z"
+     id="path9019"
+     style="fill:#f0f0f0;fill-opacity:1" />
+  <path
+     d="m 8.743523,13.138549 c -0.03937,0.03974 -0.08193,0.09994 -0.07039,0.168502 8.29e-4,0.0049 0.0021,0.0098 0.0034,0.0149 0.04883,0.171572 0.401926,0.264011 0.770928,0.201874 0.210127,-0.03538 0.394047,-0.116169 0.491757,-0.216312 0.04206,-0.0428 0.08696,-0.109523 0.06426,-0.184484 -0.0517,-0.169557 -0.404147,-0.260879 -0.770031,-0.199267 -0.208546,0.03524 -0.391868,0.115496 -0.489951,0.214782 l -2e-6,1e-6 z"
+     id="path9021"
+     style="fill:url(#radialGradient2959);fill-opacity:1" />
+  <path
+     d="m 36.755204,13.085116 c -0.01101,0.258593 0.37848,0.530843 0.869811,0.606508 0.491108,0.07563 0.894887,-0.07446 0.901213,-0.333771 0.0063,-0.257936 -0.383413,-0.527015 -0.869831,-0.601923 -0.486659,-0.07482 -0.889937,0.07201 -0.901193,0.329186 z"
+     id="path9025"
+     style="fill:#e1e1e1;fill-opacity:1" />
+  <path
+     d="m 37.100544,12.955239 c -0.04986,0.02535 -0.109185,0.06913 -0.119768,0.137852 -7.6e-4,0.0049 -0.0011,0.0099 -0.0014,0.01523 -0.0076,0.178225 0.298614,0.37693 0.668452,0.433884 0.210602,0.03243 0.410591,0.01353 0.534819,-0.05084 0.05338,-0.02741 0.116973,-0.07665 0.118971,-0.15495 0.0042,-0.177212 -0.301707,-0.374653 -0.668419,-0.431126 -0.209057,-0.03207 -0.408312,-0.01348 -0.532624,0.04996 l -2e-6,-1e-6 z"
+     id="path9027"
+     style="fill:url(#radialGradient2953);fill-opacity:1" />
+  <path
+     d="m 7.342947,39.388553 18.500009,0 0,5.000001 -18,0 -0.500009,-5.000001 z"
+     id="rect8993"
+     style="fill:url(#linearGradient2908);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:2.40899992;marker:none;visibility:visible;display:inline;overflow:visible" />
+  <path
+     d="m 7.842955,44.38855 c 0,0 -0.400008,-3.605827 -0.400008,-3.605827 1.874581,2.857731 8.873019,3.605827 13.612771,3.605827 0,0 -13.212763,0 -13.212763,0 z"
+     id="path8995"
+     style="opacity:0.81142853;fill:url(#linearGradient2905);fill-opacity:1;fill-rule:evenodd;stroke:none" />
+  <path
+     d="m 10.749526,13.388553 -0.103274,0.381009 -1.54175,5.670889 -0.261555,0.948102 0.763997,-0.203795 12.994774,-3.544305 0.04127,-0.01771 0.03442,-0.01771 c 0.688135,-0.354354 1.05583,-1.07045 1.142548,-1.727849 0.0434,-0.328702 0.03039,-0.650575 -0.08254,-0.948099 C 23.630774,13.648209 23.35314,13.398308 23.0629,13.406298 l 0,-0.01771 -0.04821,0 -11.955461,0 -0.30973,0 3.3e-5,10e-7 z m 0.439836,0.350376 11.976544,0 c 0.0056,0.04787 0.01906,0.07443 0.0067,0.165 -0.03757,0.285021 -0.199195,1.304699 -0.605242,1.527141 l -12.596058,3.437485 1.217592,-5.129624 3.91e-4,0 z"
+     id="path9039"
+     style="fill:url(#radialGradient2902);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  <path
+     d="m 41.845089,37.007838 c 0.04152,0.595269 0.663261,1.080716 1.388137,1.080716 0.724546,0 1.273145,-0.485447 1.22471,-1.080716 -0.04811,-0.592121 -0.669522,-1.070225 -1.387148,-1.070225 -0.717957,2.81e-4 -1.266555,0.478104 -1.225699,1.070225 z"
+     id="path9091"
+     style="fill:#e1e1e1;fill-opacity:1" />
+  <path
+     d="m 42.313953,36.589191 c -0.06623,0.07554 -0.142011,0.196558 -0.142011,0.357441 0,0.01155 6.6e-4,0.02308 0.0013,0.03533 0.02867,0.410252 0.514002,0.756851 1.059636,0.756851 0.310708,0 0.594727,-0.113668 0.759471,-0.304629 0.07084,-0.08149 0.151565,-0.216493 0.137068,-0.396263 -0.03328,-0.406755 -0.517956,-0.750556 -1.058978,-0.750556 -0.308401,2.8e-4 -0.591431,0.112968 -0.756505,0.301831 l -2e-6,0 z"
+     id="path9093"
+     style="fill:url(#radialGradient2947);fill-opacity:1" />
+  <rect
+     width="42"
+     height="5"
+     x="2.842947"
+     y="39.388554"
+     id="rect6300-3"
+     style="opacity:0.3;fill:url(#radialGradient2896);fill-opacity:1;stroke:none" />
+  <path
+     d="M 37.509771,13.5 23.966059,28.509772 10.490228,13.5 16.5,13.5 l 0,-13.009772 15,0 0,13.009772 6.009771,0 z"
+     id="path4348"
+     style="fill:url(#linearGradient3390);fill-opacity:1;fill-rule:nonzero;stroke:#426296;stroke-width:0.98045682999999995;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+  <path
+     d="M 35.205341,14.5 24,27 12.632926,14.5 17.5,14.5 l 0,-13.0000004 13,0 0,13.0000004 4.705341,0 z"
+     id="path4360"
+     style="opacity:0.35400002;fill:none;stroke:url(#linearGradient2901);stroke-width:0.98045683;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+  <g
+     transform="matrix(0.9756098,0,0,0.9101061,-53.590358,-1.2966929)"
+     id="g4301"
+     style="display:inline">
+    <rect
+       width="40"
+       height="10"
+       rx="2.1286025"
+       ry="2.1286025"
+       x="59.530113"
+       y="1.8948202"
+       id="rect5480"
+       style="fill:url(#linearGradient4307);fill-opacity:1;stroke:#426296;stroke-width:1;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;display:inline" />
+    <path
+       d="m 7.03125,1.53125 c -0.8685059,0 -1.5,0.6314941 -1.5,1.5 l 0,4.9375 c 0,0.8685059 0.6314941,1.5 1.5,1.5 l 34.9375,0 c 0.868506,0 1.5,-0.631494 1.5,-1.5 l 0,-4.9375 c 0,-0.8685066 -0.631492,-1.5 -1.5,-1.5 l -34.9375,0 z"
+       transform="translate(55.030111,1.3948202)"
+       id="path6463"
+       style="fill:none;stroke:#ffffff;stroke-width:1;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;display:inline" />
+    <rect
+       width="12.299999"
+       height="4.3950915"
+       x="62.105114"
+       y="4.7210903"
+       id="rect6467"
+       style="fill:#d3d7cf;fill-opacity:1;stroke:none;display:inline" />
+    <rect
+       width="1.0249972"
+       height="6.592638"
+       x="76.455116"
+       y="3.6223171"
+       id="rect6469"
+       style="fill:#555753;fill-opacity:1;stroke:none;display:inline" />
+  </g>
+  <path
+     d="m 23.876714,6.0036101 2.799774,0 0.851985,-4.2599277 1.703971,6.3898916 1.277979,-3.833935 1.277978,2.5559567 1.277978,-0.8519856 5.36068,0"
+     id="path3969"
+     style="fill:none;stroke:#426296;stroke-width:0.42599279000000001px;stroke-linecap:round;stroke-linejoin:round;stroke-opacity:1;filter:url(#filter4007)"
+     inkscape:connector-curvature="0" />
+  <path
+     inkscape:connector-curvature="0"
+     style="fill:none;stroke:#426296;stroke-width:0.42599279000000001px;stroke-linecap:round;stroke-linejoin:round;stroke-opacity:1;filter:url(#filter3965)"
+     id="path3477"
+     d="m 23.876714,6.0036101 2.799774,0 0.851985,-4.2599277 1.703971,6.3898916 1.277979,-3.833935 1.277978,2.5559567 1.277978,-0.8519856 5.36068,0" />
+  <path
+     d="m 23.876714,6.0036101 2.799774,0 0.851985,-4.2599277 1.703971,6.3898916 1.277979,-3.833935 1.277978,2.5559567 1.277978,-0.8519856 5.36068,0"
+     id="path3871"
+     style="fill:none;stroke:#426296;stroke-width:0.42599279000000001px;stroke-linecap:round;stroke-linejoin:round;stroke-opacity:1;"
+     inkscape:connector-curvature="0" />
+</svg>
diff -pruN 3.4.1-6/dnd2share/src/applet-dnd2share.c 3.4.1+git20201022.a0d3415c-1/dnd2share/src/applet-dnd2share.c
--- 3.4.1-6/dnd2share/src/applet-dnd2share.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/dnd2share/src/applet-dnd2share.c	2020-10-21 15:04:44.000000000 +0000
@@ -19,7 +19,6 @@
 
 #include <string.h>
 #include <stdlib.h>
-#define __USE_POSIX
 #include <time.h>
 #include <glib/gstdio.h>
 
diff -pruN 3.4.1-6/dock-rendering/src/rendering-3D-plane.c 3.4.1+git20201022.a0d3415c-1/dock-rendering/src/rendering-3D-plane.c
--- 3.4.1-6/dock-rendering/src/rendering-3D-plane.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/dock-rendering/src/rendering-3D-plane.c	2020-10-21 15:04:44.000000000 +0000
@@ -37,8 +37,8 @@ extern cairo_surface_t *my_pFlatSeparato
 	double hi = /**myIconsParam.fReflectSize*/pDock->iIconSize * myIconsParam.fReflectHeightRatio * pDock->container.fRatio + myDocksParam.iFrameMargin;\
 	double h0 = pDock->iMaxIconHeight/** * pDock->container.fRatio*/;\
 	double H = iVanishingPointY;\
-	double l = myDocksParam.iDockLineWidth;\
-	double r = MIN (myDocksParam.iDockRadius, (hi + h0) / 2);\
+	double l = _get_dock_linewidth();\
+	double r = MIN (_get_dock_radius(), (hi + h0) / 2);\
 	double gamma = 0, h, w, dw = 0
 
 static void cd_rendering_calculate_max_dock_size_3D_plane (CairoDock *pDock)
@@ -48,7 +48,7 @@ static void cd_rendering_calculate_max_d
 	//pDock->iMaxDockHeight = (int) ((1 + myIconsParam.fAmplitude) * pDock->iMaxIconHeight + myIconsParam.fReflectSize * pDock->container.fRatio) + myIconsParam.iLabelSize + myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin;
 	
 	_define_parameters (hi, h0, H, l, r, gamma, h, w, dw);
-	double h0max = (1 + myIconsParam.fAmplitude) * pDock->iMaxIconHeight * pDock->container.fRatio + MAX ((pDock->container.bIsHorizontal ? myIconsParam.iLabelSize : 0), myDocksParam.iFrameMargin + myDocksParam.iDockLineWidth);
+	double h0max = (1 + myIconsParam.fAmplitude) * pDock->iMaxIconHeight * pDock->container.fRatio + MAX ((pDock->container.bIsHorizontal ? myIconsParam.iLabelSize : 0), myDocksParam.iFrameMargin + l);
 	pDock->iMaxDockHeight = (int) (hi + h0max + l);
 	
 	// 1ere estimation.
@@ -61,7 +61,7 @@ static void cd_rendering_calculate_max_d
 	// -> dw
 	dw = h * gamma + 0*r + (l+(r==0)*2)*sqrt(1+gamma*gamma);  // en fait, h*gamma + r*(1-sin)/cos, or (1-sin)/cos <= 1, on majore pour simplifier. on aurait r + gamma * (h - 2 * r) si on utilisait des cercles au lieu de courbes de Bezier.
 	
-	r = MIN (myDocksParam.iDockRadius, h / 2);
+	r = MIN (_get_dock_radius(), h / 2);
 	dw = r + gamma * (h - r) + (l+(r==0)*2)*sqrt(1+gamma*gamma);  // h-2r si on utilisait des cercles au lieu de courbes de Bezier.
 	//g_print ("r:%.1f, h:%.1f => dw=%.1f (%.1f)\n", r, h, dw, h * gamma + 0*r + (l+(r==0)*2)*sqrt(1+gamma*gamma));
 	
@@ -101,7 +101,7 @@ static void cd_rendering_calculate_max_d
 	
 	// taille min.
 	double fRatio = (pDock->iRefCount == 0 && pDock->iVisibility == CAIRO_DOCK_VISI_RESERVE ? 1. : pDock->container.fRatio);  // prevent the dock from resizing itself and all the maximized windows each time an icon is removed/inserted.
-	pDock->iMinDockHeight = myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin + /**myIconsParam.fReflectSize*/pDock->iIconSize * myIconsParam.fReflectHeightRatio * fRatio + pDock->iMaxIconHeight * fRatio;
+	pDock->iMinDockHeight = l + myDocksParam.iFrameMargin + /**myIconsParam.fReflectSize*/pDock->iIconSize * myIconsParam.fReflectHeightRatio * fRatio + pDock->iMaxIconHeight * fRatio;
 	
 	//double gamma_min = pDock->fFlatDockWidth / 2 / H;
 	//double dw_min = h * gamma_min + r + (l+(r==0)*2)*sqrt(1+gamma_min*gamma_min);
@@ -149,15 +149,16 @@ static void cd_rendering_make_3D_separat
 	double fRightInclination = (icon->fDrawX + icon->fWidth * icon->fScale - pDock->container.iWidth / 2) / iVanishingPointY;
 	
 	double fHeight, fBigWidth, fLittleWidth;
+	double fLineWidth = _get_dock_linewidth();
 	if (bIncludeEdges)
 	{
-		fHeight = (bBackGround ? pDock->iDecorationsHeight - hi : hi) + 2*myDocksParam.iDockLineWidth;
+		fHeight = (bBackGround ? pDock->iDecorationsHeight - hi : hi) + 2*fLineWidth;
 		fBigWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY : iVanishingPointY + fHeight);
 		fLittleWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY - fHeight : iVanishingPointY);
 	}
 	else
 	{
-		fHeight = pDock->iDecorationsHeight - myDocksParam.iDockLineWidth;
+		fHeight = pDock->iDecorationsHeight - fLineWidth;
 		fBigWidth = fabs (fRightInclination - fLeftInclination) * (iVanishingPointY + hi);
 		fLittleWidth = fabs (fRightInclination - fLeftInclination) * (iVanishingPointY + hi - fHeight);
 	}
@@ -169,12 +170,12 @@ static void cd_rendering_make_3D_separat
 	if (bIncludeEdges)
 	{
 		fDockOffsetX = icon->fDrawX - (bBackGround ? fHeight * fLeftInclination : 0);
-		fDockOffsetY = pDock->container.iHeight - fHeight - (bBackGround ? myDocksParam.iDockLineWidth + hi : -.5*myDocksParam.iDockLineWidth);
+		fDockOffsetY = pDock->container.iHeight - fHeight - (bBackGround ? fLineWidth + hi : -.5*fLineWidth);
 	}
 	else
 	{
 		fDockOffsetX = icon->fDrawX - (fHeight - hi) * fLeftInclination;
-		fDockOffsetY = pDock->container.iHeight - fHeight - myDocksParam.iDockLineWidth;
+		fDockOffsetY = pDock->container.iHeight - fHeight - fLineWidth;
 	}	
 	
 	cairo_translate (pCairoContext, fDockOffsetX, fDockOffsetY);  // coin haut gauche.
@@ -200,9 +201,10 @@ static void cd_rendering_draw_3D_separat
 	hi = (pDock->container.bDirectionUp ? pDock->container.iHeight - (icon->fDrawY + icon->fHeight * icon->fScale) : icon->fDrawY);
 	double fLeftInclination = (icon->fDrawX - pDock->container.iWidth / 2) / iVanishingPointY;
 	double fRightInclination = (icon->fDrawX + icon->fWidth * icon->fScale - pDock->container.iWidth / 2) / iVanishingPointY;
+	double fLineWidth = _get_dock_linewidth();
 	
 	double fHeight, fLittleWidth;
-	fHeight = (bBackGround ? pDock->iDecorationsHeight - hi - 0.5*myDocksParam.iDockLineWidth : hi + 1.5*myDocksParam.iDockLineWidth);
+	fHeight = (bBackGround ? pDock->iDecorationsHeight - hi - 0.5*fLineWidth : hi + 1.5*fLineWidth);
 	//fBigWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY : iVanishingPointY + fHeight);
 	fLittleWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY - fHeight : iVanishingPointY);
 	
@@ -211,9 +213,9 @@ static void cd_rendering_draw_3D_separat
 	//g_print ("fBigWidth : %.2f ; fLittleWidth : %.2f\n", fBigWidth, fLittleWidth);
 	
 	double fDockOffsetX, fDockOffsetY;
-	fDockOffsetY =  (bBackGround ? 2.*myDocksParam.iDockLineWidth : - 1.0*myDocksParam.iDockLineWidth);
+	fDockOffsetY =  (bBackGround ? 2.*fLineWidth : - 1.0*fLineWidth);
 	
-	fDockOffsetX = (bBackGround ? .5*myDocksParam.iDockLineWidth * fLeftInclination + 1.*fLeftInclination : - 0.5 * myDocksParam.iDockLineWidth * fLeftInclination);
+	fDockOffsetX = (bBackGround ? .5*fLineWidth * fLeftInclination + 1.*fLeftInclination : - 0.5 * fLineWidth * fLeftInclination);
 	//fDockOffsetX = -.5*myDocksParam.iDockLineWidth;
 	
 	
@@ -256,12 +258,13 @@ static void cd_rendering_draw_3D_separat
 		cairo_set_source_rgba (pCairoContext, 0.0, 0.0, 0.0, 1.0);
 		cairo_fill (pCairoContext);
 		
-		if (myDocksParam.iDockLineWidth != 0)
+		int iDockLineWidth = _get_dock_linewidth();
+		if (iDockLineWidth != 0)
 		{
 			cd_rendering_draw_3D_separator_edge (icon, pCairoContext, pDock, bBackGround);
 			
 			cairo_set_operator (pCairoContext, CAIRO_OPERATOR_OVER);
-			cairo_set_line_width (pCairoContext, myDocksParam.iDockLineWidth);
+			cairo_set_line_width (pCairoContext, iDockLineWidth);
 			if (myDocksParam.bUseDefaultColors)
 				gldi_style_colors_set_line_color (pCairoContext);
 			else
@@ -438,7 +441,8 @@ static gboolean _cd_separator_is_impacte
 	double fHeight;
 	if (bIncludeEdges)
 	{
-		fHeight = (bBackGround ? pDock->iDecorationsHeight - hi : hi) + (bIncludeEdges ? myDocksParam.iDockLineWidth : 0);
+		int iDockLineWidth = _get_dock_linewidth();
+		fHeight = (bBackGround ? pDock->iDecorationsHeight - hi : hi) + (bIncludeEdges ? iDockLineWidth : 0);
 		//fBigWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY : iVanishingPointY + fHeight);
 		//fLittleWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY - fHeight : iVanishingPointY);
 	}
@@ -528,8 +532,12 @@ static gboolean _cd_separator_is_impacte
 static void cd_rendering_render_optimized_3D_plane (cairo_t *pCairoContext, CairoDock *pDock, GdkRectangle *pArea)
 {
 	//g_print ("%s ((%d;%d) x (%d;%d) / (%dx%d))\n", __func__, pArea->x, pArea->y, pArea->width, pArea->height, pDock->container.iWidth, pDock->container.iHeight);
-	double fLineWidth = myDocksParam.iDockLineWidth;
+	double fLineWidth = _get_dock_linewidth();
 	double fMargin = myDocksParam.iFrameMargin;
+	double fRadius = _get_dock_radius();
+	if (2*fRadius > pDock->iDecorationsHeight + fLineWidth)
+		fRadius = (pDock->iDecorationsHeight + fLineWidth) / 2 - 1;
+	
 	int iHeight = pDock->container.iHeight;
 	
 	//\____________________ On dessine les decorations du fond sur la portion de fenetre.
@@ -553,7 +561,6 @@ static void cd_rendering_render_optimize
 	else
 		cairo_rectangle (pCairoContext, fDockOffsetX, fDockOffsetY, pDock->iDecorationsHeight, pArea->height);
 	
-	double fRadius = MIN (myDocksParam.iDockRadius, (pDock->iDecorationsHeight + myDocksParam.iDockLineWidth) / 2 - 1);
 	double fDeltaXTrapeze=0.;
 	double fOffsetX;
 	if (cairo_dock_is_extended_dock (pDock))  // mode panel etendu.
@@ -569,9 +576,6 @@ static void cd_rendering_render_optimize
 	if (pDock->backgroundBuffer.pSurface != NULL)
 	{
 		double fInclinationOnHorizon = (fDockWidth / 2) / iVanishingPointY;
-		double fRadius = myDocksParam.iDockRadius;
-		if (2*fRadius > pDock->iDecorationsHeight + fLineWidth)
-			fRadius = (pDock->iDecorationsHeight + fLineWidth) / 2 - 1;
 		double fDeltaXForLoop = fInclinationOnHorizon * (pDock->iDecorationsHeight + fLineWidth - (/**myDocksParam.bRoundedBottomCorner*/TRUE ? 2 : 1) * fRadius);
 		
 		double cosa = 1. / sqrt (1 + fInclinationOnHorizon * fInclinationOnHorizon);
diff -pruN 3.4.1-6/dock-rendering/src/rendering-commons.c 3.4.1+git20201022.a0d3415c-1/dock-rendering/src/rendering-commons.c
--- 3.4.1-6/dock-rendering/src/rendering-commons.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/dock-rendering/src/rendering-commons.c	2020-10-21 15:04:44.000000000 +0000
@@ -176,7 +176,7 @@ void cd_rendering_draw_flat_separator_op
 	
 	double fDockOffsetX, fDockOffsetY;
 	fDockOffsetX = icon->fDrawX - (fHeight - hi) * fLeftInclination;
-	fDockOffsetY = fHeight + myDocksParam.iDockLineWidth;
+	fDockOffsetY = fHeight + _get_dock_linewidth();
 	
 	glEnable (GL_BLEND);
 	glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
@@ -235,17 +235,18 @@ void cd_rendering_draw_physical_separato
 	//g_print ("%s : hi = %.2f/%.2f\n", icon->cName, myIconsParam.fReflectSize * pDock->container.fRatio + myDocksParam.iFrameMargin, pDock->container.iHeight - (icon->fDrawY + icon->fHeight * icon->fScale));
 	double fLeftInclination = (icon->fDrawX - pDock->container.iWidth / 2) / iVanishingPointY;
 	double fRightInclination = (icon->fDrawX + icon->fWidth * icon->fScale - pDock->container.iWidth / 2) / iVanishingPointY;
+	int iDockLineWidth = _get_dock_linewidth();
 	
 	double fHeight, fBigWidth, fLittleWidth;
 	if (bBackGround)
 	{
-		fHeight = pDock->iDecorationsHeight + myDocksParam.iDockLineWidth - hi;
+		fHeight = pDock->iDecorationsHeight + iDockLineWidth - hi;
 		fBigWidth = fabs (fRightInclination - fLeftInclination) * (iVanishingPointY + 0);
 		fLittleWidth = fabs (fRightInclination - fLeftInclination) * (iVanishingPointY + 0 - fHeight);
 	}
 	else
 	{
-		fHeight = hi + myDocksParam.iDockLineWidth;
+		fHeight = hi + iDockLineWidth;
 		fBigWidth = fabs (fRightInclination - fLeftInclination) * (iVanishingPointY + hi);
 		fLittleWidth = fabs (fRightInclination - fLeftInclination) * (iVanishingPointY + hi - fHeight);
 	}
@@ -255,7 +256,7 @@ void cd_rendering_draw_physical_separato
 	if (bBackGround)
 	{
 		fDockOffsetX = icon->fDrawX - fHeight * fLeftInclination;
-		fDockOffsetY = pDock->iDecorationsHeight + 2*myDocksParam.iDockLineWidth;
+		fDockOffsetY = pDock->iDecorationsHeight + 2*iDockLineWidth;
 	}
 	else
 	{
@@ -298,14 +299,14 @@ void cd_rendering_draw_physical_separato
 	glVertex3f(fLittleWidth + fDeltaXRight - fBigWidth, - fHeight, 0.);  // Top Left Of The Texture and Quad
 	glEnd();
 	
-	if (myDocksParam.iDockLineWidth != 0)
+	if (iDockLineWidth != 0)
 	{
 		glPolygonMode (GL_FRONT, GL_LINE);
 		glEnable (GL_LINE_SMOOTH);
 		glHint (GL_LINE_SMOOTH_HINT, GL_NICEST);
 		glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 		
-		glLineWidth (myDocksParam.iDockLineWidth);
+		glLineWidth (iDockLineWidth);
 		gldi_color_set_opengl (&myDocksParam.fLineColor);
 		
 		glBegin(GL_LINES);
diff -pruN 3.4.1-6/dock-rendering/src/rendering-commons.h 3.4.1+git20201022.a0d3415c-1/dock-rendering/src/rendering-commons.h
--- 3.4.1-6/dock-rendering/src/rendering-commons.h	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/dock-rendering/src/rendering-commons.h	2020-10-21 15:04:44.000000000 +0000
@@ -36,5 +36,9 @@ void cd_rendering_draw_physical_separato
 
 void cd_rendering_draw_flat_separator_opengl (Icon *icon, CairoDock *pDock);
 
+#define _get_dock_radius() (myDocksParam.bUseDefaultColors ? myStyleParam.iCornerRadius : myDocksParam.iDockRadius)
+
+#define _get_dock_linewidth() (myDocksParam.bUseDefaultColors ? myStyleParam.iLineWidth : myDocksParam.iDockLineWidth)
+
 
 #endif
diff -pruN 3.4.1-6/dock-rendering/src/rendering-config.c 3.4.1+git20201022.a0d3415c-1/dock-rendering/src/rendering-config.c
--- 3.4.1-6/dock-rendering/src/rendering-config.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/dock-rendering/src/rendering-config.c	2020-10-21 15:04:44.000000000 +0000
@@ -25,8 +25,8 @@
 #include "rendering-config.h"
 #include "rendering-rainbow.h"
 
-extern int iVanishingPointY;double my_fRainbowColor[4];
-double my_fRainbowLineColor[4];
+extern int iVanishingPointY;
+extern double my_fRainbowColor[4];
 
 extern double my_fInclinationOnHorizon;
 extern double my_fForegroundRatio;
diff -pruN 3.4.1-6/dock-rendering/src/rendering-curve.c 3.4.1+git20201022.a0d3415c-1/dock-rendering/src/rendering-curve.c
--- 3.4.1-6/dock-rendering/src/rendering-curve.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/dock-rendering/src/rendering-curve.c	2020-10-21 15:04:44.000000000 +0000
@@ -51,7 +51,7 @@ extern cairo_surface_t *my_pFlatSeparato
 #define YCurve(h, t) (h * yCurve (t))
 
 #define _define_parameters(h, hi, ti, xi, dw)\
-	double h = 4./3 * (pDock->iDecorationsHeight + myDocksParam.iDockLineWidth);  /* hauteur de controle de la courbe de Bezier, de telle facon qu'elle atteigne 'iDecorationsHeight'.*/\
+	double h = 4./3 * (pDock->iDecorationsHeight + _get_dock_linewidth());  /* hauteur de controle de la courbe de Bezier, de telle facon qu'elle atteigne 'iDecorationsHeight'.*/\
 	double hi = .5 * pDock->iMaxIconHeight * pDock->container.fRatio + myDocksParam.iFrameMargin - 1;  /* hauteur de la courbe a la 1ere icone.*/\
 	double ti = .5 * (1. - sqrt (MAX (1. - 4./3 * hi / h, 0.01)));\
 	double xi = xCurve (my_fCurveCurvature, ti);\
@@ -106,16 +106,17 @@ static void cd_rendering_calculate_max_d
 		fCurveCurvature = my_fCurveCurvature;
 		cd_rendering_calculate_reference_curve (my_fCurveCurvature);
 	}
+	int iDockLineWidth = _get_dock_linewidth();
 	
 	// on calcule tout ce qu'on peut.
 	cairo_dock_calculate_icons_positions_at_rest_linear (pDock->icons, pDock->fFlatDockWidth);
 	
 	pDock->iDecorationsHeight = myDocksParam.iFrameMargin + my_iCurveAmplitude + .5 * pDock->iMaxIconHeight;  // de bas en haut.
 	
-	pDock->iMaxDockHeight = myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin + my_iCurveAmplitude + (1 + myIconsParam.fAmplitude) * pDock->iMaxIconHeight * pDock->container.fRatio + (pDock->container.bIsHorizontal ? myIconsParam.iLabelSize : 0);  // de bas en haut.
+	pDock->iMaxDockHeight = iDockLineWidth + myDocksParam.iFrameMargin + my_iCurveAmplitude + (1 + myIconsParam.fAmplitude) * pDock->iMaxIconHeight * pDock->container.fRatio + (pDock->container.bIsHorizontal ? myIconsParam.iLabelSize : 0);  // de bas en haut.
 	
 	double fRatio = (pDock->iRefCount == 0 && pDock->iVisibility == CAIRO_DOCK_VISI_RESERVE ? 1. : pDock->container.fRatio);  // prevent the dock from resizing itself and all the maximized windows each time an icon is removed/inserted.
-	pDock->iMinDockHeight = myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin + my_iCurveAmplitude + pDock->iMaxIconHeight * fRatio;  // de bas en haut.
+	pDock->iMinDockHeight = iDockLineWidth + myDocksParam.iFrameMargin + my_iCurveAmplitude + pDock->iMaxIconHeight * fRatio;  // de bas en haut.
 	
 	_define_parameters (h, hi, ti, xi, dw);
 	
@@ -126,7 +127,7 @@ static void cd_rendering_calculate_max_d
 	dw = w * xi / (1 - 2 * xi);  // abscisse de la 1ere icone pour satisfaire a la contrainte y=hi.
 	// -> pointe
 	double tan_theta = (my_fCurveCurvature != 1 ? h / ((1 - my_fCurveCurvature) * (w + 2 * dw) / 2) : 1e6);  // la tangente a une courbe de Bezier en son origine est la droite reliant les deux premiers points de controle.
-	double fDeltaTip = .5 * myDocksParam.iDockLineWidth * sqrt (1 + tan_theta * tan_theta) / tan_theta;  // prolongement de la pointe.
+	double fDeltaTip = .5 * iDockLineWidth * sqrt (1 + tan_theta * tan_theta) / tan_theta;  // prolongement de la pointe.
 	dw += fDeltaTip;
 	//g_print ("dw : %.2f (ratio : %.2f, w : %.2f) -> W = %.2f\n", dw, pDock->container.fRatio, w, w+2*dw);
 	
@@ -162,7 +163,7 @@ static void cd_rendering_calculate_max_d
 
 static void cd_rendering_make_3D_curve_separator (Icon *icon, cairo_t *pCairoContext, CairoDock *pDock, gboolean bIncludeEdges, gboolean bBackGround)
 {
-	double fLineWidth = myDocksParam.iDockLineWidth;
+	double fLineWidth = _get_dock_linewidth();
 	double hi;
 	
 	Icon *pPrevIcon = cairo_dock_get_previous_icon (pDock->icons, icon);
@@ -240,7 +241,7 @@ static void cd_rendering_make_3D_curve_s
 		
 		double fDockWidth = cairo_dock_get_current_dock_width_linear (pDock) - 2 * myDocksParam.iFrameMargin;
 		
-		double h = 4./3 * (pDock->iDecorationsHeight + myDocksParam.iDockLineWidth);
+		double h = 4./3 * (pDock->iDecorationsHeight + fLineWidth);
 		double hi_ = .5 * pDock->iMaxIconHeight + myDocksParam.iFrameMargin - 1;
 		double ti = .5 * (1. - sqrt (MAX (1. - 4./3 * hi_ / h, 0)));
 		double xi = xCurve (my_fCurveCurvature, ti);
@@ -306,13 +307,13 @@ static void cd_rendering_make_3D_curve_s
 	double fHeight, fBigWidth, fLittleWidth;
 	if (bIncludeEdges)
 	{
-		fHeight = (bBackGround ? pDock->iDecorationsHeight - hi : hi) + myDocksParam.iDockLineWidth;
+		fHeight = (bBackGround ? pDock->iDecorationsHeight - hi : hi) + fLineWidth;
 		fBigWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY : iVanishingPointY + fHeight);
 		fLittleWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY - fHeight : iVanishingPointY);
 	}
 	else
 	{
-		fHeight = pDock->iDecorationsHeight - myDocksParam.iDockLineWidth;
+		fHeight = pDock->iDecorationsHeight - fLineWidth;
 		fBigWidth = fabs (fRightInclination - fLeftInclination) * (iVanishingPointY + hi);
 		fLittleWidth = fabs (fRightInclination - fLeftInclination) * (iVanishingPointY + hi - fHeight);
 	}
@@ -326,17 +327,17 @@ static void cd_rendering_make_3D_curve_s
 	{
 		sens = 1;
 		if (bIncludeEdges)
-			fDockOffsetY = pDock->container.iHeight - fHeight - (bBackGround ? myDocksParam.iDockLineWidth + hi : 0);
+			fDockOffsetY = pDock->container.iHeight - fHeight - (bBackGround ? fLineWidth + hi : 0);
 		else
-			fDockOffsetY = pDock->container.iHeight - fHeight - myDocksParam.iDockLineWidth;
+			fDockOffsetY = pDock->container.iHeight - fHeight - fLineWidth;
 	}
 	else
 	{
 		sens = -1;
 		if (bIncludeEdges)
-			fDockOffsetY = fHeight + (bBackGround ? myDocksParam.iDockLineWidth + hi : 0);
+			fDockOffsetY = fHeight + (bBackGround ? fLineWidth + hi : 0);
 		else
-			fDockOffsetY = fHeight + myDocksParam.iDockLineWidth;
+			fDockOffsetY = fHeight + fLineWidth;
 	}
 	
 	if (bIncludeEdges)
@@ -415,10 +416,10 @@ static void cd_rendering_draw_3D_curve_s
 	}
 	double fLeftInclination = (icon->fDrawX - pDock->container.iWidth / 2) / fVanishingDistanceLeft;
 	double fRightInclination = (icon->fDrawX + icon->fWidth * icon->fScale - pDock->container.iWidth / 2) / fVanishingDistanceRight;
-	
+	int iDockLineWidth = _get_dock_linewidth();
 	
 	double fHeight, fLittleWidth;
-	fHeight = (bBackGround ? pDock->iDecorationsHeight - hi - 0.5*myDocksParam.iDockLineWidth : hi + 1.5*myDocksParam.iDockLineWidth);
+	fHeight = (bBackGround ? pDock->iDecorationsHeight - hi - 0.5*iDockLineWidth : hi + 1.5*iDockLineWidth);
 	//fBigWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY : iVanishingPointY + fHeight);
 	fLittleWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY - fHeight : iVanishingPointY);
 	
@@ -431,14 +432,14 @@ static void cd_rendering_draw_3D_curve_s
 	if (pDock->container.bDirectionUp)
 	{
 		sens = 1;
-		fDockOffsetY =  (bBackGround ? 0.5*myDocksParam.iDockLineWidth : - 1.*myDocksParam.iDockLineWidth);
+		fDockOffsetY =  (bBackGround ? 0.5*iDockLineWidth : - 1.*iDockLineWidth);
 	}
 	else
 	{
 		sens = -1;
-		fDockOffsetY =  (bBackGround ? - 0.5*myDocksParam.iDockLineWidth : 1.*myDocksParam.iDockLineWidth);
+		fDockOffsetY =  (bBackGround ? - 0.5*iDockLineWidth : 1.*iDockLineWidth);
 	}
-	fDockOffsetX = (bBackGround ? .5*myDocksParam.iDockLineWidth * fLeftInclination + 1.*fLeftInclination : - 0.5 * myDocksParam.iDockLineWidth * fLeftInclination);
+	fDockOffsetX = (bBackGround ? .5*iDockLineWidth * fLeftInclination + 1.*fLeftInclination : - 0.5 * iDockLineWidth * fLeftInclination);
 	//fDockOffsetX = -.5*myDocksParam.iDockLineWidth;
 	
 	if (pDock->container.bIsHorizontal)
@@ -477,7 +478,7 @@ static void cd_rendering_draw_3D_curve_s
 		cd_rendering_draw_3D_curve_separator_edge (icon, pCairoContext, pDock, bBackGround);
 		
 		cairo_set_operator (pCairoContext, CAIRO_OPERATOR_OVER);
-		cairo_set_line_width (pCairoContext, myDocksParam.iDockLineWidth);
+		cairo_set_line_width (pCairoContext, _get_dock_linewidth());
 		if (myDocksParam.bUseDefaultColors)
 			gldi_style_colors_set_line_color (pCairoContext);
 		else
@@ -525,7 +526,7 @@ static void cairo_dock_draw_curved_frame
 static void cd_rendering_render_curve (cairo_t *pCairoContext, CairoDock *pDock)
 {
 	//\____________________ On definit la position du cadre.
-	double fLineWidth = myDocksParam.iDockLineWidth;
+	double fLineWidth = _get_dock_linewidth();
 	
 	_define_parameters (h, hi, ti, xi, dw);
 	double w = cairo_dock_get_current_dock_width_linear (pDock) - 2 * myDocksParam.iFrameMargin;
@@ -662,11 +663,12 @@ static gboolean _cd_separator_is_impacte
 	double hi = .5 * pDock->iMaxIconHeight + myDocksParam.iFrameMargin - 1;
 	double fLeftInclination = fabs (icon->fDrawX - pDock->container.iWidth / 2) / iVanishingPointY;
 	double fRightInclination = fabs (icon->fDrawX + icon->fWidth * icon->fScale - pDock->container.iWidth / 2) / iVanishingPointY;
+	int iDockLineWidth = _get_dock_linewidth();
 	
 	double fHeight;
 	if (bIncludeEdges)
 	{
-		fHeight = (bBackGround ? pDock->iDecorationsHeight - hi : hi) + (bIncludeEdges ? myDocksParam.iDockLineWidth : 0);
+		fHeight = (bBackGround ? pDock->iDecorationsHeight - hi : hi) + (bIncludeEdges ? iDockLineWidth : 0);
 		//fBigWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY : iVanishingPointY + fHeight);
 		//fLittleWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY - fHeight : iVanishingPointY);
 	}
@@ -756,7 +758,7 @@ static gboolean _cd_separator_is_impacte
 static void cd_rendering_render_optimized_curve (cairo_t *pCairoContext, CairoDock *pDock, GdkRectangle *pArea)
 {
 	//\____________________ On trace le cadre.
-	double fLineWidth = myDocksParam.iDockLineWidth;
+	double fLineWidth = _get_dock_linewidth();
 	_define_parameters (h, hi, ti, xi, dw);
 	int sens;
 	double dx, dy, w;
@@ -1098,7 +1100,7 @@ const CairoDockGLPath *cairo_dock_genera
 static void cd_rendering_render_curve_opengl (CairoDock *pDock)
 {
 	//\____________________ On definit la position du cadre.
-	double fLineWidth = myDocksParam.iDockLineWidth;
+	double fLineWidth = _get_dock_linewidth();;
 	
 	_define_parameters (h, hi, ti, xi, dw);
 	double w = cairo_dock_get_current_dock_width_linear (pDock) - 2 * myDocksParam.iFrameMargin;
diff -pruN 3.4.1-6/dock-rendering/src/rendering-panel.c 3.4.1+git20201022.a0d3415c-1/dock-rendering/src/rendering-panel.c
--- 3.4.1-6/dock-rendering/src/rendering-panel.c	2015-02-19 16:01:14.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/dock-rendering/src/rendering-panel.c	2020-10-21 15:04:44.000000000 +0000
@@ -26,6 +26,7 @@
 
 #include <cairo.h>
 
+#include "rendering-commons.h"
 #include "rendering-panel.h"
 
 extern gdouble my_fPanelRadius;
@@ -75,7 +76,8 @@ static void cd_compute_size (CairoDock *
 	
 	//\_____________ On en deduit l'ecart entre les groupes d'icones.
 	double W = cairo_dock_get_max_authorized_dock_width (pDock);
-	double fScreenBorderGap = myDocksParam.iDockRadius + myDocksParam.iDockLineWidth;  // on laisse un ecart avec le bord de l'ecran.
+	int iDockLineWidth = _get_dock_linewidth();
+	double fScreenBorderGap = _get_dock_radius() + iDockLineWidth;  // on laisse un ecart avec le bord de l'ecran.
 	double fGroupGap = (iNbGroups > 1 ? (W - 2*fScreenBorderGap - fGroupsWidth) / (iNbGroups - 1) : W - fScreenBorderGap - fGroupsWidth);
 	if (fGroupGap < myIconsParam.iIconGap)  // les icones depassent en largeur.
 		fGroupGap = myIconsParam.iIconGap;
@@ -116,13 +118,13 @@ static void cd_compute_size (CairoDock *
 	pDock->iMaxDockWidth = pDock->fFlatDockWidth = pDock->iMinDockWidth = MAX (W, x);  // if > W, we'll come back here with a smaller ratio.
 	//g_print ("iMaxDockWidth : %d (%.2f)\n", pDock->iMaxDockWidth, pDock->container.fRatio);
 	
-	pDock->iMaxDockHeight = myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin + hicon * pDock->container.fRatio + myDocksParam.iFrameMargin + myDocksParam.iDockLineWidth + (pDock->container.bIsHorizontal ? myIconsParam.iLabelSize : 0);
+	pDock->iMaxDockHeight = iDockLineWidth + myDocksParam.iFrameMargin + hicon * pDock->container.fRatio + myDocksParam.iFrameMargin + iDockLineWidth + (pDock->container.bIsHorizontal ? myIconsParam.iLabelSize : 0);
 	
 	pDock->iMaxDockHeight = MAX (pDock->iMaxDockHeight, pDock->iMaxIconHeight * (1 + myIconsParam.fAmplitude));  // au moins la taille du FBO.
 	//g_print ("panel view: pDock->iMaxIconHeight = %d\n", pDock->iMaxIconHeight);
 	
 	pDock->iDecorationsWidth = pDock->iMaxDockWidth;
-	pDock->iMinDockHeight = 2 * (myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin) + hicon * pDock->container.fRatio;  /// TODO: make the height constant, to avoid moving all windows when space is reserved and ratio changes.
+	pDock->iMinDockHeight = 2 * (iDockLineWidth + myDocksParam.iFrameMargin) + hicon * pDock->container.fRatio;  /// TODO: make the height constant, to avoid moving all windows when space is reserved and ratio changes.
 	
 	pDock->iActiveWidth = pDock->iMaxDockWidth;
 	pDock->iActiveHeight = pDock->iMinDockHeight;
@@ -142,9 +144,11 @@ static void cd_compute_size (CairoDock *
 static void cd_render (cairo_t *pCairoContext, CairoDock *pDock)
 {
 	//\____________________ On trace le cadre.
-	double fLineWidth = myDocksParam.iDockLineWidth;
+	double fLineWidth = _get_dock_linewidth();
 	double fMargin = myDocksParam.iFrameMargin;
-	double fRadius = (pDock->iDecorationsHeight + fLineWidth - 2 * myDocksParam.iDockRadius > 0 ? myDocksParam.iDockRadius : (pDock->iDecorationsHeight + fLineWidth) / 2 - 1);
+	double fRadius = _get_dock_radius();
+	if (2 * fRadius > pDock->iDecorationsHeight + fLineWidth)
+		fRadius = (pDock->iDecorationsHeight + fLineWidth) / 2 - 1;
 	double fExtraWidth = 2 * fRadius + fLineWidth;
 	double fDockWidth;
 	int sens;
@@ -321,7 +325,7 @@ static void cd_render (cairo_t *pCairoCo
 static void cd_render_optimized (cairo_t *pCairoContext, CairoDock *pDock, GdkRectangle *pArea)
 {
 	//g_print ("%s ((%d;%d) x (%d;%d) / (%dx%d))\n", __func__, pArea->x, pArea->y, pArea->width, pArea->height, pDock->container.iWidth, pDock->container.iHeight);
-	double fLineWidth = myDocksParam.iDockLineWidth;
+	double fLineWidth = _get_dock_linewidth();
 	double fMargin = myDocksParam.iFrameMargin;
 	int iHeight = pDock->container.iHeight;
 
@@ -347,7 +351,7 @@ static void cd_render_optimized (cairo_t
 
 	fDockOffsetY = (pDock->container.bDirectionUp ? pDock->container.iHeight - pDock->iDecorationsHeight - fLineWidth : fLineWidth);
 	
-	double fRadius = MIN (myDocksParam.iDockRadius, (pDock->iDecorationsHeight + myDocksParam.iDockLineWidth) / 2 - 1);
+	double fRadius = MIN (_get_dock_radius(), (pDock->iDecorationsHeight + fLineWidth) / 2 - 1);
 	double fOffsetX;
 	if (cairo_dock_is_extended_dock (pDock))  // mode panel etendu.
 	{
@@ -438,9 +442,11 @@ static void cd_render_optimized (cairo_t
 static void cd_render_opengl (CairoDock *pDock)
 {
 	//\_____________ On definit notre rectangle.
-	double fLineWidth = myDocksParam.iDockLineWidth;
+	double fLineWidth = _get_dock_linewidth();
 	double fMargin = myDocksParam.iFrameMargin;
-	double fRadius = (pDock->iDecorationsHeight + fLineWidth - 2 * myDocksParam.iDockRadius > 0 ? myDocksParam.iDockRadius : (pDock->iDecorationsHeight + fLineWidth) / 2 - 1);
+	double fRadius = _get_dock_radius();
+	if (2 * fRadius > pDock->iDecorationsHeight + fLineWidth)
+		fRadius = (pDock->iDecorationsHeight + fLineWidth) / 2 - 1;
 	double fExtraWidth = 2 * fRadius + fLineWidth;
 	double fDockWidth;
 	double fFrameHeight = pDock->iDecorationsHeight + fLineWidth;
@@ -660,7 +666,8 @@ static Icon *cd_calculate_icons (CairoDo
 	
 	//\_____________ On en deduit l'ecart entre les groupes d'icones.
 	double W = cairo_dock_get_max_authorized_dock_width (pDock);
-	double fScreenBorderGap = myDocksParam.iDockRadius + myDocksParam.iDockLineWidth;  // on laisse un ecart avec le bord de l'ecran.
+	int iDockLineWidth = _get_dock_linewidth();
+	double fScreenBorderGap = _get_dock_radius() + iDockLineWidth;  // on laisse un ecart avec le bord de l'ecran.
 	double fGroupGap;
 	if (iNbGroups > 1)
 	{
@@ -725,9 +732,9 @@ static Icon *cd_calculate_icons (CairoDo
 		pIcon->fDrawX = pIcon->fX;
 		
 		if (pDock->container.bDirectionUp)
-			pIcon->fY = pDock->iMaxDockHeight - (myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin + pIcon->fHeight);
+			pIcon->fY = pDock->iMaxDockHeight - (iDockLineWidth + myDocksParam.iFrameMargin + pIcon->fHeight);
 		else
-			pIcon->fY = myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin;
+			pIcon->fY = iDockLineWidth + myDocksParam.iFrameMargin;
 		pIcon->fDrawY = pIcon->fY;
 		
 		pIcon->fWidthFactor = 1.;
diff -pruN 3.4.1-6/dock-rendering/src/rendering-rainbow.c 3.4.1+git20201022.a0d3415c-1/dock-rendering/src/rendering-rainbow.c
--- 3.4.1-6/dock-rendering/src/rendering-rainbow.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/dock-rendering/src/rendering-rainbow.c	2020-10-21 15:04:44.000000000 +0000
@@ -26,6 +26,7 @@
 
 #include <cairo.h>
 
+#include "rendering-commons.h"
 #include "rendering-rainbow.h"
 
 extern int my_iSpaceBetweenRows;
@@ -178,7 +179,7 @@ static void cd_rendering_render_rainbow
 			cairo_translate (pCairoContext, 0., pDock->container.iHeight);
 			cairo_scale (pCairoContext, 1., -1.);
 		}
-		cairo_set_line_width (pCairoContext, myDocksParam.iDockLineWidth);
+		cairo_set_line_width (pCairoContext, _get_dock_linewidth());
 		cairo_move_to (pCairoContext, pDock->container.iWidth/2 - fRadius * cos (my_fRainbowConeOffset), pDock->container.iHeight - fRadius * sin (my_fRainbowConeOffset));
 		cairo_line_to (pCairoContext, pDock->container.iWidth/2, pDock->container.iHeight);
 		cairo_line_to (pCairoContext, pDock->container.iWidth/2 + fRadius * cos (my_fRainbowConeOffset), pDock->container.iHeight - fRadius * sin (my_fRainbowConeOffset));
@@ -676,7 +677,7 @@ static void cd_rendering_render_rainbow_
 		pVertexTab[2*4+0] = - pVertexTab[2*0+0];
 		pVertexTab[2*4+1] = pVertexTab[2*0+1];
 		
-		cairo_dock_draw_current_path_opengl (myDocksParam.iDockLineWidth, my_fRainbowLineColor, 5);
+		cairo_dock_draw_current_path_opengl (_get_dock_linewidth(), my_fRainbowLineColor, 5);
 		
 		glDisableClientState(GL_COLOR_ARRAY);
 		glPopMatrix ();
diff -pruN 3.4.1-6/Doncky/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/Doncky/data/misc/icon.svg
--- 3.4.1-6/Doncky/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Doncky/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,634 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   version="1.0"
+   width="48"
+   height="48"
+   id="svg36265">
+  <defs
+     id="defs36267">
+    <linearGradient
+       id="linearGradient5048">
+      <stop
+         id="stop5050"
+         style="stop-color:black;stop-opacity:0"
+         offset="0" />
+      <stop
+         id="stop5056"
+         style="stop-color:black;stop-opacity:1"
+         offset="0.5" />
+      <stop
+         id="stop5052"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="302.85715"
+       y1="366.64789"
+       x2="302.85715"
+       y2="609.50507"
+       id="linearGradient2611"
+       xlink:href="#linearGradient5048"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.06732488,0,0,0.01470022,-0.3411391,37.040146)" />
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient2608"
+       xlink:href="#linearGradient5060"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.02303994,0,0,0.01470022,21.62311,37.040176)" />
+    <linearGradient
+       id="linearGradient5060">
+      <stop
+         id="stop5062"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop5064"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient2605"
+       xlink:href="#linearGradient5060"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.02303995,0,0,0.01470022,26.360882,37.040176)" />
+    <linearGradient
+       id="linearGradient2490">
+      <stop
+         id="stop2492"
+         style="stop-color:#2e4a5a;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2494"
+         style="stop-color:#6e8796;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="-51.786404"
+       y1="53.623615"
+       x2="-51.786404"
+       y2="2.9062471"
+       id="linearGradient2602"
+       xlink:href="#linearGradient2490"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.8074968,0,0,0.8948322,59.410232,-2.9805533)" />
+    <linearGradient
+       id="linearGradient3993">
+      <stop
+         id="stop3995"
+         style="stop-color:#a3c0d0;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4001"
+         style="stop-color:#427da1;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="14.76559"
+       cy="10.898237"
+       r="18.000002"
+       fx="14.76559"
+       fy="10.898237"
+       id="radialGradient2600"
+       xlink:href="#linearGradient3993"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-2.2703142e-8,2.1357283,-3.5601359,-3.7844828e-8,54.620625,-24.438287)" />
+    <radialGradient
+       cx="102"
+       cy="112.3047"
+       r="139.55859"
+       id="XMLID_8_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         id="stop41"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop47"
+         style="stop-color:black;stop-opacity:1"
+         offset="0.18851049" />
+      <stop
+         id="stop49"
+         style="stop-color:black;stop-opacity:0"
+         offset="0.25718147" />
+      <stop
+         id="stop51"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </radialGradient>
+    <radialGradient
+       cx="102"
+       cy="112.3047"
+       r="139.55859"
+       id="radialGradient2597"
+       xlink:href="#XMLID_8_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.3617022,0,0,-0.3907784,0.8510637,47.517004)" />
+    <linearGradient
+       id="linearGradient3211">
+      <stop
+         id="stop3213"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3215"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="24"
+       y1="1.9999999"
+       x2="24"
+       y2="46.01725"
+       id="linearGradient2594"
+       xlink:href="#linearGradient3211"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1,0,0,0.9777778,0,-0.9666693)" />
+    <linearGradient
+       id="linearGradient4267">
+      <stop
+         id="stop4269"
+         style="stop-color:#c4c4c4;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4271"
+         style="stop-color:#c4c4c4;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="35.516502"
+       y1="4.8577352"
+       x2="34.102982"
+       y2="6.5436172"
+       id="linearGradient2591"
+       xlink:href="#linearGradient4267"
+       gradientUnits="userSpaceOnUse" />
+    <filter
+       x="-0.14846256"
+       y="-0.16434373"
+       width="1.2969251"
+       height="1.3286875"
+       color-interpolation-filters="sRGB"
+       id="filter3212">
+      <feGaussianBlur
+         id="feGaussianBlur3214"
+         stdDeviation="0.77391625" />
+    </filter>
+    <linearGradient
+       id="linearGradient8589">
+      <stop
+         id="stop8591"
+         style="stop-color:#fefefe;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop8593"
+         style="stop-color:#cbcbcb;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="32.892288"
+       y1="8.0590115"
+       x2="36.358372"
+       y2="5.4565363"
+       id="linearGradient2581"
+       xlink:href="#linearGradient8589"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9976985,0,0,1.0406866,0.1638029,-1.1057939)" />
+  </defs>
+  <g
+     id="layer1">
+    <rect
+       width="32.508301"
+       height="3.5700529"
+       x="7.7378473"
+       y="42.429947"
+       id="rect2879"
+       style="opacity:0.3;fill:url(#linearGradient2611);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+    <path
+       d="m 7.7378475,42.430102 c 0,0 0,3.569856 0,3.569856 -1.1865002,0.0067 -2.8683795,-0.799823 -2.8683795,-1.785158 0,-0.985333 1.3240446,-1.784697 2.8683795,-1.784698 z"
+       id="path2881"
+       style="opacity:0.3;fill:url(#radialGradient2608);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+    <path
+       d="m 40.246148,42.430102 c 0,0 0,3.569856 0,3.569856 1.1865,0.0067 2.86838,-0.799823 2.86838,-1.785158 0,-0.985333 -1.324045,-1.784697 -2.86838,-1.784698 z"
+       id="path2883"
+       style="opacity:0.3;fill:url(#radialGradient2605);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+    <path
+       d="m 6.4999609,0.49719878 c 8.0202951,0 16.0405901,0 24.0608861,0 0.525234,1.96019962 6.133094,6.85160272 10.939195,9.62640622 0,11.459733 0,22.919465 0,34.379198 -11.666694,0 -23.333387,0 -35.0000811,0 0,-14.668535 0,-29.33707 0,-44.00560422 z"
+       id="path4160"
+       style="fill:url(#radialGradient2600);fill-opacity:1;stroke:url(#linearGradient2602);stroke-width:0.99992186;stroke-linecap:butt;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;display:inline" />
+    <path
+       d="m 7.3617017,44 c -0.199297,0 -0.361702,-0.175459 -0.361702,-0.39078 l 0,-42.2040499 c 0,-0.2157088 0.162405,-0.3907775 0.361702,-0.3907775 C 14.844793,1.1224073 23.137385,0.85281757 30.611384,1.0412872 L 40.894021,9.9073127 41,43.60922 C 41,43.824541 40.837957,44 40.638297,44 L 7.3617017,44 z"
+       id="path4191"
+       style="opacity:0.05;fill:url(#radialGradient2597);fill-opacity:1" />
+    <path
+       d="m 40.500039,10.258811 c 0,10.949037 0,22.31441 0,33.263447 -11.000026,0 -22.000052,0 -33.0000781,0 0,-14.014841 0,-28.029681 0,-42.0445213 7.5619931,0 15.3043341,0 22.8663281,0"
+       id="path2435"
+       style="opacity:0.4;fill:none;stroke:url(#linearGradient2594);stroke-width:1;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;display:inline" />
+    <path
+       d="m 30.560847,0.5 c 1.406933,0.4746531 8.965454,5.8794034 10.939195,9.623605 0,11.459733 0,0.825538 0,12.285271 C 1.0542159,38.137806 6.2643971,0.5 30.560847,0.5 z"
+       id="path4238"
+       style="fill:none;stroke:url(#linearGradient2591);stroke-width:0.99992186;stroke-linecap:butt;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;display:inline" />
+    <path
+       d="m 33.5185,6.5184992 -25.037,-0.037"
+       id="path3318"
+       style="opacity:0.15;fill:none;stroke:white;stroke-width:0.96299994;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="M 11.5185,2.4814998 11.4815,43.518498"
+       id="path3332"
+       style="opacity:0.15;fill:none;stroke:white;stroke-width:0.96299982;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="M 36.4815,43.5185 36.5185,6.9135006"
+       id="path3344"
+       style="opacity:0.15;fill:white;fill-rule:evenodd;stroke:white;stroke-width:0.96299982;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="M 16.5185,2.4814998 16.4815,43.518498"
+       id="path2512"
+       style="opacity:0.15;fill:none;stroke:white;stroke-width:0.96299982;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="M 21.5185,2.4814998 21.4815,43.518498"
+       id="path2514"
+       style="opacity:0.15;fill:none;stroke:white;stroke-width:0.96299982;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="M 26.5185,2.4814998 26.4815,43.518498"
+       id="path2516"
+       style="opacity:0.15;fill:none;stroke:white;stroke-width:0.96299982;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="M 31.5185,2.4814998 31.4815,43.518498"
+       id="path2518"
+       style="opacity:0.15;fill:white;fill-rule:evenodd;stroke:white;stroke-width:0.96299982;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="M 39.518501,11.5185 8.4815006,11.4815"
+       id="path3290"
+       style="opacity:0.15;fill:none;stroke:white;stroke-width:0.963;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="M 39.518501,16.5185 8.4815006,16.4815"
+       id="path3292"
+       style="opacity:0.15;fill:none;stroke:white;stroke-width:0.963;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="M 39.518501,21.5185 8.4815006,21.4815"
+       id="path3294"
+       style="opacity:0.15;fill:none;stroke:white;stroke-width:0.963;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="M 39.518501,26.5185 8.4815006,26.4815"
+       id="path3296"
+       style="opacity:0.15;fill:none;stroke:white;stroke-width:0.963;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="M 39.518501,31.5185 8.4815006,31.4815"
+       id="path3298"
+       style="opacity:0.15;fill:none;stroke:white;stroke-width:0.963;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="M 39.518501,36.5185 8.4815006,36.4815"
+       id="path3300"
+       style="opacity:0.15;fill:none;stroke:white;stroke-width:0.963;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="M 39.518501,41.5185 8.4815006,41.4815"
+       id="path3302"
+       style="opacity:0.15;fill:none;stroke:white;stroke-width:0.963;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="m 23.5185,6.5185013 -13.037,-0.037"
+       id="path3554"
+       style="opacity:0.5;fill:none;stroke:white;stroke-width:0.96299994;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="M 11.5185,4.4815019 11.4815,23.518501"
+       id="path3556"
+       style="opacity:0.5;fill:none;stroke:white;stroke-width:0.96299988;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="m 20.4815,41.481504 17.037,0.037"
+       id="path3342"
+       style="opacity:0.5;fill:none;stroke:white;stroke-width:0.96299988;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="m 36.4815,43.5185 0.037,-15.036999"
+       id="path3559"
+       style="opacity:0.5;fill:none;stroke:white;stroke-width:0.96299976;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="m 28.617256,0.92125832 c 4.282522,0 2.15325,8.48317128 2.15325,8.48317128 0,0 10.357642,-1.8023467 10.357642,2.8187444 0,-2.6097233 -11.302304,-10.7285956 -12.510892,-11.30191568 z"
+       id="path12038"
+       style="opacity:0.4;fill:black;fill-opacity:1;fill-rule:evenodd;stroke:none;display:inline;filter:url(#filter3212)" />
+    <path
+       d="m 28.617256,0.92125832 c 3.186493,0 2.33576,7.66187848 2.33576,7.66187848 0,0 10.175132,-0.9810539 10.175132,3.6400372 0,-1.125939 0.08591,-1.932245 -0.133777,-2.2835928 C 39.416058,7.4154025 32.881194,1.7511811 30.41941,1.008793 30.235188,0.95323837 29.544367,0.92125832 28.617256,0.92125832 z"
+       id="path4474"
+       style="fill:url(#linearGradient2581);fill-opacity:1;fill-rule:evenodd;stroke:none;display:inline" />
+    <path
+       d="m 15.418139,14.488215 c -0.984178,0.655811 -0.867847,2.37835 0.205592,2.888211 2.446567,0.889629 4.03338,-0.373088 4.611805,-2.716069 0.01594,-0.345284 0.145762,-0.852771 -0.366912,-0.694374 -1.53566,-0.0742 -2.998979,0.03158 -4.450485,0.522232 z m 6.581859,-1.16849 c 10e-7,1.811225 10e-7,3.622449 10e-7,5.433674 -0.583509,0 -1.167019,0 -1.750528,0 -0.03443,-0.401185 0.06962,-1.254643 -0.05338,-1.366595 -0.685348,0.999506 -1.880735,1.541418 -3.071008,1.593509 -3.191549,0.153979 -4.589253,-1.776793 -3.656989,-4.706193 1.789679,-1.856738 4.352084,-1.533176 6.735433,-1.533988 -0.102484,-3.0989613 -4.019309,-2.394731 -6.105457,-1.780758 -0.553096,0.370674 -0.235482,-0.534077 -0.317946,-0.852318 -0.191423,-0.6987361 0.743586,-0.5876142 1.18473,-0.7923279 1.606758,-0.3878425 3.363654,-0.5006931 4.927038,0.1208233 1.637293,0.8020096 1.980037,2.2409526 2.108103,3.8841736 z"
+       id="text34519"
+       style="font-size:18.4205246px;font-style:normal;font-weight:normal;opacity:0.6;fill:white;fill-opacity:1;stroke:none;font-family:Bitstream Vera Sans" />
+    <path
+       d="m 13.000001,22.000001 2.345838,0 0,1 -2.345838,0 0,-1 z"
+       id="path3406"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 15.66538,22.000001 2.213403,0 0,1 -2.213403,0 0,-1 z"
+       id="path3404"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 18.198324,22.000001 1.948514,0 0,1 -1.948514,0 0,-1 z"
+       id="path3402"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 20.46638,22.000001 0.855871,0 0,1 -0.855871,0 0,-1 z"
+       id="path3399"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 21.641802,22.000001 1.915398,0 0,1 -1.915398,0 0,-1 z"
+       id="path3397"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 23.876751,22.000001 4.961553,0 0,1 -4.961553,0 0,-1 z"
+       id="path3395"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 29.157845,22.000001 3.769581,0 0,1 -3.769581,0 0,-1 z"
+       id="path3392"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 33.246978,22.000001 1.153856,0 0,1 -1.153856,0 0,-1 z"
+       id="path3389"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 13.000001,28.000001 3.691817,0 0,1 -3.691817,0 0,-1 z"
+       id="path3385"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 16.965762,28.000001 1.776154,0 0,1 -1.776154,0 0,-1 z"
+       id="path3383"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 19.116682,28.000001 0.835125,0 0,1 -0.835125,0 0,-1 z"
+       id="path3381"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 20.158534,28.000001 1.608114,0 0,1 -1.608114,0 0,-1 z"
+       id="path3379"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 22.040582,28.000001 1.608115,0 0,1 -1.608115,0 0,-1 z"
+       id="path3373"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 24.157899,28.000001 2.582748,0 0,1 -2.582748,0 0,-1 z"
+       id="path3371"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 27.048195,28.000001 3.389342,0 0,1 -3.389342,0 0,-1 z"
+       id="path3369"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 30.913124,28.000001 2.280283,0 0,1 -2.280283,0 0,-1 z"
+       id="path3367"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 33.467342,28.000001 0.532659,0 0,1 -0.532659,0 0,-1 z"
+       id="path3365"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 13.000001,24.000001 3.928045,0 0,1 -3.928045,0 0,-1 z"
+       id="path3363"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 17.235966,24.000001 4.208949,0 0,1 -4.208949,0 0,-1 z"
+       id="path3361"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 21.752835,24.000001 1.680758,0 0,1 -1.680758,0 0,-1 z"
+       id="path3359"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 23.741513,24.000001 3.959254,0 0,1 -3.959254,0 0,-1 z"
+       id="path3357"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 31.027365,24.000001 1.056505,0 0,1 -1.056505,0 0,-1 z"
+       id="path3355"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 28.008687,24.000001 2.710758,0 0,1 -2.710758,0 0,-1 z"
+       id="path3353"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 32.391791,24.000001 1,0 0,1 -1,0 0,-1 z"
+       id="path3351"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 13.000001,26.000001 4.28514,0 0,1 -4.28514,0 0,-1 z"
+       id="path3347"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 17.621054,26.000001 4.59158,0 0,1 -4.59158,0 0,-1 z"
+       id="path3345"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 22.548547,26.000001 1.833555,0 0,1 -1.833555,0 0,-1 z"
+       id="path3343"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 24.718015,26.000001 4.319185,0 0,1 -4.319185,0 0,-1 z"
+       id="path3341"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 32.666216,26.000001 1.152552,0 0,1 -1.152552,0 0,-1 z"
+       id="path3339"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 29.373113,26.000001 2.95719,0 0,1 -2.95719,0 0,-1 z"
+       id="path3337"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 13.000001,34 3.691817,0 0,1 -3.691817,0 0,-1 z"
+       id="path3176"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 16.965762,34 1.776154,0 0,1 -1.776154,0 0,-1 z"
+       id="path3174"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 19.116682,34 0.835125,0 0,1 -0.835125,0 0,-1 z"
+       id="path3172"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 20.158534,34 1.608114,0 0,1 -1.608114,0 0,-1 z"
+       id="path3170"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 22.040582,34 1.608115,0 0,1 -1.608115,0 0,-1 z"
+       id="path3168"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 24.157899,34 2.582748,0 0,1 -2.582748,0 0,-1 z"
+       id="path3166"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 27.048195,34 3.389342,0 0,1 -3.389342,0 0,-1 z"
+       id="path3164"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 30.913124,34 2.280283,0 0,1 -2.280283,0 0,-1 z"
+       id="path3162"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 33.467342,34 0.532659,0 0,1 -0.532659,0 0,-1 z"
+       id="path3160"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 13.000001,32 3.061572,0 0,1 -3.061572,0 0,-1 z"
+       id="path3158"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 16.386811,32 5.083544,0 0,1 -5.083544,0 0,-1 z"
+       id="path3156"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 21.795593,32 2.454976,0 0,1 -2.454976,0 0,-1 z"
+       id="path3154"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 27.187523,32 1.949485,0 0,1 -1.949485,0 0,-1 z"
+       id="path3152"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 29.462246,32 3.128973,0 0,1 -3.128973,0 0,-1 z"
+       id="path3150"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 24.575807,32 2.286488,0 0,1 -2.286488,0 0,-1 z"
+       id="path3146"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 13.000001,35.99828 3.868703,0 0,1 -3.868703,0 0,-1 z"
+       id="path35069"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 17.188156,35.99828 1.218185,0 0,1 -1.218185,0 0,-1 0,0 z"
+       id="path35067"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 18.725793,35.99828 2.781317,0 0,1 -2.781317,0 0,-1 z"
+       id="path35065"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 21.826562,35.99828 1.89781,0 0,1 -1.89781,0 0,-1 z"
+       id="path35063"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 24.043824,35.99828 1.8978,0 0,1 -1.8978,0 0,-1 z"
+       id="path35061"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 26.261087,35.99828 2.747329,0 0,1 -2.747329,0 0,-1 z"
+       id="path35059"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 29.327858,35.99828 0.572556,0 0,1 -0.572556,0 0,-1 z"
+       id="path35057"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 30.219866,35.99828 3.562873,0 0,1 -3.562873,0 0,-1 z"
+       id="path35055"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 13.000001,37.99828 3.796419,0 0,1 -3.796419,0 0,-1 z"
+       id="path35051"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 19.256707,37.99828 2.438723,0 0,1 -2.438723,0 0,-1 z"
+       id="path35049"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 22.045643,37.99828 2.235065,0 0,1 -2.235065,0 0,-1 z"
+       id="path35047"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 28.036462,37.99828 1.963539,0 0,1 -1.963539,0 0,-1 0,0 z"
+       id="path35045"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 26.910715,37.99828 0.775544,0 0,1 -0.775544,0 0,-1 z"
+       id="path35043"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 24.630921,37.99828 1.929581,0 0,1 -1.929581,0 0,-1 z"
+       id="path35041"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 17.146623,37.99828 1.759881,0 0,1 -1.759881,0 0,-1 0,0 z"
+       id="path35006"
+       style="opacity:0.6;fill:white;fill-opacity:1;stroke:none;display:inline" />
+    <path
+       d="m 24.5,10.5 2.000693,0"
+       id="path35629"
+       style="opacity:0.6;fill:none;stroke:white;stroke-width:0.99999982px;stroke-linecap:square;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 28,10.5 1.9997,0"
+       id="path36140"
+       style="opacity:0.6;fill:none;stroke:white;stroke-width:0.9999997px;stroke-linecap:square;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 31.5,10.5 2.000915,0"
+       id="path36142"
+       style="opacity:0.6;fill:none;stroke:white;stroke-width:0.99999964px;stroke-linecap:square;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 24.5,12.5 2.000693,0"
+       id="path36150"
+       style="opacity:0.6;fill:none;stroke:white;stroke-width:0.99999982px;stroke-linecap:square;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 28,12.5 1.9997,0"
+       id="path36152"
+       style="opacity:0.6;fill:none;stroke:white;stroke-width:0.9999997px;stroke-linecap:square;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 31.5,12.5 0.001,0"
+       id="path36154"
+       style="opacity:0.6;fill:none;stroke:white;stroke-width:0.99999964px;stroke-linecap:square;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 24.5,14.5 3,0"
+       id="path36156"
+       style="opacity:0.6;fill:none;stroke:white;stroke-width:0.99999982px;stroke-linecap:square;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 29,14.5 1.5,0"
+       id="path36158"
+       style="opacity:0.6;fill:none;stroke:white;stroke-width:0.9999997px;stroke-linecap:square;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 32,14.5 1,0"
+       id="path36160"
+       style="opacity:0.6;fill:none;stroke:white;stroke-width:0.99999964px;stroke-linecap:square;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 24.5,16.5 2.000693,0"
+       id="path36162"
+       style="opacity:0.6;fill:none;stroke:white;stroke-width:0.99999982px;stroke-linecap:square;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 28,16.5 1.9997,0"
+       id="path36164"
+       style="opacity:0.6;fill:none;stroke:white;stroke-width:0.9999997px;stroke-linecap:square;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 31.5,16.5 2.000915,0"
+       id="path36166"
+       style="opacity:0.6;fill:none;stroke:white;stroke-width:0.99999964px;stroke-linecap:square;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 24.5,18.5 3,0"
+       id="path36168"
+       style="opacity:0.6;fill:none;stroke:white;stroke-width:0.99999982px;stroke-linecap:square;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 29,18.5 1.5,0"
+       id="path36170"
+       style="opacity:0.6;fill:none;stroke:white;stroke-width:0.9999997px;stroke-linecap:square;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 32,18.5 10e-4,0"
+       id="path36172"
+       style="opacity:0.6;fill:none;stroke:white;stroke-width:0.99999964px;stroke-linecap:square;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 33.5,18.5 10e-4,0"
+       id="path36174"
+       style="opacity:0.6;fill:none;stroke:white;stroke-width:0.99999964px;stroke-linecap:square;stroke-linejoin:miter;stroke-opacity:1" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/drop-indicator/data/misc/lightning_icon_benji_par_01.svg 3.4.1+git20201022.a0d3415c-1/drop-indicator/data/misc/lightning_icon_benji_par_01.svg
--- 3.4.1-6/drop-indicator/data/misc/lightning_icon_benji_par_01.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/drop-indicator/data/misc/lightning_icon_benji_par_01.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,82 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 20010904//EN"
+"http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd">
+<!-- Created with Inkscape (http://www.inkscape.org/) --><svg height="200.00000pt" id="svg4845" inkscape:export-filename="/home/bpcomp/images/icon64test.png" inkscape:export-xdpi="72.000000" inkscape:export-ydpi="72.000000" inkscape:version="0.40" sodipodi:docbase="/home/bpcomp/Inkscape" sodipodi:docname="lightning-icon.svg" sodipodi:version="0.32" width="200.00000pt" xmlns="http://www.w3.org/2000/svg" xmlns:cc="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:xlink="http://www.w3.org/1999/xlink">
+  <metadata>
+    <rdf:RDF xmlns:cc="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
+      <cc:Work rdf:about="">
+        <dc:title>Lightning Icon</dc:title>
+        <dc:description></dc:description>
+        <dc:subject>
+          <rdf:Bag>
+            <rdf:li>icon</rdf:li>
+            <rdf:li>weather</rdf:li>
+            <rdf:li>lightning</rdf:li>
+          </rdf:Bag>
+        </dc:subject>
+        <dc:publisher>
+          <cc:Agent rdf:about="http://www.openclipart.org">
+            <dc:title>Benji Park</dc:title>
+          </cc:Agent>
+        </dc:publisher>
+        <dc:creator>
+          <cc:Agent>
+            <dc:title>Benji Park</dc:title>
+          </cc:Agent>
+        </dc:creator>
+        <dc:rights>
+          <cc:Agent>
+            <dc:title>Benji Park</dc:title>
+          </cc:Agent>
+        </dc:rights>
+        <dc:date></dc:date>
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
+        <cc:license rdf:resource="http://web.resource.org/cc/PublicDomain"/>
+        <dc:language>en</dc:language>
+      </cc:Work>
+      <cc:License rdf:about="http://web.resource.org/cc/PublicDomain">
+        <cc:permits rdf:resource="http://web.resource.org/cc/Reproduction"/>
+        <cc:permits rdf:resource="http://web.resource.org/cc/Distribution"/>
+        <cc:permits rdf:resource="http://web.resource.org/cc/DerivativeWorks"/>
+      </cc:License>
+    </rdf:RDF>
+  </metadata>
+  <defs id="defs3">
+    <linearGradient id="linearGradient1709">
+      <stop id="stop1710" offset="0.0000000" style="stop-color:#ffcd00;stop-opacity:1.0000000;"/>
+      <stop id="stop1711" offset="1.0000000" style="stop-color:#ff0000;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient4728">
+      <stop id="stop4729" offset="0.0000000" style="stop-color:#eefb11;stop-opacity:1.0000000;"/>
+      <stop id="stop4730" offset="1.0000000" style="stop-color:#fbcd11;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient gradientTransform="scale(1.395076,0.716807)" gradientUnits="userSpaceOnUse" id="linearGradient4844" inkscape:collect="always" x1="33.831200" x2="33.831200" xlink:href="#linearGradient4140" y1="32.140640" y2="47.052849"/>
+    <linearGradient id="linearGradient4140">
+      <stop id="stop4141" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop4142" offset="1.0000000" style="stop-color:#fffcfc;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient gradientTransform="scale(1.395076,0.716807)" gradientUnits="userSpaceOnUse" id="linearGradient4843" inkscape:collect="always" x1="33.713825" x2="33.770935" xlink:href="#linearGradient4140" y1="32.828346" y2="45.819080"/>
+    <linearGradient id="linearGradient4830" inkscape:collect="always">
+      <stop id="stop4831" offset="0" style="stop-color:#000000;stop-opacity:1;"/>
+      <stop id="stop4832" offset="1" style="stop-color:#000000;stop-opacity:0;"/>
+    </linearGradient>
+    <linearGradient gradientTransform="scale(0.960291,1.041351)" gradientUnits="userSpaceOnUse" id="linearGradient4842" inkscape:collect="always" x1="24.699118" x2="62.643452" xlink:href="#linearGradient4830" y1="20.796894" y2="53.925991"/>
+    <linearGradient gradientTransform="scale(0.960882,1.040710)" gradientUnits="userSpaceOnUse" id="linearGradient4731" inkscape:collect="always" x1="40.586456" x2="46.952221" xlink:href="#linearGradient4728" y1="33.980247" y2="37.406559"/>
+    <radialGradient cx="41.217018" cy="36.044060" fx="42.015064" fy="36.314224" gradientUnits="userSpaceOnUse" id="radialGradient1712" inkscape:collect="always" r="26.079197" xlink:href="#linearGradient1709"/>
+    <radialGradient cx="41.217018" cy="36.044060" fx="42.015064" fy="36.314224" gradientUnits="userSpaceOnUse" id="radialGradient1718" inkscape:collect="always" r="26.079197" xlink:href="#linearGradient1709"/>
+    <linearGradient gradientTransform="scale(0.960291,1.041351)" gradientUnits="userSpaceOnUse" id="linearGradient1719" inkscape:collect="always" x1="24.699118" x2="62.643452" xlink:href="#linearGradient4830" y1="20.796894" y2="53.925991"/>
+    <linearGradient gradientTransform="scale(1.395076,0.716807)" gradientUnits="userSpaceOnUse" id="linearGradient1720" inkscape:collect="always" x1="33.713825" x2="33.770935" xlink:href="#linearGradient4140" y1="32.828346" y2="45.819080"/>
+    <linearGradient gradientTransform="scale(1.395076,0.716807)" gradientUnits="userSpaceOnUse" id="linearGradient1721" inkscape:collect="always" x1="33.831200" x2="33.831200" xlink:href="#linearGradient4140" y1="32.140640" y2="47.052849"/>
+    <linearGradient gradientTransform="scale(0.960882,1.040710)" gradientUnits="userSpaceOnUse" id="linearGradient1722" inkscape:collect="always" x1="40.586456" x2="46.952221" xlink:href="#linearGradient4728" y1="33.980247" y2="37.406559"/>
+  </defs>
+  <sodipodi:namedview bordercolor="#666666" borderopacity="1.0" gridoriginx="0.0000000pt" gridoriginy="0.0000000pt" gridspacingx="1.0000000pt" gridspacingy="1.0000000pt" id="base" inkscape:current-layer="layer1" inkscape:cx="209.45450" inkscape:cy="47.272727" inkscape:grid-bbox="false" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:window-height="914" inkscape:window-width="1276" inkscape:window-x="0" inkscape:window-y="46" inkscape:zoom="1.3750000" pagecolor="#ffffff" showgrid="false"/>
+  <g id="layer1" inkscape:groupmode="layer" inkscape:label="Layer 1">
+    <g id="g1713" transform="matrix(3.278788,0.000000,0.000000,3.278788,-9.760310,-5.696974)">
+      <path d="M 60.104076 39.286118 A 17.290970 17.290970 0 1 1  25.522137,39.286118 A 17.290970 17.290970 0 1 1  60.104076 39.286118 z" id="path3504" sodipodi:cx="42.813107" sodipodi:cy="39.286118" sodipodi:rx="17.290970" sodipodi:ry="17.290970" sodipodi:type="arc" style="fill:url(#radialGradient1718);fill-opacity:1.0000000;fill-rule:evenodd;stroke:#000079;stroke-width:3.4694470e-17;stroke-linejoin:round;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000;display:block" transform="matrix(1.767188,0.000000,0.000000,1.767188,-38.62515,-30.78355)"/>
+      <path d="M 49.889882,20.489922 L 34.070171,36.606485 L 42.597500,36.904246 L 29.067505,50.350314 L 34.798186,50.457235 L 25.302585,60.947415 L 48.246702,48.151650 L 39.705905,48.241710 L 56.994214,34.436959 L 47.642600,34.413959 L 63.007583,20.059689 L 49.889882,20.489922 z " id="path4829" sodipodi:nodetypes="cccccccccccc" style="opacity:0.78873241;fill:url(#linearGradient1719);fill-opacity:1.0000000;fill-rule:evenodd;stroke:#ff8600;stroke-width:0.0000000;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000;display:block" transform="matrix(1.767188,0.000000,0.000000,1.767188,-36.23224,-30.20553)"/>
+      <path d="M 57.231457 28.348059 A 9.9989319 5.1375728 0 1 1  37.233593,28.348059 A 9.9989319 5.1375728 0 1 1  57.231457 28.348059 z" id="path4764" sodipodi:cx="47.232525" sodipodi:cy="28.348059" sodipodi:rx="9.9989319" sodipodi:ry="5.1375728" sodipodi:type="arc" style="opacity:0.84507042;fill:url(#linearGradient1720);fill-opacity:1.0000000;fill-rule:evenodd;stroke:url(#linearGradient1721);stroke-width:0.0000000;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4.0000000;stroke-dashoffset:0.0000000;stroke-opacity:1.0000000;marker-start:none;display:block" transform="matrix(1.767188,0.000000,0.000000,1.767188,-46.21685,-31.51325)"/>
+      <path d="M 49.079714,19.239922 L 33.260003,35.356485 L 41.787332,35.654246 L 28.257337,49.100314 L 33.988018,49.207235 L 24.492417,59.697415 L 47.436534,46.901650 L 38.895737,46.991710 L 56.184046,33.186959 L 46.832432,33.163959 L 62.197415,18.809689 L 49.079714,19.239922 z " id="path4828" sodipodi:nodetypes="cccccccccccc" style="fill:url(#linearGradient1722);fill-opacity:1.0000000;fill-rule:evenodd;stroke:#ff8600;stroke-width:0.48413596pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;display:block" transform="matrix(1.767188,0.000000,0.000000,1.767188,-36.23224,-30.20553)"/>
+    </g>
+  </g>
+</svg>
diff -pruN 3.4.1-6/drop-indicator/data/misc/plastik_icon_v17.svg 3.4.1+git20201022.a0d3415c-1/drop-indicator/data/misc/plastik_icon_v17.svg
--- 3.4.1-6/drop-indicator/data/misc/plastik_icon_v17.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/drop-indicator/data/misc/plastik_icon_v17.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,451 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 20010904//EN"
+"http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd">
+<!-- Created with Inkscape (http://www.inkscape.org/) --><svg height="200.00000pt" id="svg2994" inkscape:export-filename="/home/Krug/Projekte/Icon-Sets/set1/png/v17.png" inkscape:export-xdpi="72.000000" inkscape:export-ydpi="72.000000" inkscape:version="0.39" sodipodi:docbase="/home/Krug/Projekte/Icon-Sets/set1/vorlagen" sodipodi:docname="v17.svg" sodipodi:version="0.32" width="200.00000pt" xmlns="http://www.w3.org/2000/svg" xmlns:cc="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:xlink="http://www.w3.org/1999/xlink">
+  <metadata>
+    <rdf:RDF xmlns:cc="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
+      <cc:Work rdf:about="">
+        <dc:title>plastik-icon-theme</dc:title>
+        <dc:description></dc:description>
+        <dc:subject>
+          <rdf:Bag>
+            <rdf:li>icon</rdf:li>
+          </rdf:Bag>
+        </dc:subject>
+        <dc:publisher>
+          <cc:Agent rdf:about="http://www.openclipart.org/">
+            <dc:title>Open Clip Art Library</dc:title>
+          </cc:Agent>
+        </dc:publisher>
+        <dc:creator>
+          <cc:Agent>
+            <dc:title>Juliane Krug</dc:title>
+          </cc:Agent>
+        </dc:creator>
+        <dc:rights>
+          <cc:Agent>
+            <dc:title>Juliane Krug</dc:title>
+          </cc:Agent>
+        </dc:rights>
+        <dc:date></dc:date>
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
+        <cc:license rdf:resource="http://web.resource.org/cc/PublicDomain"/>
+        <dc:language>en</dc:language>
+      </cc:Work>
+      <cc:License rdf:about="http://web.resource.org/cc/PublicDomain">
+        <cc:permits rdf:resource="http://web.resource.org/cc/Reproduction"/>
+        <cc:permits rdf:resource="http://web.resource.org/cc/Distribution"/>
+        <cc:permits rdf:resource="http://web.resource.org/cc/DerivativeWorks"/>
+      </cc:License>
+    </rdf:RDF>
+  </metadata>
+  <defs id="defs2996">
+    <linearGradient id="linearGradient28256">
+      <stop id="stop28257" offset="0.0000000" style="stop-color:#b1004f;stop-opacity:0.39417988;"/>
+      <stop id="stop28258" offset="1.0000000" style="stop-color:#c96c00;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient27597">
+      <stop id="stop27598" offset="0.0000000" style="stop-color:#ac4978;stop-opacity:0.68518519;"/>
+      <stop id="stop27599" offset="1.0000000" style="stop-color:#0083f1;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient27568">
+      <stop id="stop27569" offset="0.0000000" style="stop-color:#a6005a;stop-opacity:1.0000000;"/>
+      <stop id="stop27570" offset="1.0000000" style="stop-color:#510000;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient20622">
+      <stop id="stop20623" offset="0.0000000" style="stop-color:#4f0000;stop-opacity:1.0000000;"/>
+      <stop id="stop20624" offset="1.0000000" style="stop-color:#c96c00;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient19948">
+      <stop id="stop19949" offset="0.0000000" style="stop-color:#82e240;stop-opacity:0.0000000;"/>
+      <stop id="stop19950" offset="1.0000000" style="stop-color:#057c00;stop-opacity:0.78042328;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient19944">
+      <stop id="stop19945" offset="0.0000000" style="stop-color:#3a3b60;stop-opacity:0.76455027;"/>
+      <stop id="stop19946" offset="1.0000000" style="stop-color:#828295;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient14931">
+      <stop id="stop14932" offset="0.0000000" style="stop-color:#82e240;stop-opacity:1.0000000;"/>
+      <stop id="stop14933" offset="1.0000000" style="stop-color:#054700;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <pattern id="pattern14302" inkscape:collect="always" patternTransform="matrix(1.253629,0.000000,0.000000,1.227857,3.289795e-6,3.194092e-5)" xlink:href="#pattern13664"/>
+    <linearGradient id="linearGradient13640">
+      <stop id="stop13641" offset="0.0000000" style="stop-color:#9fa09f;stop-opacity:1.0000000;"/>
+      <stop id="stop13642" offset="1.0000000" style="stop-color:#e3e3e2;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient12980">
+      <stop id="stop12981" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:0.88095236;"/>
+      <stop id="stop12982" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient12973">
+      <stop id="stop12974" offset="0.0000000" style="stop-color:#486dc9;stop-opacity:1.0000000;"/>
+      <stop id="stop12975" offset="1.0000000" style="stop-color:#4788ff;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2918">
+      <stop id="stop2919" offset="0.0000000" style="stop-color:#000000;stop-opacity:0.24603175;"/>
+      <stop id="stop2920" offset="1.0000000" style="stop-color:#999a9a;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1562">
+      <stop id="stop1563" offset="0.0000000" style="stop-color:#486dc9;stop-opacity:1.0000000;"/>
+      <stop id="stop1564" offset="1.0000000" style="stop-color:#4788ff;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1549">
+      <stop id="stop1550" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:0.64550263;"/>
+      <stop id="stop1551" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient4249">
+      <stop id="stop4250" offset="0.0000000" style="stop-color:#000000;stop-opacity:0.30158731;"/>
+      <stop id="stop4251" offset="1.0000000" style="stop-color:#999a9a;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1561" inkscape:collect="always" spreadMethod="reflect" x1="0.49618322" x2="0.49618322" xlink:href="#linearGradient1562" y1="0.27343750" y2="0.28906250"/>
+    <linearGradient id="linearGradient2852" inkscape:collect="always" x1="0.40127388" x2="0.50955415" xlink:href="#linearGradient1549" y1="0.13281250" y2="0.44531250"/>
+    <linearGradient id="linearGradient2858" inkscape:collect="always" x1="0.51461989" x2="0.67251462" xlink:href="#linearGradient1549" y1="0.070312500" y2="0.50781250"/>
+    <radialGradient cx="0.32944608" cy="0.68750000" fx="0.32653061" fy="0.69531250" id="radialGradient2917" inkscape:collect="always" r="0.24793652" xlink:href="#linearGradient2918"/>
+    <linearGradient id="linearGradient9791">
+      <stop id="stop9792" offset="0.0000000" style="stop-color:#000000;stop-opacity:1.0000000;"/>
+      <stop id="stop9793" offset="1" style="stop-color:#fff;stop-opacity:1;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient9799">
+      <stop id="stop9800" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop9801" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2243">
+      <stop id="stop2244" offset="0" style="stop-color:#000;stop-opacity:1;"/>
+      <stop id="stop2245" offset="1" style="stop-color:#fff;stop-opacity:1;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2246">
+      <stop id="stop2247" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop2248" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient4173">
+      <stop id="stop4174" offset="0" style="stop-color:#000;stop-opacity:1;"/>
+      <stop id="stop4175" offset="1" style="stop-color:#fff;stop-opacity:1;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient4177">
+      <stop id="stop4178" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop4179" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1538">
+      <stop id="stop1539" offset="0" style="stop-color:#000;stop-opacity:1;"/>
+      <stop id="stop1540" offset="1" style="stop-color:#fff;stop-opacity:1;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1542">
+      <stop id="stop1543" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop1544" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient5311">
+      <stop id="stop5312" offset="0.0000000" style="stop-color:#000000;stop-opacity:0.39215687;"/>
+      <stop id="stop5313" offset="1.0000000" style="stop-color:#000000;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient5315">
+      <stop id="stop5316" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop5317" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient4384">
+      <stop id="stop4385" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:0.77513230;"/>
+      <stop id="stop4386" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient4376">
+      <stop id="stop4377" offset="0.0000000" style="stop-color:#000000;stop-opacity:0.52645504;"/>
+      <stop id="stop4378" offset="1.0000000" style="stop-color:#000000;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient4362">
+      <stop id="stop4363" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:0.66666669;"/>
+      <stop id="stop4364" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient4358">
+      <stop id="stop4359" offset="0" style="stop-color:#000;stop-opacity:1;"/>
+      <stop id="stop4360" offset="1" style="stop-color:#fff;stop-opacity:1;"/>
+    </linearGradient>
+    <pattern height="255.54016" id="pattern13664" patternTransform="translate(-1.731302,-1.731328)" patternUnits="userSpaceOnUse" width="254.84764">
+      <rect height="255.54016" id="rect1578" style="fill:url(#linearGradient1561);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;" width="254.84764" x="0.0000000" y="7.1054274e-15"/>
+      <path d="M 14.272865,69.402456 C 12.464431,74.709419 10.655999,80.016383 8.8475647,85.323346 C 24.822058,119.66252 38.988118,162.43041 32.357196,205.19828 C 34.165630,208.63220 35.974062,212.06612 37.782496,215.50004 C 95.652359,199.26698 153.52221,183.03390 211.39207,166.80084 C 207.47380,129.65210 209.88504,87.820740 186.07401,49.735474 C 145.38425,57.539831 104.69451,65.344190 64.004776,73.148547 C 59.483693,69.714630 54.962611,66.280713 50.441528,62.846796 C 38.385307,65.032016 26.329085,67.217235 14.272865,69.402456 z " id="path2226" sodipodi:nodetypes="ccccccccc" style="fill:#9cd9ff;fill-opacity:0.47619048;fill-rule:evenodd;stroke:none;stroke-width:1.3288093pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+      <path d="M 177.86469,55.121391 C 139.92945,62.904554 101.73967,69.773659 63.708449,77.215141 C 56.075774,74.854568 51.293921,64.245468 42.366694,68.313994 C 33.907696,69.843544 25.448697,71.373092 16.989699,72.902641 C 15.337123,78.737675 10.732956,85.174496 15.316211,90.855124 C 31.058428,126.27862 41.308841,165.50452 36.083449,204.46514 C 36.764327,209.92827 42.128685,212.14978 46.489699,208.77764 C 99.924397,193.77893 153.36516,178.79999 206.80219,163.80889 C 203.68327,126.92676 203.34643,87.932489 184.11469,55.027641 C 182.18913,53.892362 179.90249,54.980704 177.86469,55.121391 z " id="path2851" style="fill:url(#linearGradient2852);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.3288093pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+      <path d="M 194.94459,68.905844 C 161.01107,76.754413 127.07756,84.602981 93.144049,92.451550 C 88.527242,97.991717 83.910436,103.53188 79.293629,109.07205 C 64.519852,111.38045 49.746076,113.68886 34.972299,115.99726 C 32.894737,118.99818 30.817174,121.99911 28.739612,125.00003 C 28.047091,126.84675 27.354571,128.69347 26.662050,130.54019 C 34.741459,159.16438 36.588181,190.55866 32.202216,203.94739 C 33.818098,207.41000 35.433980,210.87260 37.049862,214.33521 C 94.759929,198.86891 152.46998,183.40261 210.18005,167.93631 C 205.10156,134.92615 208.33333,102.60852 194.94459,68.905844 z " id="path2856" sodipodi:nodetypes="cccccccccc" style="fill:#537ed2;fill-opacity:0.51820731;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+      <path d="M 38.098383,214.89357 C 41.112433,210.52314 44.126493,206.15269 47.140543,201.78225 C 36.591353,174.93527 38.701193,141.53261 42.619463,121.24128 C 56.182713,119.05606 69.745963,116.87084 83.309213,114.68562 C 87.830283,109.37866 92.351379,104.07169 96.872459,98.764730 C 137.86360,89.087320 178.85475,79.409920 219.84591,69.732517 C 214.11920,99.389070 212.00936,119.68041 224.36698,153.08306 C 221.35293,157.76567 218.33887,162.44829 215.32482,167.13090 C 156.24933,183.05179 97.173857,198.97269 38.098383,214.89357 z " id="path2855" sodipodi:nodetypes="ccccccccc" style="fill:#9cd9ff;fill-opacity:0.47450981;fill-rule:evenodd;stroke:none;stroke-width:1.3288093pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+      <path d="M 211.55219,74.861349 C 174.23719,84.308243 136.53822,92.605117 99.083447,101.64260 C 93.755489,107.00485 89.836565,114.93525 82.939979,118.08321 C 70.685718,120.06134 58.431459,122.03947 46.177199,124.01760 C 41.979747,149.85859 42.136301,177.00688 51.583449,201.73635 C 46.145914,207.70982 47.755023,208.26004 54.845402,205.51843 C 107.47683,191.33066 160.10826,177.14288 212.73969,162.95510 C 215.18519,157.84278 222.14124,153.21662 218.36999,147.03470 C 209.97757,123.77929 209.82544,98.242833 214.89594,74.236349 C 213.78136,74.444682 212.66677,74.653016 211.55219,74.861349 z " id="path2857" style="fill:url(#linearGradient2858);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.3288093pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    </pattern>
+    <pattern height="313.76666" id="pattern14303" patternTransform="translate(-21.12040,25.00770)" patternUnits="userSpaceOnUse" width="319.48441">
+      <rect height="313.76666" id="rect14301" style="fill:url(#pattern14302);stroke:none;" width="319.48441" x="3.5527137e-15" y="7.1054274e-15"/>
+    </pattern>
+    <radialGradient cx="0.27861771" cy="0.71774191" fx="0.28178504" fy="0.71572578" id="radialGradient4865" inkscape:collect="always" r="0.20151046" xlink:href="#linearGradient2918"/>
+    <radialGradient cx="0.32944608" cy="0.68750000" fx="0.32653061" fy="0.69531250" id="radialGradient28455" inkscape:collect="always" r="0.24793652" xlink:href="#linearGradient2918"/>
+    <linearGradient id="linearGradient28454" inkscape:collect="always" x1="-0.41558442" x2="0.67532468" xlink:href="#linearGradient1549" y1="0.46875000" y2="0.47656250"/>
+    <linearGradient id="linearGradient28453" inkscape:collect="always" x1="0.12631579" x2="0.70526314" xlink:href="#linearGradient1549" y1="0.27343750" y2="0.22656250"/>
+    <linearGradient id="linearGradient28452" inkscape:collect="always" spreadMethod="pad" x1="0.46443516" x2="0.71548116" xlink:href="#linearGradient1549" y1="0.13281250" y2="0.67968750"/>
+    <linearGradient id="linearGradient28449">
+      <stop id="stop28450" offset="0.0000000" style="stop-color:#000000;stop-opacity:0.30158731;"/>
+      <stop id="stop28451" offset="1.0000000" style="stop-color:#999a9a;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient28446">
+      <stop id="stop28447" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:0.64550263;"/>
+      <stop id="stop28448" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient28443">
+      <stop id="stop28444" offset="0.0000000" style="stop-color:#486dc9;stop-opacity:1.0000000;"/>
+      <stop id="stop28445" offset="1.0000000" style="stop-color:#4788ff;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient28440">
+      <stop id="stop28441" offset="0.0000000" style="stop-color:#000000;stop-opacity:0.39607844;"/>
+      <stop id="stop28442" offset="1.0000000" style="stop-color:#999a9a;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2944">
+      <stop id="stop2945" offset="0.0000000" style="stop-color:#aeaead;stop-opacity:0.14285715;"/>
+      <stop id="stop2946" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2949">
+      <stop id="stop2950" offset="0.0000000" style="stop-color:#000000;stop-opacity:0.15294118;"/>
+      <stop id="stop2951" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient3587">
+      <stop id="stop3588" offset="0.0000000" style="stop-color:#bebcbc;stop-opacity:1.0000000;"/>
+      <stop id="stop3589" offset="1.0000000" style="stop-color:#d2d3d3;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient3593">
+      <stop id="stop3594" offset="0.0000000" style="stop-color:#00bcbc;stop-opacity:1.0000000;"/>
+      <stop id="stop3596" offset="0.50000000" style="stop-color:#005ec7;stop-opacity:1.0000000;"/>
+      <stop id="stop3601" offset="0.75079733" style="stop-color:#ff2fe3;stop-opacity:1.0000000;"/>
+      <stop id="stop3602" offset="0.87539864" style="stop-color:#7fbfff;stop-opacity:1.0000000;"/>
+      <stop id="stop3603" offset="0.93769932" style="stop-color:#3fffff;stop-opacity:1.0000000;"/>
+      <stop id="stop3604" offset="0.96884966" style="stop-color:#1f50ff;stop-opacity:1.0000000;"/>
+      <stop id="stop3605" offset="0.98442483" style="stop-color:#0fa13c;stop-opacity:1.0000000;"/>
+      <stop id="stop3606" offset="0.99000001" style="stop-color:#07509d;stop-opacity:1.0000000;"/>
+      <stop id="stop3607" offset="0.99000001" style="stop-color:#ff28ce;stop-opacity:1.0000000;"/>
+      <stop id="stop3595" offset="1.0000000" style="stop-color:#0000ff;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient4231">
+      <stop id="stop4232" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:0.43529412;"/>
+      <stop id="stop4233" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient8024">
+      <stop id="stop8025" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:0.89417988;"/>
+      <stop id="stop8026" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient8031">
+      <stop id="stop8032" offset="0.0000000" style="stop-color:#920000;stop-opacity:1.0000000;"/>
+      <stop id="stop8033" offset="1.0000000" style="stop-color:#ff0000;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient9280">
+      <stop id="stop9281" offset="0.0000000" style="stop-color:#c90000;stop-opacity:1.0000000;"/>
+      <stop id="stop9282" offset="1.0000000" style="stop-color:#8c0000;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1715" inkscape:collect="always" x1="0.34061137" x2="0.72052401" xlink:href="#linearGradient1549" y1="0.10156250" y2="0.63281250"/>
+    <linearGradient id="linearGradient12988" inkscape:collect="always" x1="0.50740987" x2="0.41357866" xlink:href="#linearGradient5311" y1="0.73437500" y2="0.26562500"/>
+    <linearGradient id="linearGradient12986" inkscape:collect="always" x1="-0.11557789" x2="1.0653267" xlink:href="#linearGradient9799" y1="0.10156250" y2="0.60937500"/>
+    <radialGradient cx="0.53600001" cy="0.42968750" fx="0.53599995" fy="0.42187500" id="radialGradient12983" inkscape:collect="always" r="0.59205157" xlink:href="#linearGradient4362"/>
+    <linearGradient id="linearGradient12977" inkscape:collect="always" x1="0.53600001" x2="0.47999999" xlink:href="#linearGradient4376" y1="0.75000000" y2="0.32812500"/>
+    <linearGradient id="linearGradient12972" inkscape:collect="always" x1="-0.048000000" x2="0.56800002" xlink:href="#linearGradient12973" y1="0.23437500" y2="0.54687500"/>
+    <linearGradient id="linearGradient1885">
+      <stop id="stop1886" offset="0" style="stop-color:#000;stop-opacity:1;"/>
+      <stop id="stop1887" offset="1" style="stop-color:#fff;stop-opacity:1;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1882">
+      <stop id="stop1883" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:0.66666669;"/>
+      <stop id="stop1884" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1879">
+      <stop id="stop1880" offset="0.0000000" style="stop-color:#000000;stop-opacity:0.52645504;"/>
+      <stop id="stop1881" offset="1.0000000" style="stop-color:#000000;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1876">
+      <stop id="stop1877" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:0.77513230;"/>
+      <stop id="stop1878" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1873">
+      <stop id="stop1874" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop1875" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1870">
+      <stop id="stop1871" offset="0.0000000" style="stop-color:#000000;stop-opacity:0.39215687;"/>
+      <stop id="stop1872" offset="1.0000000" style="stop-color:#000000;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1867">
+      <stop id="stop1868" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop1869" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1864">
+      <stop id="stop1865" offset="0" style="stop-color:#000;stop-opacity:1;"/>
+      <stop id="stop1866" offset="1" style="stop-color:#fff;stop-opacity:1;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1861">
+      <stop id="stop1862" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop1863" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1858">
+      <stop id="stop1859" offset="0" style="stop-color:#000;stop-opacity:1;"/>
+      <stop id="stop1860" offset="1" style="stop-color:#fff;stop-opacity:1;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1855">
+      <stop id="stop1856" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop1857" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1852">
+      <stop id="stop1853" offset="0" style="stop-color:#000;stop-opacity:1;"/>
+      <stop id="stop1854" offset="1" style="stop-color:#fff;stop-opacity:1;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1849">
+      <stop id="stop1850" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop1851" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1846">
+      <stop id="stop1847" offset="0.0000000" style="stop-color:#000000;stop-opacity:1.0000000;"/>
+      <stop id="stop1848" offset="1" style="stop-color:#fff;stop-opacity:1;"/>
+    </linearGradient>
+    <radialGradient cx="0.32944608" cy="0.68750000" fx="0.32653061" fy="0.69531250" id="radialGradient1845" inkscape:collect="always" r="0.24793652" xlink:href="#linearGradient2918"/>
+    <linearGradient id="linearGradient1843" inkscape:collect="always" x1="0.62427747" x2="0.17919075" xlink:href="#linearGradient4249" y1="0.67968750" y2="0.023437500"/>
+    <linearGradient id="linearGradient1842" inkscape:collect="always" spreadMethod="pad" x1="0.78059071" x2="0.10548523" xlink:href="#linearGradient4249" y1="0.45312500" y2="0.023437500"/>
+    <linearGradient id="linearGradient1839">
+      <stop id="stop1840" offset="0.0000000" style="stop-color:#000000;stop-opacity:0.30158731;"/>
+      <stop id="stop1841" offset="1.0000000" style="stop-color:#999a9a;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1836">
+      <stop id="stop1837" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:0.64550263;"/>
+      <stop id="stop1838" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1833">
+      <stop id="stop1834" offset="0.0000000" style="stop-color:#486dc9;stop-opacity:1.0000000;"/>
+      <stop id="stop1835" offset="1.0000000" style="stop-color:#4788ff;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1830">
+      <stop id="stop1831" offset="0.0000000" style="stop-color:#000000;stop-opacity:0.39682540;"/>
+      <stop id="stop1832" offset="1.0000000" style="stop-color:#999a9a;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1827">
+      <stop id="stop1828" offset="0.0000000" style="stop-color:#486dc9;stop-opacity:1.0000000;"/>
+      <stop id="stop1829" offset="1.0000000" style="stop-color:#4788ff;stop-opacity:1.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient1824">
+      <stop id="stop1825" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:0.88095236;"/>
+      <stop id="stop1826" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2643">
+      <stop id="stop2644" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:0.77513230;"/>
+      <stop id="stop2645" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2640">
+      <stop id="stop2641" offset="0.0000000" style="stop-color:#000000;stop-opacity:0.52645504;"/>
+      <stop id="stop2642" offset="1.0000000" style="stop-color:#000000;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2637">
+      <stop id="stop2638" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:0.66666669;"/>
+      <stop id="stop2639" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2634">
+      <stop id="stop2635" offset="0" style="stop-color:#000;stop-opacity:1;"/>
+      <stop id="stop2636" offset="1" style="stop-color:#fff;stop-opacity:1;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2699">
+      <stop id="stop2700" offset="0" style="stop-color:#000;stop-opacity:1;"/>
+      <stop id="stop2701" offset="1" style="stop-color:#fff;stop-opacity:1;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2696">
+      <stop id="stop2697" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop2698" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2693">
+      <stop id="stop2694" offset="0.0000000" style="stop-color:#000000;stop-opacity:0.39215687;"/>
+      <stop id="stop2695" offset="1.0000000" style="stop-color:#000000;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2690">
+      <stop id="stop2691" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop2692" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2779">
+      <stop id="stop2780" offset="0.0000000" style="stop-color:#000000;stop-opacity:1.0000000;"/>
+      <stop id="stop2781" offset="1" style="stop-color:#fff;stop-opacity:1;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2776">
+      <stop id="stop2777" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop2778" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2773">
+      <stop id="stop2774" offset="0" style="stop-color:#000;stop-opacity:1;"/>
+      <stop id="stop2775" offset="1" style="stop-color:#fff;stop-opacity:1;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2770">
+      <stop id="stop2771" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop2772" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2767">
+      <stop id="stop2768" offset="0" style="stop-color:#000;stop-opacity:1;"/>
+      <stop id="stop2769" offset="1" style="stop-color:#fff;stop-opacity:1;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2764">
+      <stop id="stop2765" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop2766" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2761">
+      <stop id="stop2762" offset="0" style="stop-color:#000;stop-opacity:1;"/>
+      <stop id="stop2763" offset="1" style="stop-color:#fff;stop-opacity:1;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2758">
+      <stop id="stop2759" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop2760" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2755">
+      <stop id="stop2756" offset="0.0000000" style="stop-color:#000000;stop-opacity:0.39215687;"/>
+      <stop id="stop2757" offset="1.0000000" style="stop-color:#000000;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient2752">
+      <stop id="stop2753" offset="0.0000000" style="stop-color:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop2754" offset="1.0000000" style="stop-color:#ffffff;stop-opacity:0.0000000;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient3428" inkscape:collect="always" x1="0.94736844" x2="0.15789473" xlink:href="#linearGradient14931" y1="0.41406250" y2="0.48437500"/>
+    <linearGradient id="linearGradient3431" inkscape:collect="always" x1="-0.50434780" x2="0.77391303" xlink:href="#linearGradient12980" y1="0.38281250" y2="0.28906250"/>
+  </defs>
+  <sodipodi:namedview bordercolor="#666666" borderopacity="1.0" id="base" inkscape:cx="229.23835" inkscape:cy="74.808888" inkscape:guide-bbox="true" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:window-height="937" inkscape:window-width="1272" inkscape:window-x="0" inkscape:window-y="0" inkscape:zoom="1.7894328" pagecolor="#ffffff" showguides="true"/>
+  <rect height="255.54016" id="rect28468" style="fill:url(#linearGradient1561);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;" transform="translate(0.634603,1.825403)" width="254.84764" x="-1.7313021" y="-1.7313277"/>
+  <path d="M -9.0152839,238.08549 L -87.824226,166.51958 L 457.52181,94.041177 L 526.63845,185.55167 L -9.0152839,238.08549 z " id="path28469" sodipodi:nodetypes="ccccc" style="fill:url(#radialGradient2917);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;" transform="translate(0.634603,1.825403)"/>
+  <path d="M -22.410847,247.51664 L -92.177263,175.95073 L 390.59580,103.47232 L 451.78199,194.98282 L -22.410847,247.51664 z " id="path2915" sodipodi:nodetypes="ccccc" style="fill:url(#radialGradient4865);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+  <g id="g1951">
+    <path d="M 20.956361,100.51129 L 106.87743,130.54875 L 187.21015,36.943667 L 20.956361,100.51129 z " id="path28312" style="fill:#9cd9ff;fill-opacity:0.47450981;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    <path d="M 37.022901,214.37419 L 89.413801,123.56329 L 106.17889,129.15166 L 120.84834,115.87930 L 219.34324,171.06438 L 37.022901,214.37419 z " id="path28313" style="fill:#9cd9ff;fill-opacity:0.47450981;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    <path d="M 21.996250,99.459565 L 22.058750,99.709565 L 38.715000,212.89707 L 89.839995,124.30332 L 21.996250,99.459565 z " id="path29760" sodipodi:nodetypes="ccccc" style="fill:#9cd9ff;fill-opacity:0.47450981;fill-rule:evenodd;stroke:none;stroke-width:0.89789753pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    <path d="M 186.29957,38.018302 L 119.48707,115.92456 L 217.92457,171.08081 L 186.29957,38.018302 z " id="path29765" sodipodi:nodetypes="cccc" style="fill:#9cd9ff;fill-opacity:0.47450981;fill-rule:evenodd;stroke:none;stroke-width:0.89789753pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    <path d="M 37.472522,99.700702 C 61.795439,108.19029 86.118355,116.67988 110.44127,125.16946 C 133.19127,98.669452 155.94127,72.169452 178.69127,45.669452 C 131.61835,63.679869 84.545439,81.690285 37.472522,99.700702 z " id="path29770" style="fill:url(#linearGradient1715);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    <path d="M 110.26104,129.99111 C 104.36927,132.80830 97.970663,126.13503 92.521105,127.10128 C 79.837340,147.57545 68.219984,169.04057 55.933393,189.88612 C 52.782194,195.34821 49.630994,200.81028 46.479795,206.27236 C 100.93812,193.33486 155.39646,180.39736 209.85479,167.45986 C 180.84437,151.18903 151.83396,134.91819 122.82354,118.64736 C 118.63604,122.42861 114.44854,126.20986 110.26104,129.99111 z " id="path29771" style="fill:url(#linearGradient28452);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    <path d="M 40.968750,202.41030 C 55.322917,177.54572 69.677083,152.68113 84.031250,127.81655 C 65.000000,120.84780 45.968750,113.87905 26.937500,106.91030 C 31.614583,138.74363 36.291667,170.57697 40.968750,202.41030 z " id="path29772" style="fill:url(#linearGradient28454);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:0.89789753pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    <path d="M 126.43749,114.86800 C 155.16666,130.96175 183.89582,147.05550 212.62499,163.14925 C 203.39582,124.30550 194.16666,85.461748 184.93749,46.617998 C 165.43749,69.367998 145.93749,92.117998 126.43749,114.86800 z " id="path29773" style="fill:url(#linearGradient28453);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:0.89789753pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    <path d="M 109.67162,136.13710 L 122.24544,118.67347 L 108.97308,129.85019 L 26.544723,101.20984 L 23.750542,100.51129 L 23.750542,108.89384 L 109.67162,136.13710 z " id="path1716" sodipodi:nodetypes="ccccccc" style="fill:#537ed2;fill-opacity:0.51764709;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+  </g>
+  <path d="M 394.76496 283.65384 A 111.64530 115.91880 0 1 0 171.47436,283.65384 A 111.64530 115.91880 0 1 0 394.76496 283.65384 z" id="path12987" sodipodi:cx="283.11966" sodipodi:cy="283.65384" sodipodi:rx="111.64530" sodipodi:ry="115.91880" sodipodi:type="arc" style="fill:url(#linearGradient12988);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;" transform="matrix(0.553574,0.000000,0.405529,0.541474,-150.1983,20.42060)"/>
+  <g id="g12989" transform="translate(15.79043,5.208536)">
+    <path d="M 394.76496 283.65384 A 111.64530 115.91880 0 1 0 171.47436,283.65384 A 111.64530 115.91880 0 1 0 394.76496 283.65384 z" id="path11712" sodipodi:cx="283.11966" sodipodi:cy="283.65384" sodipodi:rx="111.64530" sodipodi:ry="115.91880" sodipodi:type="arc" style="fill:url(#linearGradient12972);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;" transform="matrix(0.543747,0.000000,0.000000,0.539080,-0.999567,14.81238)"/>
+    <path d="M 394.76496 283.65384 A 111.64530 115.91880 0 1 0 171.47436,283.65384 A 111.64530 115.91880 0 1 0 394.76496 283.65384 z" id="path12976" sodipodi:cx="283.11966" sodipodi:cy="283.65384" sodipodi:rx="111.64530" sodipodi:ry="115.91880" sodipodi:type="arc" style="fill:url(#linearGradient12977);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;" transform="matrix(0.543747,0.000000,0.000000,0.539080,-1.730767,15.10032)"/>
+    <path d="M 394.76496 283.65384 A 111.64530 115.91880 0 1 0 171.47436,283.65384 A 111.64530 115.91880 0 1 0 394.76496 283.65384 z" id="path12978" sodipodi:cx="283.11966" sodipodi:cy="283.65384" sodipodi:rx="111.64530" sodipodi:ry="115.91880" sodipodi:type="arc" style="fill:url(#radialGradient12983);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;" transform="matrix(0.543747,0.000000,0.000000,0.539080,-1.150937,15.10034)"/>
+    <g id="g11713" style="fill:#004696;fill-opacity:0.71708685;stroke:none;stroke-opacity:1.0000000;" transform="matrix(0.525012,0.000000,0.000000,0.539080,8.390303,14.81236)">
+      <path d="M 293.62881,174.51524 L 289.47368,175.20776 L 287.39612,176.59280 L 285.31856,174.51524 L 283.24100,175.20776 L 282.54848,181.44044 L 292.24377,182.82548 L 299.86150,186.28809 L 306.09418,194.59834 L 306.78670,198.06094 L 309.55679,201.52355 L 302.63158,201.52355 L 295.70637,204.29363 L 294.32133,206.37119 L 296.39889,208.44875 L 299.86150,207.75623 L 302.63158,211.21884 L 308.86427,218.83657 L 315.09695,227.83934 L 309.55679,224.37673 L 306.09418,219.52909 L 302.63158,220.22161 L 304.70914,225.76177 L 305.40166,228.53186 L 299.86150,229.22438 L 297.09141,236.14958 L 296.39889,240.30471 L 293.62881,243.07479 L 288.78116,239.61219 L 291.55125,239.61219 L 292.93629,236.14958 L 286.01108,234.07202 L 278.39335,235.45706 L 277.00831,241.68975 L 272.85319,245.84488 L 267.31302,250.69252 L 268.00554,257.61773 L 272.16066,256.23269 L 272.85319,261.08033 L 276.31579,261.08033 L 276.31579,254.84765 L 279.08587,254.84765 L 279.08587,249.30748 L 285.31856,244.45983 L 286.70360,247.92244 L 282.54848,251.38504 L 283.93352,256.23269 L 288.78116,252.77008 L 291.55125,252.07756 L 291.55125,254.84765 L 286.01108,256.92521 L 283.24100,263.15789 L 277.00831,264.54294 L 272.85319,262.46537 L 268.00554,259.00277 L 268.00554,264.54294 L 266.62050,266.62050 L 261.08033,272.85319 L 250.69252,274.93075 L 254.15512,281.85596 L 252.07756,285.31856 L 245.15235,283.93352 L 240.99723,287.39612 L 240.99723,295.70637 L 243.76731,297.78393 L 250.00000,297.78393 L 254.84765,292.93629 L 259.00277,287.39612 L 268.00554,286.01108 L 277.70083,293.62881 L 273.54571,297.78393 L 281.85596,295.01385 L 273.54571,284.62604 L 277.00831,284.62604 L 288.08864,297.78393 L 292.24377,303.32410 L 291.55125,293.62881 L 295.70637,288.08864 L 297.09141,282.54848 L 303.32410,279.77839 L 308.17175,277.00831 L 308.86427,281.16343 L 315.78947,284.62604 L 310.94183,288.08864 L 304.01662,286.70360 L 298.47645,290.85873 L 294.32133,295.01385 L 299.16898,299.16898 L 305.40166,297.78393 L 310.24931,298.47645 L 308.17175,304.70914 L 308.86427,308.86427 L 299.86150,308.86427 L 286.70360,308.17175 L 281.16343,312.32687 L 266.62050,304.70914 L 267.31302,299.16898 L 252.07756,299.16898 L 247.92244,301.93906 L 243.76731,299.16898 L 233.37950,306.78670 L 231.99446,310.24931 L 225.06925,311.63435 L 218.83657,319.25208 L 220.91413,322.71468 L 216.75900,332.40997 L 223.68421,342.79778 L 231.99446,353.87812 L 239.61219,353.18560 L 243.07479,354.57064 L 252.07756,353.18560 L 259.00277,358.03324 L 263.85042,357.34072 L 267.31302,362.18837 L 265.92798,364.26593 L 273.54571,378.80886 L 268.69806,385.04155 L 277.00831,393.35180 L 284.62604,396.81440 L 304.70914,390.58172 L 309.55679,387.11911 L 313.01939,382.27147 L 323.40720,376.03878 L 322.71468,368.42105 L 328.25485,359.41828 L 340.72022,338.64266 L 342.10526,333.10249 L 331.71745,338.64266 L 322.71468,335.18006 L 317.17452,325.48476 L 307.47922,312.32687 L 310.24931,311.63435 L 317.17452,320.63712 L 331.02493,334.48753 L 342.79778,325.48476 L 349.72299,314.40443 L 351.10803,307.47922 L 346.26039,304.70914 L 339.33518,309.55679 L 331.02493,304.01662 L 333.79501,300.55402 L 337.25762,303.32410 L 342.10526,302.63158 L 357.34072,296.39889 L 365.65097,299.16898 L 367.03601,296.39889 L 373.96122,306.78670 L 378.11634,305.40166 L 375.34626,294.32133 L 378.11634,270.08310 L 384.34903,273.54571 L 389.19668,262.46537 L 385.04155,253.46260 L 376.03878,229.22438 L 364.26593,217.45152 L 362.18837,216.75900 L 356.64820,211.21884 L 359.41828,208.44875 L 348.33795,200.13850 L 333.10249,190.44321 L 325.48476,191.13573 L 319.94460,187.67313 L 317.17452,182.82548 L 313.01939,184.21053 L 308.86427,180.74792 L 315.09695,180.74792 L 317.17452,180.05540 L 312.32687,176.59280 L 309.55679,175.20776 L 305.40166,176.59280 L 293.62881,174.51524 z " id="path11693" style="fill-rule:evenodd;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;"/>
+      <path d="M 270.42936,170.01385 C 271.12188,171.39889 273.19945,173.13019 273.19945,173.13019 L 275.62327,174.51524 L 271.81440,175.55402 L 272.50693,177.97784 L 276.31579,176.93906 L 278.73961,178.32410 L 277.35457,180.74792 L 272.50693,181.09418 L 260.73407,182.47922 L 254.15512,184.90305 L 249.65374,185.94183 L 249.65374,188.36565 L 248.96122,191.82825 L 246.88366,194.59834 L 242.03601,192.86704 L 243.76731,189.40443 L 240.65097,192.86704 L 238.57341,196.32964 L 239.95845,197.71468 L 237.18837,200.48476 L 233.03324,206.37119 L 227.83934,201.17729 L 224.03047,200.48476 L 219.87535,200.48476 L 212.95014,207.75623 L 203.94737,215.72022 L 204.98615,217.10526 L 210.18006,213.64266 L 211.56510,213.64266 L 216.06648,212.25762 L 220.91413,210.52632 L 222.64543,211.21884 L 220.22161,216.41274 L 217.45152,219.52909 L 215.72022,221.95291 L 217.10526,223.33795 L 214.68144,229.57064 L 210.87258,232.34072 L 207.75623,231.64820 L 211.21884,234.76454 L 209.48753,236.49584 L 204.63989,237.88089 L 206.71745,241.68975 L 202.56233,244.11357 L 202.21607,240.99723 L 200.48476,238.91967 L 205.67867,236.14958 L 202.21607,233.37950 L 197.02216,235.11080 L 198.40720,238.91967 L 196.32964,239.61219 L 192.86704,238.22715 L 195.63712,234.76454 L 192.86704,233.03324 L 191.13573,235.11080 L 185.94183,233.03324 L 182.13296,236.14958 L 178.67036,235.11080 L 173.47645,240.30471 L 180.05540,224.72299 L 177.97784,223.33795 L 175.90028,224.72299 L 187.32687,209.83379 L 201.86981,195.63712 L 217.45152,184.21053 L 220.91413,183.17175 L 228.53186,181.78670 L 232.34072,179.01662 L 240.65097,177.97784 L 246.53740,176.24654 L 251.73130,176.24654 L 257.27147,173.82271 L 264.19668,173.47645 L 268.00554,170.70637 L 270.42936,170.01385 z " id="path11699" style="fill-rule:evenodd;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;"/>
+      <path d="M 249.65374,206.37119 L 247.57618,208.44875 L 246.53740,212.95014 L 240.65097,217.79778 L 234.76454,219.87535 L 228.87812,225.41551 L 225.41551,230.26316 L 226.80055,231.99446 L 225.06925,234.41828 L 227.14681,236.49584 L 231.99446,233.37950 L 237.18837,230.60942 L 241.68975,230.95568 L 244.11357,230.26316 L 248.96122,230.26316 L 252.77008,226.10803 L 256.23269,225.41551 L 260.04155,222.64543 L 260.04155,220.56787 L 262.81163,219.87535 L 267.65928,214.33518 L 266.96676,211.56510 L 265.92798,207.40997 L 257.61773,207.40997 L 254.50139,207.06371 L 249.65374,206.37119 z " id="path11700" style="fill-rule:evenodd;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;"/>
+      <path d="M 239.61219,200.48476 L 236.49585,204.29363 L 235.11080,207.40997 L 231.64820,208.79501 L 226.45429,209.14127 L 224.03047,214.33518 L 221.60665,216.41274 L 224.03047,217.79778 L 227.14681,214.33518 L 231.64820,215.02770 L 234.07202,211.21884 L 237.18837,208.79501 L 242.03601,203.60111 L 242.03601,201.86981 L 239.61219,200.48476 z " id="path11701" style="fill-rule:evenodd;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;"/>
+      <path d="M 250.69252,192.52078 L 247.57618,196.32964 L 245.84488,199.79224 L 245.15235,202.90859 L 247.22992,203.60111 L 250.69252,198.06094 L 252.42382,195.29086 L 250.69252,192.52078 z " id="path11702" style="fill-rule:evenodd;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;"/>
+      <path d="M 260.73407,199.44598 L 256.57895,200.83102 L 252.07756,200.48476 L 249.30748,201.86981 L 251.38504,203.60111 L 256.57895,203.94737 L 259.34903,204.98615 L 261.77285,204.63989 L 260.73407,199.44598 z " id="path11703" style="fill-rule:evenodd;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;"/>
+      <path d="M 255.54017,253.80886 L 253.11634,257.61773 L 253.80886,261.77285 L 253.11634,263.85042 L 251.73130,264.88920 L 251.03878,267.65928 L 252.07756,268.69806 L 249.30748,269.73684 L 254.84765,271.46814 L 260.38781,268.00554 L 258.65651,265.23546 L 259.34903,262.11911 L 256.57895,259.69529 L 258.31025,257.96399 L 255.54017,253.80886 z " id="path11704" style="fill-rule:evenodd;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;"/>
+      <path d="M 248.96122,259.00277 L 246.88366,262.46537 L 245.84488,265.58172 L 248.61496,265.92798 L 251.38504,262.81163 L 251.38504,259.34903 L 248.96122,259.00277 z " id="path11705" style="fill-rule:evenodd;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;"/>
+      <path d="M 337.60388,367.03601 L 334.48753,370.15235 L 331.02493,371.19114 L 328.25485,377.07756 L 325.48476,380.88643 L 329.29363,381.92521 L 333.10249,378.46260 L 336.21884,373.96122 L 339.33518,368.76731 L 337.60388,367.03601 z " id="path11706" style="fill-rule:evenodd;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;"/>
+      <path d="M 162.04986,265.58172 L 162.39612,277.00831 L 164.47368,284.27978 L 165.51247,292.59003 L 166.89751,299.86150 L 171.74515,311.98061 L 172.09141,318.55956 L 177.63158,327.56233 C 177.63158,327.56233 180.05540,332.06371 180.74792,333.79501 C 181.44044,335.52632 186.98061,342.45152 186.98061,342.45152 L 188.71191,346.95291 L 185.59557,350.41551 L 187.32687,355.26316 L 188.01939,358.37950 L 181.09418,349.72299 L 172.09141,335.52632 L 165.51247,318.55956 L 161.70360,300.55402 L 160.31856,279.08587 L 162.04986,265.58172 z " id="path11707" style="fill-rule:evenodd;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;"/>
+      <path d="M 246.19114,233.72576 L 244.45983,236.84211 L 245.84488,238.91967 L 245.84488,241.68975 L 248.61496,242.38227 L 253.11634,239.26593 L 253.11634,236.14958 L 250.00000,236.14958 L 246.19114,233.72576 z " id="path11708" style="fill-rule:evenodd;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;"/>
+      <path d="M 277.35457,216.41274 L 273.89197,218.49030 L 274.58449,222.64543 L 278.04709,223.68421 L 280.12465,221.60665 L 279.43213,219.18283 L 277.35457,216.41274 z " id="path11709" style="fill-rule:evenodd;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;"/>
+      <path d="M 296.74515,215.37396 L 294.32133,219.87535 L 294.32133,223.68421 L 296.39889,227.14681 L 297.78393,227.83934 L 299.86150,226.80055 L 298.13019,223.33795 L 298.82271,220.91413 L 298.13019,220.22161 L 299.16898,218.14404 L 296.74515,215.37396 z " id="path11710" style="fill-rule:evenodd;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;"/>
+      <path d="M 338.98892,186.98061 L 336.91136,190.44321 L 341.75900,192.52078 L 347.29917,195.29086 L 352.49307,200.83102 L 359.07202,204.98615 L 350.06925,196.32964 L 344.18283,190.78947 L 338.98892,186.98061 z " id="path11711" style="fill-rule:evenodd;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;"/>
+    </g>
+    <path d="M 211.91084,163.99574 C 173.98348,223.23292 150.26865,129.75001 94.713090,166.13249 C 94.713090,134.13890 119.76880,108.17309 150.64102,108.17309 C 181.51324,108.17309 209.77409,133.07052 211.91084,163.99574 z " id="path12984" sodipodi:nodetypes="cccc" style="fill:url(#linearGradient12986);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+  </g>
+  <path d="M 174.63329,182.38179 L 166.49012,222.05835 L 225.51110,234.28244 L 233.52368,187.69187 L 174.63329,182.38179 z " id="path1971" style="fill:#0060ff;fill-opacity:0.69187677;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+  <path d="M 98.494889,184.33674 L 144.21081,220.66110 L 226.32871,234.63201 L 161.81028,187.82947 L 98.494889,184.33674 z " id="path3421" style="fill:url(#linearGradient1843);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+  <g id="g1961" transform="matrix(0.301344,0.153283,-0.129243,0.309114,182.2066,147.3372)">
+    <path d="M 20.956361,100.51129 L 106.87743,130.54875 L 187.21015,36.943667 L 20.956361,100.51129 z " id="path1962" style="fill:#9cd9ff;fill-opacity:0.47450981;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    <path d="M 37.022901,214.37419 L 89.413801,123.56329 L 106.17889,129.15166 L 120.84834,115.87930 L 219.34324,171.06438 L 37.022901,214.37419 z " id="path1963" style="fill:#9cd9ff;fill-opacity:0.47450981;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    <path d="M 21.996250,99.459565 L 22.058750,99.709565 L 38.715000,212.89707 L 89.839995,124.30332 L 21.996250,99.459565 z " id="path1964" sodipodi:nodetypes="ccccc" style="fill:#9cd9ff;fill-opacity:0.47450981;fill-rule:evenodd;stroke:none;stroke-width:0.89789753pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    <path d="M 186.29957,38.018302 L 119.48707,115.92456 L 217.92457,171.08081 L 186.29957,38.018302 z " id="path1965" sodipodi:nodetypes="cccc" style="fill:#9cd9ff;fill-opacity:0.47450981;fill-rule:evenodd;stroke:none;stroke-width:0.89789753pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    <path d="M 37.472522,99.700702 C 61.795439,108.19029 86.118355,116.67988 110.44127,125.16946 C 133.19127,98.669452 155.94127,72.169452 178.69127,45.669452 C 131.61835,63.679869 84.545439,81.690285 37.472522,99.700702 z " id="path1966" style="fill:url(#linearGradient1715);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    <path d="M 110.26104,129.99111 C 104.36927,132.80830 97.970663,126.13503 92.521105,127.10128 C 79.837340,147.57545 68.219984,169.04057 55.933393,189.88612 C 52.782194,195.34821 49.630994,200.81028 46.479795,206.27236 C 100.93812,193.33486 155.39646,180.39736 209.85479,167.45986 C 180.84437,151.18903 151.83396,134.91819 122.82354,118.64736 C 118.63604,122.42861 114.44854,126.20986 110.26104,129.99111 z " id="path1967" style="fill:url(#linearGradient28452);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    <path d="M 40.968750,202.41030 C 55.322917,177.54572 69.677083,152.68113 84.031250,127.81655 C 65.000000,120.84780 45.968750,113.87905 26.937500,106.91030 C 31.614583,138.74363 36.291667,170.57697 40.968750,202.41030 z " id="path1968" style="fill:url(#linearGradient28454);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:0.89789753pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    <path d="M 126.43749,114.86800 C 155.16666,130.96175 183.89582,147.05550 212.62499,163.14925 C 203.39582,124.30550 194.16666,85.461748 184.93749,46.617998 C 165.43749,69.367998 145.93749,92.117998 126.43749,114.86800 z " id="path1969" style="fill:url(#linearGradient28453);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:0.89789753pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+    <path d="M 109.67162,136.13710 L 122.24544,118.67347 L 108.97308,129.85019 L 26.544723,101.20984 L 23.750542,100.51129 L 23.750542,108.89384 L 109.67162,136.13710 z " id="path1970" sodipodi:nodetypes="ccccccc" style="fill:#537ed2;fill-opacity:0.51764709;fill-rule:evenodd;stroke:none;stroke-width:1.0000000pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000;"/>
+  </g>
+  <path d="M 125.85877,219.29323 C 166.48810,208.56345 165.55164,204.69076 124.81411,180.48637 C 90.430554,162.42714 72.126271,163.41416 84.626634,178.73233 C 60.296465,183.56225 26.281037,173.73932 7.6417829,142.70140 C -9.4364133,180.62587 49.326323,205.05466 75.787435,209.31872 C 65.709671,230.32719 102.09811,225.39704 125.85877,219.29323 z " id="path3422" sodipodi:nodetypes="cccccc" style="fill:url(#linearGradient1842);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:3.7500000;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000;"/>
+  <path d="M 124.76092,219.26867 C 160.58721,210.68743 162.41944,205.57623 149.05369,169.12762 C 136.24369,141.41788 122.58510,140.32674 121.59558,161.67934 C 101.17091,164.76222 83.309230,147.71323 90.072970,105.31178 C 53.456725,151.97622 79.500995,191.04096 95.574736,199.95160 C 74.851876,225.72195 103.91956,224.06659 124.76092,219.26867 z " id="path9145" sodipodi:nodetypes="cccccc" style="fill:url(#linearGradient3428);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:3.7500000;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000;"/>
+  <path d="M 127.85757,152.60868 C 126.39784,156.75987 124.39238,161.99996 125.07543,165.90254 C 131.70471,177.21906 127.24964,194.04315 114.00701,198.01906 C 109.21691,200.29570 103.05048,200.30569 98.485190,201.28288 C 98.129120,206.62762 89.024814,212.14134 94.121782,216.85995 C 105.17502,221.20999 117.43447,216.70060 128.58934,214.69122 C 136.53424,212.43592 146.45728,210.46092 151.21246,203.31132 C 154.58662,192.31448 148.13391,181.35324 144.78319,171.09116 C 141.30855,163.73826 137.00140,154.00811 128.75690,151.86404 C 128.50015,152.07662 127.90060,152.57306 127.85757,152.60868 z " id="path3429" style="fill:url(#linearGradient3431);fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:3.7500000;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4.0000000;stroke-opacity:1.0000000;"/>
+</svg>
diff -pruN 3.4.1-6/drop-indicator/data/misc/reload.svg 3.4.1+git20201022.a0d3415c-1/drop-indicator/data/misc/reload.svg
--- 3.4.1-6/drop-indicator/data/misc/reload.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/drop-indicator/data/misc/reload.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,73 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 20010904//EN"
+"http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd">
+<!-- Created with Sodipodi ("http://www.sodipodi.com/") --><svg height="437.5" id="svg1" sodipodi:docbase="/usr/share/icons/Lemon/scalable/actions/" sodipodi:docname="/usr/share/icons/Lemon/scalable/actions/reload.svg" sodipodi:version="0.34" version="1.0" width="437.5" x="0" xmlns="http://www.w3.org/2000/svg" xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:xlink="http://www.w3.org/1999/xlink" y="0">
+  <metadata>
+    <rdf:RDF xmlns:cc="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
+      <cc:Work rdf:about="">
+        <dc:title>Lemon SVG theme</dc:title>
+        <dc:description></dc:description>
+        <dc:subject>
+          <rdf:Bag>
+            <rdf:li>icon</rdf:li>
+            <rdf:li>action</rdf:li>
+            <rdf:li>computer</rdf:li>
+            <rdf:li>lemon_theme_icon</rdf:li>
+            <rdf:li>icons</rdf:li>
+            <rdf:li>theme</rdf:li>
+          </rdf:Bag>
+        </dc:subject>
+        <dc:publisher>
+          <cc:Agent rdf:about="http://www.openclipart.org">
+            <dc:title>Jose Hevia</dc:title>
+          </cc:Agent>
+        </dc:publisher>
+        <dc:creator>
+          <cc:Agent>
+            <dc:title>Jose Hevia</dc:title>
+          </cc:Agent>
+        </dc:creator>
+        <dc:rights>
+          <cc:Agent>
+            <dc:title>Jose Hevia</dc:title>
+          </cc:Agent>
+        </dc:rights>
+        <dc:date></dc:date>
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
+        <cc:license rdf:resource="http://web.resource.org/cc/PublicDomain"/>
+        <dc:language>en</dc:language>
+      </cc:Work>
+      <cc:License rdf:about="http://web.resource.org/cc/PublicDomain">
+        <cc:permits rdf:resource="http://web.resource.org/cc/Reproduction"/>
+        <cc:permits rdf:resource="http://web.resource.org/cc/Distribution"/>
+        <cc:permits rdf:resource="http://web.resource.org/cc/DerivativeWorks"/>
+      </cc:License>
+    </rdf:RDF>
+  </metadata>
+  <sodipodi:namedview id="base"/>
+  <defs id="defs3">
+    <linearGradient id="linearGradient580">
+      <stop id="stop581" offset="0" style="stop-color:#ffff8a;stop-opacity:0.6667;"/>
+      <stop id="stop582" offset="1" style="stop-color:#000000;stop-opacity:0.3961;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient53">
+      <stop id="stop54" offset="0" style="stop-color:#faff00;stop-opacity:1;"/>
+      <stop id="stop55" offset="1" style="stop-color:#ffa200;stop-opacity:1;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient48">
+      <stop id="stop49" offset="0" style="stop-color:#005d00;stop-opacity:1;"/>
+      <stop id="stop50" offset="1" style="stop-color:#ffff7f;stop-opacity:1;"/>
+    </linearGradient>
+    <linearGradient id="linearGradient51" xlink:href="#linearGradient53"/>
+    <linearGradient id="linearGradient52" x1="-1.87901605e-9" x2="1" xlink:href="#linearGradient53" y1="3.2877483e-9" y2="3.2877483e-9"/>
+    <linearGradient id="linearGradient32" x1="0.10917" x2="0.74235803" xlink:href="#linearGradient48" y1="0.515625" y2="0.49218801"/>
+    <linearGradient id="linearGradient33" x1="-1.49062593e-8" x2="1" xlink:href="#linearGradient48" y1="3.64054813e-8" y2="3.64054813e-8"/>
+    <radialGradient cx="0.5" cy="0.5" fx="0.5" fy="0.5" id="radialGradient579" r="0.5" xlink:href="#linearGradient580"/>
+    <linearGradient id="linearGradient1128" x1="5.85739501e-9" x2="1" xlink:href="#linearGradient48" y1="1.37658901e-7" y2="1.37658901e-7"/>
+    <linearGradient id="linearGradient1131" x1="-5.52663018e-8" x2="1" xlink:href="#linearGradient48" y1="-4.15234389e-8" y2="-4.15234389e-8"/>
+    <linearGradient id="linearGradient1132" x1="-3.44118014e-8" x2="1" xlink:href="#linearGradient48" y1="2.72773306e-8" y2="2.72773306e-8"/>
+  </defs>
+  <path d="M 269.25 145.0625 C 295.1875 169.25 342.1875 228.3125 357 245.8125 C 372.5625 229.3125 416.3125 157.0625 424.3125 143.6875 C 414.375 143.3125 395.25 143.4375 369.1875 143.875 C 334.9375 21.06251 242.8125 11.12499 217.5 11.12499 C 86.625 12.68749 18.0625 130.5625 20.875 178.75 C 39.6875 178.5 125.5625 177.25 152.5625 176.1875 C 159.4375 85.68748 211.75 76.5625 250.4375 74.24999 C 280.4375 73.4375 318.875 98.37502 328.0625 143.9375 C 330 144.125 287.125 144.9375 269.25 145.0625 z " id="path629" sodipodi:nodetypes="cccccccccc" style="font-size:12;fill:#ffb200;fill-rule:evenodd;stroke:#8b0000;stroke-width:12.69966;stroke-opacity:1;fill-opacity:1;"/>
+  <path d="M 164.7978 288.5 C 141.0419 266.0625 98.87661 211.3125 85.51009 195.125 C 69.40951 210.4375 22.56593 277.375 13.99921 289.8125 C 23.53804 290.125 41.6436 290.0625 66.67544 289.625 C 102.036 404.875 191.2879 429 219.1145 429 C 346.2787 427.4375 432.7358 308.5 430.0017 260.375 C 387.958 260.5625 334.1273 261.875 280.236 262.9375 C 273.5527 353.375 226.6484 367.8125 192.9891 368 C 164.7371 368.75 132.6574 334.3125 113.033 289.125 C 132.779 288.8125 150.3377 288.625 164.7978 288.5 z " id="path632" style="font-size:12;fill:#ffff00;fill-rule:evenodd;stroke:#275a00;stroke-width:12.40281;stroke-opacity:1;"/>
+</svg>
diff -pruN 3.4.1-6/dustbin/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/dustbin/data/misc/icon.svg
--- 3.4.1-6/dustbin/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/dustbin/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,780 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   version="1.1"
+   width="48"
+   height="48"
+   id="svg2541">
+  <defs
+     id="defs2543">
+    <linearGradient
+       x1="92.004761"
+       y1="47.258526"
+       x2="55.992207"
+       y2="10.900407"
+       id="linearGradient14689"
+       xlink:href="#linearGradient2793"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.500942,0,0,0.500942,-0.5731737,-0.060288)"
+       spreadMethod="reflect" />
+    <linearGradient
+       id="linearGradient4302">
+      <stop
+         id="stop4304"
+         style="stop-color:#c0c0c0;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4306"
+         style="stop-color:#abacb0;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="63.999081"
+       y1="6.4738212"
+       x2="63.999081"
+       y2="31.225994"
+       id="linearGradient2857"
+       xlink:href="#linearGradient4302"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.1456259,0,0,1.1456259,-9.3190033,-13.992276)" />
+    <linearGradient
+       x1="32.626884"
+       y1="37.21664"
+       x2="63.999931"
+       y2="37.21664"
+       id="linearGradient3961"
+       xlink:href="#linearGradient2793"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.5976473,0,0,0.5396451,-6.761717,-4.7542661)"
+       spreadMethod="reflect" />
+    <linearGradient
+       x1="97.717728"
+       y1="17.833755"
+       x2="62.373119"
+       y2="17.833755"
+       id="linearGradient13703"
+       xlink:href="#linearGradient2793"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.6160503,0,0,0.5936306,-7.9395479,-5.9435742)"
+       spreadMethod="reflect" />
+    <linearGradient
+       id="linearGradient4294">
+      <stop
+         id="stop4296"
+         style="stop-color:#e6e7e7;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4298"
+         style="stop-color:#676b73;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="29.232975"
+       y1="1.2616313"
+       x2="29.232977"
+       y2="57.745785"
+       id="linearGradient2944"
+       xlink:href="#linearGradient4294"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.044519,0,0,1.044519,0.9058083,-0.6999367)" />
+    <linearGradient
+       id="linearGradient2338">
+      <stop
+         id="stop3317"
+         style="stop-color:#f8f8f8;stop-opacity:0.15463917"
+         offset="0" />
+      <stop
+         id="stop3322"
+         style="stop-color:#b0b2b6;stop-opacity:0.17525773"
+         offset="0.49817383" />
+      <stop
+         id="stop3319"
+         style="stop-color:#5b5e62;stop-opacity:0.3298969"
+         offset="0.83783782" />
+      <stop
+         id="stop2342"
+         style="stop-color:#ffffff;stop-opacity:0.15463917"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="4.8849959"
+       y1="38.13002"
+       x2="35.514687"
+       y2="39.751118"
+       id="linearGradient2942"
+       xlink:href="#linearGradient2338"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.2635854,0,0,1.4786159,5.8086801,-19.347029)" />
+    <linearGradient
+       x1="25.632622"
+       y1="10.611729"
+       x2="38.714096"
+       y2="18.389904"
+       id="linearGradient16586"
+       xlink:href="#linearGradient5176"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1,0,0,1,-164.71303,28.239477)" />
+    <linearGradient
+       x1="24.365993"
+       y1="20.246058"
+       x2="32.600704"
+       y2="28.554564"
+       id="linearGradient16584"
+       xlink:href="#linearGradient5162"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1,0,0,1,-164.71303,28.239477)" />
+    <linearGradient
+       x1="22.008699"
+       y1="36.509514"
+       x2="23.585091"
+       y2="14.412428"
+       id="linearGradient16582"
+       xlink:href="#linearGradient5162"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1,0,0,1,-164.71303,28.239477)" />
+    <radialGradient
+       cx="20.089987"
+       cy="10.853651"
+       r="22.597088"
+       fx="20.089987"
+       fy="10.853651"
+       id="radialGradient16580"
+       xlink:href="#linearGradient5196"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.790269,0,0,1.769263,-148.89909,16.289507)" />
+    <radialGradient
+       cx="23.688078"
+       cy="14.210698"
+       r="22.597088"
+       fx="23.688078"
+       fy="14.210698"
+       id="radialGradient16578"
+       xlink:href="#linearGradient5188"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-2.135667,0,0,2.110607,-137.81127,12.570337)" />
+    <linearGradient
+       x1="25.632622"
+       y1="10.611729"
+       x2="38.714096"
+       y2="18.389904"
+       id="linearGradient16576"
+       xlink:href="#linearGradient5176"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1,0,0,1,-164.71303,28.239477)" />
+    <linearGradient
+       x1="24.365993"
+       y1="20.246058"
+       x2="32.600704"
+       y2="28.554564"
+       id="linearGradient16574"
+       xlink:href="#linearGradient5162"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1,0,0,1,-164.71303,28.239477)" />
+    <linearGradient
+       x1="22.008699"
+       y1="36.509514"
+       x2="23.585091"
+       y2="14.412428"
+       id="linearGradient16572"
+       xlink:href="#linearGradient5162"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1,0,0,1,-164.71303,28.239477)" />
+    <radialGradient
+       cx="20.089987"
+       cy="10.853651"
+       r="22.597088"
+       fx="20.089987"
+       fy="10.853651"
+       id="radialGradient16570"
+       xlink:href="#linearGradient5196"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.790269,0,0,1.769263,-148.89909,16.289507)" />
+    <radialGradient
+       cx="23.688078"
+       cy="14.210698"
+       r="22.597088"
+       fx="23.688078"
+       fy="14.210698"
+       id="radialGradient16568"
+       xlink:href="#linearGradient5188"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-2.135667,0,0,2.110607,-137.81127,12.570337)" />
+    <linearGradient
+       x1="25.632622"
+       y1="10.611729"
+       x2="38.714096"
+       y2="18.389904"
+       id="linearGradient16566"
+       xlink:href="#linearGradient5176"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1,0,0,1,-164.71303,28.239477)" />
+    <linearGradient
+       x1="24.365993"
+       y1="20.246058"
+       x2="32.600704"
+       y2="28.554564"
+       id="linearGradient16564"
+       xlink:href="#linearGradient5162"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1,0,0,1,-164.71303,28.239477)" />
+    <linearGradient
+       x1="22.008699"
+       y1="36.509514"
+       x2="23.585091"
+       y2="14.412428"
+       id="linearGradient16562"
+       xlink:href="#linearGradient5162"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1,0,0,1,-164.71303,28.239477)" />
+    <radialGradient
+       cx="20.089987"
+       cy="10.853651"
+       r="22.597088"
+       fx="20.089987"
+       fy="10.853651"
+       id="radialGradient16560"
+       xlink:href="#linearGradient5196"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.790269,0,0,1.769263,-148.89909,16.289507)" />
+    <radialGradient
+       cx="23.688078"
+       cy="14.210698"
+       r="22.597088"
+       fx="23.688078"
+       fy="14.210698"
+       id="radialGradient16558"
+       xlink:href="#linearGradient5188"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-2.135667,0,0,2.110607,-137.81127,12.570337)" />
+    <linearGradient
+       x1="25.632622"
+       y1="10.611729"
+       x2="38.714096"
+       y2="18.389904"
+       id="linearGradient16556"
+       xlink:href="#linearGradient5176"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.500942,0,0,0.500942,127.79749,34.542958)" />
+    <linearGradient
+       x1="24.365993"
+       y1="20.246058"
+       x2="32.600704"
+       y2="28.554564"
+       id="linearGradient16554"
+       xlink:href="#linearGradient5162"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.500942,0,0,0.500942,127.79749,34.542958)" />
+    <linearGradient
+       x1="22.008699"
+       y1="36.509514"
+       x2="23.585091"
+       y2="14.412428"
+       id="linearGradient16552"
+       xlink:href="#linearGradient5162"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.500942,0,0,0.500942,127.79749,34.542958)" />
+    <radialGradient
+       cx="20.089987"
+       cy="10.853651"
+       r="22.597088"
+       fx="20.089987"
+       fy="10.853651"
+       id="radialGradient16550"
+       xlink:href="#linearGradient5196"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.8968209,0,0,0.8862981,135.71936,28.556716)" />
+    <radialGradient
+       cx="23.688078"
+       cy="14.210698"
+       r="22.597088"
+       fx="23.688078"
+       fy="14.210698"
+       id="radialGradient16548"
+       xlink:href="#linearGradient5188"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.0698453,0,0,1.0572917,141.27372,26.693628)" />
+    <radialGradient
+       cx="24.837126"
+       cy="40.663769"
+       r="21.478369"
+       fx="24.837126"
+       fy="40.663769"
+       id="radialGradient16546"
+       xlink:href="#linearGradient5150"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1,0,0,0.325103,0,27.44386)" />
+    <linearGradient
+       id="linearGradient5176">
+      <stop
+         id="stop5178"
+         style="stop-color:#000000;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop5180"
+         style="stop-color:#000000;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="25.632622"
+       y1="10.611729"
+       x2="38.714096"
+       y2="18.389904"
+       id="linearGradient16544"
+       xlink:href="#linearGradient5176"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1,0,0,1,-164.71303,28.239477)" />
+    <linearGradient
+       x1="24.365993"
+       y1="20.246058"
+       x2="32.600704"
+       y2="28.554564"
+       id="linearGradient16542"
+       xlink:href="#linearGradient5162"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1,0,0,1,-164.71303,28.239477)" />
+    <linearGradient
+       x1="22.008699"
+       y1="36.509514"
+       x2="23.585091"
+       y2="14.412428"
+       id="linearGradient16540"
+       xlink:href="#linearGradient5162"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1,0,0,1,-164.71303,28.239477)" />
+    <radialGradient
+       cx="20.089987"
+       cy="10.853651"
+       r="22.597088"
+       fx="20.089987"
+       fy="10.853651"
+       id="radialGradient16538"
+       xlink:href="#linearGradient5196"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.790269,0,0,1.769263,-148.89909,16.289507)" />
+    <radialGradient
+       cx="23.688078"
+       cy="14.210698"
+       r="22.597088"
+       fx="23.688078"
+       fy="14.210698"
+       id="radialGradient16536"
+       xlink:href="#linearGradient5188"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-2.135667,0,0,2.110607,-137.81127,12.570337)" />
+    <radialGradient
+       cx="24.837126"
+       cy="40.663769"
+       r="21.478369"
+       fx="24.837126"
+       fy="40.663769"
+       id="radialGradient16534"
+       xlink:href="#linearGradient5150"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1,0,0,0.325103,0,27.44386)" />
+    <linearGradient
+       x1="73.373505"
+       y1="82.788712"
+       x2="89.456299"
+       y2="82.788712"
+       id="linearGradient16532"
+       xlink:href="#linearGradient2793"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.5120754,0,0,0.4900506,90.554105,0.02408511)" />
+    <linearGradient
+       x1="24.365993"
+       y1="20.246058"
+       x2="32.600704"
+       y2="28.554564"
+       id="linearGradient16530"
+       xlink:href="#linearGradient5162"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.500942,0,0,0.500942,116.96896,34.747555)" />
+    <linearGradient
+       id="linearGradient5162">
+      <stop
+         id="stop5164"
+         style="stop-color:#babdb6;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop5166"
+         style="stop-color:#ffffff;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="22.008699"
+       y1="36.509514"
+       x2="23.585091"
+       y2="14.412428"
+       id="linearGradient16528"
+       xlink:href="#linearGradient5162"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.500942,0,0,0.500942,116.96896,34.747555)" />
+    <linearGradient
+       id="linearGradient5196">
+      <stop
+         id="stop5198"
+         style="stop-color:#dfe2dc;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop5200"
+         style="stop-color:#86917a;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="20.089987"
+       cy="10.853651"
+       r="22.597088"
+       fx="20.089987"
+       fy="10.853651"
+       id="radialGradient16526"
+       xlink:href="#linearGradient5196"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.8968209,0,0,0.8862981,109.0471,28.761313)" />
+    <linearGradient
+       id="linearGradient5188">
+      <stop
+         id="stop5190"
+         style="stop-color:#ffffff;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop5192"
+         style="stop-color:#aeaea3;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="23.688078"
+       cy="14.210698"
+       r="22.597088"
+       fx="23.688078"
+       fy="14.210698"
+       id="radialGradient16524"
+       xlink:href="#linearGradient5188"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.0698453,0,0,1.0572917,103.49274,26.898224)" />
+    <linearGradient
+       id="linearGradient5150">
+      <stop
+         id="stop5152"
+         style="stop-color:#000000;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop5154"
+         style="stop-color:#000000;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="24.837126"
+       cy="40.663769"
+       r="21.478369"
+       fx="24.837126"
+       fy="40.663769"
+       id="radialGradient16522"
+       xlink:href="#linearGradient5150"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1,0,0,0.325103,0,27.44386)" />
+    <linearGradient
+       id="linearGradient2793">
+      <stop
+         id="stop2795"
+         style="stop-color:#555753;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2797"
+         style="stop-color:#d3d7cf;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="27.405413"
+       y1="52.355087"
+       x2="37.462498"
+       y2="68.298302"
+       id="linearGradient2781"
+       xlink:href="#linearGradient2793"
+       gradientUnits="userSpaceOnUse"
+       spreadMethod="reflect" />
+    <linearGradient
+       id="linearGradient5060">
+      <stop
+         id="stop5062"
+         style="stop-color:#000000;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop5064"
+         style="stop-color:#000000;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="62.71241"
+       cy="108.02493"
+       r="47.38271"
+       fx="62.71241"
+       fy="108.02493"
+       id="radialGradient2773"
+       xlink:href="#linearGradient5060"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.46584864,0,0,0.12994518,2.7851652,42.535268)" />
+  </defs>
+  <g
+     transform="translate(0,1.0000003)"
+     id="layer1">
+    <g
+       transform="matrix(0.7450674,0,0,0.7450674,0.1110998,0.1110989)"
+       id="g2519">
+      <path
+         d="m 54.072827,56.572601 a 22.073171,6.1571611 0 0 1 -44.146342,0 22.073171,6.1571611 0 1 1 44.146342,0 z"
+         id="path12941"
+         style="color:#000000;fill:url(#radialGradient2773);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.05496335;marker:none;visibility:visible;display:inline;overflow:visible" />
+      <path
+         d="m 46.331873,53.131126 a 16.276243,4.2701988 0 1 1 -32.552486,0 16.276243,4.2701988 0 1 1 32.552486,0 z"
+         transform="matrix(1.1278169,0,0,1.0058418,-2.4096027,1.4160777)"
+         id="path5870"
+         style="color:#000000;fill:#d9dcd5;fill-opacity:1;fill-rule:evenodd;stroke:#838383;stroke-width:0.47033069;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+      <path
+         d="m 46.331873,53.131126 a 16.276243,4.2701988 0 1 1 -32.552486,0 16.276243,4.2701988 0 1 1 32.552486,0 z"
+         transform="matrix(1.1278169,0,0,1.0058418,-2.4096027,1.4160777)"
+         id="path3037"
+         style="opacity:0.5;color:#000000;fill:url(#linearGradient2781);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:0.47033069;marker:none;visibility:visible;display:inline;overflow:visible" />
+      <g
+         transform="translate(-90.692784,-0.7358441)"
+         id="g16471">
+        <path
+           d="m 46.315495,40.663769 a 21.478369,6.9826794 0 1 1 -42.956738,0 21.478369,6.9826794 0 1 1 42.956738,0 z"
+           transform="matrix(0.5545408,0,0,0.5545408,115.28351,32.036699)"
+           id="path4275"
+           style="opacity:0.3258427;color:#000000;fill:url(#radialGradient16522);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <path
+           d="m 121.48526,53.568032 -0.88555,1.41688 1.85966,0.796993 1.32832,-1.062658 5.93318,0.442773 1.85965,2.479537 1.68254,-2.745202 2.12532,1.151215 2.83375,-0.354221 -0.70844,-1.505431 1.94821,-1.948209 -2.7452,-3.099419 2.65665,0.354219 1.15121,-1.062658 -1.50543,0.265664 -1.59399,-2.745201 -2.30243,-0.531329 1.85966,-0.619884 0.0885,-1.593988 -3.63075,-3.187975 -1.32832,-4.250634 -6.02173,1.771097 -1.50543,3.542195 -0.53133,-1.151213 -1.50544,0.08855 0,1.416878 -1.77109,-2.036762 -2.39099,2.568091 0,3.63075 4.16208,3.63075 -2.65665,1.505433 0.0886,1.505431 1.50543,1.328323 z"
+           id="path4273"
+           style="color:#000000;fill:url(#radialGradient16524);fill-opacity:1;fill-rule:evenodd;stroke:url(#radialGradient16526);stroke-width:0.50094199;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <path
+           d="m 126.71,46.129424 -0.44278,3.27653 1.06266,1.682541 -2.30242,0.708442 -1.32832,2.656645 6.02173,0.442773 1.41687,2.036765 1.15122,-3.099423 -2.21387,-1.416875 -3.36509,0.974102 1.32832,-1.771095 -0.70844,-3.099424 -0.61988,-2.390981 z"
+           id="path5158"
+           style="opacity:0.76966289;color:#000000;fill:url(#linearGradient16528);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <path
+           d="m 127.24133,46.660753 2.21387,3.45364 3.63075,-2.479536 2.21387,1.239768 1.7711,-1.505433 1.59399,1.416878 -1.50543,-2.479536 -3.45365,-0.796994 -4.33918,-2.125317 c 0,0 -6.19884,1.859652 -5.84462,1.859652 0.35421,0 5.13618,0.08855 5.13618,0.08855 l 0.79699,-1.151213 2.12532,0.974103 -4.33919,1.505433 z"
+           id="path5160"
+           style="opacity:0.61797755;color:#000000;fill:url(#linearGradient16530);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <path
+           d="m 131.75763,36.476943 -5.22474,1.771098 -0.70844,1.948207 3.01087,2.125317 2.83375,-2.745202 0.0886,-3.09942 z"
+           id="path5172"
+           style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <path
+           d="m 131.84618,36.654053 1.15122,3.719304 2.12531,1.859653 -4.33919,-0.974104 c 0,0 -1.23976,1.416878 -0.70843,1.416878 0.53132,0 6.28739,0.708439 6.28739,0.708439 l -0.0885,1.151213 -8.14705,-1.505433 3.54219,-3.27653 0.17711,-3.09942 z"
+           id="path5174"
+           style="opacity:0.13483145;color:#000000;fill:url(#linearGradient16532);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <path
+           d="m 120.68827,41.87879 -0.44277,4.427744 0.9741,-3.010866 2.56809,0.796994 0.61988,-1.328323 3.09943,0.442774 0.70843,-0.619884 -4.51629,-0.17711 -0.44278,1.239769 -1.94821,-0.974104 -0.61988,-0.796994 z"
+           id="path5184"
+           style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <path
+           d="m 128.21543,48.431851 1.50544,1.771098 3.45364,-2.302428 2.12531,1.151214 3.45364,3.276531 -3.80786,-2.922312 -1.85965,-0.531329 -3.63075,2.479539 -1.23977,-2.922313 z"
+           id="path5186"
+           style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <path
+           d="m 46.315495,40.663769 a 21.478369,6.9826794 0 1 1 -42.956738,0 21.478369,6.9826794 0 1 1 42.956738,0 z"
+           transform="matrix(-0.5545408,0,0,0.5545408,134.44323,32.717865)"
+           id="path2423"
+           style="opacity:0.3258427;color:#000000;fill:url(#radialGradient16534);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <g
+           transform="matrix(-0.500942,0,0,0.500942,18.541824,6.4015722)"
+           id="g2507">
+          <path
+             d="m -173.72864,65.809652 1.76777,2.828427 -3.71232,1.59099 -2.65165,-2.12132 -11.84403,0.883883 -3.71231,4.949748 -3.35876,-5.480078 -4.24264,2.298097 -5.65685,-0.707106 1.41421,-3.005204 -3.88909,-3.889088 5.48008,-6.187184 -5.3033,0.707107 -2.2981,-2.12132 3.00521,0.53033 3.18198,-5.480078 4.59619,-1.06066 -3.71231,-1.237437 -0.17678,-3.18198 7.24785,-6.363961 2.65165,-8.485282 12.02081,3.535534 3.0052,7.071068 1.06066,-2.298097 3.00521,0.176777 0,2.828427 3.53553,-4.065864 4.77297,5.126524 0,7.247844 -8.3085,7.247845 5.3033,3.005204 -0.17678,3.005203 -3.0052,2.651651 z"
+             id="path2425"
+             style="color:#000000;fill:url(#radialGradient16536);fill-opacity:1;fill-rule:evenodd;stroke:url(#radialGradient16538);stroke-width:1;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -184.15847,50.96041 0.88389,6.540737 -2.12132,3.358757 4.59619,1.414214 2.65165,5.303301 -12.02081,0.883883 -2.82843,4.065864 -2.2981,-6.187184 4.41942,-2.828427 6.71751,1.944544 -2.65165,-3.535534 1.41422,-6.187185 1.23743,-4.77297 z"
+             id="path2427"
+             style="opacity:0.76966289;color:#000000;fill:url(#linearGradient16540);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -185.21913,52.02107 -4.41941,6.894291 -7.24785,-4.949748 -4.41941,2.474874 -3.53554,-3.005204 -3.18198,2.828427 3.00521,-4.949747 6.89429,-1.59099 8.66205,-4.242641 c 0,0 12.37437,3.712311 11.66726,3.712311 -0.7071,0 -10.25304,0.176776 -10.25304,0.176776 l -1.59099,-2.298097 -4.24264,1.944544 8.66205,3.005204 z"
+             id="path2429"
+             style="opacity:0.61797755;color:#000000;fill:url(#linearGradient16542);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -194.23474,31.69175 10.42983,3.535534 1.41421,3.889087 -6.01041,4.242641 -5.65685,-5.480078 -0.17678,-6.187184 z"
+             id="path2431"
+             style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -194.41151,32.045303 -2.2981,7.424621 -4.24264,3.712311 8.66206,-1.944544 c 0,0 2.47487,2.828427 1.41421,2.828427 -1.06066,0 -12.55114,1.414214 -12.55114,1.414214 l 0.17677,2.298097 16.26346,-3.005204 -7.07107,-6.540738 -0.35355,-6.187184 z"
+             id="path2433"
+             style="opacity:0.13483145;color:#000000;fill:url(#linearGradient16544);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -172.13765,42.475128 0.88388,8.838835 -1.94454,-6.010408 -5.12653,1.590991 -1.23743,-2.651651 -6.18719,0.883884 -1.41421,-1.237437 9.01561,-0.353554 0.88388,2.474874 3.88909,-1.944544 1.23744,-1.59099 z"
+             id="path2435"
+             style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -187.16367,55.556604 -3.0052,3.535534 -6.89429,-4.596195 -4.24264,2.298097 -6.89429,6.540738 7.60139,-5.833631 3.71231,-1.06066 7.24785,4.949748 2.47487,-5.833631 z"
+             id="path2437"
+             style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        </g>
+        <path
+           d="m 46.315495,40.663769 a 21.478369,6.9826794 0 1 1 -42.956738,0 21.478369,6.9826794 0 1 1 42.956738,0 z"
+           transform="matrix(-0.5545408,0,0,0.5545408,129.48295,31.832103)"
+           id="path2479"
+           style="opacity:0.3258427;color:#000000;fill:url(#radialGradient16546);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <path
+           d="m 123.28119,53.363437 0.88556,1.41688 -1.85966,0.796994 -1.32832,-1.062659 -5.93318,0.442773 -1.85965,2.479538 -1.68254,-2.745203 -2.12532,1.151215 -2.83375,-0.354221 0.70843,-1.505431 -1.9482,-1.948208 2.7452,-3.099422 -2.65665,0.35422 -1.15121,-1.062658 1.50543,0.265664 1.59399,-2.745201 2.30243,-0.531329 -1.85966,-0.619884 -0.0886,-1.593988 3.63075,-3.187975 1.32832,-4.250634 6.02173,1.771097 1.50543,3.542195 0.53133,-1.151213 1.50544,0.08855 0,1.416878 1.77109,-2.036762 2.39098,2.568091 0,3.630749 -4.16207,3.63075 2.65664,1.505431 -0.0885,1.505436 -1.50544,1.328322 z"
+           id="path2481"
+           style="color:#000000;fill:url(#radialGradient16548);fill-opacity:1;fill-rule:evenodd;stroke:url(#radialGradient16550);stroke-width:0.50094199;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <path
+           d="m 118.05645,45.924828 0.44278,3.27653 -1.06266,1.682542 2.30243,0.708437 1.32832,2.656651 -6.02173,0.442772 -1.41688,2.03676 -1.15121,-3.099418 2.21387,-1.416879 3.36508,0.974106 -1.32832,-1.7711 0.70844,-3.09942 0.61988,-2.390981 z"
+           id="path2483"
+           style="opacity:0.76966289;color:#000000;fill:url(#linearGradient16552);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <path
+           d="m 117.52513,46.456157 -2.21387,3.45364 -3.63075,-2.479537 -2.21387,1.239769 -1.7711,-1.505433 -1.59399,1.416878 1.50544,-2.479536 3.45363,-0.796994 4.33919,-2.125317 c 0,0 6.19884,1.859652 5.84462,1.859652 -0.35422,0 -5.13618,0.08855 -5.13618,0.08855 l -0.79699,-1.151214 -2.12532,0.974104 4.33919,1.505433 z"
+           id="path2485"
+           style="opacity:0.61797755;color:#000000;fill:url(#linearGradient16554);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <path
+           d="m 113.00883,36.272347 5.22474,1.771097 0.70844,1.948207 -3.01087,2.125317 -2.83376,-2.745201 -0.0885,-3.09942 z"
+           id="path2487"
+           style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <path
+           d="m 112.92028,36.449456 -1.15122,3.719305 -2.12531,1.859652 4.33918,-0.974103 c 0,0 1.23977,1.416878 0.70844,1.416878 -0.53133,0 -6.28739,0.708439 -6.28739,0.708439 l 0.0885,1.151213 8.14705,-1.505433 -3.5422,-3.27653 -0.1771,-3.099421 z"
+           id="path2489"
+           style="opacity:0.13483145;color:#000000;fill:url(#linearGradient16556);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <path
+           d="m 124.07819,41.674194 0.44277,4.427744 -0.9741,-3.010866 -2.56809,0.796994 -0.61989,-1.328323 -3.09942,0.442774 -0.70844,-0.619884 4.5163,-0.17711 0.44277,1.239768 1.94821,-0.974103 0.61989,-0.796994 z"
+           id="path2491"
+           style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <path
+           d="m 116.55102,48.227255 -1.50543,1.771097 -3.45364,-2.302427 -2.12531,1.151213 -3.45364,3.276528 3.80785,-2.922308 1.85966,-0.531329 3.63075,2.479535 1.23976,-2.922309 z"
+           id="path2493"
+           style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        <g
+           transform="matrix(0,-0.500942,-0.500942,0,143.56035,-60.06773)"
+           id="g2586">
+          <path
+             d="m -173.72864,65.809652 1.76777,2.828427 -3.71232,1.59099 -2.65165,-2.12132 -11.84403,0.883883 -3.71231,4.949748 -3.35876,-5.480078 -4.24264,2.298097 -5.65685,-0.707106 1.41421,-3.005204 -3.88909,-3.889088 5.48008,-6.187184 -5.3033,0.707107 -2.2981,-2.12132 3.00521,0.53033 3.18198,-5.480078 4.59619,-1.06066 -3.71231,-1.237437 -0.17678,-3.18198 7.24785,-6.363961 2.65165,-8.485282 12.02081,3.535534 3.0052,7.071068 1.06066,-2.298097 3.00521,0.176777 0,2.828427 3.53553,-4.065864 4.77297,5.126524 0,7.247844 -8.3085,7.247845 5.3033,3.005204 -0.17678,3.005203 -3.0052,2.651651 z"
+             id="path2588"
+             style="color:#000000;fill:url(#radialGradient16558);fill-opacity:1;fill-rule:evenodd;stroke:url(#radialGradient16560);stroke-width:1;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -184.15847,50.96041 0.88389,6.540737 -2.12132,3.358757 4.59619,1.414214 2.65165,5.303301 -12.02081,0.883883 -2.82843,4.065864 -2.2981,-6.187184 4.41942,-2.828427 6.71751,1.944544 -2.65165,-3.535534 1.41422,-6.187185 1.23743,-4.77297 z"
+             id="path2590"
+             style="opacity:0.76966289;color:#000000;fill:url(#linearGradient16562);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -185.21913,52.02107 -4.41941,6.894291 -7.24785,-4.949748 -4.41941,2.474874 -3.53554,-3.005204 -3.18198,2.828427 3.00521,-4.949747 6.89429,-1.59099 8.66205,-4.242641 c 0,0 12.37437,3.712311 11.66726,3.712311 -0.7071,0 -10.25304,0.176776 -10.25304,0.176776 l -1.59099,-2.298097 -4.24264,1.944544 8.66205,3.005204 z"
+             id="path2592"
+             style="opacity:0.61797755;color:#000000;fill:url(#linearGradient16564);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -194.23474,31.69175 10.42983,3.535534 1.41421,3.889087 -6.01041,4.242641 -5.65685,-5.480078 -0.17678,-6.187184 z"
+             id="path2594"
+             style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -194.41151,32.045303 -2.2981,7.424621 -4.24264,3.712311 8.66206,-1.944544 c 0,0 2.47487,2.828427 1.41421,2.828427 -1.06066,0 -12.55114,1.414214 -12.55114,1.414214 l 0.17677,2.298097 16.26346,-3.005204 -7.07107,-6.540738 -0.35355,-6.187184 z"
+             id="path2596"
+             style="opacity:0.13483145;color:#000000;fill:url(#linearGradient16566);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -172.13765,42.475128 0.88388,8.838835 -1.94454,-6.010408 -5.12653,1.590991 -1.23743,-2.651651 -6.18719,0.883884 -1.41421,-1.237437 9.01561,-0.353554 0.88388,2.474874 3.88909,-1.944544 1.23744,-1.59099 z"
+             id="path2598"
+             style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -187.16367,55.556604 -3.0052,3.535534 -6.89429,-4.596195 -4.24264,2.298097 -6.89429,6.540738 7.60139,-5.833631 3.71231,-1.06066 7.24785,4.949748 2.47487,-5.833631 z"
+             id="path2600"
+             style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        </g>
+        <g
+           transform="matrix(0.500942,0,0,0.500942,226.25289,6.2244201)"
+           id="g2552">
+          <path
+             d="m -173.72864,65.809652 1.76777,2.828427 -3.71232,1.59099 -2.65165,-2.12132 -11.84403,0.883883 -3.71231,4.949748 -3.35876,-5.480078 -4.24264,2.298097 -5.65685,-0.707106 1.41421,-3.005204 -3.88909,-3.889088 5.48008,-6.187184 -5.3033,0.707107 -2.2981,-2.12132 3.00521,0.53033 3.18198,-5.480078 4.59619,-1.06066 -3.71231,-1.237437 -0.17678,-3.18198 7.24785,-6.363961 2.65165,-8.485282 12.02081,3.535534 3.0052,7.071068 1.06066,-2.298097 3.00521,0.176777 0,2.828427 3.53553,-4.065864 4.77297,5.126524 0,7.247844 -8.3085,7.247845 5.3033,3.005204 -0.17678,3.005203 -3.0052,2.651651 z"
+             id="path2554"
+             style="color:#000000;fill:url(#radialGradient16568);fill-opacity:1;fill-rule:evenodd;stroke:url(#radialGradient16570);stroke-width:1;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -184.15847,50.96041 0.88389,6.540737 -2.12132,3.358757 4.59619,1.414214 2.65165,5.303301 -12.02081,0.883883 -2.82843,4.065864 -2.2981,-6.187184 4.41942,-2.828427 6.71751,1.944544 -2.65165,-3.535534 1.41422,-6.187185 1.23743,-4.77297 z"
+             id="path2556"
+             style="opacity:0.76966289;color:#000000;fill:url(#linearGradient16572);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -185.21913,52.02107 -4.41941,6.894291 -7.24785,-4.949748 -4.41941,2.474874 -3.53554,-3.005204 -3.18198,2.828427 3.00521,-4.949747 6.89429,-1.59099 8.66205,-4.242641 c 0,0 12.37437,3.712311 11.66726,3.712311 -0.7071,0 -10.25304,0.176776 -10.25304,0.176776 l -1.59099,-2.298097 -4.24264,1.944544 8.66205,3.005204 z"
+             id="path2558"
+             style="opacity:0.61797755;color:#000000;fill:url(#linearGradient16574);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -194.23474,31.69175 10.42983,3.535534 1.41421,3.889087 -6.01041,4.242641 -5.65685,-5.480078 -0.17678,-6.187184 z"
+             id="path2560"
+             style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -194.41151,32.045303 -2.2981,7.424621 -4.24264,3.712311 8.66206,-1.944544 c 0,0 2.47487,2.828427 1.41421,2.828427 -1.06066,0 -12.55114,1.414214 -12.55114,1.414214 l 0.17677,2.298097 16.26346,-3.005204 -7.07107,-6.540738 -0.35355,-6.187184 z"
+             id="path2562"
+             style="opacity:0.13483145;color:#000000;fill:url(#linearGradient16576);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -172.13765,42.475128 0.88388,8.838835 -1.94454,-6.010408 -5.12653,1.590991 -1.23743,-2.651651 -6.18719,0.883884 -1.41421,-1.237437 9.01561,-0.353554 0.88388,2.474874 3.88909,-1.944544 1.23744,-1.59099 z"
+             id="path2564"
+             style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -187.16367,55.556604 -3.0052,3.535534 -6.89429,-4.596195 -4.24264,2.298097 -6.89429,6.540738 7.60139,-5.833631 3.71231,-1.06066 7.24785,4.949748 2.47487,-5.833631 z"
+             id="path2566"
+             style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        </g>
+        <g
+           transform="matrix(0,0.500942,0.500942,0,97.571112,143.10433)"
+           id="g2526">
+          <path
+             d="m -173.72864,65.809652 1.76777,2.828427 -3.71232,1.59099 -2.65165,-2.12132 -11.84403,0.883883 -3.71231,4.949748 -3.35876,-5.480078 -4.24264,2.298097 -5.65685,-0.707106 1.41421,-3.005204 -3.88909,-3.889088 5.48008,-6.187184 -5.3033,0.707107 -2.2981,-2.12132 3.00521,0.53033 3.18198,-5.480078 4.59619,-1.06066 -3.71231,-1.237437 -0.17678,-3.18198 7.24785,-6.363961 2.65165,-8.485282 12.02081,3.535534 3.0052,7.071068 1.06066,-2.298097 3.00521,0.176777 0,2.828427 3.53553,-4.065864 4.77297,5.126524 0,7.247844 -8.3085,7.247845 5.3033,3.005204 -0.17678,3.005203 -3.0052,2.651651 z"
+             id="path2528"
+             style="color:#000000;fill:url(#radialGradient16578);fill-opacity:1;fill-rule:evenodd;stroke:url(#radialGradient16580);stroke-width:1;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -184.15847,50.96041 0.88389,6.540737 -2.12132,3.358757 4.59619,1.414214 2.65165,5.303301 -12.02081,0.883883 -2.82843,4.065864 -2.2981,-6.187184 4.41942,-2.828427 6.71751,1.944544 -2.65165,-3.535534 1.41422,-6.187185 1.23743,-4.77297 z"
+             id="path2530"
+             style="opacity:0.76966289;color:#000000;fill:url(#linearGradient16582);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -185.21913,52.02107 -4.41941,6.894291 -7.24785,-4.949748 -4.41941,2.474874 -3.53554,-3.005204 -3.18198,2.828427 3.00521,-4.949747 6.89429,-1.59099 8.66205,-4.242641 c 0,0 12.37437,3.712311 11.66726,3.712311 -0.7071,0 -10.25304,0.176776 -10.25304,0.176776 l -1.59099,-2.298097 -4.24264,1.944544 8.66205,3.005204 z"
+             id="path2532"
+             style="opacity:0.61797755;color:#000000;fill:url(#linearGradient16584);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -194.23474,31.69175 10.42983,3.535534 1.41421,3.889087 -6.01041,4.242641 -5.65685,-5.480078 -0.17678,-6.187184 z"
+             id="path2534"
+             style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -194.41151,32.045303 -2.2981,7.424621 -4.24264,3.712311 8.66206,-1.944544 c 0,0 2.47487,2.828427 1.41421,2.828427 -1.06066,0 -12.55114,1.414214 -12.55114,1.414214 l 0.17677,2.298097 16.26346,-3.005204 -7.07107,-6.540738 -0.35355,-6.187184 z"
+             id="path2536"
+             style="opacity:0.13483145;color:#000000;fill:url(#linearGradient16586);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -172.13765,42.475128 0.88388,8.838835 -1.94454,-6.010408 -5.12653,1.590991 -1.23743,-2.651651 -6.18719,0.883884 -1.41421,-1.237437 9.01561,-0.353554 0.88388,2.474874 3.88909,-1.944544 1.23744,-1.59099 z"
+             id="path2538"
+             style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+          <path
+             d="m -187.16367,55.556604 -3.0052,3.535534 -6.89429,-4.596195 -4.24264,2.298097 -6.89429,6.540738 7.60139,-5.833631 3.71231,-1.06066 7.24785,4.949748 2.47487,-5.833631 z"
+             id="path2540"
+             style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+        </g>
+      </g>
+      <path
+         d="m 98.723392,24.095787 a 32.811855,6.9077592 0 1 1 -65.62371,0 32.811855,6.9077592 0 1 1 65.62371,0 z"
+         transform="matrix(0.6160503,0,0,0.5936306,-7.9395479,-5.9435742)"
+         id="path18342"
+         style="opacity:0.77272728;color:#000000;fill:#585858;fill-opacity:0.51308899;fill-rule:evenodd;stroke:#636363;stroke-width:0.82836396;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+      <path
+         d="m 8.7846192,9.874405 c -0.047387,-0.060952 4.1571018,43.847117 4.1576458,43.860417 0.179079,4.384981 7.978264,5.174059 18.744208,5.518532 13.155136,-0.13563 18.090889,-2.344669 18.27729,-5.393863 0.01495,-0.06012 4.218457,-43.924966 4.233406,-43.985086 2.484537,-9.707939 -17.304754,-8.9943506 -24.235456,-8.9943506 -7.441625,0 -23.9765981,-0.2281916 -21.1770938,8.9943506 z"
+         id="path1751"
+         style="fill:url(#linearGradient2942);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient2944);stroke-width:0.50094199;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+      <path
+         d="m 10.382476,8.7853504 c 0,0 16.786073,-5.2090301 41.432664,-0.7666522 9.397627,-7.0052879 -22.164201,-7.51787053 -22.164201,-7.51787053 0,0 -27.0702623,1.45009523 -19.268463,8.28452273 z"
+         id="path18338"
+         style="fill:#d9dcd5;fill-opacity:1;fill-rule:evenodd;stroke:none" />
+      <path
+         d="m 10.382476,8.7853504 c 0,0 16.786073,-5.2090301 41.432664,-0.7666522 9.397627,-7.0052879 -22.164201,-7.5178705 -22.164201,-7.5178705 0,0 -27.0702623,1.4500952 -19.268463,8.2845227 z"
+         id="path13701"
+         style="fill:url(#linearGradient13703);fill-opacity:1;fill-rule:evenodd;stroke:#636363;stroke-width:0.50094199;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+      <path
+         d="m 48.756328,2.7753734 c 0.02461,0.00642 0.05237,0.012074 0.07701,0.018551 0.110099,0.029 0.21721,0.062537 0.327277,0.092754 0.02643,0.00723 0.05059,0.011249 0.07701,0.018552 0.06406,0.017771 0.128666,0.037405 0.192516,0.055652 0.01874,0.00533 0.03904,0.013175 0.05775,0.01855 0.01226,0.00354 0.02625,-0.00356 0.0385,0 0.03369,0.00974 0.06266,0.027221 0.09626,0.037102 0.03943,0.011644 0.07624,0.025249 0.115513,0.037102 0.02723,0.00817 0.04985,0.010284 0.077,0.018551 0.06308,0.019308 0.129985,0.035759 0.192517,0.055653 0.01656,0.00524 0.04124,0.013265 0.05775,0.018551 0.0525,0.016914 0.102002,0.038291 0.15401,0.055653 0.01861,0.00617 0.03921,0.012319 0.05776,0.01855 0.122961,0.041679 0.246414,0.085401 0.365778,0.1298569 0.03161,0.011691 0.06494,0.025205 0.09626,0.037101 0.03672,0.014027 0.05997,0.022784 0.09626,0.037102 0.07481,0.029512 0.158203,0.061941 0.23102,0.092755 0.02454,0.010297 0.05271,0.026653 0.077,0.037102 0.0056,0.00245 0.01364,-0.00246 0.01925,0 0.03648,0.015978 0.07962,0.039314 0.115507,0.055653 0.01933,0.0088 0.03861,0.00965 0.05776,0.018551 0.0071,0.00326 0.0122,0.015274 0.01925,0.018551 0.06885,0.032318 0.145408,0.058992 0.211768,0.092754 0.01765,0.00898 0.04029,0.028015 0.05775,0.037102 0.02234,0.011597 0.05498,0.025329 0.077,0.037102 0.01277,0.00688 0.02584,0.011615 0.0385,0.018551 0.01343,0.00731 0.0252,0.01117 0.0385,0.018551 0.01256,0.007 0.0068,0.011493 0.01925,0.018551 0.01257,0.00705 0.02606,0.011436 0.03851,0.018551 0.01232,0.00712 0.02629,0.011369 0.0385,0.018551 0.0063,0.00368 0.01294,0.014856 0.01925,0.018551 0.03038,0.018034 0.06663,0.037221 0.09626,0.055653 0.01258,0.00777 0.02606,0.010711 0.0385,0.018552 0.01642,0.010413 0.02233,0.026561 0.03851,0.037101 0.01848,0.012047 0.0396,0.024886 0.05775,0.037102 0.06256,0.04188 0.134062,0.085899 0.192512,0.1298567 0.0053,0.00402 0.01402,0.014511 0.01926,0.018551 0.05896,0.044848 0.118883,0.082755 0.173266,0.1298569 0.0039,0.00339 -0.0038,0.015149 0,0.01855 0.01662,0.014548 0.04159,0.022334 0.05775,0.037102 0.0094,0.00862 0.01005,0.028403 0.01926,0.037102 0.01267,0.011939 0.02613,0.025018 0.0385,0.037102 0.0045,0.00441 0.01481,-0.00443 0.01925,0 0.0046,0.00454 0.01468,0.013986 0.01925,0.018551 0.0123,0.012455 0.02652,0.024496 0.0385,0.037102 0.003,0.00308 -0.0029,0.015462 0,0.018552 0.0051,0.00542 0.01421,0.013101 0.01925,0.01855 0.05799,0.062251 0.104211,0.1194458 0.154009,0.1855096 0.01017,0.013454 0.02869,0.023488 0.0385,0.037102 0.003,0.00417 -0.003,0.014361 0,0.018551 0.0042,0.00585 0.01516,0.012666 0.01926,0.01855 0.01164,0.016886 0.0274,0.038517 0.0385,0.055653 0.0045,0.00881 0.01497,0.00969 0.01925,0.018551 0.0086,0.017588 0.01161,0.038107 0.01925,0.055652 0.01872,0.044737 0.02674,0.084297 0.0385,0.1298562 0.0074,0.026475 0.01448,0.06597 0.01925,0.092754 0.0015,0.00918 -0.0012,0.00936 0,0.018551 0.0022,0.013426 0.0178,0.023561 0.01926,0.037102 0.0019,0.023017 3e-5,0.051151 0,0.074204 -0.0015,0.01481 0.002,0.040994 0,0.055653 -0.0015,0.00974 -0.01755,0.027432 -0.01926,0.037102 -0.0026,0.014506 0.0031,0.022747 0,0.037101 -0.01362,0.067227 -0.03282,0.1214985 -0.05775,0.1855098 -0.0036,0.00914 0.0038,0.00947 0,0.01855 -0.0058,0.01459 -0.01285,0.022677 -0.01925,0.037102 -0.006,0.013523 -0.01277,0.023723 -0.01925,0.037102 -0.0084,0.017905 -0.01,0.019449 -0.01925,0.037102 -0.0046,0.00882 -0.0144,0.02834 -0.01925,0.037102 -0.01213,0.02191 -0.02509,0.052683 -0.0385,0.074204 -0.0027,0.00429 -0.01647,-0.00427 -0.01926,0 -0.0055,0.00858 0.0057,0.010034 0,0.01855 -0.02832,0.042572 -0.06311,0.088794 -0.09625,0.1298571 -0.0066,0.00821 -0.01244,0.010395 -0.01926,0.018551 -0.0068,0.00815 -0.01225,0.029008 -0.01925,0.037102 -0.05598,0.064777 -0.125496,0.124407 -0.192512,0.185509 -0.0084,0.00763 -0.01071,0.010973 -0.01926,0.018551 -0.01367,0.012131 -0.04368,0.025114 -0.05775,0.037102 -0.0089,0.00747 -0.01024,0.029689 -0.01926,0.037102 -0.03244,0.026698 -0.08114,0.048207 -0.115507,0.074204 -0.0058,0.00432 -0.01344,0.014252 -0.01926,0.01855 -0.0599,0.044508 -0.1274,0.087358 -0.192512,0.129857 -0.0147,0.0096 -0.02356,0.027605 -0.0385,0.037102 -0.02685,0.016886 -0.06866,0.039081 -0.09626,0.055654 -0.225273,0.135309 -0.486685,0.254972 -0.750812,0.371018 -0.05194,0.022636 -0.10106,0.05224 -0.154009,0.074204 -0.05907,0.024653 -0.113123,0.050366 -0.173266,0.074204 -0.05381,0.021328 -0.0995,0.034953 -0.154015,0.055653 -0.02726,0.010349 -0.06885,0.026904 -0.09626,0.037102 -0.0053,0.00195 -0.01397,-0.00195 -0.01925,0 -0.04937,0.018299 -0.08501,0.037835 -0.134758,0.055652 -0.08291,0.029676 -0.166729,0.064359 -0.250271,0.092755 -0.139257,0.047354 -0.28443,0.085797 -0.423536,0.129857 -0.08347,0.026435 -0.167545,0.048857 -0.250271,0.074203 -0.06346,0.019445 -0.129756,0.055365 -0.192516,0.074204 -0.100864,0.030279 -0.190503,0.045374 -0.288773,0.074205 -0.04644,0.012124 -0.107478,0.025138 -0.154013,0.037101 -0.07486,0.019246 -0.136674,0.036821 -0.211767,0.055652 -0.04668,0.011707 -0.107245,0.025555 -0.154012,0.037103 -0.07523,0.018577 -0.136308,0.037481 -0.211768,0.055652 -0.08158,0.019646 -0.168435,0.036477 -0.25027,0.055653 -0.245508,0.057529 -0.483831,0.11355 -0.73156,0.166959 -0.08257,0.017804 -0.167458,0.038296 -0.250271,0.055653 -0.130428,0.027337 -0.273285,0.047955 -0.404282,0.074203 -0.06529,0.013083 -0.127088,0.042838 -0.192516,0.055653 -0.0063,0.00123 -0.013,-0.00122 -0.01925,0 -0.255924,0.05003 -0.512143,0.083794 -0.770062,0.129858 -0.08401,0.015004 -0.166057,0.041057 -0.250271,0.055652 -0.168428,0.029191 -0.331343,0.046617 -0.500541,0.074204 -0.126898,0.020691 -0.257721,0.054393 -0.385032,0.074204 -0.25462,0.039623 -0.513904,0.075084 -0.770062,0.111305 -0.08539,0.012133 -0.164716,0.025335 -0.25027,0.037102 -0.171092,0.023416 -0.348093,0.033669 -0.519793,0.055653 -0.08586,0.011054 -0.164267,0.026396 -0.25027,0.037102 -0.09246,0.011442 -0.196157,0.026058 -0.288774,0.037102 -0.153567,0.018314 -0.308056,0.038405 -0.462037,0.055653 -0.0065,7.3e-4 -0.01276,-7.29e-4 -0.01925,0 -0.697209,0.077897 -1.39448,0.146155 -2.098421,0.20406 -0.174455,0.01448 -0.345034,0.023738 -0.519792,0.037102 -0.611591,0.046326 -1.234029,0.095908 -1.848151,0.129857 -0.169248,0.00943 -0.350445,0.00997 -0.519793,0.018551 -0.08779,0.0044 -0.181715,0.014373 -0.269522,0.018551 -0.169387,0.00812 -0.350366,0.011214 -0.519792,0.018551 -0.70262,0.030062 -1.39683,0.05575 -2.098421,0.074204 -0.175404,0.00466 -0.344563,0.014517 -0.519792,0.018551 -0.35669,0.00819 -0.703129,0.012617 -1.058837,0.01855 -0.182814,7.39e-4 -0.375229,-1.34e-4 -0.558296,0 -0.0063,4e-6 -0.01294,-2e-6 -0.01925,0 -0.08838,5.4e-5 -0.18109,9.3e-5 -0.269522,0 -0.0063,-8e-6 -0.01293,9e-6 -0.01925,0 -0.372697,-4.36e-4 -0.743164,0.00326 -1.116591,0 -0.0063,-5.8e-5 -0.01292,5.9e-5 -0.01925,0 -0.1836,-0.00171 -0.374566,-0.016087 -0.558295,-0.01855 -0.19001,-0.00248 -0.387451,0.00332 -0.577547,0 -0.19016,-0.0034 -0.368082,-0.014261 -0.558296,-0.018551 -0.0063,-1.44e-4 -0.01291,1.44e-4 -0.01925,0 -0.09507,-0.0021 -0.174447,0.00233 -0.269522,0 C 28.428959,9.541718 28.231857,9.533627 28.041638,9.52792 27.851419,9.522213 27.673512,9.516072 27.483342,9.509368 c -0.0063,-2.23e-4 -0.01291,2.25e-4 -0.01925,0 -0.18383,-0.00651 -0.374552,-0.011067 -0.558296,-0.01855 -0.27867,-0.011182 -0.568713,-0.023588 -0.847069,-0.037102 -0.0063,-3.11e-4 -0.01295,3.12e-4 -0.01925,0 C 25.28672,9.417022 24.535743,9.3609 23.78704,9.305309 c -0.0063,-4.72e-4 -0.01298,4.72e-4 -0.01925,0 C 23.20778,9.263598 22.649396,9.2105 22.092903,9.156901 c -0.0062,-6.06e-4 -0.01302,6.06e-4 -0.01925,0 C 21.69859,9.12068 21.330113,9.087647 20.957059,9.045595 20.863745,9.035019 20.780714,9.019446 20.687538,9.008494 20.547849,8.992157 20.403367,8.988593 20.264003,8.971391 19.845913,8.919787 19.427511,8.864146 19.012651,8.804433 18.874365,8.784528 18.727009,8.75107 18.589116,8.730229 18.405259,8.70244 18.233195,8.685517 18.050073,8.656025 17.958511,8.641278 17.87192,8.615553 17.780551,8.600372 17.729243,8.591848 17.677784,8.590483 17.626538,8.581821 17.580886,8.574102 17.537379,8.571098 17.491777,8.56327 17.400603,8.547651 17.313228,8.523681 17.222255,8.507618 17.176769,8.499586 17.132929,8.49721 17.087494,8.489066 16.996625,8.472778 16.908632,8.450154 16.817972,8.433414 16.772641,8.425043 16.728488,8.423347 16.68321,8.414863 16.592656,8.397894 16.504027,8.376639 16.413689,8.35921 16.052337,8.289492 15.693285,8.213898 15.335601,8.136598 15.24618,8.117273 15.155259,8.100757 15.066079,8.080946 14.9769,8.061134 14.88549,8.045597 14.796557,8.025292 14.752091,8.01514 14.706201,7.998467 14.661796,7.988191 14.543863,7.956787 14.416999,7.928008 14.296017,7.895436 14.235525,7.87915 14.183795,7.856411 14.122752,7.839783 14.000666,7.806526 13.880417,7.781855 13.756972,7.747028 13.695249,7.729615 13.626309,7.709232 13.564457,7.691376 13.502605,7.673519 13.453032,7.654055 13.391193,7.635722 13.329353,7.61739 13.260364,7.598912 13.198676,7.58007 13.136989,7.561227 13.067555,7.543802 13.006161,7.524417 12.914071,7.495338 12.827672,7.462058 12.736639,7.431662 12.675951,7.411399 12.623417,7.3969 12.563375,7.37601 12.533353,7.365564 12.496951,7.349516 12.467117,7.338907 12.40745,7.317691 12.352663,7.305148 12.293853,7.283255 12.176234,7.239468 12.060671,7.181544 11.947325,7.134847 11.748969,7.053128 11.550302,6.966891 11.369778,6.875134 11.297568,6.838431 11.226691,6.802298 11.15801,6.763828 c -0.0049,-0.00275 -0.01439,0.00276 -0.01925,0 C 11.09906,6.741426 11.08091,6.712647 11.0425,6.689624 11.03067,6.682574 11.0157,6.678186 11.004,6.671074 10.875071,6.592653 10.750149,6.515952 10.63822,6.429911 10.62806,6.422101 10.62902,6.419235 10.61897,6.411359 10.60494,6.400316 10.59419,6.385432 10.58047,6.374258 10.57057,6.366318 10.57087,6.363716 10.56122,6.355707 10.47967,6.288323 10.399861,6.223945 10.330201,6.151646 c -0.0084,-0.00857 -0.01108,-0.00991 -0.01925,-0.018551 -0.01433,-0.015137 -0.02473,-0.040292 -0.0385,-0.055652 -0.0031,-0.00351 -0.01615,0.00353 -0.01925,0 -0.03442,-0.038701 -0.04623,-0.071167 -0.07701,-0.111306 -0.0071,-0.00909 -0.01238,-0.00939 -0.01925,-0.018551 -0.02339,-0.03117 -0.03666,-0.060697 -0.05776,-0.092755 -0.0063,-0.00939 -0.01317,-0.00908 -0.01925,-0.01855 C 10.055591,5.79838 10.023941,5.76414 10.002921,5.7249752 9.997671,5.7151852 9.98871,5.6977442 9.983669,5.6878732 9.966027,5.6533232 9.960136,5.6121162 9.945166,5.5765684 9.938746,5.5613334 9.931827,5.5548864 9.925914,5.5394664 c -0.00273,-0.014291 0.00212,-0.041478 0,-0.055653 -0.00212,-0.014175 -0.017738,-0.02304 -0.019252,-0.037102 -0.00202,-0.018748 9.593e-4,-0.037107 0,-0.055653 -4.824e-4,-0.00928 2.234e-4,-0.00932 0,-0.01855 -2.179e-4,-0.00922 -3.96e-5,-0.02793 0,-0.037102 3.6e-5,-0.00918 -2.896e-4,-0.00942 0,-0.01855 5.926e-4,-0.018243 -0.0016,-0.037611 0,-0.055653 7.935e-4,-0.00903 -0.00104,-0.00957 0,-0.018551 0.00157,-0.013457 0.017129,-0.023757 0.019252,-0.037102 0.00212,-0.013345 -0.00267,-0.04242 0,-0.055653 0.00177,-0.00883 -0.00201,-0.00977 0,-0.018551 0.00202,-0.00877 0.017,-0.028378 0.019252,-0.037102 0.00224,-0.00873 -0.00247,-0.00987 0,-0.01855 0.00248,-0.00867 -0.00271,-0.00993 0,-0.018552 0.010808,-0.03454 0.02412,-0.07754 0.038503,-0.1113051 0.00361,-0.00843 0.015424,-0.01017 0.019252,-0.018551 0.0057,-0.012571 0.01303,-0.024639 0.01925,-0.037102 0.0062,-0.012462 0.01256,-0.024749 0.01925,-0.037102 0.0067,-0.012353 0.01209,-0.024857 0.01925,-0.037102 0.0024,-0.00408 -0.0024,-0.014482 0,-0.018551 0.0097,-0.016307 0.02798,-0.039536 0.0385,-0.055653 0.01583,-0.02413 0.02092,-0.031952 0.0385,-0.055653 0.0059,-0.0079 0.0132,-0.029249 0.01925,-0.037102 0.006,-0.00787 0.01303,-0.010728 0.01925,-0.018551 0.0062,-0.00781 0.01283,-0.010793 0.01925,-0.01855 0.0128,-0.015551 0.02498,-0.040289 0.0385,-0.055653 0.0095,-0.01073 0.02866,-0.00791 0.0385,-0.018552 0.01388,-0.01527 0.02394,-0.022017 0.0385,-0.037102 0.0073,-0.00752 0.01178,-0.029624 0.01925,-0.037102 0.0149,-0.014992 0.02294,-0.022295 0.0385,-0.037101 0.0078,-0.00738 0.01129,-0.011213 0.01925,-0.018551 0.01588,-0.014716 0.04124,-0.041121 0.05776,-0.055653 0.0083,-0.00725 0.01082,-0.01135 0.01925,-0.018552 0.02522,-0.021661 0.05045,-0.034401 0.07701,-0.055653 0.0089,-0.00706 0.02948,-0.011533 0.0385,-0.01855 0.03598,-0.028154 0.05809,-0.065322 0.09626,-0.092755 0.0287,-0.020511 0.06641,-0.035544 0.09626,-0.055653 0.02978,-0.020172 0.0654,-0.035881 0.09626,-0.055653 0.02062,-0.013139 0.03668,-0.024139 0.05776,-0.037102 0.108257,-0.067343 0.208462,-0.1413737 0.327276,-0.2040605 0.09199,-0.048532 0.191956,-0.084057 0.288774,-0.1298569 0.07261,-0.03435 0.137078,-0.078468 0.211767,-0.1113058 0.04979,-0.021892 0.103502,-0.034424 0.154012,-0.055653 0.02526,-0.010614 0.0516,-0.026653 0.07701,-0.037102 0.05081,-0.020898 0.102731,-0.035409 0.154012,-0.055653 0.02564,-0.010122 0.05128,-0.027142 0.07701,-0.037102 0.05146,-0.019919 0.102325,-0.036379 0.154012,-0.055653 0.05169,-0.019274 0.102261,-0.037017 0.154014,-0.055653 0.05175,-0.018635 0.102357,-0.037649 0.154012,-0.055653 0.05166,-0.018004 0.102618,-0.038275 0.154012,-0.055653 0.02571,-0.00867 0.05139,-0.010029 0.07701,-0.018551 0.0512,-0.017068 0.103313,-0.039202 0.154012,-0.055653 0.07605,-0.024676 0.156566,-0.050896 0.231018,-0.074204 0.02804,-0.00808 0.04901,-0.010592 0.07701,-0.01855 0.08399,-0.023875 0.166243,-0.051134 0.25027,-0.074204 0.0056,-0.00154 0.01365,0.00154 0.01925,0 0.10647,-0.029172 0.219468,-0.064101 0.327278,-0.092755 -3.917038,0.4550765 -6.3145159,1.2130588 -6.3145159,2.560031 5e-7,0.2623088 0,4.39398 0,4.6562899 5e-7,2.845393 10.6746199,5.157165 23.8334449,5.157164 13.158823,10e-7 23.833444,-2.311771 23.833444,-5.157164 0,-0.2623099 0,-4.3939801 0,-4.6562899 0,-1.3760966 -2.498373,-2.1529061 -6.564785,-2.6156836 z"
+         id="path18314"
+         style="color:#000000;fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:#808389;stroke-width:0.25;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+      <path
+         d="m 48.756328,2.7753734 c 0.02461,0.00642 0.05237,0.012074 0.07701,0.018551 0.110099,0.029 0.21721,0.062537 0.327277,0.092754 0.02643,0.00723 0.05059,0.011249 0.07701,0.018552 0.06406,0.017771 0.128666,0.037405 0.192516,0.055652 0.01874,0.00533 0.03904,0.013175 0.05775,0.01855 0.01226,0.00354 0.02625,-0.00356 0.0385,0 0.03369,0.00974 0.06266,0.027221 0.09626,0.037102 0.03943,0.011644 0.07624,0.025249 0.115513,0.037102 0.02723,0.00817 0.04985,0.010284 0.077,0.018551 0.06308,0.019308 0.129985,0.035759 0.192517,0.055653 0.01656,0.00524 0.04124,0.013265 0.05775,0.018551 0.0525,0.016914 0.102002,0.038291 0.15401,0.055653 0.01861,0.00617 0.03921,0.012319 0.05776,0.01855 0.122961,0.041679 0.246414,0.085401 0.365778,0.1298569 0.03161,0.011691 0.06494,0.025205 0.09626,0.037101 0.03672,0.014027 0.05997,0.022784 0.09626,0.037102 0.07481,0.029512 0.158203,0.061941 0.23102,0.092755 0.02454,0.010297 0.05271,0.026653 0.077,0.037102 0.0056,0.00245 0.01364,-0.00246 0.01925,0 0.03648,0.015978 0.07962,0.039314 0.115507,0.055653 0.01933,0.0088 0.03861,0.00965 0.05776,0.018551 0.0071,0.00326 0.0122,0.015274 0.01925,0.018551 0.06885,0.032318 0.145408,0.058992 0.211768,0.092754 0.01765,0.00898 0.04029,0.028015 0.05775,0.037102 0.02234,0.011597 0.05498,0.025329 0.077,0.037102 0.01277,0.00688 0.02584,0.011615 0.0385,0.018551 0.01343,0.00731 0.0252,0.01117 0.0385,0.018551 0.01256,0.007 0.0068,0.011493 0.01925,0.018551 0.01257,0.00705 0.02606,0.011436 0.03851,0.018551 0.01232,0.00712 0.02629,0.011369 0.0385,0.018551 0.0063,0.00368 0.01294,0.014856 0.01925,0.018551 0.03038,0.018034 0.06663,0.037221 0.09626,0.055653 0.01258,0.00777 0.02606,0.010711 0.0385,0.018552 0.01642,0.010413 0.02233,0.026561 0.03851,0.037101 0.01848,0.012047 0.0396,0.024886 0.05775,0.037102 0.06256,0.04188 0.134062,0.085899 0.192512,0.1298567 0.0053,0.00402 0.01402,0.014511 0.01926,0.018551 0.05896,0.044848 0.118883,0.082755 0.173266,0.1298569 0.0039,0.00339 -0.0038,0.015149 0,0.01855 0.01662,0.014548 0.04159,0.022334 0.05775,0.037102 0.0094,0.00862 0.01005,0.028403 0.01926,0.037102 0.01267,0.011939 0.02613,0.025018 0.0385,0.037102 0.0045,0.00441 0.01481,-0.00443 0.01925,0 0.0046,0.00454 0.01468,0.013986 0.01925,0.018551 0.0123,0.012455 0.02652,0.024496 0.0385,0.037102 0.003,0.00308 -0.0029,0.015462 0,0.018552 0.0051,0.00542 0.01421,0.013101 0.01925,0.01855 0.05799,0.062251 0.104211,0.1194458 0.154009,0.1855096 0.01017,0.013454 0.02869,0.023488 0.0385,0.037102 0.003,0.00417 -0.003,0.014361 0,0.018551 0.0042,0.00585 0.01516,0.012666 0.01926,0.01855 0.01164,0.016886 0.0274,0.038517 0.0385,0.055653 0.0045,0.00881 0.01497,0.00969 0.01925,0.018551 0.0086,0.017588 0.01161,0.038107 0.01925,0.055652 0.01872,0.044737 0.02674,0.084297 0.0385,0.1298562 0.0074,0.026475 0.01448,0.06597 0.01925,0.092754 0.0015,0.00918 -0.0012,0.00936 0,0.018551 0.0022,0.013426 0.0178,0.023561 0.01926,0.037102 0.0019,0.023017 3e-5,0.051151 0,0.074204 -0.0015,0.01481 0.002,0.040994 0,0.055653 -0.0015,0.00974 -0.01755,0.027432 -0.01926,0.037102 -0.0026,0.014506 0.0031,0.022747 0,0.037101 -0.01362,0.067227 -0.03282,0.1214985 -0.05775,0.1855098 -0.0036,0.00914 0.0038,0.00947 0,0.01855 -0.0058,0.01459 -0.01285,0.022677 -0.01925,0.037102 -0.006,0.013523 -0.01277,0.023723 -0.01925,0.037102 -0.0084,0.017905 -0.01,0.019449 -0.01925,0.037102 -0.0046,0.00882 -0.0144,0.02834 -0.01925,0.037102 -0.01213,0.02191 -0.02509,0.052683 -0.0385,0.074204 -0.0027,0.00429 -0.01647,-0.00427 -0.01926,0 -0.0055,0.00858 0.0057,0.010034 0,0.01855 -0.02832,0.042572 -0.06311,0.088794 -0.09625,0.1298572 -0.0066,0.00822 -0.01244,0.010395 -0.01926,0.018551 -0.0068,0.00815 -0.01225,0.029008 -0.01925,0.037102 -0.05598,0.064777 -0.125496,0.1244069 -0.192512,0.1855093 -0.0084,0.00763 -0.01071,0.010973 -0.01926,0.018551 -0.01367,0.012131 -0.04368,0.025114 -0.05775,0.037102 -0.0089,0.00747 -0.01024,0.029689 -0.01926,0.037101 -0.03244,0.026699 -0.08114,0.048207 -0.115507,0.074205 -0.0058,0.00432 -0.01344,0.014252 -0.01926,0.01855 -0.0599,0.044507 -0.1274,0.087357 -0.192512,0.1298567 -0.0147,0.0096 -0.02356,0.027605 -0.0385,0.037102 -0.02685,0.016886 -0.06866,0.039081 -0.09626,0.055654 -0.225273,0.1353094 -0.486685,0.2549724 -0.750812,0.3710181 -0.05194,0.022637 -0.10106,0.05224 -0.154009,0.074204 -0.05907,0.024653 -0.113123,0.050366 -0.173266,0.074204 -0.05381,0.021329 -0.0995,0.034953 -0.154015,0.055653 -0.02726,0.010349 -0.06885,0.026905 -0.09626,0.037102 -0.0053,0.00195 -0.01397,-0.00195 -0.01925,0 -0.04937,0.018299 -0.08501,0.037836 -0.134758,0.055653 -0.08291,0.029676 -0.166729,0.064358 -0.250271,0.092754 -0.139257,0.047355 -0.28443,0.085797 -0.423536,0.1298567 -0.08347,0.026436 -0.167545,0.048857 -0.250271,0.074204 -0.06346,0.019444 -0.129756,0.055364 -0.192516,0.074204 -0.100864,0.030279 -0.190503,0.045374 -0.288773,0.074205 -0.04644,0.012124 -0.107478,0.025138 -0.154013,0.037101 -0.07486,0.019246 -0.136674,0.036821 -0.211767,0.055653 -0.04668,0.011706 -0.107245,0.025554 -0.154012,0.037102 -0.07523,0.018577 -0.136308,0.037482 -0.211768,0.055653 -0.08158,0.019645 -0.168435,0.036477 -0.25027,0.055652 -0.245508,0.057529 -0.483831,0.11355 -0.73156,0.166959 -0.08257,0.017804 -0.167458,0.038296 -0.250271,0.055653 -0.130428,0.027337 -0.273285,0.047955 -0.404282,0.074203 -0.06529,0.013083 -0.127088,0.042838 -0.192516,0.055653 -0.0063,0.00123 -0.013,-0.00122 -0.01925,0 -0.255924,0.05003 -0.512143,0.083794 -0.770062,0.129858 -0.08401,0.015004 -0.166057,0.041057 -0.250271,0.055652 -0.168428,0.029191 -0.331343,0.046617 -0.500541,0.074204 -0.126898,0.020691 -0.257721,0.054393 -0.385032,0.074204 -0.25462,0.039623 -0.513904,0.075084 -0.770062,0.111305 -0.08539,0.012133 -0.164716,0.025335 -0.25027,0.037102 -0.171092,0.023416 -0.348093,0.033669 -0.519793,0.055653 -0.08586,0.011054 -0.164267,0.026396 -0.25027,0.037102 -0.09246,0.011442 -0.196157,0.026058 -0.288774,0.037102 -0.153567,0.018314 -0.308056,0.038405 -0.462037,0.055653 -0.0065,7.3e-4 -0.01276,-7.29e-4 -0.01925,0 -0.697209,0.077897 -1.39448,0.146155 -2.098421,0.20406 -0.174455,0.01448 -0.345034,0.023738 -0.519792,0.037102 -0.611591,0.046326 -1.234029,0.095908 -1.848151,0.129857 -0.169248,0.00943 -0.350445,0.00997 -0.519793,0.018551 -0.08779,0.0044 -0.181715,0.014373 -0.269522,0.018551 -0.169387,0.00812 -0.350366,0.011214 -0.519792,0.018551 -0.70262,0.030062 -1.39683,0.05575 -2.098421,0.074204 -0.175404,0.00466 -0.344563,0.014517 -0.519792,0.018551 -0.35669,0.00819 -0.703129,0.012617 -1.058837,0.01855 -0.182814,7.39e-4 -0.375229,-1.34e-4 -0.558296,0 -0.0063,4e-6 -0.01294,-2e-6 -0.01925,0 -0.08838,5.4e-5 -0.18109,9.3e-5 -0.269522,0 -0.0063,-8e-6 -0.01293,9e-6 -0.01925,0 -0.372697,-4.36e-4 -0.743164,0.00326 -1.116591,0 -0.0063,-5.8e-5 -0.01292,5.9e-5 -0.01925,0 -0.1836,-0.00171 -0.374566,-0.016087 -0.558295,-0.01855 -0.19001,-0.00248 -0.387451,0.00332 -0.577547,0 -0.19016,-0.0034 -0.368082,-0.014261 -0.558296,-0.018551 -0.0063,-1.44e-4 -0.01291,1.44e-4 -0.01925,0 -0.09507,-0.0021 -0.174447,0.00233 -0.269522,0 -0.190203,-0.00475 -0.387305,-0.01284 -0.577524,-0.018546 -0.190219,-0.00571 -0.368126,-0.011848 -0.558296,-0.018552 -0.0063,-2.23e-4 -0.01291,2.25e-4 -0.01925,0 -0.18383,-0.00651 -0.374552,-0.011067 -0.558296,-0.01855 -0.27867,-0.011182 -0.568713,-0.023588 -0.847069,-0.037102 -0.0063,-3.11e-4 -0.01295,3.12e-4 -0.01925,0 C 25.28672,9.417022 24.535743,9.3609 23.78704,9.305309 c -0.0063,-4.72e-4 -0.01298,4.72e-4 -0.01925,0 C 23.20778,9.263598 22.649396,9.2105 22.092903,9.156901 c -0.0062,-6.06e-4 -0.01302,6.06e-4 -0.01925,0 C 21.69859,9.12068 21.330113,9.087647 20.957059,9.045595 20.863745,9.035019 20.780714,9.019446 20.687538,9.008494 20.547849,8.992157 20.403367,8.988593 20.264003,8.971391 19.845913,8.919787 19.427511,8.864146 19.012651,8.804433 18.874365,8.784528 18.727009,8.75107 18.589116,8.730229 18.405259,8.70244 18.233195,8.685517 18.050073,8.656025 17.958511,8.641278 17.87192,8.615553 17.780551,8.600372 17.729243,8.591848 17.677784,8.590483 17.626538,8.581821 17.580886,8.574102 17.537379,8.571098 17.491777,8.56327 17.400603,8.547651 17.313228,8.523681 17.222255,8.507618 17.176769,8.499586 17.132929,8.49721 17.087494,8.489066 16.996625,8.472778 16.908632,8.450154 16.817972,8.433414 16.772641,8.425043 16.728488,8.423347 16.68321,8.414863 16.592656,8.397894 16.504027,8.376639 16.413689,8.35921 16.052337,8.289492 15.693285,8.213898 15.335601,8.136598 15.24618,8.117273 15.155259,8.100757 15.066079,8.080946 14.9769,8.061134 14.88549,8.045597 14.796557,8.025292 14.752087,8.01514 14.706197,7.998467 14.661796,7.988191 14.543863,7.956787 14.416999,7.928008 14.296017,7.895436 14.235527,7.87915 14.183795,7.856411 14.122752,7.839783 14.000666,7.806526 13.880417,7.781855 13.756972,7.747028 13.695252,7.729614 13.626309,7.709232 13.564457,7.691375 13.502607,7.673518 13.453032,7.654054 13.391193,7.635722 13.329353,7.617389 13.260364,7.598911 13.198676,7.580069 13.136986,7.561227 13.067555,7.543801 13.006161,7.524416 12.914071,7.495337 12.827672,7.462057 12.736639,7.431661 12.675949,7.411398 12.623417,7.396899 12.563375,7.376009 12.533355,7.365563 12.496955,7.349515 12.467115,7.338907 12.40745,7.317691 12.352663,7.3051479 12.293853,7.2832547 12.176234,7.2394679 12.060671,7.181544 11.947325,7.1348467 11.748969,7.053128 11.550302,6.9668913 11.369778,6.8751338 11.297568,6.8384308 11.226691,6.8022983 11.15801,6.763828 c -0.0049,-0.00275 -0.01439,0.00276 -0.01925,0 C 11.09906,6.741426 11.08091,6.712647 11.0425,6.689624 11.03067,6.682574 11.0157,6.678186 11.004,6.671074 10.875071,6.592653 10.750149,6.5159528 10.63822,6.4299115 c -0.01016,-0.00781 -0.0092,-0.010676 -0.01925,-0.018552 -0.01403,-0.011043 -0.02478,-0.025927 -0.0385,-0.037101 -0.0099,-0.00794 -0.0096,-0.010542 -0.01925,-0.018552 -0.08155,-0.067384 -0.161359,-0.1317617 -0.231019,-0.2040602 -0.0084,-0.00857 -0.01108,-0.00991 -0.01925,-0.018551 -0.01433,-0.015137 -0.02473,-0.040293 -0.0385,-0.055653 -0.0031,-0.00351 -0.01615,0.00353 -0.01925,0 -0.03442,-0.0387 -0.04623,-0.071166 -0.07701,-0.1113058 -0.0071,-0.00909 -0.01238,-0.00939 -0.01925,-0.018551 -0.02339,-0.03117 -0.03666,-0.060697 -0.05776,-0.092755 -0.0063,-0.00939 -0.01317,-0.00908 -0.01925,-0.01855 -0.02434,-0.037901 -0.05599,-0.072141 -0.07701,-0.1113058 C 9.997671,5.7151847 9.98871,5.6977437 9.983669,5.6878727 9.966027,5.6533227 9.960136,5.6121157 9.945166,5.5765679 9.938746,5.5613329 9.931827,5.5548859 9.925914,5.5394659 c -0.00273,-0.014291 0.00212,-0.041478 0,-0.055653 -0.00212,-0.014175 -0.017738,-0.02304 -0.019252,-0.037102 -0.00202,-0.018748 9.593e-4,-0.037107 0,-0.055653 -4.824e-4,-0.00928 2.234e-4,-0.00932 0,-0.01855 -2.179e-4,-0.00922 -3.96e-5,-0.02793 0,-0.037102 3.6e-5,-0.00918 -2.896e-4,-0.00942 0,-0.01855 5.926e-4,-0.018243 -0.0016,-0.037611 0,-0.055653 7.935e-4,-0.00903 -0.00104,-0.00957 0,-0.018551 0.00157,-0.013457 0.017129,-0.023757 0.019252,-0.037102 0.00212,-0.013345 -0.00267,-0.04242 0,-0.055653 0.00177,-0.00883 -0.00201,-0.00977 0,-0.018551 0.00202,-0.00877 0.017,-0.028378 0.019252,-0.037102 0.00224,-0.00873 -0.00247,-0.00987 0,-0.01855 0.00248,-0.00867 -0.00271,-0.00993 0,-0.018552 0.010808,-0.03454 0.02412,-0.07754 0.038503,-0.1113051 0.00361,-0.00843 0.015424,-0.01017 0.019252,-0.018551 0.0057,-0.012571 0.01303,-0.024639 0.01925,-0.037102 0.0062,-0.012462 0.01256,-0.024749 0.01925,-0.037102 0.0067,-0.012353 0.01209,-0.024857 0.01925,-0.037102 0.0024,-0.00408 -0.0024,-0.014482 0,-0.018551 0.0097,-0.016307 0.02798,-0.039536 0.0385,-0.055653 0.01583,-0.02413 0.02092,-0.031952 0.0385,-0.055653 0.0059,-0.0079 0.0132,-0.029249 0.01925,-0.037102 0.006,-0.00787 0.01303,-0.010728 0.01925,-0.018551 0.0062,-0.00781 0.01283,-0.010793 0.01925,-0.01855 0.0128,-0.015551 0.02498,-0.040289 0.0385,-0.055653 0.0095,-0.01073 0.02866,-0.00791 0.0385,-0.018552 0.01388,-0.01527 0.02394,-0.022017 0.0385,-0.037102 0.0073,-0.00752 0.01178,-0.029624 0.01925,-0.037102 0.0149,-0.014992 0.02294,-0.022295 0.0385,-0.037101 0.0078,-0.00738 0.01129,-0.011213 0.01925,-0.018551 0.01588,-0.014716 0.04124,-0.041121 0.05776,-0.055653 0.0083,-0.00725 0.01082,-0.01135 0.01925,-0.018552 0.02522,-0.021661 0.05045,-0.034401 0.07701,-0.055653 0.0089,-0.00706 0.02948,-0.011533 0.0385,-0.01855 0.03598,-0.028154 0.05809,-0.065322 0.09626,-0.092755 0.0287,-0.020511 0.06641,-0.035544 0.09626,-0.055653 0.02978,-0.020172 0.0654,-0.035881 0.09626,-0.055653 0.02062,-0.013139 0.03668,-0.024139 0.05776,-0.037102 0.108257,-0.067343 0.208462,-0.1413737 0.327276,-0.2040605 0.09199,-0.048532 0.191956,-0.084057 0.288774,-0.1298569 0.07261,-0.03435 0.137078,-0.078468 0.211767,-0.1113058 0.04979,-0.021892 0.103502,-0.034424 0.154012,-0.055653 0.02526,-0.010614 0.0516,-0.026653 0.07701,-0.037102 0.05081,-0.020898 0.102731,-0.035409 0.154012,-0.055653 0.02564,-0.010122 0.05128,-0.027142 0.07701,-0.037102 0.05146,-0.019919 0.102325,-0.036379 0.154012,-0.055653 0.05169,-0.019274 0.102261,-0.037017 0.154014,-0.055653 0.05175,-0.018635 0.102357,-0.037649 0.154012,-0.055653 0.05166,-0.018004 0.102618,-0.038275 0.154012,-0.055653 0.02571,-0.00867 0.05139,-0.010029 0.07701,-0.018551 0.0512,-0.017068 0.103313,-0.039202 0.154012,-0.055653 0.07605,-0.024676 0.156566,-0.050896 0.231018,-0.074204 0.02804,-0.00808 0.04901,-0.010592 0.07701,-0.01855 0.08399,-0.023875 0.166243,-0.051134 0.25027,-0.074204 0.0056,-0.00154 0.01365,0.00154 0.01925,0 0.10647,-0.029172 0.219468,-0.064101 0.327278,-0.092755 -3.917038,0.4550765 -6.3145159,1.2130588 -6.3145159,2.560031 5e-7,0.2623088 0,4.39398 0,4.6562904 5e-7,2.845393 10.6746199,5.157165 23.8334449,5.157164 13.158823,10e-7 23.833444,-2.311771 23.833444,-5.157164 0,-0.2623104 0,-4.3939806 0,-4.6562904 0,-1.3760966 -2.498373,-2.1529061 -6.564785,-2.6156836 z"
+         id="path3959"
+         style="color:#000000;fill:url(#linearGradient3961);fill-opacity:1;fill-rule:evenodd;stroke:#808389;stroke-width:0;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+      <path
+         d="m 62.57917,0.6242872 c -1.553279,0.008421 -3.103485,0.0417867 -4.650119,0.0740647 -11.578868,0.4118319 -23.463926,1.3401304 -34.011203,4.6660485 -3.500296,1.1997063 -7.969754,3.1310232 -7.455564,6.0732706 1.111892,3.175002 6.294835,4.712809 10.453162,5.925142 12.525374,3.173742 26.208488,3.873295 39.545229,3.814309 12.323398,-0.225081 24.963203,-1.039613 36.355475,-4.295727 3.74732,-1.203653 8.48857,-2.912796 8.76221,-5.962173 4.8e-4,-0.355968 -0.0701,-0.733708 -0.23059,-1.0739326 C 109.52547,6.7647001 104.34291,5.3653147 99.972277,4.1793719 88.039824,1.3676335 75.227293,0.5557215 62.57917,0.6242872 z m -2.267415,1.6294134 c 12.234812,-0.1627784 24.711291,0.4359668 36.278618,2.9255391 3.959057,0.9812013 8.648737,2.1543244 10.299437,4.7030817 0.14532,0.2814906 0.23101,0.5572276 0.23059,0.8517396 -0.24788,2.522934 -4.56072,3.929418 -7.955167,4.925274 -10.319504,2.693979 -21.772202,3.405892 -32.935144,3.592116 -12.080854,0.0488 -24.471547,-0.558934 -35.817448,-3.184762 -3.76675,-1.003037 -8.446773,-2.261371 -9.45396,-4.888243 -0.465772,-2.434299 3.554697,-4.043782 6.725378,-5.0363707 9.554072,-2.7517339 20.332931,-3.5106079 30.821454,-3.851341 0.600424,-0.011446 1.20453,-0.029027 1.806242,-0.037034 z"
+         transform="matrix(0.500942,0,0,0.500942,-0.5731737,-0.06028798)"
+         id="path18219"
+         style="color:#000000;fill:#d9dcd5;fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient2857);stroke-width:0.49905977;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+      <path
+         d="M 30.775361,0.2524437 C 29.997258,0.2566624 29.220695,0.2733764 28.445921,0.2895458 22.64558,0.4958497 16.691855,0.9608734 11.408281,2.6269655 9.6548356,3.2279488 7.4158964,4.1954265 7.6734758,5.6693218 8.2304692,7.259814 10.826823,8.030166 12.909904,8.637474 19.18439,10.227335 26.038836,10.57777 32.71977,10.548222 38.893077,10.435469 45.224887,10.027436 50.931754,8.396312 52.808944,7.793351 55.184035,6.93717 55.321113,5.4096089 55.321354,5.2312896 55.285972,5.0420638 55.205601,4.871631 54.292734,3.3284344 51.696572,2.6274235 49.507139,2.0333349 43.529672,0.6248171 37.111337,0.2180963 30.775361,0.2524437 z m -1.135844,0.8162416 c 6.128932,-0.0815425 12.378924,0.2183941 18.173484,1.4655254 1.983258,0.491525 4.332516,1.0791916 5.159421,2.3559712 0.0728,0.1410104 0.115722,0.2791387 0.115512,0.4266721 C 52.96376,6.580698 50.803278,7.285265 49.102856,7.784131 43.933383,9.133658 38.196246,9.490285 32.60426,9.583572 26.552452,9.60802 20.345434,9.303579 14.661796,7.988191 12.774872,7.485728 10.430452,6.855376 9.9259099,5.5394651 9.6925851,4.3200225 11.706607,3.5137649 13.294934,3.0165355 18.08097,1.6380764 23.480553,1.2579246 28.734695,1.087237 c 0.300778,-0.00573 0.6034,-0.014541 0.904822,-0.018552 z"
+         id="path7867"
+         style="color:#000000;fill:url(#linearGradient14689);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:0.49905977;marker:none;visibility:visible;display:inline;overflow:visible" />
+    </g>
+  </g>
+</svg>
diff -pruN 3.4.1-6/Folders/src/applet-init.c 3.4.1+git20201022.a0d3415c-1/Folders/src/applet-init.c
--- 3.4.1-6/Folders/src/applet-init.c	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Folders/src/applet-init.c	2020-10-21 15:04:44.000000000 +0000
@@ -146,6 +146,12 @@ CD_APPLET_RELOAD_BEGIN
 
 		if (myConfig.cDirPath == NULL)
 		{
+			// in case of deletion of a path: force resizing
+			if (myIcon->pSubDock)
+			{
+				gldi_object_unref (GLDI_OBJECT(myIcon->pSubDock));
+				myIcon->pSubDock = NULL;
+			}
 			CD_APPLET_SET_IMAGE_ON_MY_ICON (myConfig.cImageFile);
 			gldi_dialog_show_temporary_with_icon (D_("Open the configuration of the applet to choose a folder to import."),
 				myIcon, myContainer,
diff -pruN 3.4.1-6/Folders/src/applet-notifications.c 3.4.1+git20201022.a0d3415c-1/Folders/src/applet-notifications.c
--- 3.4.1-6/Folders/src/applet-notifications.c	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Folders/src/applet-notifications.c	2020-10-21 15:04:44.000000000 +0000
@@ -19,7 +19,6 @@
 
 #include <stdlib.h>
 #include <string.h>
-#define __USE_POSIX 1
 #include <time.h>
 
 #include "applet-struct.h"
diff -pruN 3.4.1-6/.gitignore 3.4.1+git20201022.a0d3415c-1/.gitignore
--- 3.4.1-6/.gitignore	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/.gitignore	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,35 @@
+Makefile
+Makefile.in
+.deps
+*/data/*.conf
+*.gmo
+.libs
+*.lo
+*.la
+POTFILES
+stamp-it
+aclocal.m4
+autom4te.cache
+config.guess
+config.h
+config.h.in
+config.log
+config.status
+config.sub
+configure
+depcomp
+install-sh
+libtool
+ltmain.sh
+missing
+stamp-h1
+compile*
+data/messages
+*/data/messages
+Dbus/demos/demo_bash/store
+*.cmake
+CMakeFiles/
+install_manifest.txt
+CMakeCache.txt
+_CPack_Packages/
+build/
diff -pruN 3.4.1-6/Global-Menu/registrar/appmenu-registrar.py 3.4.1+git20201022.a0d3415c-1/Global-Menu/registrar/appmenu-registrar.py
--- 3.4.1-6/Global-Menu/registrar/appmenu-registrar.py	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Global-Menu/registrar/appmenu-registrar.py	2020-10-21 15:04:44.000000000 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 #
 # This is a part of the Cairo-Dock plug-ins.
 # Copyright : (C) 2011 by Fabrice Rey
@@ -18,17 +18,11 @@
 # Developped as a part of Cairo-Dock, but usable as a stand-alone systray daemon.
 # The code follows the same logic as the KDE watcher, to ensure a complete compatibility.
 
-from __future__ import print_function
 import sys
 
-try:
-	import glib
-	import gobject
-	g_bMainLoopInGObject = True
-except:
-	from gi.repository import GLib as glib
-	from gi.repository import GObject as gobject
-	g_bMainLoopInGObject = False
+from gi.repository import GLib as glib
+from gi.repository import GObject as gobject
+g_bMainLoopInGObject = False
 
 import dbus, dbus.service
 from dbus.mainloop.glib import DBusGMainLoop
diff -pruN 3.4.1-6/GMenu/data/misc/icon_old.svg 3.4.1+git20201022.a0d3415c-1/GMenu/data/misc/icon_old.svg
--- 3.4.1-6/GMenu/data/misc/icon_old.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/GMenu/data/misc/icon_old.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,2237 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   id="svg2"
+   sodipodi:version="0.32"
+   inkscape:version="0.46"
+   width="256"
+   height="256"
+   version="1.0"
+   sodipodi:docbase="/home/arkham/Desktop"
+   sodipodi:docname="icon.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <sodipodi:namedview
+     inkscape:window-height="905"
+     inkscape:window-width="1279"
+     inkscape:pageshadow="2"
+     inkscape:pageopacity="0.0"
+     guidetolerance="10.0"
+     gridtolerance="10.0"
+     objecttolerance="10.0"
+     borderopacity="1.0"
+     bordercolor="#666666"
+     pagecolor="#ffffff"
+     id="base"
+     width="48px"
+     height="48px"
+     inkscape:zoom="1.9453125"
+     inkscape:cx="72.846957"
+     inkscape:cy="131.02766"
+     inkscape:window-x="1"
+     inkscape:window-y="29"
+     inkscape:current-layer="svg2"
+     showgrid="false"
+     showguides="true"
+     inkscape:guide-bbox="true">
+    <sodipodi:guide
+       orientation="0,1"
+       position="44.722892,242.12048"
+       id="guide4297" />
+    <sodipodi:guide
+       orientation="0,1"
+       position="240.57831,19.02008"
+       id="guide4299" />
+    <sodipodi:guide
+       orientation="1,0"
+       position="23.13253,234.92369"
+       id="guide4301" />
+    <sodipodi:guide
+       orientation="1,0"
+       position="233.89558,263.19679"
+       id="guide4303" />
+  </sodipodi:namedview>
+  <metadata
+     id="metadata7">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <defs
+     id="defs5">
+    <linearGradient
+       x1="278.7821"
+       y1="598.48175"
+       x2="300.01877"
+       y2="538.17981"
+       id="linearGradient3203"
+       xlink:href="#linearGradient23837"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="278.7821"
+       y1="598.48175"
+       x2="300.01877"
+       y2="538.17981"
+       id="linearGradient23835"
+       xlink:href="#linearGradient23837"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="353.82788"
+       y1="353.77969"
+       x2="370.98239"
+       y2="331.95367"
+       id="linearGradient2254"
+       xlink:href="#linearGradient5197"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="353.82788"
+       y1="353.77969"
+       x2="370.98239"
+       y2="331.95367"
+       id="linearGradient10090"
+       xlink:href="#linearGradient5197"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="416.03726"
+       y1="314.99216"
+       x2="416.67383"
+       y2="287.50903"
+       id="linearGradient2365"
+       xlink:href="#linearGradient5197"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.5914941,0,0,1.5914941,-1056.2044,29.12901)" />
+    <linearGradient
+       x1="333.62714"
+       y1="305.53073"
+       x2="338.83194"
+       y2="276.24545"
+       id="linearGradient2368"
+       xlink:href="#linearGradient5197"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.5914941,0,0,1.5914941,-1056.2044,29.12901)" />
+    <linearGradient
+       x1="379.11264"
+       y1="378.87973"
+       x2="383.80917"
+       y2="225.32318"
+       id="linearGradient2371"
+       xlink:href="#linearGradient5197"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.5914941,0,0,1.5914941,-1056.2044,29.12901)"
+       spreadMethod="repeat" />
+    <linearGradient
+       x1="267.00482"
+       y1="450.1579"
+       x2="195.34068"
+       y2="423.26831"
+       id="linearGradient2375"
+       xlink:href="#linearGradient5197"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.5914941,0,0,1.5914941,-1056.2044,29.12901)" />
+    <linearGradient
+       id="linearGradient23837">
+      <stop
+         id="stop23839"
+         style="stop-color:#ffba00;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop23841"
+         style="stop-color:#ffffba;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="346.8956"
+       y1="409.87292"
+       x2="406.49899"
+       y2="371.66501"
+       id="linearGradient2379"
+       xlink:href="#linearGradient23837"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.5914941,0,0,1.5914941,-1056.2044,29.12901)" />
+    <linearGradient
+       x1="228.8004"
+       y1="401.76709"
+       x2="361.57016"
+       y2="343.16568"
+       id="linearGradient2382"
+       xlink:href="#linearGradient5197"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.5914941,0,0,1.5914941,-1056.2044,29.12901)" />
+    <linearGradient
+       x1="335.76212"
+       y1="383.67514"
+       x2="432.98227"
+       y2="334.34232"
+       id="linearGradient2385"
+       xlink:href="#linearGradient5197"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.5914941,0,0,1.5914941,-1056.2044,29.12901)" />
+    <linearGradient
+       x1="584.44714"
+       y1="496.83411"
+       x2="411.60892"
+       y2="312.98669"
+       id="linearGradient2388"
+       xlink:href="#linearGradient5197"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.5914941,0,0,1.5914941,-1056.2044,29.12901)" />
+    <linearGradient
+       x1="283.11636"
+       y1="420.78415"
+       x2="450.77399"
+       y2="341.96973"
+       id="linearGradient11090"
+       xlink:href="#linearGradient5197"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient3225">
+      <stop
+         id="stop3227"
+         style="stop-color:#000000;stop-opacity:0.71951222"
+         offset="0" />
+      <stop
+         id="stop3229"
+         style="stop-color:#ffffff;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="533.03326"
+       y1="446.52438"
+       x2="547.33417"
+       y2="428.58325"
+       id="linearGradient2392"
+       xlink:href="#linearGradient3225"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.5914941,0,0,1.5914941,-1056.2044,29.12901)" />
+    <linearGradient
+       id="linearGradient5197">
+      <stop
+         id="stop5199"
+         style="stop-color:#000000;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop5201"
+         style="stop-color:#ffffff;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="263.61029"
+       y1="435.38452"
+       x2="358.50229"
+       y2="314.54004"
+       id="linearGradient7163"
+       xlink:href="#linearGradient5197"
+       gradientUnits="userSpaceOnUse"
+       spreadMethod="reflect" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient5498"
+       id="linearGradient3804"
+       gradientUnits="userSpaceOnUse"
+       x1="220.36789"
+       y1="756.76105"
+       x2="185.21225"
+       y2="491.06723" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient5498"
+       id="linearGradient3802"
+       gradientUnits="userSpaceOnUse"
+       x1="247.47713"
+       y1="274.88394"
+       x2="130.31757"
+       y2="580.54669" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient5498"
+       id="linearGradient3800"
+       gradientUnits="userSpaceOnUse"
+       x1="370.62177"
+       y1="-309.6048"
+       x2="370.20648"
+       y2="458.38397" />
+    <linearGradient
+       id="linearGradient5498">
+      <stop
+         id="stop5500"
+         offset="0"
+         style="stop-color:#eeeeee;stop-opacity:1;" />
+      <stop
+         id="stop5502"
+         offset="1"
+         style="stop-color:#eeeeee;stop-opacity:0;" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient5498"
+       id="linearGradient3798"
+       gradientUnits="userSpaceOnUse"
+       x1="1508.4957"
+       y1="-363.42487"
+       x2="361.1441"
+       y2="630.52039" />
+    <linearGradient
+       id="XMLID_9_"
+       gradientUnits="userSpaceOnUse"
+       x1="331.49609"
+       y1="790.51508"
+       x2="409.85471"
+       y2="688.75092">
+      <stop
+         offset="0"
+         style="stop-color:#FFFFFF"
+         id="stop147" />
+      <stop
+         offset="1"
+         style="stop-color:#193D6B"
+         id="stop3851" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#XMLID_9_"
+       id="linearGradient3796"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.1256295,0,0,1.1256295,-41.873391,-39.54673)"
+       x1="331.49609"
+       y1="790.51508"
+       x2="409.85471"
+       y2="688.75092" />
+    <linearGradient
+       id="XMLID_8_"
+       gradientUnits="userSpaceOnUse"
+       x1="319.186"
+       y1="713.54639"
+       x2="373.12509"
+       y2="626.00598">
+      <stop
+         offset="0"
+         style="stop-color:#FFFFFF"
+         id="stop140" />
+      <stop
+         offset="1"
+         style="stop-color:#193D6B"
+         id="stop142" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#XMLID_8_"
+       id="linearGradient3794"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.1256295,0,0,1.1256295,-41.873391,-39.54673)"
+       x1="319.186"
+       y1="713.54639"
+       x2="373.12509"
+       y2="626.00598" />
+    <linearGradient
+       id="XMLID_7_-677"
+       gradientUnits="userSpaceOnUse"
+       x1="264.5405"
+       y1="704.23578"
+       x2="335.09619"
+       y2="612.60522">
+      <stop
+         offset="0"
+         style="stop-color:#ffffff"
+         id="stop2829" />
+      <stop
+         offset="1"
+         style="stop-color:#1d487f"
+         id="stop2831" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#XMLID_7_-677"
+       id="linearGradient3792"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.1256295,0,0,1.1256295,-41.873391,-39.54673)"
+       x1="264.5405"
+       y1="704.23578"
+       x2="335.09619"
+       y2="612.60522" />
+    <linearGradient
+       id="XMLID_6_-533"
+       gradientUnits="userSpaceOnUse"
+       x1="237.20799"
+       y1="684.01898"
+       x2="328.18469"
+       y2="565.86761">
+      <stop
+         offset="0"
+         style="stop-color:#ffffff"
+         id="stop2589" />
+      <stop
+         offset="1"
+         style="stop-color:#1d487f"
+         id="stop2591" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#XMLID_6_-533"
+       id="linearGradient3790"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.1256295,0,0,1.1256295,-41.873391,-39.54673)"
+       x1="237.20799"
+       y1="684.01898"
+       x2="328.18469"
+       y2="565.86761" />
+    <linearGradient
+       id="XMLID_5_-672"
+       gradientUnits="userSpaceOnUse"
+       x1="220.9512"
+       y1="634.63232"
+       x2="278.14471"
+       y2="560.35498">
+      <stop
+         offset="0"
+         style="stop-color:#ffffff"
+         id="stop3077" />
+      <stop
+         offset="1"
+         style="stop-color:#1d487f"
+         id="stop3079" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#XMLID_5_-672"
+       id="linearGradient3788"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.1256295,0,0,1.1256295,-41.873391,-39.54673)"
+       x1="220.9512"
+       y1="634.63232"
+       x2="278.14471"
+       y2="560.35498" />
+    <linearGradient
+       id="XMLID_4_"
+       gradientUnits="userSpaceOnUse"
+       x1="429.84909"
+       y1="815.45459"
+       x2="480.12021"
+       y2="643.30768"
+       gradientTransform="matrix(-1.1256295,0,0,1.1256295,1028.9091,-39.54673)">
+      <stop
+         offset="0"
+         style="stop-color:#FFFFFF"
+         id="stop112" />
+      <stop
+         offset="1"
+         style="stop-color:#E5EAF2"
+         id="stop114" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#XMLID_4_"
+       id="linearGradient3786"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.1256295,0,0,1.1256295,1028.9091,-39.54673)"
+       x1="429.84909"
+       y1="815.45459"
+       x2="480.12021"
+       y2="643.30768" />
+    <radialGradient
+       gradientTransform="matrix(1.1256295,0,0,1.1256295,-41.873391,-39.54673)"
+       id="XMLID_25_"
+       cx="375.21439"
+       cy="783.16357"
+       r="300.5752"
+       fx="375.21439"
+       fy="783.16357"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         offset="0.0112"
+         style="stop-color:#D2E8EC"
+         id="stop46" />
+      <stop
+         offset="0.2921"
+         style="stop-color:#60A8CE"
+         id="stop48" />
+      <stop
+         offset="0.4575"
+         style="stop-color:#4680A8"
+         id="stop50" />
+      <stop
+         offset="0.6767"
+         style="stop-color:#2F5C84"
+         id="stop52" />
+      <stop
+         offset="0.8653"
+         style="stop-color:#234970"
+         id="stop54" />
+      <stop
+         offset="1"
+         style="stop-color:#1F426A"
+         id="stop3826" />
+    </radialGradient>
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#XMLID_25_"
+       id="radialGradient3784"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.1256295,0,0,1.1256295,-41.873391,-39.54673)"
+       cx="375.21439"
+       cy="783.16357"
+       fx="375.21439"
+       fy="783.16357"
+       r="300.5752" />
+    <mask
+       maskUnits="userSpaceOnUse"
+       x="122.963"
+       y="97.149"
+       width="576.609"
+       height="587.491"
+       id="XMLID_23_">
+      <g
+         id="g31"
+         style="filter:url(#Adobe_OpacityMaskFilter)">
+        <radialGradient
+           id="XMLID_24_"
+           cx="88.977501"
+           cy="-20.899401"
+           r="673.11609"
+           fx="88.977501"
+           fy="-20.899401"
+           gradientUnits="userSpaceOnUse">
+          <stop
+             offset="0.309"
+             style="stop-color:#FFFFFF"
+             id="stop34" />
+          <stop
+             offset="1"
+             style="stop-color:#000000"
+             id="stop3816" />
+        </radialGradient>
+        <ellipse
+           sodipodi:ry="349.10599"
+           sodipodi:rx="512.93402"
+           sodipodi:cy="286.172"
+           sodipodi:cx="295.89499"
+           cx="295.89499"
+           cy="286.172"
+           rx="512.93402"
+           ry="349.10599"
+           id="ellipse38"
+           style="fill:url(#XMLID_24_)" />
+      </g>
+    </mask>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient3998">
+      <stop
+         style="stop-color:#000000;stop-opacity:1;"
+         offset="0"
+         id="stop4000" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0;"
+         offset="1"
+         id="stop4002" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3998"
+       id="linearGradient3782"
+       gradientUnits="userSpaceOnUse"
+       x1="484.04007"
+       y1="472.70938"
+       x2="796.16766"
+       y2="541.27319" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3267"
+       id="radialGradient2947"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.3229542,0.6351433,-0.4319039,0.8996224,31.99003,-180.68645)"
+       cx="335.87881"
+       cy="325.21933"
+       fx="335.87881"
+       fy="325.21933"
+       r="265.40691" />
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient3267">
+      <stop
+         style="stop-color:#e90000;stop-opacity:1;"
+         offset="0"
+         id="stop3269" />
+      <stop
+         style="stop-color:#e90000;stop-opacity:0;"
+         offset="1"
+         id="stop3271" />
+    </linearGradient>
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3267"
+       id="radialGradient3273"
+       cx="335.87881"
+       cy="325.21933"
+       fx="335.87881"
+       fy="325.21933"
+       r="265.40691"
+       gradientTransform="matrix(1.3229542,0.6351433,-0.4319039,0.8996224,31.99003,-180.68645)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient2309">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop2311" />
+      <stop
+         id="stop2317"
+         offset="0"
+         style="stop-color:#ffffff;stop-opacity:0.49803922;" />
+      <stop
+         style="stop-color:#5a5a5a;stop-opacity:1;"
+         offset="1"
+         id="stop2313" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3024">
+      <stop
+         style="stop-color:#18191a;stop-opacity:1;"
+         offset="0"
+         id="stop3026" />
+      <stop
+         style="stop-color:#000000;stop-opacity:1;"
+         offset="1"
+         id="stop3028" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient2920">
+      <stop
+         style="stop-color:#000000;stop-opacity:0;"
+         offset="0"
+         id="stop2922" />
+      <stop
+         id="stop2940"
+         offset="0.11653384"
+         style="stop-color:#000000;stop-opacity:0;" />
+      <stop
+         id="stop2938"
+         offset="0.20999166"
+         style="stop-color:#000000;stop-opacity:1;" />
+      <stop
+         id="stop2928"
+         offset="0.8901099"
+         style="stop-color:#000000;stop-opacity:1;" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0;"
+         offset="1"
+         id="stop2924" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient3291">
+      <stop
+         style="stop-color:#000000;stop-opacity:1;"
+         offset="0"
+         id="stop3293" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0;"
+         offset="1"
+         id="stop3295" />
+    </linearGradient>
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3291"
+       id="radialGradient3297"
+       cx="63.912209"
+       cy="115.70919"
+       fx="63.912209"
+       fy="115.7093"
+       r="63.912209"
+       gradientTransform="matrix(1,0,0,0.197802,0,92.82166)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="-601.46729"
+       y1="628.96088"
+       x2="-574.59741"
+       y2="680.40417"
+       id="XMLID_121_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9837,-0.1799,0.1799,0.9837,500.9515,-643.7268)">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop626" />
+      <stop
+         style="stop-color:#f6c08f;stop-opacity:1"
+         offset="1"
+         id="stop628" />
+    </linearGradient>
+    <linearGradient
+       x1="39.012699"
+       y1="89.889603"
+       x2="95.521896"
+       y2="107.6497"
+       id="XMLID_120_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9895,0.1448,-0.1448,0.9895,14.2829,-5.8352)">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop619" />
+      <stop
+         style="stop-color:#f6c08f;stop-opacity:1"
+         offset="1"
+         id="stop621" />
+    </linearGradient>
+    <linearGradient
+       x1="54.2402"
+       y1="93.582497"
+       x2="102.9066"
+       y2="100.176"
+       id="XMLID_119_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9951,9.89e-2,-9.89e-2,0.9951,10.3843,-6.0754)">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop612" />
+      <stop
+         style="stop-color:#f6c08f;stop-opacity:1"
+         offset="1"
+         id="stop614" />
+    </linearGradient>
+    <linearGradient
+       x1="58.369099"
+       y1="113.8594"
+       x2="105.8753"
+       y2="85.464897"
+       id="XMLID_118_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#b9120d;stop-opacity:1"
+         offset="0"
+         id="stop580" />
+      <stop
+         style="stop-color:#bb180d;stop-opacity:1"
+         offset="0.078"
+         id="stop582" />
+      <stop
+         style="stop-color:#c0290c;stop-opacity:1"
+         offset="0.1822"
+         id="stop584" />
+      <stop
+         style="stop-color:#c8450a;stop-opacity:1"
+         offset="0.30129999"
+         id="stop586" />
+      <stop
+         style="stop-color:#d36c08;stop-opacity:1"
+         offset="0.4314"
+         id="stop588" />
+      <stop
+         style="stop-color:#e29e05;stop-opacity:1"
+         offset="0.57059997"
+         id="stop590" />
+      <stop
+         style="stop-color:#f4da02;stop-opacity:1"
+         offset="0.71509999"
+         id="stop592" />
+      <stop
+         style="stop-color:#fefd00;stop-opacity:1"
+         offset="0.79210001"
+         id="stop594" />
+      <stop
+         style="stop-color:#fefd07;stop-opacity:1"
+         offset="0.8136"
+         id="stop596" />
+      <stop
+         style="stop-color:#fefd1b;stop-opacity:1"
+         offset="0.84549999"
+         id="stop598" />
+      <stop
+         style="stop-color:#fefe3c;stop-opacity:1"
+         offset="0.88370001"
+         id="stop600" />
+      <stop
+         style="stop-color:#fffe69;stop-opacity:1"
+         offset="0.92680001"
+         id="stop602" />
+      <stop
+         style="stop-color:#ffffa3;stop-opacity:1"
+         offset="0.97359997"
+         id="stop604" />
+      <stop
+         style="stop-color:#ffffc7;stop-opacity:1"
+         offset="1"
+         id="stop606" />
+    </linearGradient>
+    <linearGradient
+       x1="99.205597"
+       y1="87.746597"
+       x2="100.7206"
+       y2="63.169102"
+       id="XMLID_117_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9975,-7.07e-2,7.07e-2,0.9975,-10.9669,13.6507)">
+      <stop
+         style="stop-color:#de5c01;stop-opacity:1"
+         offset="0"
+         id="stop563" />
+      <stop
+         style="stop-color:#fefd00;stop-opacity:1"
+         offset="0.736"
+         id="stop565" />
+      <stop
+         style="stop-color:#fefe26;stop-opacity:1"
+         offset="0.77829999"
+         id="stop567" />
+      <stop
+         style="stop-color:#fffe54;stop-opacity:1"
+         offset="0.8369"
+         id="stop569" />
+      <stop
+         style="stop-color:#ffff76;stop-opacity:1"
+         offset="0.889"
+         id="stop571" />
+      <stop
+         style="stop-color:#ffff8b;stop-opacity:1"
+         offset="0.93199998"
+         id="stop573" />
+      <stop
+         style="stop-color:#ffff92;stop-opacity:1"
+         offset="0.96069998"
+         id="stop575" />
+    </linearGradient>
+    <linearGradient
+       x1="-172.72121"
+       y1="332.082"
+       x2="-161.4561"
+       y2="309.89331"
+       id="XMLID_116_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9975,-7.07e-2,7.07e-2,0.9975,254.6004,-268.4704)">
+      <stop
+         style="stop-color:#f79a09;stop-opacity:1"
+         offset="0"
+         id="stop546" />
+      <stop
+         style="stop-color:#fefd00;stop-opacity:1"
+         offset="0.736"
+         id="stop548" />
+      <stop
+         style="stop-color:#fefe26;stop-opacity:1"
+         offset="0.77829999"
+         id="stop550" />
+      <stop
+         style="stop-color:#fffe54;stop-opacity:1"
+         offset="0.8369"
+         id="stop552" />
+      <stop
+         style="stop-color:#ffff76;stop-opacity:1"
+         offset="0.889"
+         id="stop554" />
+      <stop
+         style="stop-color:#ffff8b;stop-opacity:1"
+         offset="0.93199998"
+         id="stop556" />
+      <stop
+         style="stop-color:#ffff92;stop-opacity:1"
+         offset="0.96069998"
+         id="stop558" />
+    </linearGradient>
+    <linearGradient
+       x1="-51.966301"
+       y1="212.7881"
+       x2="-52.194302"
+       y2="196.4341"
+       id="XMLID_115_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9992,-4.12e-2,4.12e-2,0.9992,151.8961,-153.906)">
+      <stop
+         style="stop-color:#f79a09;stop-opacity:1"
+         offset="0"
+         id="stop529" />
+      <stop
+         style="stop-color:#fefd00;stop-opacity:1"
+         offset="0.736"
+         id="stop531" />
+      <stop
+         style="stop-color:#fefe26;stop-opacity:1"
+         offset="0.77829999"
+         id="stop533" />
+      <stop
+         style="stop-color:#fffe54;stop-opacity:1"
+         offset="0.8369"
+         id="stop535" />
+      <stop
+         style="stop-color:#ffff76;stop-opacity:1"
+         offset="0.889"
+         id="stop537" />
+      <stop
+         style="stop-color:#ffff8b;stop-opacity:1"
+         offset="0.93199998"
+         id="stop539" />
+      <stop
+         style="stop-color:#ffff92;stop-opacity:1"
+         offset="0.96069998"
+         id="stop541" />
+    </linearGradient>
+    <linearGradient
+       x1="113.4365"
+       y1="55.834"
+       x2="119.687"
+       y2="34.332298"
+       id="XMLID_114_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#f79a09;stop-opacity:1"
+         offset="0"
+         id="stop512" />
+      <stop
+         style="stop-color:#fefd00;stop-opacity:1"
+         offset="0.736"
+         id="stop514" />
+      <stop
+         style="stop-color:#fefe26;stop-opacity:1"
+         offset="0.77829999"
+         id="stop516" />
+      <stop
+         style="stop-color:#fffe54;stop-opacity:1"
+         offset="0.8369"
+         id="stop518" />
+      <stop
+         style="stop-color:#ffff76;stop-opacity:1"
+         offset="0.889"
+         id="stop520" />
+      <stop
+         style="stop-color:#ffff8b;stop-opacity:1"
+         offset="0.93199998"
+         id="stop522" />
+      <stop
+         style="stop-color:#ffff92;stop-opacity:1"
+         offset="0.96069998"
+         id="stop524" />
+    </linearGradient>
+    <linearGradient
+       x1="1.1396"
+       y1="145.4453"
+       x2="-9.9659004"
+       y2="133.9595"
+       id="XMLID_113_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9996,-2.82e-2,2.82e-2,0.9996,104.7769,-104.6242)">
+      <stop
+         style="stop-color:#f79a09;stop-opacity:1"
+         offset="0"
+         id="stop495" />
+      <stop
+         style="stop-color:#fefd00;stop-opacity:1"
+         offset="0.736"
+         id="stop497" />
+      <stop
+         style="stop-color:#fefe26;stop-opacity:1"
+         offset="0.77829999"
+         id="stop499" />
+      <stop
+         style="stop-color:#fffe54;stop-opacity:1"
+         offset="0.8369"
+         id="stop501" />
+      <stop
+         style="stop-color:#ffff76;stop-opacity:1"
+         offset="0.889"
+         id="stop503" />
+      <stop
+         style="stop-color:#ffff8b;stop-opacity:1"
+         offset="0.93199998"
+         id="stop505" />
+      <stop
+         style="stop-color:#ffff92;stop-opacity:1"
+         offset="0.96069998"
+         id="stop507" />
+    </linearGradient>
+    <linearGradient
+       x1="117.8823"
+       y1="41.729"
+       x2="91.359299"
+       y2="17.106001"
+       id="XMLID_112_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#de5c01;stop-opacity:1"
+         offset="0"
+         id="stop478" />
+      <stop
+         style="stop-color:#fefd00;stop-opacity:1"
+         offset="0.736"
+         id="stop480" />
+      <stop
+         style="stop-color:#fefe26;stop-opacity:1"
+         offset="0.77829999"
+         id="stop482" />
+      <stop
+         style="stop-color:#fffe54;stop-opacity:1"
+         offset="0.8369"
+         id="stop484" />
+      <stop
+         style="stop-color:#ffff76;stop-opacity:1"
+         offset="0.889"
+         id="stop486" />
+      <stop
+         style="stop-color:#ffff8b;stop-opacity:1"
+         offset="0.93199998"
+         id="stop488" />
+      <stop
+         style="stop-color:#ffff92;stop-opacity:1"
+         offset="0.96069998"
+         id="stop490" />
+    </linearGradient>
+    <linearGradient
+       x1="105.1567"
+       y1="22.737801"
+       x2="86.211197"
+       y2="14.4171"
+       id="XMLID_111_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#f79a09;stop-opacity:1"
+         offset="0"
+         id="stop461" />
+      <stop
+         style="stop-color:#fefd00;stop-opacity:1"
+         offset="0.736"
+         id="stop463" />
+      <stop
+         style="stop-color:#fefe26;stop-opacity:1"
+         offset="0.77829999"
+         id="stop465" />
+      <stop
+         style="stop-color:#fffe54;stop-opacity:1"
+         offset="0.8369"
+         id="stop467" />
+      <stop
+         style="stop-color:#ffff76;stop-opacity:1"
+         offset="0.889"
+         id="stop469" />
+      <stop
+         style="stop-color:#ffff8b;stop-opacity:1"
+         offset="0.93199998"
+         id="stop471" />
+      <stop
+         style="stop-color:#ffff92;stop-opacity:1"
+         offset="0.96069998"
+         id="stop473" />
+    </linearGradient>
+    <linearGradient
+       x1="88.330597"
+       y1="117.3682"
+       x2="117.2648"
+       y2="72.7407"
+       id="XMLID_110_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#de5c01;stop-opacity:1"
+         offset="0"
+         id="stop444" />
+      <stop
+         style="stop-color:#fefd00;stop-opacity:1"
+         offset="0.736"
+         id="stop446" />
+      <stop
+         style="stop-color:#fefe26;stop-opacity:1"
+         offset="0.77829999"
+         id="stop448" />
+      <stop
+         style="stop-color:#fffe54;stop-opacity:1"
+         offset="0.8369"
+         id="stop450" />
+      <stop
+         style="stop-color:#ffff76;stop-opacity:1"
+         offset="0.889"
+         id="stop452" />
+      <stop
+         style="stop-color:#ffff8b;stop-opacity:1"
+         offset="0.93199998"
+         id="stop454" />
+      <stop
+         style="stop-color:#ffff92;stop-opacity:1"
+         offset="0.96069998"
+         id="stop456" />
+    </linearGradient>
+    <linearGradient
+       x1="10.9453"
+       y1="37.099602"
+       x2="25.7187"
+       y2="19.835199"
+       id="XMLID_109_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9946,0.1039,-0.1039,0.9946,3.786,-2.0567)">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop436" />
+      <stop
+         style="stop-color:#f6c08f;stop-opacity:1"
+         offset="1"
+         id="stop438" />
+    </linearGradient>
+    <linearGradient
+       x1="15.2012"
+       y1="26.939899"
+       x2="4.5215001"
+       y2="25.8437"
+       id="XMLID_108_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop429" />
+      <stop
+         style="stop-color:#f6c08f;stop-opacity:1"
+         offset="1"
+         id="stop431" />
+    </linearGradient>
+    <linearGradient
+       x1="15.8809"
+       y1="22.228001"
+       x2="27.7244"
+       y2="23.85"
+       id="XMLID_107_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9959,9.03e-2,-9.03e-2,0.9959,2.3457,-2.346)">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop422" />
+      <stop
+         style="stop-color:#f6c08f;stop-opacity:1"
+         offset="1"
+         id="stop424" />
+    </linearGradient>
+    <linearGradient
+       x1="6.9833999"
+       y1="23.1094"
+       x2="25.178301"
+       y2="25.6012"
+       id="XMLID_106_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop415" />
+      <stop
+         style="stop-color:#f6c08f;stop-opacity:1"
+         offset="1"
+         id="stop417" />
+    </linearGradient>
+    <linearGradient
+       x1="13.3721"
+       y1="22.875999"
+       x2="26.2598"
+       y2="24.641001"
+       id="XMLID_105_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9959,9.03e-2,-9.03e-2,0.9959,2.3457,-2.346)">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop408" />
+      <stop
+         style="stop-color:#f6c08f;stop-opacity:1"
+         offset="1"
+         id="stop410" />
+    </linearGradient>
+    <linearGradient
+       x1="16.3398"
+       y1="35.804699"
+       x2="27.0674"
+       y2="23.268299"
+       id="XMLID_104_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9946,0.1039,-0.1039,0.9946,3.786,-2.0567)">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop401" />
+      <stop
+         style="stop-color:#f6c08f;stop-opacity:1"
+         offset="1"
+         id="stop403" />
+    </linearGradient>
+    <linearGradient
+       x1="15.5088"
+       y1="33.507801"
+       x2="9.6995001"
+       y2="44.351501"
+       id="XMLID_103_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop394" />
+      <stop
+         style="stop-color:#eed8a5;stop-opacity:1"
+         offset="1"
+         id="stop396" />
+    </linearGradient>
+    <linearGradient
+       x1="23.0117"
+       y1="34.750999"
+       x2="33.993099"
+       y2="21.917999"
+       id="XMLID_102_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9992,3.98e-2,-3.98e-2,0.9992,0.9958,-1.3319)">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop387" />
+      <stop
+         style="stop-color:#f6c08f;stop-opacity:1"
+         offset="1"
+         id="stop389" />
+    </linearGradient>
+    <linearGradient
+       x1="22.559601"
+       y1="28.492201"
+       x2="22.559601"
+       y2="23.245199"
+       id="XMLID_101_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop380" />
+      <stop
+         style="stop-color:#f6c08f;stop-opacity:1"
+         offset="1"
+         id="stop382" />
+    </linearGradient>
+    <linearGradient
+       x1="60.286098"
+       y1="34.297401"
+       x2="61.244999"
+       y2="36.0061"
+       id="XMLID_100_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#8b8b89;stop-opacity:1"
+         offset="0"
+         id="stop373" />
+      <stop
+         style="stop-color:#120500;stop-opacity:1"
+         offset="1"
+         id="stop375" />
+    </linearGradient>
+    <linearGradient
+       x1="21.340799"
+       y1="37.1255"
+       x2="9.2384996"
+       y2="55.278999"
+       id="XMLID_99_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop366" />
+      <stop
+         style="stop-color:#f2c072;stop-opacity:1"
+         offset="1"
+         id="stop368" />
+    </linearGradient>
+    <linearGradient
+       x1="20.4468"
+       y1="33.1045"
+       x2="7.1675"
+       y2="53.023399"
+       id="XMLID_98_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop359" />
+      <stop
+         style="stop-color:#f2c072;stop-opacity:1"
+         offset="1"
+         id="stop361" />
+    </linearGradient>
+    <linearGradient
+       x1="18.313"
+       y1="39.891102"
+       x2="12.6977"
+       y2="53.833"
+       id="XMLID_97_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop352" />
+      <stop
+         style="stop-color:#f2c072;stop-opacity:1"
+         offset="1"
+         id="stop354" />
+    </linearGradient>
+    <linearGradient
+       x1="11.7305"
+       y1="44.491699"
+       x2="5.9211001"
+       y2="55.3354"
+       id="XMLID_96_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop345" />
+      <stop
+         style="stop-color:#eed8a5;stop-opacity:1"
+         offset="1"
+         id="stop347" />
+    </linearGradient>
+    <linearGradient
+       x1="12.3135"
+       y1="37.8647"
+       x2="6.5040002"
+       y2="48.708801"
+       id="XMLID_95_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop338" />
+      <stop
+         style="stop-color:#eed8a5;stop-opacity:1"
+         offset="1"
+         id="stop340" />
+    </linearGradient>
+    <linearGradient
+       x1="21.0347"
+       y1="49.271"
+       x2="7.7561002"
+       y2="69.188797"
+       id="XMLID_94_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.8104,-0.5859,0.5859,0.8104,-28.537,20.3312)">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop331" />
+      <stop
+         style="stop-color:#f2c072;stop-opacity:1"
+         offset="1"
+         id="stop333" />
+    </linearGradient>
+    <linearGradient
+       x1="13.8481"
+       y1="55.797401"
+       x2="0.56919998"
+       y2="75.715698"
+       id="XMLID_93_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.8104,-0.5859,0.5859,0.8104,-28.537,20.3312)">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop324" />
+      <stop
+         style="stop-color:#f2c072;stop-opacity:1"
+         offset="1"
+         id="stop326" />
+    </linearGradient>
+    <linearGradient
+       x1="-414.43649"
+       y1="422.68359"
+       x2="-414.43649"
+       y2="470.3703"
+       id="XMLID_92_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9324,0.3616,-0.3616,0.9324,554.92,-207.713)">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop317" />
+      <stop
+         style="stop-color:#f2c06e;stop-opacity:1"
+         offset="1"
+         id="stop319" />
+    </linearGradient>
+    <linearGradient
+       x1="-411.27289"
+       y1="427.6279"
+       x2="-411.27289"
+       y2="475.31949"
+       id="XMLID_91_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.992,0.1261,-0.1261,0.992,477.0624,-332.3914)">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop310" />
+      <stop
+         style="stop-color:#f2c06e;stop-opacity:1"
+         offset="1"
+         id="stop312" />
+    </linearGradient>
+    <linearGradient
+       x1="80.929199"
+       y1="67.844704"
+       x2="60.433201"
+       y2="71.759697"
+       id="XMLID_90_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#fffaee;stop-opacity:1"
+         offset="0.0047"
+         id="stop291" />
+      <stop
+         style="stop-color:#f5f89b;stop-opacity:1"
+         offset="0.2757"
+         id="stop293" />
+      <stop
+         style="stop-color:#f3ed91;stop-opacity:1"
+         offset="0.31020001"
+         id="stop295" />
+      <stop
+         style="stop-color:#ecc267;stop-opacity:1"
+         offset="0.4668"
+         id="stop297" />
+      <stop
+         style="stop-color:#e6a046;stop-opacity:1"
+         offset="0.6182"
+         id="stop299" />
+      <stop
+         style="stop-color:#e2872e;stop-opacity:1"
+         offset="0.76109999"
+         id="stop301" />
+      <stop
+         style="stop-color:#e07820;stop-opacity:1"
+         offset="0.89209998"
+         id="stop303" />
+      <stop
+         style="stop-color:#df731b;stop-opacity:1"
+         offset="1"
+         id="stop305" />
+    </linearGradient>
+    <linearGradient
+       x1="15.8564"
+       y1="36.413101"
+       x2="-3.4365001"
+       y2="67.833"
+       id="XMLID_89_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9897,-8.01e-2,9.49e-2,1.1727,-3.8203,-4.9468)">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop284" />
+      <stop
+         style="stop-color:#f2c06e;stop-opacity:1"
+         offset="1"
+         id="stop286" />
+    </linearGradient>
+    <linearGradient
+       x1="847.4707"
+       y1="-1065.021"
+       x2="847.4707"
+       y2="-1007.9581"
+       id="XMLID_88_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9673,0.2537,-0.2537,0.9673,-1076.666,855.2322)">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop277" />
+      <stop
+         style="stop-color:#f6c08f;stop-opacity:1"
+         offset="1"
+         id="stop279" />
+    </linearGradient>
+    <linearGradient
+       x1="35.5"
+       y1="48.361301"
+       x2="50.721401"
+       y2="63.893299"
+       id="XMLID_87_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#df731b;stop-opacity:1"
+         offset="0.19660001"
+         id="stop268" />
+      <stop
+         style="stop-color:#f9bd5f;stop-opacity:1"
+         offset="0.8427"
+         id="stop270" />
+      <stop
+         style="stop-color:#fffccf;stop-opacity:1"
+         offset="1"
+         id="stop272" />
+    </linearGradient>
+    <linearGradient
+       x1="54.825199"
+       y1="41.267101"
+       x2="58.138699"
+       y2="44.27"
+       id="XMLID_86_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#eea272;stop-opacity:1"
+         offset="0"
+         id="stop253" />
+      <stop
+         style="stop-color:#efa777;stop-opacity:1"
+         offset="0.1865"
+         id="stop255" />
+      <stop
+         style="stop-color:#f2b585;stop-opacity:1"
+         offset="0.4064"
+         id="stop257" />
+      <stop
+         style="stop-color:#f6cd9c;stop-opacity:1"
+         offset="0.64300001"
+         id="stop259" />
+      <stop
+         style="stop-color:#fceebb;stop-opacity:1"
+         offset="0.88980001"
+         id="stop261" />
+      <stop
+         style="stop-color:#ffc;stop-opacity:1"
+         offset="1"
+         id="stop263" />
+    </linearGradient>
+    <linearGradient
+       x1="34.783699"
+       y1="57.5415"
+       x2="48.052399"
+       y2="84.078903"
+       id="XMLID_85_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#941403;stop-opacity:1"
+         offset="0.0169"
+         id="stop244" />
+      <stop
+         style="stop-color:#e35100;stop-opacity:1"
+         offset="0.5"
+         id="stop246" />
+      <stop
+         style="stop-color:#df731b;stop-opacity:1"
+         offset="1"
+         id="stop248" />
+    </linearGradient>
+    <linearGradient
+       x1="41.703602"
+       y1="34.057598"
+       x2="54.7924"
+       y2="16.8533"
+       id="XMLID_84_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.19660001"
+         id="stop235" />
+      <stop
+         style="stop-color:#f9bd5f;stop-opacity:1"
+         offset="0.8427"
+         id="stop237" />
+      <stop
+         style="stop-color:#fffccf;stop-opacity:1"
+         offset="1"
+         id="stop239" />
+    </linearGradient>
+    <linearGradient
+       x1="18.3477"
+       y1="30.846201"
+       x2="12.8857"
+       y2="16.8496"
+       id="XMLID_83_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#941403;stop-opacity:1"
+         offset="0.0112"
+         id="stop226" />
+      <stop
+         style="stop-color:#e85c0a;stop-opacity:1"
+         offset="0.47189999"
+         id="stop228" />
+      <stop
+         style="stop-color:#f9bd5f;stop-opacity:1"
+         offset="1"
+         id="stop230" />
+    </linearGradient>
+    <linearGradient
+       x1="12.4712"
+       y1="61.107399"
+       x2="12.4712"
+       y2="111.4548"
+       id="XMLID_82_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.999,4.48e-2,-4.48e-2,0.999,3.2321,-0.6968)">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop217" />
+      <stop
+         style="stop-color:#f6c08f;stop-opacity:1"
+         offset="1"
+         id="stop219" />
+    </linearGradient>
+    <linearGradient
+       x1="209.7227"
+       y1="-130.65919"
+       x2="224.26109"
+       y2="-85.618599"
+       id="XMLID_81_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9929,0.1186,-0.1186,0.9929,-207.2682,181.2932)">
+      <stop
+         style="stop-color:#de7210;stop-opacity:1"
+         offset="0.0562"
+         id="stop210" />
+      <stop
+         style="stop-color:#f6c08f;stop-opacity:1"
+         offset="1"
+         id="stop212" />
+    </linearGradient>
+    <linearGradient
+       x1="6.1064"
+       y1="87.056602"
+       x2="32.828098"
+       y2="87.056602"
+       id="XMLID_80_"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9988,4.9e-2,-4.9e-2,0.9988,4.7153,-1.2399)">
+      <stop
+         style="stop-color:#b30000;stop-opacity:1"
+         offset="0.0562"
+         id="stop203" />
+      <stop
+         style="stop-color:#de5c01;stop-opacity:1"
+         offset="1"
+         id="stop205" />
+    </linearGradient>
+    <linearGradient
+       x1="51.277802"
+       y1="74.424301"
+       x2="78.689102"
+       y2="84.211601"
+       id="XMLID_79_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#941403;stop-opacity:1"
+         offset="0"
+         id="stop196" />
+      <stop
+         style="stop-color:#df731b;stop-opacity:1"
+         offset="1"
+         id="stop198" />
+    </linearGradient>
+    <linearGradient
+       x1="38.767601"
+       y1="82.582497"
+       x2="91.339104"
+       y2="84.7472"
+       id="XMLID_78_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#b30000;stop-opacity:1"
+         offset="0"
+         id="stop189" />
+      <stop
+         style="stop-color:#df731b;stop-opacity:1"
+         offset="1"
+         id="stop191" />
+    </linearGradient>
+    <linearGradient
+       x1="48.730999"
+       y1="44.320301"
+       x2="51.856499"
+       y2="42.945099"
+       id="XMLID_77_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#f2c8a9;stop-opacity:1"
+         offset="0"
+         id="stop182" />
+      <stop
+         style="stop-color:#ffc;stop-opacity:1"
+         offset="1"
+         id="stop184" />
+    </linearGradient>
+    <linearGradient
+       x1="24.450199"
+       y1="33.952599"
+       x2="63.643002"
+       y2="38.8517"
+       id="XMLID_76_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#941403;stop-opacity:1"
+         offset="0.0112"
+         id="stop169" />
+      <stop
+         style="stop-color:#a32104;stop-opacity:1"
+         offset="0.1357"
+         id="stop171" />
+      <stop
+         style="stop-color:#c84107;stop-opacity:1"
+         offset="0.49779999"
+         id="stop173" />
+      <stop
+         style="stop-color:#df5509;stop-opacity:1"
+         offset="0.78930002"
+         id="stop175" />
+      <stop
+         style="stop-color:#e85c0a;stop-opacity:1"
+         offset="0.972"
+         id="stop177" />
+    </linearGradient>
+    <linearGradient
+       x1="41.838902"
+       y1="36.961899"
+       x2="52.696899"
+       y2="37.8922"
+       id="XMLID_75_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#941403;stop-opacity:1"
+         offset="0.0112"
+         id="stop162" />
+      <stop
+         style="stop-color:#e85c0a;stop-opacity:1"
+         offset="0.89719999"
+         id="stop164" />
+    </linearGradient>
+    <linearGradient
+       x1="64.477501"
+       y1="56.3008"
+       x2="78.466103"
+       y2="48.0854"
+       id="XMLID_74_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#df731b;stop-opacity:1"
+         offset="0"
+         id="stop149" />
+      <stop
+         style="stop-color:#df731b;stop-opacity:1"
+         offset="0.5449"
+         id="stop151" />
+      <stop
+         style="stop-color:#ec8811;stop-opacity:1"
+         offset="0.70139998"
+         id="stop153" />
+      <stop
+         style="stop-color:#f4950b;stop-opacity:1"
+         offset="0.85930002"
+         id="stop155" />
+      <stop
+         style="stop-color:#f79a09;stop-opacity:1"
+         offset="1"
+         id="stop157" />
+    </linearGradient>
+    <linearGradient
+       x1="62.651901"
+       y1="34.546398"
+       x2="62.651901"
+       y2="11.8951"
+       id="XMLID_71_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:black;stop-opacity:0"
+         offset="0.0137"
+         id="stop120" />
+      <stop
+         style="stop-color:#c4e0e3;stop-opacity:0.2"
+         offset="0.64999998"
+         id="stop122" />
+      <stop
+         style="stop-color:#c4e0e3;stop-opacity:1"
+         offset="0.82239997"
+         id="stop124" />
+      <stop
+         style="stop-color:#cde5e8;stop-opacity:1"
+         offset="0.84979999"
+         id="stop126" />
+      <stop
+         style="stop-color:#e8f4f7;stop-opacity:1"
+         offset="0.9443"
+         id="stop128" />
+      <stop
+         style="stop-color:#f2fafc;stop-opacity:1"
+         offset="1"
+         id="stop130" />
+    </linearGradient>
+    <linearGradient
+       x1="38.491699"
+       y1="19.146999"
+       x2="29.173901"
+       y2="32.832401"
+       id="XMLID_70_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#0f80bc;stop-opacity:1"
+         offset="0"
+         id="stop111" />
+      <stop
+         style="stop-color:#0a5f9e;stop-opacity:1"
+         offset="0.33759999"
+         id="stop113" />
+      <stop
+         style="stop-color:#00145a;stop-opacity:1"
+         offset="1"
+         id="stop115" />
+    </linearGradient>
+    <clipPath
+       id="XMLID_68_">
+      <ellipse
+         sodipodi:ry="58.254002"
+         sodipodi:rx="58.215"
+         sodipodi:cy="59.375"
+         sodipodi:cx="63.755001"
+         id="use99"
+         ry="58.254002"
+         rx="58.215"
+         cy="59.375"
+         cx="63.755001" />
+    </clipPath>
+    <linearGradient
+       x1="76.371597"
+       y1="16.591801"
+       x2="93.231796"
+       y2="18.029301"
+       id="XMLID_69_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#0f80bc;stop-opacity:1"
+         offset="0"
+         id="stop102" />
+      <stop
+         style="stop-color:#0a5f9e;stop-opacity:1"
+         offset="0.33759999"
+         id="stop104" />
+      <stop
+         style="stop-color:#00145a;stop-opacity:1"
+         offset="1"
+         id="stop106" />
+    </linearGradient>
+    <radialGradient
+       cx="64.551804"
+       cy="14.1646"
+       r="52.241501"
+       fx="64.551804"
+       fy="14.1646"
+       id="XMLID_67_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#0f80bc;stop-opacity:1"
+         offset="0"
+         id="stop85" />
+      <stop
+         style="stop-color:#0a5f9e;stop-opacity:1"
+         offset="0.33759999"
+         id="stop87" />
+      <stop
+         style="stop-color:#00145a;stop-opacity:1"
+         offset="1"
+         id="stop89" />
+    </radialGradient>
+    <radialGradient
+       cx="64.550797"
+       cy="14.1733"
+       r="52.233299"
+       fx="64.550797"
+       fy="14.1733"
+       id="XMLID_66_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#0f80bc;stop-opacity:1"
+         offset="0"
+         id="stop76" />
+      <stop
+         style="stop-color:#0a5f9e;stop-opacity:1"
+         offset="0.33759999"
+         id="stop78" />
+      <stop
+         style="stop-color:#00145a;stop-opacity:1"
+         offset="1"
+         id="stop80" />
+    </radialGradient>
+    <radialGradient
+       cx="65.405296"
+       cy="19.1201"
+       r="57.382702"
+       fx="65.405296"
+       fy="19.1201"
+       id="XMLID_65_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#0f80bc;stop-opacity:1"
+         offset="0"
+         id="stop65" />
+      <stop
+         style="stop-color:#0b629b;stop-opacity:1"
+         offset="0.26429999"
+         id="stop67" />
+      <stop
+         style="stop-color:#031747;stop-opacity:1"
+         offset="0.84390002"
+         id="stop69" />
+      <stop
+         style="stop-color:#00022f;stop-opacity:1"
+         offset="1"
+         id="stop71" />
+    </radialGradient>
+    <radialGradient
+       cx="64.548798"
+       cy="14.1724"
+       r="52.237301"
+       fx="64.548798"
+       fy="14.1724"
+       id="XMLID_64_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#0f80bc;stop-opacity:1"
+         offset="0"
+         id="stop56" />
+      <stop
+         style="stop-color:#0a5f9e;stop-opacity:1"
+         offset="0.33759999"
+         id="stop58" />
+      <stop
+         style="stop-color:#00145a;stop-opacity:1"
+         offset="1"
+         id="stop60" />
+    </radialGradient>
+    <radialGradient
+       cx="64.553703"
+       cy="14.1758"
+       r="52.228901"
+       fx="64.553703"
+       fy="14.1758"
+       id="XMLID_63_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#0f80bc;stop-opacity:1"
+         offset="0"
+         id="stop47" />
+      <stop
+         style="stop-color:#0a5f9e;stop-opacity:1"
+         offset="0.33759999"
+         id="stop49" />
+      <stop
+         style="stop-color:#00145a;stop-opacity:1"
+         offset="1"
+         id="stop51" />
+    </radialGradient>
+    <radialGradient
+       cx="64.551804"
+       cy="14.1748"
+       r="52.231701"
+       fx="64.551804"
+       fy="14.1748"
+       id="XMLID_62_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#0f80bc;stop-opacity:1"
+         offset="0"
+         id="stop36" />
+      <stop
+         style="stop-color:#0a5f9e;stop-opacity:1"
+         offset="0.33759999"
+         id="stop38" />
+      <stop
+         style="stop-color:#00145a;stop-opacity:1"
+         offset="1"
+         id="stop40" />
+    </radialGradient>
+    <radialGradient
+       cx="64.568802"
+       cy="7.2266002"
+       r="104.221"
+       fx="64.568802"
+       fy="7.2266002"
+       id="XMLID_61_"
+       gradientUnits="userSpaceOnUse">
+      <stop
+         style="stop-color:#67c5d5;stop-opacity:1"
+         offset="0"
+         id="stop13" />
+      <stop
+         style="stop-color:#66c2d3;stop-opacity:1"
+         offset="0.1604"
+         id="stop15" />
+      <stop
+         style="stop-color:#62b9ce;stop-opacity:1"
+         offset="0.27950001"
+         id="stop17" />
+      <stop
+         style="stop-color:#5ca8c6;stop-opacity:1"
+         offset="0.38519999"
+         id="stop19" />
+      <stop
+         style="stop-color:#5392ba;stop-opacity:1"
+         offset="0.48320001"
+         id="stop21" />
+      <stop
+         style="stop-color:#4874aa;stop-opacity:1"
+         offset="0.57590002"
+         id="stop23" />
+      <stop
+         style="stop-color:#3a5097;stop-opacity:1"
+         offset="0.66460001"
+         id="stop25" />
+      <stop
+         style="stop-color:#2a2781;stop-opacity:1"
+         offset="0.74849999"
+         id="stop27" />
+      <stop
+         style="stop-color:#1b006d;stop-opacity:1"
+         offset="0.81459999"
+         id="stop29" />
+      <stop
+         style="stop-color:#596aad;stop-opacity:1"
+         offset="1"
+         id="stop31" />
+    </radialGradient>
+    <linearGradient
+       id="linearGradient1045">
+      <stop
+         id="stop1046"
+         offset="0.00000000"
+         style="stop-color:#ffffff;stop-opacity:0.74901962;" />
+      <stop
+         id="stop1047"
+         offset="1.0000000"
+         style="stop-color:#ffffff;stop-opacity:0.00000000;" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient3159">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop3161" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop3163" />
+    </linearGradient>
+    <inkscape:perspective
+       sodipodi:type="inkscape:persp3d"
+       inkscape:vp_x="0 : 24 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_z="48 : 24 : 1"
+       inkscape:persp3d-origin="24 : 16 : 1"
+       id="perspective7" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3159"
+       id="linearGradient3165"
+       x1="23.807722"
+       y1="3.9314766"
+       x2="23.446424"
+       y2="30.591192"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9997941,-2.0293493e-2,2.0293493e-2,0.9997941,-0.3545885,0.4867899)" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3267"
+       id="radialGradient3488"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.3229542,0.6351433,-0.4319039,0.8996224,31.99003,-180.68645)"
+       cx="335.87881"
+       cy="325.21933"
+       fx="335.87881"
+       fy="325.21933"
+       r="265.40691" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#XMLID_6_-533"
+       id="linearGradient3919"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.1256295,0,0,1.1256295,-41.873391,-39.54673)"
+       x1="237.20799"
+       y1="684.01898"
+       x2="328.18469"
+       y2="565.86761" />
+    <linearGradient
+       gradientTransform="translate(-0.6250002,-0.625)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3309"
+       id="linearGradient3323"
+       y2="0"
+       x2="28.5"
+       y1="47.875"
+       x1="28.25" />
+    <linearGradient
+       gradientTransform="translate(-0.6250002,-0.625)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3309"
+       id="linearGradient3315"
+       y2="0"
+       x2="28.5"
+       y1="47.875"
+       x1="28.25" />
+    <linearGradient
+       gradientTransform="matrix(0.9944959,0,0,1.0017939,72.263151,6.1599889)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient2199"
+       id="linearGradient3237"
+       y2="0.093517713"
+       x2="34.559841"
+       y1="47.911613"
+       x1="34.913395" />
+    <linearGradient
+       id="linearGradient2199">
+      <stop
+         id="stop2201"
+         offset="0"
+         style="stop-color:#8f0000;stop-opacity:1" />
+      <stop
+         id="stop2203"
+         offset="1"
+         style="stop-color:#bf0000;stop-opacity:1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3309">
+      <stop
+         id="stop3311"
+         offset="0"
+         style="stop-color:#8f0000;stop-opacity:1" />
+      <stop
+         id="stop3313"
+         offset="1"
+         style="stop-color:#be0000;stop-opacity:1" />
+    </linearGradient>
+    <inkscape:perspective
+       id="perspective4397"
+       inkscape:persp3d-origin="24 : 16 : 1"
+       inkscape:vp_z="48 : 24 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_x="0 : 24 : 1"
+       sodipodi:type="inkscape:persp3d" />
+  </defs>
+  <path
+     sodipodi:nodetypes="ccc"
+     id="path2276"
+     d="M 106.11175,33.029662 L 106.11175,28.523223 L 106.11175,33.029662 z"
+     style="fill:#ffffff;fill-opacity:0.75688076;fill-rule:nonzero;stroke:none;stroke-width:0.5;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:4;stroke-opacity:1" />
+  <g
+     transform="matrix(0.3408868,0,0,0.3482837,286.09375,-90.188967)"
+     id="layer1"
+     style="opacity:1;display:inline">
+    <path
+       d="M -603.03725,892.27178 C -603.03725,892.27178 -611.6417,879.36518 -613.07577,876.49698 C -614.50984,873.62888 -638.17204,783.28228 -632.43576,753.16668 C -626.69945,723.05118 -624.54835,700.10598 -619.52909,693.65268 C -614.50984,687.19928 -585.82838,651.34748 -582.24318,649.19638 C -578.65801,647.04528 -563.60024,622.66598 -554.27877,622.66598 C -544.95729,622.66598 -478.27287,652.78158 -469.66845,651.34748 C -461.064,649.91338 -423.7781,649.91338 -420.90995,647.76228 C -418.04181,645.61118 -407.28625,637.00678 -407.28625,637.00678 L -397.24774,631.27048 C -397.24774,631.27048 -374.30256,629.11938 -370.00036,629.11938 C -365.69812,629.11938 -338.45076,644.89418 -331.28038,652.78158 C -324.11001,660.66898 -278.93669,712.29558 -279.65372,739.54298 C -280.37075,766.79038 -279.65372,788.30148 -282.52189,796.18888 C -285.39003,804.07628 -293.27744,832.04078 -295.42854,839.92818 C -297.57964,847.81548 -301.88188,864.30738 -302.59892,870.76068 C -303.31595,877.21408 -311.20336,883.66738 -314.07149,886.53548 C -316.93963,889.40368 -354.22554,895.13998 -361.39591,898.00808 C -368.56629,900.87628 -390.79441,916.65098 -397.24774,919.51918 C -403.70108,922.38738 -418.04181,932.42588 -418.04181,932.42588 C -418.04181,932.42588 -438.11883,952.50288 -442.42105,954.65398 C -446.72327,956.80508 -483.29213,963.97548 -496.1988,956.08808 C -509.10545,948.20068 -523.44618,934.57698 -529.89951,926.68958 C -536.35285,918.80218 -550.69358,903.74438 -555.71283,899.44218 C -560.73209,895.13998 -603.03725,893.70588 -603.03725,892.27178 z"
+       id="path17935"
+       style="fill:#ececec;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M 372.83644,338.83038 C 372.83644,365.82845 357.24164,387.71471 338.00449,387.71471 C 318.76733,387.71471 303.17253,365.82845 303.17253,338.83038 C 303.17253,311.83231 318.76733,289.94605 338.00448,289.94605 C 357.24164,289.94605 372.83644,311.83231 372.83644,338.83038 z"
+       transform="matrix(1.6597987,0,0,1.5671594,-1081.6708,38.56396)"
+       id="path6186"
+       style="fill:url(#linearGradient7163);fill-opacity:1;stroke:none" />
+    <path
+       d="M -599.84463,888.85088 C -599.84463,888.85088 -615.07136,845.07398 -615.54721,809.86218 C -616.02304,774.65028 -617.92637,754.18938 -611.26468,727.54258 C -604.60299,700.89578 -604.60299,697.56498 -604.60299,697.56498 L -638.86315,763.23028 C -638.86315,763.23028 -644.09734,792.25618 -644.57318,795.11128 C -645.04902,797.96628 -640.29066,850.30818 -640.29066,850.30818 L -635.05647,868.38988 L -623.6364,886.47168 L -616.97471,892.65758 L -599.84463,888.85088 z"
+       id="path6184"
+       style="fill:#cccccc;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M -318.65921,889.80248 C -318.65921,889.80248 -303.43246,846.02568 -302.95662,810.81378 C -302.48078,775.60198 -300.57746,755.14108 -307.23913,728.49428 C -313.90082,701.84748 -313.90082,698.51658 -313.90082,698.51658 L -279.64069,764.18198 C -279.64069,764.18198 -274.40647,793.20788 -273.93063,796.06288 C -273.45479,798.91788 -278.21318,851.25978 -278.21318,851.25978 L -283.44736,869.34158 L -294.8674,887.42338 L -301.5291,893.60918 L -318.65921,889.80248 z"
+       id="path4226"
+       style="fill:#cccccc;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M -257.95658,669.00768 L -255.88752,677.28398 L -169.40035,765.42638 L -161.12403,772.46128 L -157.81354,770.80598 L -161.53787,760.04678 L -173.53848,743.08048 L -188.84962,726.52788 L -214.5061,704.59568 L -231.05867,691.35368 L -245.12834,678.52538 L -250.92177,672.73198 L -253.40463,670.66288 L -257.95658,669.00768 z"
+       id="path2253"
+       style="fill:url(#linearGradient2392);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M 450.27399,341.96973 C 450.28415,357.33234 435.15489,369.79062 416.4885,369.79062 C 397.8221,369.79062 382.69284,357.33234 382.703,341.96973 C 382.69284,326.60712 397.8221,314.14884 416.48849,314.14884 C 435.15489,314.14884 450.28415,326.60712 450.27399,341.96973 z"
+       transform="matrix(1.7780927,0,0,1.9037854,-1140.3443,-78.37891)"
+       id="path10113"
+       style="fill:url(#linearGradient11090);fill-opacity:1;stroke:none;stroke-opacity:1" />
+    <path
+       d="M -376.71114,604.30118 C -376.71114,604.30118 -363.86359,603.34948 -358.15356,600.97028 C -352.44354,598.59108 -344.35433,592.88108 -344.35433,592.88108 C -344.35433,592.88108 -331.98261,570.04098 -350.06435,543.39418 C -368.14609,516.74738 -413.35048,521.98158 -413.35048,521.98158 L -419.06051,525.31248 L -376.71114,604.30118 z"
+       id="path13048"
+       style="fill:url(#linearGradient2388);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M -416.2055,525.31248 L -416.2055,525.31248 C -416.2055,525.31248 -389.5587,530.07078 -373.85611,560.52428 C -358.15356,590.97778 -374.80779,604.77698 -374.80779,604.77698 C -374.80779,604.77698 -406.21295,610.96288 -425.24637,600.97028 C -444.2798,590.97778 -453.32067,557.66928 -453.32067,557.66928 C -453.32067,557.66928 -452.369,546.72508 -438.09393,537.20828 C -423.81887,527.69158 -415.72965,525.78828 -416.2055,525.31248 z"
+       id="path12067"
+       style="fill:url(#linearGradient2385);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M -559.43201,515.79568 C -559.43201,515.79568 -564.19037,558.62088 -544.68111,584.31608 C -525.17185,610.01118 -491.38752,620.47958 -491.38752,620.47958 C -491.38752,620.47958 -481.39497,572.89598 -499.95256,548.62838 C -518.51016,524.36078 -559.43201,515.79568 -559.43201,515.79568 z"
+       id="path7165"
+       style="fill:url(#linearGradient2382);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M -512.03071,626.71548 C -512.75895,626.89758 -514.39748,631.81318 -514.39748,631.81318 C -514.39748,631.81318 -515.12572,634.36198 -514.7616,636.18258 C -514.39748,638.00308 -514.7616,639.64168 -513.8513,641.09818 C -512.94101,642.55458 -470.70338,689.34368 -470.70338,689.34368 C -470.70338,689.34368 -467.97249,693.71308 -463.0569,693.16698 C -458.14132,692.62078 -456.5028,692.07458 -455.04632,691.16428 C -453.58985,690.25398 -418.08839,654.57048 -418.08839,654.57048 L -405.52633,638.54928 C -405.52633,638.54928 -404.61605,634.72608 -404.98016,631.26698 C -405.34428,627.80788 -410.9881,622.16398 -410.9881,622.16398 C -410.9881,622.16398 -416.44985,618.52288 -417.90633,617.97668 C -419.3628,617.43048 -441.02779,608.14548 -454.86426,607.78138 C -468.70073,607.41728 -490.54778,613.06108 -490.54778,613.06108 L -512.03071,626.71548 z"
+       id="path3205"
+       style="fill:url(#linearGradient2379);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M -669.56538,984.66768 C -683.40645,979.73268 -688.77198,970.59168 -687.7895,953.62018 C -686.37551,929.19428 -670.84023,911.38798 -637.60035,896.09428 C -617.27743,886.74368 -604.83729,884.60898 -575.98218,885.52058 C -555.58301,886.16498 -550.04081,886.92008 -538.5141,890.62478 C -512.83469,898.87818 -491.37143,914.38018 -482.14005,931.34128 C -477.31653,940.20368 -475.14059,954.86448 -477.09923,965.30488 C -478.48421,972.68758 -485.02605,980.33438 -493.09067,983.99768 C -499.06753,986.71258 -505.32016,986.91678 -581.48444,986.88438 C -646.80179,986.85648 -664.68901,986.40638 -669.56538,984.66768 z M -580.85052,966.13288 C -546.40331,964.41088 -545.58588,964.29008 -541.32746,960.29198 C -526.51329,946.38328 -531.4386,921.82988 -551.83579,907.90628 C -564.65604,899.15498 -578.58303,895.80098 -598.65526,896.63098 C -626.11603,897.76658 -644.91493,907.49348 -653.69298,925.10878 C -660.69629,939.16258 -658.02291,954.17068 -646.84005,963.58048 C -640.72929,968.72228 -636.17497,968.89848 -580.85052,966.13288 z M -426.31376,985.07918 C -428.93973,984.16688 -433.70179,980.92568 -436.89615,977.87648 C -458.29071,957.45428 -440.03308,916.58618 -401.22782,898.03628 C -381.3531,888.53558 -363.62042,884.73358 -339.61965,884.82688 C -315.10858,884.92218 -306.359,886.58788 -287.18578,894.80888 C -268.3667,902.87808 -257.49101,910.06238 -247.42947,921.07138 C -234.56237,935.15008 -229.29765,956.07588 -235.11809,970.00598 C -237.88577,976.63008 -245.7016,983.22058 -253.28819,985.32758 C -261.35851,987.56898 -419.80184,987.34148 -426.31376,985.07918 z M -261.48975,963.58048 C -240.26459,945.72068 -251.64751,913.26948 -283.47384,900.90658 C -296.30079,895.92408 -321.68737,894.83608 -335.82556,898.66318 C -370.01024,907.91658 -386.32855,939.06918 -367.66097,959.43898 L -362.51481,965.05438 L -339.50773,966.22768 C -326.85383,966.87288 -305.27589,967.51118 -291.55676,967.64608 L -266.6128,967.89118 L -261.48975,963.58048 z M -467.94882,693.69998 C -469.84038,692.63678 -481.47119,680.30818 -493.79505,666.30308 C -514.2161,643.09608 -516.20347,640.30088 -516.21763,634.76648 C -516.22618,631.42648 -515.49005,627.30518 -514.58176,625.60798 C -512.52875,621.77198 -498.58903,614.67648 -482.63569,609.34728 C -462.06467,602.47548 -441.82561,605.47378 -414.14572,619.49358 C -410.95459,621.10978 -407.19468,623.58128 -405.79038,624.98558 C -402.67635,628.09958 -402.47335,635.20758 -405.38475,639.18918 C -407.33359,641.85438 -407.46706,641.68098 -406.82652,637.31668 C -405.83715,630.57558 -410.19347,623.11088 -417.19547,619.54888 C -433.27476,611.36938 -457.33434,606.98378 -471.27455,609.69148 C -482.88205,611.94598 -497.931,618.15108 -497.931,620.68268 C -497.931,621.84348 -493.28566,624.41538 -487.58628,626.41008 C -467.02935,633.60488 -449.83251,644.51658 -438.87447,657.31858 C -435.7686,660.94708 -432.41515,663.91588 -431.42235,663.91588 C -430.42952,663.91588 -426.45185,660.87208 -422.58307,657.15198 C -411.83438,646.81638 -417.21996,654.81738 -433.75311,673.74668 C -451.99605,694.63358 -459.00802,698.72508 -467.94882,693.69998 z M -455.40193,688.03728 C -453.63949,686.32548 -509.08509,629.82328 -511.22783,631.14748 C -512.23013,631.76698 -513.05019,634.36978 -513.05019,636.93148 C -513.05019,640.68208 -508.84629,646.22398 -491.46477,665.38708 C -479.5928,678.47588 -468.67117,689.51738 -467.19448,689.92368 C -464.07562,690.78168 -457.07446,689.66178 -455.40193,688.03728 z"
+       id="path2227"
+       style="fill:#cda809" />
+    <path
+       d="M -668.33584,670.32038 C -668.33584,670.32038 -695.05416,695.22728 -702.75266,702.02008 C -710.45117,708.81288 -721.09322,715.83208 -733.54666,728.05918 C -746.00012,740.28618 -757.09503,754.32458 -757.77429,755.68318 C -758.45358,757.04178 -762.30283,762.70238 -762.07641,766.09878 C -761.84998,769.49518 -762.98211,774.02368 -760.49142,773.11798 C -758.00073,772.21228 -708.1869,725.56848 -704.79051,721.71918 C -701.3941,717.86998 -677.16647,693.41588 -672.18509,688.20808 C -667.20371,683.00028 -664.26017,677.11318 -664.26017,677.11318 L -662.67518,671.90538 L -662.44876,670.32038 L -668.33584,670.32038 z"
+       id="path6164"
+       style="fill:url(#linearGradient2375);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M -483.28817,976.96358 C -477.3233,970.14688 -475.73183,963.39968 -476.83811,949.61768 C -477.38599,942.79238 -479.07335,936.97578 -482.14005,931.34128 C -487.39901,921.67878 -501.25897,908.31868 -513.3121,901.29348 C -517.98233,898.57138 -521.19197,896.32838 -520.44464,896.30908 C -517.5357,896.23388 -495.77339,908.63748 -484.41593,916.84388 C -477.84406,921.59238 -469.96049,926.36068 -466.89686,927.43998 C -459.71707,929.96948 -456.0321,928.45088 -438.24997,915.63428 C -430.80973,910.27168 -418.27671,903.07818 -410.39882,899.64878 C -390.49137,890.98268 -385.50323,889.98358 -401.25271,897.81688 C -439.87913,917.02838 -457.49576,955.51368 -437.66331,977.35948 L -432.67974,982.84888 L -438.846,978.32088 C -444.29747,974.31778 -446.69575,973.70858 -459.53542,973.06528 C -473.92366,972.34448 -474.12512,972.38618 -481.22031,977.56128 L -488.38203,982.78488 L -483.28817,976.96358 z M -638.55147,874.11948 C -660.86288,840.43878 -672.64742,806.20698 -675.14207,767.83058 C -675.72281,758.89688 -676.95349,750.83198 -677.87691,749.90858 C -681.00049,746.78498 -698.1324,753.89158 -725.51466,769.66938 C -752.16097,785.02318 -753.7051,785.64198 -759.0286,783.10068 C -762.92392,781.24118 -763.85352,779.66458 -764.56165,773.71638 C -765.59479,765.03838 -762.80147,758.59008 -752.35559,745.53938 C -740.23005,730.39008 -732.84454,723.21998 -712.78271,707.12068 C -655.60799,661.23898 -641.20508,634.77968 -637.1853,568.24258 C -635.54001,541.00908 -634.49961,534.59508 -628.95419,517.49838 C -611.33869,463.18918 -562.63069,417.87338 -505.90016,403.01428 C -443.42455,386.65038 -377.95879,405.18008 -332.82452,452.00228 C -300.20408,485.84268 -286.76656,518.20138 -283.81658,570.01768 C -280.11229,635.08258 -265.42883,661.55138 -207.15066,708.21788 C -176.62046,732.66508 -156.44201,757.51738 -156.11813,771.07078 C -155.92727,779.05838 -157.96781,782.48838 -163.77786,783.94668 C -168.22892,785.06378 -173.61722,782.56678 -202.6551,765.93058 C -224.66597,753.32028 -240.20376,747.29358 -243.54818,750.06918 C -244.90275,751.19338 -245.68152,755.39098 -245.68557,761.58968 C -245.69406,774.53038 -249.39536,796.76078 -254.47152,814.35948 C -261.17291,837.59258 -272.32483,859.24798 -293.6195,890.37908 C -294.19802,891.22478 -296.00721,891.08068 -297.96511,890.03288 C -301.28223,888.25768 -301.26007,888.15398 -295.97676,880.71748 C -293.03825,876.58138 -289.45293,870.86978 -288.00939,868.02498 C -285.65611,863.38728 -285.6424,862.85258 -287.87664,862.85258 C -289.77223,862.85258 -290.33045,861.23398 -290.20939,856.08878 C -290.12186,852.36868 -290.30473,832.85298 -290.61573,812.72058 C -291.09797,781.50418 -291.72024,773.78688 -294.8432,760.29138 C -306.34767,710.57658 -328.91914,670.85668 -359.48768,646.53368 C -375.68868,633.64288 -382.0479,631.13408 -393.65638,633.05398 L -402.97474,634.59508 L -403.62602,630.15748 C -404.23472,626.01018 -403.90508,625.71878 -398.58485,625.70108 C -384.37569,625.65388 -364.0327,616.74648 -354.80353,606.53088 C -347.18485,598.09798 -342.17573,584.22538 -342.19402,571.60918 C -342.23069,546.31928 -364.3965,525.20088 -393.46158,522.76418 C -402.49485,522.00688 -406.80037,522.50768 -415.61158,525.34088 C -427.81241,529.26398 -440.2358,537.81488 -445.89345,546.18368 L -449.63316,551.71548 L -456.23533,572.68468 C -453.32379,573.22598 -439.94093,553.77798 -441.03508,553.89328 C -444.17254,554.22368 -443.34875,559.24788 -439.33462,564.26438 C -436.12416,568.27658 -435.22153,568.62088 -432.18079,566.99358 C -427.86558,564.68408 -427.85129,563.65278 -432.05469,557.89818 C -434.55886,554.46998 -433.98474,554.77948 -429.78823,559.11988 C -417.12863,572.21378 -435.41085,585.36698 -438.28323,602.04558 C -438.37803,602.59608 -448.83262,597.00608 -448.29796,597.87118 C -447.66631,598.89318 -447.24595,606.66178 -455.9258,605.92758 C -463.27287,605.30618 -460.30971,582.44308 -463.29886,582.45498 C -477.06194,582.50968 -496.24301,594.07688 -496.30261,574.79218 C -496.33282,565.01658 -495.66783,561.77568 -492.62884,556.88788 C -489.16638,551.31898 -484.4033,548.82198 -484.4033,552.57568 C -484.4033,553.48648 -482.79433,556.53018 -480.82781,559.33958 C -478.8613,562.14888 -477.10421,564.71248 -476.9232,565.03648 C -475.97081,566.74078 -468.48835,563.21678 -468.48835,561.06388 C -468.48835,559.37398 -467.62236,558.86898 -465.87464,559.53968 C -461.27725,561.30388 -464.23252,544.15358 -470.82414,530.81638 C -487.19465,497.69288 -520.10153,486.17388 -547.26732,504.05748 C -564.45906,515.37498 -578.24618,544.37638 -578.24618,569.22198 C -578.24618,580.99048 -574.18239,598.16728 -568.80913,609.11038 C -561.94274,623.09438 -546.59542,637.40168 -534.77542,640.83788 C -529.80283,642.28338 -523.24592,643.25178 -520.2045,642.98978 C -514.88673,642.53158 -513.84484,643.45778 -493.03667,667.14018 C -481.13578,680.68488 -469.58975,692.72688 -467.3788,693.90018 C -460.5811,697.50738 -453.6957,694.99888 -445.00451,685.74878 C -440.71266,681.18088 -433.84301,673.86268 -429.73859,669.48608 C -423.37699,662.70258 -422.51536,662.19008 -423.89835,666.01238 C -431.12582,685.98728 -446.72794,700.52018 -460.94486,700.52018 C -470.50928,700.52018 -477.95975,694.87228 -494.52341,675.06568 C -508.16712,658.75078 -514.93038,652.69018 -522.94664,649.59558 C -525.81915,648.48668 -532.99389,645.42408 -538.89049,642.78998 L -549.6116,638.00048 L -555.60117,641.98098 C -581.85023,659.42508 -605.71328,694.72998 -619.58368,736.64188 C -628.47876,763.51998 -631.18269,781.95678 -630.74137,812.72058 C -630.22764,848.53248 -631.19406,862.85258 -634.1246,862.85258 C -636.32939,862.85258 -632.73717,870.77338 -626.75788,879.09618 C -620.44364,887.88508 -620.1446,889.24198 -624.28341,890.32428 C -626.67713,890.95028 -629.60452,887.62548 -638.55147,874.11948 z M -275.91758,859.66958 C -274.98063,857.91898 -274.57218,856.48658 -275.00984,856.48658 C -275.4475,856.48658 -276.57215,857.91898 -277.50906,859.66958 C -278.44596,861.42028 -278.85446,862.85258 -278.4168,862.85258 C -277.97914,862.85258 -276.85448,861.42028 -275.91758,859.66958 z M -257.65865,819.03338 C -252.59771,804.24058 -248.85195,784.11268 -247.81509,766.13828 C -246.46279,742.69668 -245.97737,742.06108 -232.81021,746.49388 C -227.19598,748.38388 -218.30546,752.28808 -213.05355,755.16988 C -189.23429,768.23988 -173.64354,777.74188 -172.91871,779.63088 C -171.99317,782.04268 -161.97018,782.41828 -160.53422,780.09488 C -159.99328,779.21958 -160.49574,778.50338 -161.65085,778.50338 C -162.806,778.50338 -168.75668,772.65988 -174.87463,765.51768 C -180.99254,758.37548 -193.87605,745.57758 -203.50459,737.07788 C -213.13313,728.57818 -228.53081,713.83178 -237.72169,704.30818 C -252.75448,688.73118 -254.8746,685.79398 -258.83641,675.05628 C -261.25863,668.49138 -263.22808,661.16138 -263.213,658.76738 C -263.19793,656.37338 -265.2657,651.00208 -267.80802,646.83118 C -277.19249,631.43508 -283.5202,604.23388 -285.49176,570.81338 C -287.51757,536.47258 -291.73311,518.99378 -303.7877,494.95268 C -325.47764,451.69548 -366.54957,418.36868 -414.37755,405.21738 C -433.12461,400.06248 -469.2845,398.14378 -488.79079,401.26898 C -545.90507,410.41938 -596.80553,448.92608 -620.66604,501.03408 C -629.61721,520.58208 -633.93413,540.10248 -635.57627,568.45528 C -637.64991,604.25848 -643.64403,629.48478 -654.64759,648.71698 C -657.32362,653.39418 -659.07326,658.31728 -658.54694,659.68888 C -657.55431,662.27558 -662.02941,675.67048 -667.2947,685.87248 C -670.35538,691.80288 -700.1077,721.72248 -724.1144,743.01168 C -731.22031,749.31318 -741.58227,759.87668 -747.14098,766.48618 C -752.6997,773.09568 -758.20701,778.50338 -759.37943,778.50338 C -760.55187,778.50338 -761.06851,779.21958 -760.52753,780.09488 C -758.92786,782.68328 -751.44142,781.91318 -747.89815,778.79578 C -743.8544,775.23798 -717.77174,759.89378 -704.82524,753.45618 C -690.67848,746.42178 -678.65313,742.76638 -676.55638,744.86318 C -675.60855,745.81098 -674.24297,755.33748 -673.52177,766.03328 C -672.01778,788.33818 -666.60019,812.74578 -659.28535,830.17188 C -654.03426,842.68158 -651.14926,846.19388 -655.75417,834.47098 C -657.19422,830.80498 -657.943,827.37608 -657.41813,826.85118 C -656.89327,826.32638 -651.72764,829.91488 -645.93897,834.82578 C -640.15029,839.73668 -634.91772,843.75478 -634.31105,843.75478 C -633.70437,843.75488 -633.19466,829.96848 -633.17835,813.11848 C -633.15629,790.34538 -632.42484,778.80588 -630.32846,768.15868 C -619.96175,715.50778 -596.34992,672.95368 -560.83959,642.92338 L -552.13097,635.55868 L -559.51208,627.66768 C -586.83805,598.45398 -588.17526,547.13028 -562.45808,514.59568 C -554.43566,504.44658 -543.2039,497.47268 -528.80974,493.70328 L -517.02892,490.61818 L -524.9864,490.55408 C -535.77556,490.46718 -550.01157,494.01608 -562.42529,499.88718 C -575.58319,506.11028 -576.90197,503.60978 -565.8309,493.42988 C -553.6546,482.23378 -543.13997,478.61928 -522.56569,478.55728 C -506.84033,478.50988 -505.18229,478.82148 -495.3152,483.67898 C -484.88668,488.81298 -469.2742,503.17168 -472.83125,504.35728 C -473.80539,504.68198 -478.06092,503.21428 -482.28798,501.09558 C -490.12026,497.16998 -497.34612,494.67458 -505.88847,492.94538 C -508.81185,492.35358 -506.65224,493.94758 -500.31824,497.05678 C -481.10738,506.48678 -466.20656,526.57908 -461.57124,549.30328 C -460.51806,554.46638 -459.23261,559.11448 -458.71469,559.63248 C -458.19675,560.15038 -455.87225,556.68918 -453.54913,551.94088 C -442.55001,529.45948 -413.84968,515.70448 -387.91226,520.48368 C -367.81165,524.18738 -351.18234,536.01278 -343.19077,552.28598 C -337.3614,564.15638 -336.95715,582.64818 -342.27368,594.23578 C -347.38666,605.37978 -359.13831,617.06138 -370.8675,622.65918 C -376.41628,625.30738 -380.95619,627.69418 -380.95619,627.96318 C -380.95619,628.23218 -376.83818,631.17518 -371.80508,634.50308 C -341.52433,654.52508 -315.0565,690.84998 -300.774,731.98758 C -290.96271,760.24678 -287.92951,779.63458 -287.95671,813.91418 C -287.96974,830.32638 -287.46042,843.75468 -286.82493,843.75468 C -286.18941,843.75468 -281.15297,839.81568 -275.63286,835.00148 C -261.30737,822.50778 -260.31085,823.16098 -267.9601,840.03098 C -270.58605,845.82248 -272.67288,850.99898 -272.59747,851.53438 C -272.36608,853.17738 -260.53084,827.42848 -257.65865,819.03338 z M -340.6578,519.30658 C -348.87394,511.87128 -364.33033,503.50078 -375.17648,500.61278 C -387.41719,497.35348 -407.35289,497.80898 -419.72603,501.63068 C -425.47807,503.40728 -434.95858,508.06238 -440.79384,511.97538 C -446.6291,515.88838 -451.90412,519.08988 -452.51612,519.08988 C -453.12813,519.08988 -455.90931,515.57048 -458.69655,511.26908 C -474.0853,487.52018 -504.82912,472.13988 -530.50086,475.34738 C -548.54194,477.60148 -571.1935,489.78888 -580.83444,502.42878 C -586.18684,509.44618 -587.85041,509.39458 -587.85041,502.21108 C -587.85041,483.95588 -576.44932,460.14428 -558.97431,441.90238 C -531.81489,413.55108 -494.66625,399.84248 -450.18617,401.75748 C -384.64624,404.57928 -332.29486,448.76978 -328.82123,504.20328 C -327.93251,518.38598 -329.0147,525.49168 -332.04806,525.39058 C -333.12552,525.35468 -336.99991,522.61688 -340.6578,519.30658 z M -427.90526,500.67338 C -417.5692,496.45408 -415.21345,496.12338 -395.27963,496.09288 C -374.71712,496.06138 -373.24767,496.28078 -361.06249,501.20158 C -352.94949,504.47798 -345.58807,506.34588 -340.77094,506.35058 L -333.21135,506.35788 L -333.21135,498.56808 C -333.21135,466.78578 -362.99357,429.99008 -401.60537,414.06788 C -420.90637,406.10878 -434.89091,403.68838 -460.53088,403.86958 C -487.84301,404.06248 -501.05343,407.02018 -523.3949,417.94428 C -555.1969,433.49428 -577.48583,460.56738 -583.06285,490.41968 C -583.80086,494.37008 -584.18999,497.81688 -583.92759,498.07928 C -583.6652,498.34168 -578.89014,495.11258 -573.31638,490.90338 C -556.79023,478.42348 -545.24308,474.01218 -527.06325,473.23388 C -514.60301,472.70048 -509.54949,473.21198 -500.80359,475.89168 C -488.17571,479.76088 -473.84185,488.76568 -463.71387,499.19228 C -456.64288,506.47178 -456.44125,506.55668 -447.79893,505.89318 C -442.98466,505.52348 -434.03251,503.17458 -427.90526,500.67338 z M -439.49095,517.24258 C -438.43327,514.06958 -423.58015,506.61108 -412.83923,503.85938 C -392.39271,498.62118 -364.56123,503.29648 -353.12607,513.89038 L -348.37261,518.29408 L -352.57308,518.78278 C -354.88333,519.05148 -362.65181,518.15628 -369.83643,516.79338 C -386.349,513.66098 -408.89177,513.62378 -424.98014,516.70238 C -439.96978,519.57068 -440.27072,519.58188 -439.49095,517.24258 z M -354.41265,516.05918 C -357.26919,514.75118 -368.73098,504.89318 -394.04665,504.19298 C -412.70973,503.68168 -425.62558,511.70378 -428.48216,513.01168 C -432.79089,514.98468 -414.51369,510.89568 -393.68812,510.89568 C -372.86258,510.89568 -350.10389,518.03208 -354.41265,516.05918 z M -666.52437,676.32898 C -662.37379,668.51318 -664.11642,669.43738 -676.57621,681.66018 C -683.35996,688.31478 -697.50436,700.55118 -708.00822,708.85208 C -737.53593,732.18698 -759.66703,757.56548 -759.71686,768.14818 C -759.73365,771.71468 -670.47844,683.77468 -666.52437,676.32898 z M -161.33,768.10758 C -161.33,765.03798 -167.04324,754.77528 -173.05942,747.03778 C -182.568,734.80888 -197.28691,720.86508 -214.64503,707.64218 C -222.52293,701.64108 -235.23501,690.65038 -242.89406,683.21838 C -256.61463,669.90478 -258.53287,668.69708 -255.06046,675.55878 C -253.08984,679.45298 -164.42134,768.95448 -162.53408,768.95448 C -161.87182,768.95448 -161.33,768.57338 -161.33,768.10758 z M -451.56996,600.65398 C -452.81366,598.24678 -454.67463,593.14248 -455.70543,589.31108 C -456.86585,584.99778 -458.14539,582.91058 -459.06524,583.83038 C -460.97419,585.73938 -465.27125,602.20668 -464.27925,603.81178 C -463.86497,604.48208 -460.32713,605.03058 -456.41735,605.03058 L -449.30869,605.03058 L -451.56996,600.65398 z M -466.854,590.30918 C -463.74815,583.46688 -462.73043,570.84648 -464.99686,567.27938 C -465.96171,565.76078 -467.58076,565.75098 -472.41441,567.23448 C -476.47606,568.48108 -478.78212,568.57898 -479.13513,567.51998 C -480.60665,563.10548 -485.70523,554.99498 -487.35448,554.44528 C -490.05585,553.54478 -493.95226,563.97988 -493.95226,572.11498 C -493.95226,583.33238 -482.15663,596.70448 -471.99141,597.01078 C -470.85446,597.04508 -468.54263,594.02938 -466.854,590.30918 z M -428.5081,591.93818 C -425.58734,586.48068 -424.02879,577.86168 -425.04442,572.78358 C -425.97668,568.12218 -427.54122,567.84038 -435.50994,570.89828 C -437.07151,571.49748 -439.2422,569.39998 -442.09086,564.53908 C -444.42877,560.54978 -447.06414,557.28568 -447.94723,557.28568 C -450.45725,557.28568 -454.16491,567.65628 -454.16491,574.67688 C -454.16491,580.06538 -453.17785,581.94568 -447.66332,587.06208 C -437.69231,596.31328 -431.67004,597.84628 -428.5081,591.93818 z M -479.02704,499.50948 C -487.02923,493.65818 -497.16105,479.45648 -529.45413,481.05288 C -546.01285,481.86248 -564.51585,495.68618 -565.15803,495.94678 C -567.49419,496.89488 -538.44496,488.06978 -523.1709,488.08698 C -500.10921,488.11288 -476.69531,501.21448 -479.02704,499.50948 z M -386.89112,890.53798 C -386.36226,890.00908 -384.98963,889.95258 -383.84077,890.41238 C -382.57119,890.92038 -382.94829,891.29748 -384.80229,891.37388 C -386.47998,891.44298 -387.41995,891.06678 -386.89112,890.53798 z"
+       id="path2225"
+       style="fill:#636363" />
+    <path
+       d="M -594.30785,507.38658 L -590.75869,512.96388 L -582.13934,513.97788 C -582.13934,513.97788 -566.42166,506.87958 -563.37954,505.35858 C -560.33741,503.83748 -530.93016,494.20408 -530.93016,494.20408 L -516.73356,492.68298 L -479.72099,504.34448 L -452.34184,527.66748 L -432.06098,523.10428 L -400.62566,518.03408 L -366.65521,519.55508 L -334.71287,528.68148 C -334.71287,528.68148 -322.03735,528.68148 -321.5303,526.65338 C -321.02329,524.62538 -317.47414,501.30238 -318.99521,495.72508 C -320.51628,490.14788 -328.12158,467.83898 -332.17774,463.27578 C -336.23394,458.71258 -355.50075,439.95278 -357.52883,437.92468 C -359.55691,435.89658 -380.85181,420.68598 -384.40095,418.65788 C -387.9501,416.62978 -412.28714,407.50338 -412.28714,407.50338 L -462.48226,400.91208 L -484.79121,401.92618 L -515.2125,409.02448 L -559.32338,436.40358 L -580.61827,462.26168 L -590.75869,482.03558 L -594.30785,507.38658 z"
+       id="path14027"
+       style="fill:url(#linearGradient2371);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M -575.25208,506.68538 L -575.43135,502.56238 L -571.30838,495.92978 L -561.9869,488.22168 C -561.9869,488.22168 -552.48618,483.02318 -551.76913,482.84388 C -551.05209,482.66458 -541.19283,477.82468 -537.42839,477.82468 C -533.66395,477.82468 -520.21952,477.28688 -520.21952,477.28688 C -520.21952,477.28688 -509.64323,477.46608 -508.74693,477.64538 C -507.85063,477.82468 -501.03879,480.15498 -501.03879,480.15498 L -486.87732,486.07058 L -470.56473,499.69428 C -470.56473,499.69428 -468.23437,503.81718 -468.59288,504.71348 C -468.9514,505.60978 -470.38548,507.22308 -470.38548,507.22308 C -470.38548,507.22308 -476.12177,506.14758 -477.91436,505.43058 C -479.70696,504.71348 -485.26399,502.92088 -485.98102,502.56238 C -486.69805,502.20388 -494.22694,498.26018 -495.66102,498.08088 C -497.0951,497.90168 -506.23731,495.03348 -506.23731,495.03348 L -513.76619,493.42018 L -520.57804,492.16538 L -529.36173,492.52388 L -557.14691,499.69428 L -567.36469,504.35498 L -573.10097,506.32678 L -575.25208,506.68538 z"
+       id="path15977"
+       style="fill:url(#linearGradient2368);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M -444.93068,524.07348 C -444.93068,524.07348 -432.74106,522.81868 -429.15587,521.56388 C -425.57069,520.30908 -407.82404,518.15798 -406.56922,517.97868 C -405.31441,517.79938 -387.02998,516.90308 -381.83143,517.97868 C -376.63293,519.05428 -357.27294,522.10168 -355.83887,522.10168 C -354.40481,522.10168 -346.69666,521.74308 -346.69666,521.74308 C -346.69666,521.74308 -344.72479,518.15798 -345.6211,517.08238 C -346.5174,516.00678 -348.48927,514.93128 -349.74407,514.21428 C -350.99887,513.49718 -359.42404,508.83648 -360.85815,507.76088 C -362.29222,506.68538 -377.52923,501.48688 -378.42553,501.48688 C -379.32184,501.48688 -394.91739,500.59058 -399.04033,500.59058 C -403.1633,500.59058 -413.91884,501.84538 -415.53217,502.56238 C -417.14551,503.27948 -426.8255,506.86458 -428.43883,507.58168 C -430.05216,508.29868 -434.89217,510.27058 -436.68475,512.06308 C -438.47734,513.85568 -440.62845,516.54458 -440.98697,517.26168 C -441.34549,517.97868 -444.39289,524.07348 -444.93068,524.07348 z"
+       id="path16956"
+       style="fill:url(#linearGradient2365);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M -459.49123,581.16898 L -464.43864,593.53758 L -469.38605,606.45578 C -469.38605,606.45578 -464.43864,605.63118 -458.94152,605.90608 C -453.44439,606.18088 -444.92385,607.55518 -444.92385,607.55518 L -447.67241,603.70718 L -449.87126,599.85928 C -449.87126,599.85928 -452.34497,596.56098 -453.44439,593.26268 C -454.54381,589.96438 -455.9181,585.29188 -455.9181,585.29188 L -457.84209,581.71868 L -459.49123,581.16898 z"
+       id="path9083"
+       style="fill:#636363;fill-rule:evenodd;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M -277.50906,859.66958 C -276.57215,857.91898 -275.4475,856.48658 -275.00984,856.48658 C -274.57218,856.48658 -274.98063,857.91898 -275.91758,859.66958 C -276.85448,861.42028 -277.97914,862.85258 -278.4168,862.85258 C -278.85446,862.85258 -278.44596,861.42028 -277.50906,859.66958 z M -272.59747,851.53438 C -272.67288,850.99898 -270.58605,845.82248 -267.9601,840.03098 C -260.31085,823.16098 -261.30737,822.50778 -275.63286,835.00148 C -281.15297,839.81568 -286.18941,843.75468 -286.82493,843.75468 C -287.46042,843.75468 -287.96974,830.32638 -287.95671,813.91418 C -287.92951,779.63458 -290.96271,760.24678 -300.774,731.98758 C -315.0565,690.84998 -341.52433,654.52508 -371.80508,634.50308 C -376.83818,631.17518 -380.95619,628.23218 -380.95619,627.96318 C -380.95619,627.69418 -376.41628,625.30738 -370.8675,622.65918 C -359.13831,617.06138 -347.38666,605.37978 -342.27368,594.23578 C -336.95715,582.64818 -337.3614,564.15638 -343.19077,552.28598 C -351.18234,536.01278 -367.81165,524.18738 -387.91226,520.48368 C -413.84968,515.70448 -442.55001,529.45948 -453.54913,551.94088 C -455.87225,556.68918 -458.19675,560.15038 -458.71469,559.63248 C -459.23261,559.11448 -460.51806,554.46638 -461.57124,549.30328 C -466.20656,526.57908 -481.10738,506.48678 -500.31824,497.05678 C -506.65224,493.94758 -514.36889,491.81578 -511.4455,492.40758 C -502.90316,494.13678 -490.12026,497.16998 -482.28798,501.09558 C -478.06092,503.21428 -473.80539,504.68198 -472.83125,504.35728 C -469.2742,503.17168 -484.88668,488.81298 -495.3152,483.67898 C -505.18229,478.82148 -506.84033,478.50988 -522.56569,478.55728 C -543.13997,478.61928 -553.6546,482.23378 -565.8309,493.42988 C -576.90197,503.60978 -575.58319,506.11028 -562.42529,499.88718 C -550.01157,494.01608 -535.77556,490.46718 -524.9864,490.55408 L -510.93411,492.41078 L -528.80974,493.70328 C -543.2039,497.47268 -554.43566,504.44658 -562.45808,514.59568 C -588.17526,547.13028 -586.83805,598.45398 -559.51208,627.66768 L -552.13097,635.55868 L -560.83959,642.92338 C -596.34992,672.95368 -619.96175,715.50778 -630.32846,768.15868 C -632.42484,778.80588 -633.15629,790.34538 -633.17835,813.11848 C -633.19466,829.96848 -633.70437,843.75488 -634.31105,843.75478 C -634.91772,843.75478 -640.15029,839.73668 -645.93897,834.82578 C -651.72764,829.91488 -656.89327,826.32638 -657.41813,826.85118 C -657.943,827.37608 -657.19422,830.80498 -655.75417,834.47098 C -651.14926,846.19388 -654.03426,842.68158 -659.28535,830.17188 C -666.60019,812.74578 -672.01778,788.33818 -673.52177,766.03328 C -674.24297,755.33748 -675.60855,745.81098 -676.55638,744.86318 C -678.65313,742.76638 -690.67848,746.42178 -704.82524,753.45618 C -717.77174,759.89378 -743.8544,775.23798 -747.89815,778.79578 C -751.44142,781.91318 -758.92786,782.68328 -760.52753,780.09488 C -761.06851,779.21958 -760.55187,778.50338 -759.37943,778.50338 C -758.20701,778.50338 -752.6997,773.09568 -747.14098,766.48618 C -741.58227,759.87668 -731.22031,749.31318 -724.1144,743.01168 C -700.1077,721.72248 -670.35538,691.80288 -667.2947,685.87248 C -662.02941,675.67048 -657.55431,662.27558 -658.54694,659.68888 C -659.07326,658.31728 -657.32362,653.39418 -654.64759,648.71698 C -643.64403,629.48478 -637.64991,604.25848 -635.57627,568.45528 C -633.93413,540.10248 -629.61721,520.58208 -620.66604,501.03408 C -596.80553,448.92608 -545.90507,410.41938 -488.79079,401.26898 C -469.2845,398.14378 -433.12461,400.06248 -414.37755,405.21738 C -366.54957,418.36868 -325.47764,451.69548 -303.7877,494.95268 C -291.73311,518.99378 -287.51757,536.47258 -285.49176,570.81338 C -283.5202,604.23388 -277.19249,631.43508 -267.80802,646.83118 C -265.2657,651.00208 -263.19793,656.37338 -263.213,658.76738 C -263.22808,661.16138 -261.25863,668.49138 -258.83641,675.05628 C -254.8746,685.79398 -252.75448,688.73118 -237.72169,704.30818 C -228.53081,713.83178 -213.13313,728.57818 -203.50459,737.07788 C -193.87605,745.57758 -180.99254,758.37548 -174.87463,765.51768 C -168.75668,772.65988 -162.806,778.50338 -161.65085,778.50338 C -160.49574,778.50338 -159.99328,779.21958 -160.53422,780.09488 C -161.97018,782.41828 -171.99317,782.04268 -172.91871,779.63088 C -173.64354,777.74188 -189.23429,768.23988 -213.05355,755.16988 C -218.30546,752.28808 -227.19598,748.38388 -232.81021,746.49388 C -245.97737,742.06108 -246.46279,742.69668 -247.81509,766.13828 C -248.85195,784.11268 -252.59771,804.24058 -257.65865,819.03338 C -260.53084,827.42848 -272.36608,853.17738 -272.59747,851.53438 z M -329.04891,521.31178 C -328.47686,519.03258 -328.37441,511.33368 -328.82123,504.20328 C -332.29486,448.76978 -384.64624,404.57928 -450.18617,401.75748 C -494.66625,399.84248 -531.81489,413.55108 -558.97431,441.90238 C -576.44932,460.14428 -587.85041,483.95588 -587.85041,502.21108 C -587.85041,509.39458 -586.18684,509.44618 -580.83444,502.42878 C -571.1935,489.78888 -548.54194,477.60148 -530.50086,475.34738 C -504.82912,472.13988 -474.0853,487.52018 -458.69655,511.26908 C -455.90931,515.57048 -453.12813,519.08988 -452.51612,519.08988 C -451.90412,519.08988 -446.6291,515.88838 -440.79384,511.97538 C -434.95858,508.06238 -425.47807,503.40728 -419.72603,501.63068 C -407.35289,497.80898 -387.41719,497.35348 -375.17648,500.61278 C -364.33033,503.50078 -348.87394,511.87128 -340.6578,519.30658 C -332.75312,526.46008 -330.44127,526.85938 -329.04891,521.31178 z M -424.98014,516.70238 C -408.89177,513.62378 -386.349,513.66098 -369.83643,516.79338 C -362.65181,518.15628 -354.88333,519.05148 -352.57308,518.78278 L -348.37261,518.29408 L -353.12607,513.89038 C -364.56123,503.29648 -392.39271,498.62118 -412.83923,503.85938 C -423.58015,506.61108 -438.43327,514.06958 -439.49095,517.24258 C -440.27072,519.58188 -439.96978,519.57068 -424.98014,516.70238 z M -765.53631,770.37148 C -764.75344,770.07228 -765.43688,770.30258 -765.44458,770.33438 C -765.58115,770.90028 -765.23192,769.23708 -765.61259,771.21668 C -765.99326,773.19638 -765.67875,770.99078 -765.53631,770.37148 z M -159.57611,773.52798 C -159.60853,770.90198 -157.96982,770.34878 -157.53386,771.42628 C -157.09794,772.50378 -156.71452,772.98688 -157.11802,774.53538 C -157.52155,776.08388 -159.54365,776.15398 -159.57611,773.52798 z M -466.94621,604.45168 C -467.93821,602.84658 -461.61525,584.71678 -459.06524,583.83038 C -456.41896,582.91058 -456.86585,584.99778 -455.70543,589.31108 C -454.67463,593.14248 -452.81366,598.24678 -451.56996,600.65398 L -447.00677,606.75698 L -456.41735,605.03058 C -460.32713,605.03058 -466.53193,605.12198 -466.94621,604.45168 z M -479.13655,594.74008 C -486.89769,591.36468 -493.95226,580.59168 -493.95226,572.11498 C -493.95226,563.97988 -490.05585,553.54478 -487.35448,554.44528 C -485.70523,554.99498 -480.60665,563.10548 -479.13513,567.51998 C -478.78212,568.57898 -476.47606,568.48108 -472.41441,567.23448 C -464.89668,564.92728 -463.75805,566.13278 -463.77319,576.38368 C -463.78509,584.43008 -468.83536,597.10588 -471.99141,597.01078 C -473.12835,596.97648 -476.34367,595.95468 -479.13655,594.74008 z M -438.51223,594.17608 C -439.96946,593.58118 -444.08746,590.37978 -447.66332,587.06208 C -453.17785,581.94568 -454.16491,580.06538 -454.16491,574.67688 C -454.16491,567.65628 -450.45725,557.28568 -447.94723,557.28568 C -447.06414,557.28568 -444.42877,560.54978 -442.09086,564.53908 C -439.2422,569.39998 -437.07151,571.49748 -435.50994,570.89828 C -427.54122,567.84038 -425.97668,568.12218 -425.04442,572.78358 C -424.02879,577.86168 -425.58734,586.48068 -428.5081,591.93818 C -430.40933,595.49058 -433.56411,596.19638 -438.51223,594.17608 z"
+       id="path2223"
+       style="fill:#070707" />
+    <path
+       d="M 373.43443,343.01617 C 373.43614,352.51307 369.15209,360.21346 363.86686,360.21346 C 358.58162,360.21346 354.29757,352.51307 354.29928,343.01617 C 354.29757,333.51927 358.58162,325.81888 363.86686,325.81888 C 369.15209,325.81888 373.43614,333.51927 373.43443,343.01617 L 373.43443,343.01617 z"
+       transform="matrix(1.7904309,0,0,1.5914941,-1130.4942,29.12901)"
+       id="path8144"
+       style="fill:url(#linearGradient10090);fill-opacity:1;stroke:#000000;stroke-opacity:1" />
+    <path
+       d="M -486.30029,551.98458 C -489.1561,556.52748 -490.97531,563.16348 -490.97531,570.53538 C -490.97531,584.22208 -484.74489,595.30308 -477.09947,595.30308 C -469.45403,595.30308 -463.27336,584.22208 -463.27336,570.53538 C -463.27336,568.05898 -463.44238,565.63078 -463.82044,563.37368 L -464.76539,563.87108 L -477.09947,568.59578 C -477.09947,568.59578 -478.54983,562.42738 -480.929,559.09658 C -481.87374,557.77398 -484.05699,554.90808 -486.30029,551.98458 z"
+       id="path10092"
+       style="fill:#000000;fill-opacity:1;stroke:#000000;stroke-width:1.48909414;stroke-opacity:1" />
+    <g
+       transform="matrix(1.4229651,0,0,1.376695,-956.36423,104.4242)"
+       id="g10107">
+      <path
+         d="M 373.43443,343.01617 C 373.43614,352.51307 369.15209,360.21346 363.86686,360.21346 C 358.58162,360.21346 354.29757,352.51307 354.29928,343.01617 C 354.29757,333.51927 358.58162,325.81888 363.86686,325.81888 C 369.15209,325.81888 373.43614,333.51927 373.43443,343.01617 L 373.43443,343.01617 z"
+         transform="matrix(1.125,0,0,1,-46.679302,0)"
+         id="path10103"
+         style="fill:url(#linearGradient2254);fill-opacity:1;stroke:#000000;stroke-opacity:1" />
+      <path
+         d="M 358.09375,328.53125 C 356.29933,331.38575 355.15625,335.55541 355.15625,340.1875 C 355.15625,348.78737 359.07107,355.74999 363.875,355.75 C 368.67894,355.75 372.5625,348.78738 372.5625,340.1875 C 372.5625,338.63145 372.4563,337.10572 372.21875,335.6875 L 371.625,336 L 363.875,338.96875 C 363.875,338.96875 362.96368,335.09292 361.46875,333 C 360.87513,332.16894 359.50331,330.3682 358.09375,328.53125 z"
+         id="path10105"
+         style="fill:#000000;fill-opacity:1;stroke:#000000;stroke-width:0.93565798;stroke-opacity:1" />
+    </g>
+    <path
+       d="M -518.60619,492.70318 L -508.20915,495.21278 L -498.34991,498.43948 L -494.76472,499.15648 L -501.21805,495.57128 L -509.64323,493.06168 L -512.51137,492.16538 L -517.35138,492.16538 L -518.60619,492.70318 z"
+       id="path15006"
+       style="fill:#000000;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M 327.25702,577.44623 C 327.25702,590.28094 310.87646,600.68553 290.67002,600.68553 C 270.46357,600.68553 254.08301,590.28094 254.08301,577.44623 C 254.08301,564.61152 270.46357,554.20693 290.67002,554.20693 C 310.87646,554.20693 327.25702,564.61152 327.25702,577.44623 z"
+       transform="matrix(1.7348179,0,0,1.8905525,-1099.5035,-152.19139)"
+       id="path22858"
+       style="fill:url(#linearGradient23835);fill-opacity:1;stroke:none;stroke-opacity:1" />
+    <path
+       d="M 327.25702,577.44623 C 327.25702,590.28094 310.87646,600.68553 290.67002,600.68553 C 270.46357,600.68553 254.08301,590.28094 254.08301,577.44623 C 254.08301,564.61152 270.46357,554.20693 290.67002,554.20693 C 310.87646,554.20693 327.25702,564.61152 327.25702,577.44623 z"
+       transform="matrix(1.7348179,0,0,1.8905525,-818.34631,-152.19139)"
+       id="path3201"
+       style="fill:url(#linearGradient3203);fill-opacity:1;stroke:none;stroke-opacity:1" />
+    <path
+       d="M -417.94981,653.09168 L -406.96886,639.58418 L -406.09429,639.87568 L -418.14416,654.64648 L -417.94981,653.09168 z"
+       id="path8112"
+       style="fill:#cda809;fill-rule:evenodd;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/gvfs-integration/cairo-dock-gio-vfs.c 3.4.1+git20201022.a0d3415c-1/gvfs-integration/cairo-dock-gio-vfs.c
--- 3.4.1-6/gvfs-integration/cairo-dock-gio-vfs.c	2015-02-19 16:01:14.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/gvfs-integration/cairo-dock-gio-vfs.c	2020-10-21 15:04:44.000000000 +0000
@@ -1566,6 +1566,14 @@ static GList *cairo_dock_gio_vfs_list_ap
 	return pList;
 }
 
+static void cairo_dock_gio_vfs_lock_screen (void) {
+	gchar *cResult = cairo_dock_launch_command_sync ("which xdg-screensaver");
+	if (cResult != NULL && *cResult == '/')
+		cairo_dock_launch_command ("xdg-screensaver lock");
+
+	g_free (cResult);
+}
+
 gboolean cairo_dock_gio_vfs_fill_backend(CairoDockDesktopEnvBackend *pVFSBackend)
 {
 	if(pVFSBackend)
@@ -1590,6 +1598,7 @@ gboolean cairo_dock_gio_vfs_fill_backend
 		pVFSBackend->empty_trash = cairo_dock_gio_vfs_empty_trash;
 		pVFSBackend->get_desktop_path = cairo_dock_gio_vfs_get_desktop_path;
 		pVFSBackend->list_apps_for_file = cairo_dock_gio_vfs_list_apps_for_file;
+		pVFSBackend->lock_screen = cairo_dock_gio_vfs_lock_screen;
 	}
 
 	return TRUE;
diff -pruN 3.4.1-6/Impulse/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/Impulse/data/misc/icon.svg
--- 3.4.1-6/Impulse/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Impulse/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,302 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   version="1.1"
+   width="48"
+   height="48"
+   id="svg2579">
+  <defs
+     id="defs2581">
+    <linearGradient
+       id="linearGradient6117">
+      <stop
+         id="stop6119"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6121"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6091">
+      <stop
+         id="stop6093"
+         style="stop-color:#888a85;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6095"
+         style="stop-color:#81837e;stop-opacity:0.98648649"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6105">
+      <stop
+         id="stop6107"
+         style="stop-color:white;stop-opacity:0"
+         offset="0" />
+      <stop
+         id="stop6113"
+         style="stop-color:white;stop-opacity:1"
+         offset="0.45209709" />
+      <stop
+         id="stop6109"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6041">
+      <stop
+         id="stop6043"
+         style="stop-color:#888a85;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6045"
+         style="stop-color:#2e3436;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6296">
+      <stop
+         id="stop6298"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6300"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6304">
+      <stop
+         id="stop6306"
+         style="stop-color:#eeeeec;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6308"
+         style="stop-color:#80827d;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="17.831682"
+       cy="18.914896"
+       r="19.736389"
+       fx="17.831682"
+       fy="18.914896"
+       id="radialGradient2609"
+       xlink:href="#linearGradient6304"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.4228001,0,0,0.3113668,9.6432324,19.361684)" />
+    <linearGradient
+       id="linearGradient3668-5">
+      <stop
+         id="stop3670-7"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3672-4"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient2372-9">
+      <stop
+         id="stop2374-9"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2376-4"
+         style="stop-color:white;stop-opacity:0.34482759"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient7067-5">
+      <stop
+         id="stop7069-9"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop7071-3"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="17.058823"
+       cy="41.058823"
+       r="5.7384715"
+       fx="14.68769"
+       fy="37.45607"
+       id="radialGradient3198"
+       xlink:href="#linearGradient7067-5"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.68315419,-0.12185712,0.02398557,0.64784268,16.764649,0.8299179)" />
+    <linearGradient
+       x1="28.503141"
+       y1="137.53885"
+       x2="26.256771"
+       y2="125.39074"
+       id="linearGradient3201"
+       xlink:href="#linearGradient2372-9"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.23013199,0,0,0.23039255,26.647505,-23.979015)" />
+    <radialGradient
+       cx="17.058823"
+       cy="41.058823"
+       r="5.7384715"
+       fx="14.757765"
+       fy="37.841019"
+       id="radialGradient3204"
+       xlink:href="#linearGradient3668-5"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.7193066,-0.11623586,0.01570024,0.6700801,29.013508,-2.1361776)" />
+    <linearGradient
+       x1="28.739122"
+       y1="144.11652"
+       x2="26.256771"
+       y2="125.39074"
+       id="linearGradient3207"
+       xlink:href="#linearGradient2372-9"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.31763863,0,0,0.23039255,37.291868,-25.882396)" />
+    <linearGradient
+       x1="34.825703"
+       y1="42.345951"
+       x2="28.763092"
+       y2="32.737347"
+       id="linearGradient4011"
+       xlink:href="#linearGradient6296"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-2.7545076,-0.1836338)" />
+    <radialGradient
+       cx="29.922518"
+       cy="32.704834"
+       r="19.736389"
+       fx="29.922518"
+       fy="32.704834"
+       id="radialGradient4016"
+       xlink:href="#linearGradient6041"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.94560281,0,0,0.8204423,-3.8927993,3.5285007)" />
+    <linearGradient
+       x1="15.551565"
+       y1="41"
+       x2="23.73423"
+       y2="41"
+       id="linearGradient4021"
+       xlink:href="#linearGradient6105"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-2.7545076,-0.1836338)" />
+    <linearGradient
+       x1="10.602306"
+       y1="35.894798"
+       x2="47.001671"
+       y2="35.690231"
+       id="linearGradient4025"
+       xlink:href="#linearGradient6091"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.5479662,0,0,0.3392172,6.4901656,29.075948)" />
+    <radialGradient
+       cx="26.927441"
+       cy="25.766438"
+       r="19.161766"
+       fx="26.927441"
+       fy="25.766438"
+       id="radialGradient4028"
+       xlink:href="#linearGradient6117"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.0959323,0,0,0.8089025,-8.2651612,11.473831)" />
+  </defs>
+  <path
+     d="m 42.245489,32.316367 a 20.999999,15.500001 0 0 1 -41.99999657,0 20.999999,15.500001 0 1 1 41.99999657,0 z"
+     id="path6115"
+     style="opacity:0.78165935;fill:url(#radialGradient4028);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.06208694;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  <path
+     d="m 31.745493,37.816367 a 10.5,6.5000007 0 0 1 -21,0 10.5,6.5000007 0 1 1 21,0 z"
+     id="path6051"
+     style="fill:url(#linearGradient4025);fill-opacity:1;fill-rule:evenodd;stroke:#2e3436;stroke-width:1;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  <path
+     d="m 30.745492,37.816365 a 9.4999995,5.4999999 0 0 1 -18.999999,0 9.4999995,5.4999999 0 1 1 18.999999,0 z"
+     id="path6099"
+     style="fill:none;stroke:white;stroke-width:1;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:0.35585584;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  <path
+     d="m 11.813706,39.816366 c 0,0 2.431786,4 9.431786,4 l 0,-6 -9.409006,0 -0.02278,2 z"
+     id="path6103"
+     style="opacity:0.56768559;fill:url(#linearGradient4021);fill-opacity:1;fill-rule:evenodd;stroke:none;display:inline" />
+  <path
+     d="m 40.745492,24.316367 a 19.5,17.000001 0 0 1 -39,0 19.5,17.000001 0 1 1 39,0 z"
+     id="path6216"
+     style="fill:#555753;fill-opacity:1;fill-rule:evenodd;stroke:#2e3436;stroke-width:1;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  <path
+     d="m 40.745492,23.316368 a 19.5,17.000001 0 0 1 -39,0 19.5,17.000001 0 1 1 39,0 z"
+     id="path6011"
+     style="fill:#555753;fill-opacity:1;fill-rule:evenodd;stroke:#2e3436;stroke-width:1;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  <path
+     d="m 39.120493,23.816367 a 17.6875,15.500001 0 0 1 -35.3750008,0 17.6875,15.500001 0 1 1 35.3750008,0 z"
+     id="path6013"
+     style="fill:url(#radialGradient4016);fill-opacity:1;fill-rule:evenodd;stroke:#2e3436;stroke-width:1;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  <path
+     d="m 22.739342,34.816366 a 1.000001,1.0000011 0 1 1 -2.000002,0 1.000001,1.0000011 0 1 1 2.000002,0 z"
+     id="path6089"
+     style="fill:white;fill-opacity:0.37387384;fill-rule:evenodd;stroke:none;stroke-width:0.57255107;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  <path
+     d="m 39.66216,23.316366 a 18.458334,16 0 0 1 -36.9166679,0 18.458334,16 0 1 1 36.9166679,0 z"
+     id="path6015"
+     style="fill:none;stroke:white;stroke-width:0.99999994;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:0.27477477;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  <path
+     d="m 14.279663,38.815551 c 4.370294,2.255137 21.03988,1.981742 24.965829,-10.999185 0,0 -5.636347,14.203426 -24.965829,10.999185 z"
+     id="path6039"
+     style="fill:url(#linearGradient4011);fill-opacity:1;fill-rule:evenodd;stroke:none;display:inline" />
+  <path
+     d="m 28.469316,28.468733 c 0,2.484 -3.29488,4.847635 -6.882881,4.847635 -3.588,0 -5.840945,-2.016001 -5.840945,-4.500001 0,-2.484001 2.912001,-5.500001 6.500001,-5.500001 3.588001,0 6.223825,2.668366 6.223825,5.152367 z"
+     id="path6055"
+     style="fill:none;stroke:white;stroke-width:1;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:0.26576574;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  <path
+     d="m 19.739342,34.816366 a 1.000001,1.0000011 0 1 1 -2.000002,0 1.000001,1.0000011 0 1 1 2.000002,0 z"
+     id="path6087"
+     style="fill:white;fill-opacity:0.37387384;fill-rule:evenodd;stroke:none;stroke-width:0.57255107;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  <path
+     d="m 19.739342,35.816366 a 0.50000043,1.0000009 0 1 1 -1,0 0.50000043,1.0000009 0 1 1 1,0 z"
+     id="path6083"
+     style="fill:#2e3436;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:0.80970943;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  <path
+     d="m 22.739342,35.816366 a 0.50000043,1.0000009 0 1 1 -1,0 0.50000043,1.0000009 0 1 1 1,0 z"
+     id="path6085"
+     style="fill:#2e3436;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:0.80970943;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  <g
+     id="g2589"
+     style="display:inline">
+    <path
+       d="m 27.745492,27.816367 c 0,2.484 -2.912,4.500001 -6.500001,4.500001 -3.588,0 -6.500001,-2.016001 -6.500001,-4.500001 0,-2.484001 2.912001,-5.500001 6.500001,-5.500001 3.588001,0 6.500001,3.016 6.500001,5.500001 z"
+       id="path6047"
+       style="fill:url(#radialGradient2609);fill-opacity:1;fill-rule:evenodd;stroke:#2e3436;stroke-width:1;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+    <path
+       d="m 46.089207,25.766438 a 19.161766,19.161766 0 1 1 -38.3235324,0 19.161766,19.161766 0 1 1 38.3235324,0 z"
+       transform="matrix(0.1043744,0,0,0.07828089,16.434954,25.299346)"
+       id="path6208"
+       style="fill:#eee;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:11.06305599;marker:none;visibility:visible;display:inline;overflow:visible;enable-background:accumulate" />
+  </g>
+  <path
+     d="m 45.215509,2.5011202 c -4.281846,0.682425 -8.575548,1.295279 -12.854035,1.9951357 -1.164518,0.582411 -0.747806,2.061595 -0.822837,3.105017 -1e-6,4.5144261 0,9.0288541 0,13.5432811 -2.989902,-0.664117 -6.440524,1.660678 -6.466088,4.818689 -0.134616,2.028017 1.828741,3.708429 3.803895,3.5227 2.677392,-0.136845 4.876234,-2.72166 4.589556,-5.481694 -1e-6,-4.514918 0,-9.733437 0,-14.248353 3.531124,-0.507439 7.469018,-1.0655431 11,-1.5739411 -2e-6,3.4804011 0,7.6644051 0,11.1448091 -2.865041,-0.822601 -6.474407,1.063113 -6.949161,4.077642 -0.396968,1.7765 0.848645,3.562052 2.550074,4.069766 3.184888,1.040469 6.774713,-2.028268 6.399087,-5.309882 -0.0087,-6.155364 0.02682,-12.310743 0,-18.4660878 -0.07484,-0.611833 -0.581826,-1.2280184 -1.250491,-1.197082 z"
+     id="path3406"
+     style="fill:#6a9ab8;fill-opacity:1;stroke:#2f5371;stroke-width:1.00000012;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+  <path
+     d="m 44.673622,19.648016 0.04234,-11.7365381 c 0.44614,-0.0578 0.0685,-0.0093 0.670099,-0.09587 0.0081,2.1922681 0.01129,3.6688351 0.01129,11.9484441 0,0.06161 -0.259835,-0.03092 -0.723739,-0.116032 l 3e-6,0 z"
+     id="path3996-9"
+     style="opacity:0.4;fill:url(#linearGradient3207);fill-opacity:1;fill-rule:evenodd;stroke:none" />
+  <path
+     d="m 46.056386,22.693461 c 0,2.091875 -1.848044,4.101181 -4.127723,4.487912 -2.279675,0.38673 -4.127719,-0.995562 -4.127719,-3.087436 0,-2.091875 1.848044,-4.101183 4.127719,-4.487914 2.279679,-0.38673 4.127723,0.995563 4.127723,3.087438 z"
+     id="path2716-1"
+     style="opacity:0.6;fill:url(#radialGradient3204);fill-opacity:1;stroke:none" />
+  <path
+     d="m 31.897984,21.657734 0,-15.9625761 c 0,0 0.08338,-0.8857 0.837768,-0.888753 0.06556,0.113136 12.727381,-2.0473477 12.727381,-2.0473477 0,0 0.484543,0.783694 -4.991113,1.5675567 -7.793798,1.115713 -7.861261,1.160176 -7.861261,1.961935 0,2.364917 0,7.1339981 0,15.7450081 -0.167574,-0.142514 -0.376677,-0.290712 -0.712775,-0.375823 l 0,0 z"
+     id="path2720-9"
+     style="opacity:0.4;fill:url(#linearGradient3201);fill-opacity:1;fill-rule:evenodd;stroke:none" />
+  <path
+     d="m 33.323535,24.673572 c 0,2.0233 -1.75516,3.96674 -3.92026,4.340793 -2.165102,0.374054 -3.920262,-0.962926 -3.920262,-2.986227 0,-2.023301 1.75516,-3.966741 3.920262,-4.340795 2.1651,-0.374053 3.92026,0.962927 3.92026,2.986229 z"
+     id="path2712-6"
+     style="opacity:0.6;fill:url(#radialGradient3198);fill-opacity:1;stroke:none" />
+</svg>
diff -pruN 3.4.1-6/kde-integration/src/applet-init.h 3.4.1+git20201022.a0d3415c-1/kde-integration/src/applet-init.h
--- 3.4.1-6/kde-integration/src/applet-init.h	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/kde-integration/src/applet-init.h	2020-10-21 15:04:44.000000000 +0000
@@ -18,8 +18,8 @@
 */
 
 
-#ifndef __GNOME_INTEGRATION_INIT__
-#define  __GNOME_INTEGRATION_INIT__
+#ifndef __KDE_INTEGRATION_INIT__
+#define  __KDE_INTEGRATION_INIT__
 
 
 #include <cairo-dock.h>
diff -pruN 3.4.1-6/kde-integration/src/applet-utils.c 3.4.1+git20201022.a0d3415c-1/kde-integration/src/applet-utils.c
--- 3.4.1-6/kde-integration/src/applet-utils.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/kde-integration/src/applet-utils.c	2020-10-21 15:04:44.000000000 +0000
@@ -63,10 +63,47 @@ void env_backend_lock_screen (void)
 
 void env_backend_setup_time (void)
 {
-	cairo_dock_launch_command ("kcmshell4 clock");  // from KDE4
+	cairo_dock_launch_command_printf ("kcmshell%d clock", NULL, get_kde_version());  // from KDE4
 }
 
 void env_backend_show_system_monitor (void)
 {
 	cairo_dock_launch_command ("ksysguard");
 }
+
+int get_kde_version (void)
+{
+	static int s_iKdeVersion = 0;
+	if (s_iKdeVersion == 0)
+	{
+		gchar *version = cairo_dock_launch_command_sync ("plasmashell --version");  // KDE5 or above
+		if (! version)
+			version = cairo_dock_launch_command_sync ("plasma-desktop --version");  // KDE4
+		if (version)
+		{
+			gchar *major = version;
+			while (! g_ascii_isdigit(*major) && *major != '\0')
+				major++;
+			s_iKdeVersion = atoi(major);
+		}
+		
+		if (! s_iKdeVersion)  // the commands above didn't work
+			s_iKdeVersion = 5;  // KDE5 by default
+		cd_debug ("KDE version detected: %d\n", s_iKdeVersion);
+		g_free (version);
+	}
+	return s_iKdeVersion;
+}
+
+const gchar *get_kioclient_number (void)
+{
+	static gchar *s_sNumber = NULL;
+	if (! s_sNumber)
+	{
+		if (get_kde_version() < 5)
+			s_sNumber = "";
+		else
+			s_sNumber = g_strdup_printf("%d", get_kde_version());
+	}
+	return s_sNumber;
+}
diff -pruN 3.4.1-6/kde-integration/src/applet-utils.h 3.4.1+git20201022.a0d3415c-1/kde-integration/src/applet-utils.h
--- 3.4.1-6/kde-integration/src/applet-utils.h	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/kde-integration/src/applet-utils.h	2020-10-21 15:04:44.000000000 +0000
@@ -18,8 +18,8 @@
 */
 
 
-#ifndef __APPLET_GNOME_ENV__
-#define  __APPLET_GNOME_ENV__
+#ifndef __KDE_INTEGRATION_UTILS__
+#define  __KDE_INTEGRATION_UTILS__
 
 
 #include <cairo-dock.h>
@@ -37,5 +37,9 @@ void env_backend_setup_time (void);
 
 void env_backend_show_system_monitor (void);
 
+int get_kde_version (void);
+
+const gchar *get_kioclient_number (void);
+
 
 #endif
diff -pruN 3.4.1-6/kde-integration/src/applet-vfs.c 3.4.1+git20201022.a0d3415c-1/kde-integration/src/applet-vfs.c
--- 3.4.1-6/kde-integration/src/applet-vfs.c	2015-02-19 16:01:14.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/kde-integration/src/applet-vfs.c	2020-10-21 15:04:44.000000000 +0000
@@ -26,13 +26,13 @@
 #include <glib.h>
 #include <gio/gio.h>
 
+#include "applet-utils.h"
 #include "applet-vfs.h"
 
 extern int lstat (const char *path, struct stat *buf);
 
 static GHashTable *s_hMonitorHandleTable = NULL;
 
-
 static void _vfs_backend_free_monitor_data (gpointer *data)
 {
 	if (data != NULL)
@@ -810,7 +810,7 @@ void vfs_backend_launch_uri (const gchar
 	g_return_if_fail (cURI != NULL);
 	
 	cd_debug ("%s (%s)", __func__, cURI);
-	gchar *cCommand = g_strdup_printf ("kioclient exec \"%s\"", cURI);
+	gchar *cCommand = g_strdup_printf ("kioclient%s exec \"%s\"", get_kioclient_number(), cURI);
 	cairo_dock_launch_command (cCommand);
 	g_free (cCommand);
 	
@@ -1169,7 +1169,7 @@ gboolean vfs_backend_delete_file (const
 	}
 	else
 	{
-		gchar *cCommand = g_strdup_printf ("kioclient move \"%s\" trash:/", cURI);
+		gchar *cCommand = g_strdup_printf ("kioclient%s move \"%s\" trash:/", get_kioclient_number(), cURI);
 		cairo_dock_launch_command (cCommand);
 		g_free (cCommand);
 	}
@@ -1185,7 +1185,7 @@ gboolean vfs_backend_rename_file (const
 	if (cPath)
 	{
 		gchar *cNewURI = g_strdup_printf ("%s/%s", cPath, cNewName);
-		gchar *cCommand = g_strdup_printf ("kioclient move \"%s\" \"%s\"", cOldURI, cNewURI);
+		gchar *cCommand = g_strdup_printf ("kioclient%s move \"%s\" \"%s\"", get_kioclient_number(), cOldURI, cNewURI);
 		cairo_dock_launch_command (cCommand);
 		g_free (cCommand);
 		g_free (cNewURI);
@@ -1202,7 +1202,7 @@ gboolean vfs_backend_move_file (const gc
 	
 	gchar *cFileName = g_path_get_basename (cURI);
 	gchar *cNewFileURI = g_strconcat (cDirectoryURI, "/", cFileName, NULL);
-	gchar *cCommand = g_strdup_printf ("kioclient move \"%s\" \"%s\"", cURI, cNewFileURI);
+	gchar *cCommand = g_strdup_printf ("kioclient%s move \"%s\" \"%s\"", get_kioclient_number(), cURI, cNewFileURI);
 	cairo_dock_launch_command (cCommand);
 	g_free (cCommand);
 	g_free (cNewFileURI);
diff -pruN 3.4.1-6/kde-integration/src/applet-vfs.h 3.4.1+git20201022.a0d3415c-1/kde-integration/src/applet-vfs.h
--- 3.4.1-6/kde-integration/src/applet-vfs.h	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/kde-integration/src/applet-vfs.h	2020-10-21 15:04:44.000000000 +0000
@@ -18,8 +18,8 @@
 */
 
 
-#ifndef __APPLET_GNOME_VFS__
-#define  __APPLET_GNOME_VFS__
+#ifndef __KDE_INTEGRATION_VFS__
+#define  __KDE_INTEGRATION_VFS__
 
 
 #include <cairo-dock.h>
diff -pruN 3.4.1-6/logout/data/misc/view-refresh.svg 3.4.1+git20201022.a0d3415c-1/logout/data/misc/view-refresh.svg
--- 3.4.1-6/logout/data/misc/view-refresh.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/logout/data/misc/view-refresh.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,52 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg id="svg2474" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns="http://www.w3.org/2000/svg" height="48" width="48" version="1.1" xmlns:cc="http://creativecommons.org/ns#" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:dc="http://purl.org/dc/elements/1.1/">
+ <metadata id="metadata33">
+  <rdf:RDF>
+   <cc:Work rdf:about="">
+    <dc:format>image/svg+xml</dc:format>
+    <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
+    <dc:title/>
+   </cc:Work>
+  </rdf:RDF>
+ </metadata>
+ <defs id="defs2476">
+  <linearGradient id="linearGradient3533">
+   <stop id="stop3535" stop-color="#93b9dd" offset="0"/>
+   <stop id="stop3545" stop-color="#6396cd" offset="1"/>
+  </linearGradient>
+  <linearGradient id="linearGradient5497" y2="71.781" gradientUnits="userSpaceOnUse" x2="108.56" gradientTransform="translate(-95.999 -49)" y1="102.78" x1="108.56">
+   <stop id="stop5493" stop-color="#fff" offset="0"/>
+   <stop id="stop5495" stop-color="#fff" stop-opacity="0" offset="1"/>
+  </linearGradient>
+  <linearGradient id="linearGradient5480" y2="72.781" gradientUnits="userSpaceOnUse" x2="103.56" gradientTransform="translate(-95.999 -49)" y1="49.781" x1="102.56">
+   <stop id="stop5476" stop-color="#fff" offset="0"/>
+   <stop id="stop5478" stop-color="#fff" stop-opacity="0" offset="1"/>
+  </linearGradient>
+  <linearGradient id="linearGradient4593-5-8-1-5-2" y2="91.942" xlink:href="#linearGradient3533" gradientUnits="userSpaceOnUse" x2="118.48" gradientTransform="translate(-101 -49)" y1="55.06" x1="118.48"/>
+  <linearGradient id="linearGradient4593-5-8-1-5-2-3" y2="83.576" xlink:href="#linearGradient3533" gradientUnits="userSpaceOnUse" x2="35.996" gradientTransform="translate(-5)" y1="53.838" x1="34.981"/>
+  <radialGradient id="radialGradient5147-5" gradientUnits="userSpaceOnUse" cy="197.3" cx="33.875" gradientTransform="matrix(1 0 0 .33871 0 130.47)" r="4.8438">
+   <stop id="stop6464-5-9-94-5-4-4" stop-color="#000" offset="0"/>
+   <stop id="stop6466-3-6-1-7-2-8" stop-color="#000" stop-opacity="0" offset="1"/>
+  </radialGradient>
+  <linearGradient id="linearGradient4008" y2="73.264" gradientUnits="userSpaceOnUse" x2="53.809" gradientTransform="translate(-5)" y1="84.719" x1="42.031">
+   <stop id="stop3278" stop-color="#6396cd" offset="0"/>
+   <stop id="stop3280" stop-color="#83acd5" stop-opacity="0" offset="1"/>
+  </linearGradient>
+  <linearGradient id="linearGradient4018" y2="75.139" gradientUnits="userSpaceOnUse" x2="50.684" y1="83.782" x1="39.843">
+   <stop id="stop3268" stop-color="#387ab8" offset="0"/>
+   <stop id="stop3270" stop-color="#387ab8" stop-opacity="0" offset="1"/>
+  </linearGradient>
+ </defs>
+ <path id="path6460-6-4-4-3-3" opacity=".2" style="enable-background:new;color:#000000;" d="m38.719 197.3a4.8438 1.6406 0 1 1 -9.6875 0 4.8438 1.6406 0 1 1 9.6875 0z" fill-rule="nonzero" transform="matrix(3.3032 0 0 1.6762 -89.459 -288.74)" fill="url(#radialGradient5147-5)"/>
+ <path id="path4010" stroke-linejoin="miter" style="enable-background:new;color:#000000;" d="m46.406 78.611a13.125 13.125 0 0 1 -12.779 5.486" stroke-dashoffset="0" transform="matrix(1.0667 0 0 1.0667 -14.499 -51.367)" stroke="url(#linearGradient4018)" stroke-linecap="round" stroke-miterlimit="4" stroke-dasharray="none" stroke-width="8.4375" fill="none"/>
+ <path id="path6460-6-4-4-4" opacity=".1" style="enable-background:new;color:#000000;" d="m38.719 197.3a4.8438 1.6406 0 1 1 -9.6875 0 4.8438 1.6406 0 1 1 9.6875 0z" fill-rule="nonzero" transform="matrix(4.5419 0 0 1.981 -131.42 -348.87)" fill="url(#radialGradient5147-5)"/>
+ <path id="path4788-6" stroke-linejoin="miter" style="enable-background:new;color:#000000;" d="m35.542 84.25a13.125 13.125 0 1 1 11.63 -19.365" stroke-dashoffset="0" transform="matrix(1.0667 0 0 1.0667 -14.499 -51.367)" stroke="#387ab8" stroke-linecap="round" stroke-miterlimit="4" stroke-dasharray="none" stroke-width="8.4375" fill="none"/>
+ <path id="path4847" stroke-linejoin="round" style="enable-background:new;color:#000000;" d="m38.501 9.4996v11h-11" stroke-dashoffset="0" stroke="#387ab8" stroke-linecap="round" stroke-miterlimit="4" stroke-dasharray="none" stroke-width="7" fill="none"/>
+ <path id="path4006" stroke-linejoin="miter" style="enable-background:new;color:#000000;" d="m46.387 78.638a13.125 13.125 0 0 1 -13.413 5.341" stroke-dashoffset="0" transform="matrix(1.0667 0 0 1.0667 -14.499 -51.367)" stroke="url(#linearGradient4008)" stroke-linecap="round" stroke-miterlimit="4" stroke-dasharray="none" stroke-width="6.5625" fill="none"/>
+ <path id="path4788" stroke-linejoin="miter" style="enable-background:new;color:#000000;" d="m37.321 84.14a13.125 13.125 0 1 1 9.3378 -20.123" stroke-dashoffset="0" transform="matrix(1.0667 0 0 1.0667 -14.499 -51.367)" stroke="url(#linearGradient4593-5-8-1-5-2-3)" stroke-linecap="round" stroke-miterlimit="4" stroke-dasharray="none" stroke-width="6.5625" fill="none"/>
+ <path id="path4847-1" stroke-linejoin="round" style="enable-background:new;color:#000000;" d="m38.501 9.4996v11h-11" stroke-dashoffset="0" stroke="url(#linearGradient4593-5-8-1-5-2)" stroke-linecap="round" stroke-miterlimit="4" stroke-dasharray="none" stroke-width="5" fill="none"/>
+ <path id="path4788-2" opacity="0.24" style="block-progression:tb;color:#000000;direction:ltr;text-indent:0;text-align:start;enable-background:new;text-transform:none;" d="m29.741 33.594c-3.6741 2.5333-8.6633 2.6528-12.553-0.06269-5.0104-3.4981-6.2168-10.333-2.7188-15.344 3.4981-5.0104 10.333-6.2168 15.344-2.7188 1.1612 0.81069 2.1038 1.844 2.875 3.0312h-5.1875c-1.0566-0.01494-2.0285 0.94327-2.0285 2s0.97186 2.0149 2.0285 2h11c1.0625 0.28125 2.0625-0.71875 2-2v-11c0.01671-1.068-0.96321-2.048-2.0312-2.0313-0.06245-0.00293-0.12505-0.00293-0.1875 0-0.98275 0.108-1.8025 1.0428-1.7812 2.0313v4.0625c-0.9534-1.1279-2.0667-2.152-3.2812-3l-0.09375-0.0625c-2.852-1.9611-6.0733-2.922-9.3125-2.9688-5.4622-0.07875-10.904 2.4568-14.25 7.25-5.3544 7.6691-3.4504 18.302 4.2188 23.656 6.2554 4.3673 14.483 3.9057 20.209-0.5747" stroke="#fff" stroke-miterlimit="4" stroke-dasharray="none" stroke-width="1" fill="none"/>
+ <path id="path4788-2-3" opacity=".3" style="block-progression:tb;color:#000000;direction:ltr;text-indent:0;text-align:start;enable-background:new;text-transform:none;" d="m36.501 13.562c-0.9534-1.1279-2.0667-2.152-3.2812-3l-0.0937-0.0625c-2.852-1.9611-6.0733-2.922-9.3125-2.9688-5.4622-0.07875-10.904 2.4568-14.25 7.25-5.3544 7.6691-3.4504 18.302 4.2188 23.656" stroke="url(#linearGradient5480)" stroke-miterlimit="4" stroke-dasharray="none" stroke-width="1" fill="none"/>
+ <path id="path4788-2-3-4" opacity=".3" style="block-progression:tb;color:#000000;direction:ltr;text-indent:0;text-align:start;enable-background:new;text-transform:none;" d="m32.532 30.812c-3.498 5.01-10.334 6.217-15.344 2.719s-6.217-10.334-2.719-15.344 10.334-6.217 15.344-2.719" stroke="url(#linearGradient5497)" stroke-linecap="round" stroke-miterlimit="4" stroke-dasharray="none" stroke-width="1" fill="none"/>
+</svg>
Binary files 3.4.1-6/motion-blur/data/misc/23.png and 3.4.1+git20201022.a0d3415c-1/motion-blur/data/misc/23.png differ
diff -pruN 3.4.1-6/motion-blur/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/motion-blur/data/misc/icon.svg
--- 3.4.1-6/motion-blur/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/motion-blur/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,266 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   version="1.0"
+   width="48"
+   height="48"
+   id="svg3366"
+   inkscape:version="0.47 r22583"
+   sodipodi:docname="icon.svg">
+  <metadata
+     id="metadata30">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <dc:title />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <sodipodi:namedview
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1"
+     objecttolerance="10"
+     gridtolerance="10"
+     guidetolerance="10"
+     inkscape:pageopacity="0"
+     inkscape:pageshadow="2"
+     inkscape:window-width="986"
+     inkscape:window-height="662"
+     id="namedview28"
+     showgrid="false"
+     inkscape:zoom="2.796875"
+     inkscape:cx="1.6968257"
+     inkscape:cy="23.130837"
+     inkscape:window-x="0"
+     inkscape:window-y="24"
+     inkscape:window-maximized="0"
+     inkscape:current-layer="svg3366" />
+  <defs
+     id="defs3368">
+    <linearGradient
+       id="linearGradient8838">
+      <stop
+         id="stop8840"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop8842"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient2490-182-124">
+      <stop
+         id="stop2788"
+         style="stop-color:#1f4b6a;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2790"
+         style="stop-color:#4083c2;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3242-187-536">
+      <stop
+         id="stop2778"
+         style="stop-color:#8badea;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2780"
+         style="stop-color:#6396cd;stop-opacity:1"
+         offset="0.26238" />
+      <stop
+         id="stop2782"
+         style="stop-color:#3b7caf;stop-opacity:1"
+         offset="0.66093999" />
+      <stop
+         id="stop2784"
+         style="stop-color:#194c70;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4873">
+      <stop
+         id="stop4875"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4877"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4873"
+       id="linearGradient3648"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.7372062,0,0,1.7371666,-83.518616,29.847506)"
+       x1="63.397362"
+       y1="-12.489107"
+       x2="63.397362"
+       y2="5.4675598" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3242-187-536"
+       id="radialGradient3651"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,1.878528,-2.4796237,0,34.430018,-38.361081)"
+       cx="23.895569"
+       cy="3.9900031"
+       fx="23.895569"
+       fy="3.9900031"
+       r="20.397499" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient2490-182-124"
+       id="linearGradient3653"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.78709581,0,0,0.78709598,5.6460113,4.8582996)"
+       x1="18.379412"
+       y1="44.980297"
+       x2="18.379412"
+       y2="3.0816143" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient8838"
+       id="radialGradient3656"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.7777194,0,0,0.61833637,-86.793366,33.207226)"
+       cx="62.625"
+       cy="4.625"
+       fx="62.625"
+       fy="4.625"
+       r="10.625" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3242-187-536"
+       id="radialGradient3689"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,1.878528,-2.4796237,0,34.430018,-38.361081)"
+       cx="23.895569"
+       cy="3.9900031"
+       fx="23.895569"
+       fy="3.9900031"
+       r="20.397499" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient2490-182-124"
+       id="linearGradient3691"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.78709581,0,0,0.78709598,5.6460113,4.8582996)"
+       x1="18.379412"
+       y1="44.980297"
+       x2="18.379412"
+       y2="3.0816143" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4873"
+       id="linearGradient3693"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.7372062,0,0,1.7371666,-83.518616,29.847506)"
+       x1="63.397362"
+       y1="-12.489107"
+       x2="63.397362"
+       y2="5.4675598" />
+    <filter
+       inkscape:collect="always"
+       id="filter3631"
+       x="-0.16349853"
+       width="1.3269971"
+       y="-0.14463324"
+       height="1.2892665">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="1.2867511"
+         id="feGaussianBlur3633" />
+    </filter>
+    <filter
+       inkscape:collect="always"
+       id="filter3639"
+       x="-0.10899902"
+       width="1.217998"
+       y="-0.096422158"
+       height="1.1928443">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="0.85783409"
+         id="feGaussianBlur3641" />
+    </filter>
+    <filter
+       inkscape:collect="always"
+       id="filter3651">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="0.37238328"
+         id="feGaussianBlur3653" />
+    </filter>
+    <filter
+       inkscape:collect="always"
+       id="filter3655"
+       x="-0.17209303"
+       width="1.3441861"
+       y="-0.17209302"
+       height="1.344186">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="2.2963636"
+         id="feGaussianBlur3657" />
+    </filter>
+  </defs>
+  <g
+     id="g3667"
+     transform="matrix(1.1306121,0,0,1.1306121,-3.2047399,-3.1018551)"
+     style="filter:url(#filter3655);opacity:0.8976378">
+    <g
+       id="g3669">
+      <path
+         d="m 24.536314,7.736119 c -8.835134,0 -16.0124827,7.177346 -16.0124827,16.012481 0,8.835135 7.1773487,16.012484 16.0124827,16.012482 8.835131,0 16.012487,-7.177347 16.012479,-16.012482 0,-8.835135 -7.177348,-16.012481 -16.012479,-16.012481 z"
+         id="path3671"
+         style="fill:url(#radialGradient3689);fill-opacity:1;stroke:url(#linearGradient3691);stroke-width:0.82422983999999999;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="m 39.729051,23.748061 c 0,8.390989 -6.802521,15.193276 -15.192546,15.193276 -8.390793,0 -15.1929299,-6.802365 -15.1929299,-15.193276 0,-8.3906 6.8021369,-15.1921983 15.1929299,-15.1921983 8.390025,0 15.192546,6.8015983 15.192546,15.1921983 l 0,0 z"
+         id="path3673"
+         style="opacity:0.40000000000000002;fill:none;stroke:url(#linearGradient3693);stroke-width:0.82122903999999985;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    </g>
+  </g>
+  <path
+     style="opacity:0.3;fill:url(#radialGradient3656);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:0.99999988;marker:none;visibility:visible;display:inline;overflow:visible"
+     id="path8836"
+     d="m 43.424578,36.067036 c 0,3.628418 -8.456567,6.569832 -18.888268,6.569832 -10.431702,0 -18.8882685,-2.941414 -18.8882685,-6.569832 0,-3.628418 8.4565665,-6.569833 18.8882685,-6.569833 10.431701,0 18.888268,2.941415 18.888268,6.569833 l 0,0 z" />
+  <g
+     id="g3662"
+     style="filter:url(#filter3651);opacity:0.57874016">
+    <g
+       id="g3658">
+      <path
+         style="fill:url(#radialGradient3651);fill-opacity:1;stroke:url(#linearGradient3653);stroke-width:0.82422983999999999;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0"
+         id="path2555"
+         d="m 24.536314,7.736119 c -8.835134,0 -16.0124827,7.177346 -16.0124827,16.012481 0,8.835135 7.1773487,16.012484 16.0124827,16.012482 8.835131,0 16.012487,-7.177347 16.012479,-16.012482 0,-8.835135 -7.177348,-16.012481 -16.012479,-16.012481 z" />
+      <path
+         style="opacity:0.40000000000000002;fill:none;stroke:url(#linearGradient3648);stroke-width:0.82122903999999985;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none"
+         id="path8655"
+         d="m 39.729051,23.748061 c 0,8.390989 -6.802521,15.193276 -15.192546,15.193276 -8.390793,0 -15.1929299,-6.802365 -15.1929299,-15.193276 0,-8.3906 6.8021369,-15.1921983 15.1929299,-15.1921983 8.390025,0 15.192546,6.8015983 15.192546,15.1921983 l 0,0 z" />
+    </g>
+  </g>
+  <path
+     style="opacity:0.20000000000000001;fill:#000000;fill-opacity:1;stroke:none;filter:url(#filter3639)"
+     id="path3364"
+     d="m 27.091561,15.51759 c 0,1.349621 -1.093036,2.444966 -2.439811,2.444966 -1.346775,0 -2.439811,-1.095345 -2.439811,-2.444966 0,-1.349622 1.093036,-2.444968 2.439811,-2.444968 1.346775,0 2.439811,1.095346 2.439811,2.444968 z m 6.089429,2.599792 c -0.112846,0.01832 -0.219475,0.06292 -0.310863,0.130112 l -8.334069,1.30236 -8.289183,-1.32032 c -0.214276,-0.155742 -0.515537,-0.202378 -0.754965,-0.08675 -0.239429,0.115625 -0.39639,0.389677 -0.399692,0.650457 -0.003,0.260815 0.16324,0.485741 0.399692,0.607101 l 6.495383,2.064875 -0.04443,4.740254 -2.291958,7.099374 c -0.220744,0.323276 -0.153464,0.738453 0.177641,0.953974 0.331119,0.215553 0.800674,0.149876 1.021441,-0.173436 l 3.698759,-7.663081 3.628941,7.649837 c 0.196227,0.335308 0.633641,0.451786 0.977023,0.26019 0.343383,-0.191595 0.462681,-0.618699 0.266461,-0.954009 l -2.249414,-7.129916 -0.08881,-4.462629 6.586523,-2.410832 c 0.266122,-0.182222 0.381733,-0.527198 0.26647,-0.823899 -0.115273,-0.296733 -0.432051,-0.469615 -0.754981,-0.43366 l 2.2e-5,0 z" />
+  <path
+     style="fill:#ffffff;fill-opacity:1;stroke:none;filter:url(#filter3631)"
+     id="path6668"
+     d="m 27.091561,16.338819 c 0,1.349621 -1.093036,2.444966 -2.439811,2.444966 -1.346775,0 -2.439811,-1.095345 -2.439811,-2.444966 0,-1.349622 1.093036,-2.444968 2.439811,-2.444968 1.346775,0 2.439811,1.095346 2.439811,2.444968 z m 6.089429,2.599792 c -0.112846,0.01832 -0.219475,0.06292 -0.310863,0.130112 l -8.334069,1.30236 -8.289183,-1.32032 c -0.214276,-0.155742 -0.515537,-0.202378 -0.754965,-0.08675 -0.239429,0.115625 -0.39639,0.389677 -0.399692,0.650457 -0.003,0.260815 0.16324,0.485741 0.399692,0.607101 l 6.495383,2.064875 -0.04443,4.740254 -2.291958,7.099374 c -0.220744,0.323276 -0.153464,0.738453 0.177641,0.953974 0.331119,0.215553 0.800674,0.149877 1.021441,-0.173436 l 3.698759,-7.663081 3.628941,7.649837 c 0.196227,0.335308 0.633641,0.451786 0.977023,0.26019 0.343383,-0.191595 0.462681,-0.618699 0.266461,-0.954009 l -2.249414,-7.129916 -0.08881,-4.462629 6.586523,-2.410832 c 0.266122,-0.182222 0.381733,-0.527198 0.26647,-0.823899 -0.115273,-0.296733 -0.432051,-0.469615 -0.754981,-0.43366 l 2.2e-5,0 z" />
+</svg>
diff -pruN 3.4.1-6/netspeed/data/misc/bad.svg 3.4.1+git20201022.a0d3415c-1/netspeed/data/misc/bad.svg
--- 3.4.1-6/netspeed/data/misc/bad.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/netspeed/data/misc/bad.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,107 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="256"
+   height="256"
+   id="svg2165"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   version="1.0"
+   sodipodi:docbase="/home/paradoxxx/svn/cairo-dock-plugin-dev-area/netspeed/data"
+   sodipodi:docname="bad.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <defs
+     id="defs2167">
+    <filter
+       inkscape:collect="always"
+       id="filter4270">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="3.3681571"
+         id="feGaussianBlur4272" />
+    </filter>
+    <filter
+       inkscape:collect="always"
+       id="filter7201">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="0.56135954"
+         id="feGaussianBlur7203" />
+    </filter>
+  </defs>
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="1.375"
+     inkscape:cx="100.43395"
+     inkscape:cy="123.07068"
+     inkscape:current-layer="layer1"
+     showgrid="true"
+     inkscape:document-units="px"
+     inkscape:grid-bbox="true"
+     width="256px"
+     height="256px"
+     inkscape:window-width="822"
+     inkscape:window-height="598"
+     inkscape:window-x="1192"
+     inkscape:window-y="123" />
+  <metadata
+     id="metadata2170">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     id="layer1"
+     inkscape:label="Layer 1"
+     inkscape:groupmode="layer">
+    <path
+       sodipodi:type="star"
+       style="fill:#abaeab;fill-opacity:1;fill-rule:nonzero;filter:url(#filter4270);opacity:1"
+       id="path2177"
+       sodipodi:sides="3"
+       sodipodi:cx="128.72726"
+       sodipodi:cy="127.27273"
+       sodipodi:r1="124.48904"
+       sodipodi:r2="43.571159"
+       sodipodi:arg1="0.52639236"
+       sodipodi:arg2="1.5735899"
+       inkscape:flatsided="false"
+       inkscape:rounded="-1.25"
+       inkscape:randomized="0"
+       d="M 236.36363,189.81818 C 305.07917,71.563519 -8.1637687,170.46164 128.60555,170.84372 C 265.37486,171.22579 -47.310638,70.579086 20.743132,189.21583 C 88.796901,307.85256 159.77009,-12.87284 91.05454,105.38182 C 22.338994,223.63648 265.84435,3.1662533 129.07503,2.7841772 C -7.6942795,2.4021011 234.57548,224.22938 166.52171,105.59265 C 98.467939,-13.044095 167.64808,308.07284 236.36363,189.81818 z "
+       transform="matrix(1.0748874,0,0,1.0748874,-8.9059276,7.791537)" />
+    <path
+       sodipodi:type="star"
+       style="fill:#ff000c;fill-opacity:1;fill-rule:nonzero;filter:url(#filter7201)"
+       id="path3291"
+       sodipodi:sides="3"
+       sodipodi:cx="128.72726"
+       sodipodi:cy="127.27273"
+       sodipodi:r1="124.48904"
+       sodipodi:r2="43.571159"
+       sodipodi:arg1="0.52639236"
+       sodipodi:arg2="1.5735899"
+       inkscape:flatsided="false"
+       inkscape:rounded="-1.25"
+       inkscape:randomized="0"
+       d="M 236.36363,189.81818 C 305.07917,71.563519 -8.1637687,170.46164 128.60555,170.84372 C 265.37486,171.22579 -47.310638,70.579086 20.743132,189.21583 C 88.796901,307.85256 159.77009,-12.87284 91.05454,105.38182 C 22.338994,223.63648 265.84435,3.1662533 129.07503,2.7841772 C -7.6942795,2.4021011 234.57548,224.22938 166.52171,105.59265 C 98.467939,-13.044095 167.64808,308.07284 236.36363,189.81818 z "
+       transform="matrix(0.9883932,0,0,0.9883932,1.5845996,18.207015)" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/netspeed/data/misc/default.svg 3.4.1+git20201022.a0d3415c-1/netspeed/data/misc/default.svg
--- 3.4.1-6/netspeed/data/misc/default.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/netspeed/data/misc/default.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,107 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="256"
+   height="256"
+   id="svg2165"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   version="1.0"
+   sodipodi:docbase="/home/paradoxxx/svn/cairo-dock-plugin-dev-area/netspeed/data"
+   sodipodi:docname="bad.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <defs
+     id="defs2167">
+    <filter
+       inkscape:collect="always"
+       id="filter4270">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="3.3681571"
+         id="feGaussianBlur4272" />
+    </filter>
+    <filter
+       inkscape:collect="always"
+       id="filter7201">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="0.56135954"
+         id="feGaussianBlur7203" />
+    </filter>
+  </defs>
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="1.375"
+     inkscape:cx="100.43395"
+     inkscape:cy="123.07068"
+     inkscape:current-layer="layer1"
+     showgrid="true"
+     inkscape:document-units="px"
+     inkscape:grid-bbox="true"
+     width="256px"
+     height="256px"
+     inkscape:window-width="822"
+     inkscape:window-height="598"
+     inkscape:window-x="1192"
+     inkscape:window-y="123" />
+  <metadata
+     id="metadata2170">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     id="layer1"
+     inkscape:label="Layer 1"
+     inkscape:groupmode="layer">
+    <path
+       sodipodi:type="star"
+       style="fill:#abaeab;fill-opacity:1;fill-rule:nonzero;filter:url(#filter4270);opacity:1"
+       id="path2177"
+       sodipodi:sides="3"
+       sodipodi:cx="128.72726"
+       sodipodi:cy="127.27273"
+       sodipodi:r1="124.48904"
+       sodipodi:r2="43.571159"
+       sodipodi:arg1="0.52639236"
+       sodipodi:arg2="1.5735899"
+       inkscape:flatsided="false"
+       inkscape:rounded="-1.25"
+       inkscape:randomized="0"
+       d="M 236.36363,189.81818 C 305.07917,71.563519 -8.1637687,170.46164 128.60555,170.84372 C 265.37486,171.22579 -47.310638,70.579086 20.743132,189.21583 C 88.796901,307.85256 159.77009,-12.87284 91.05454,105.38182 C 22.338994,223.63648 265.84435,3.1662533 129.07503,2.7841772 C -7.6942795,2.4021011 234.57548,224.22938 166.52171,105.59265 C 98.467939,-13.044095 167.64808,308.07284 236.36363,189.81818 z "
+       transform="matrix(1.0748874,0,0,1.0748874,-8.9059276,7.791537)" />
+    <path
+       sodipodi:type="star"
+       style="fill:#ff000c;fill-opacity:1;fill-rule:nonzero;filter:url(#filter7201)"
+       id="path3291"
+       sodipodi:sides="3"
+       sodipodi:cx="128.72726"
+       sodipodi:cy="127.27273"
+       sodipodi:r1="124.48904"
+       sodipodi:r2="43.571159"
+       sodipodi:arg1="0.52639236"
+       sodipodi:arg2="1.5735899"
+       inkscape:flatsided="false"
+       inkscape:rounded="-1.25"
+       inkscape:randomized="0"
+       d="M 236.36363,189.81818 C 305.07917,71.563519 -8.1637687,170.46164 128.60555,170.84372 C 265.37486,171.22579 -47.310638,70.579086 20.743132,189.21583 C 88.796901,307.85256 159.77009,-12.87284 91.05454,105.38182 C 22.338994,223.63648 265.84435,3.1662533 129.07503,2.7841772 C -7.6942795,2.4021011 234.57548,224.22938 166.52171,105.59265 C 98.467939,-13.044095 167.64808,308.07284 236.36363,189.81818 z "
+       transform="matrix(0.9883932,0,0,0.9883932,1.5845996,18.207015)" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/netspeed/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/netspeed/data/misc/icon.svg
--- 3.4.1-6/netspeed/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/netspeed/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,598 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   version="1.0"
+   width="48"
+   height="48"
+   id="svg2"
+   inkscape:version="0.47 r22583"
+   sodipodi:docname="icon.svg">
+  <metadata
+     id="metadata47">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <dc:title />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <sodipodi:namedview
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1"
+     objecttolerance="10"
+     gridtolerance="10"
+     guidetolerance="10"
+     inkscape:pageopacity="0"
+     inkscape:pageshadow="2"
+     inkscape:window-width="1079"
+     inkscape:window-height="759"
+     id="namedview45"
+     showgrid="false"
+     inkscape:zoom="4.9166667"
+     inkscape:cx="2.7465621"
+     inkscape:cy="45.39115"
+     inkscape:window-x="0"
+     inkscape:window-y="24"
+     inkscape:window-maximized="0"
+     inkscape:current-layer="svg2" />
+  <defs
+     id="defs4">
+    <linearGradient
+       id="linearGradient6326">
+      <stop
+         id="stop6328"
+         style="stop-color:#debc8c;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6330"
+         style="stop-color:#f4ac72;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3156">
+      <stop
+         id="stop3158"
+         style="stop-color:#ffffff;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3160"
+         style="stop-color:#ffffff;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6493">
+      <stop
+         id="stop6495"
+         style="stop-color:#4580d4;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6497"
+         style="stop-color:#114796;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4103">
+      <stop
+         id="stop4105"
+         style="stop-color:#70adfb;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4107"
+         style="stop-color:#3465a4;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient8838">
+      <stop
+         id="stop8840"
+         style="stop-color:#000000;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop8842"
+         style="stop-color:#000000;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="62.625"
+       cy="4.625"
+       r="10.625"
+       fx="62.625"
+       fy="4.625"
+       id="radialGradient5729"
+       xlink:href="#linearGradient8838"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1,0,0,0.341176,0,3.047059)" />
+    <linearGradient
+       x1="24.335312"
+       y1="61.852856"
+       x2="28.290144"
+       y2="20.663898"
+       id="linearGradient5745"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="27.888655"
+       y1="-0.81503254"
+       x2="28.290144"
+       y2="20.663898"
+       id="linearGradient5747"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="28.220636"
+       y1="-2.3103411"
+       x2="28.290144"
+       y2="20.663898"
+       id="linearGradient5749"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="30.501778"
+       y1="55.647495"
+       x2="29.724815"
+       y2="24.653727"
+       id="linearGradient5751"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       cx="22.944935"
+       cy="11.222695"
+       r="14"
+       fx="22.944935"
+       fy="4.7612267"
+       id="radialGradient5537"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.3571044,0.01021839,-0.00631345,0.8384895,-10.874695,1.3057951)" />
+    <radialGradient
+       cx="22.125"
+       cy="10.874998"
+       r="20"
+       fx="22.125"
+       fy="10.874998"
+       id="radialGradient5540"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.0099925,-0.1119962,0.05668752,0.5112133,-5.8375646,1.7934718)" />
+    <radialGradient
+       cx="20.038782"
+       cy="12.610249"
+       r="22.463524"
+       fx="20.038782"
+       fy="12.610249"
+       id="radialGradient5551"
+       xlink:href="#linearGradient4103"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.9524671,-0.05018139,0.03650944,1.4214826,-20.408334,-5.9089096)" />
+    <linearGradient
+       x1="29.01346"
+       y1="29"
+       x2="29.75"
+       y2="50"
+       id="linearGradient5553"
+       xlink:href="#linearGradient6493"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-5.0000016,-6)" />
+    <radialGradient
+       cx="26"
+       cy="15.240479"
+       r="15.074549"
+       fx="26"
+       fy="15.240479"
+       id="radialGradient6332"
+       xlink:href="#linearGradient6326"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(2.2554569,0,-2.1857407e-8,2.0564463,-32.641879,-17.341228)" />
+    <linearGradient
+       id="linearGradient4222">
+      <stop
+         offset="0"
+         style="stop-color:white;stop-opacity:1"
+         id="stop4224" />
+      <stop
+         offset="1"
+         style="stop-color:white;stop-opacity:0"
+         id="stop4226" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3840">
+      <stop
+         offset="0"
+         style="stop-color:#7790aa;stop-opacity:1;"
+         id="stop3842" />
+      <stop
+         offset="0.31757474"
+         style="stop-color:#778b9e;stop-opacity:1;"
+         id="stop3844" />
+      <stop
+         offset="1"
+         style="stop-color:#8babcb;stop-opacity:0;"
+         id="stop3846" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5432">
+      <stop
+         offset="0"
+         style="stop-color:#426296;stop-opacity:1;"
+         id="stop5434" />
+      <stop
+         offset="1"
+         style="stop-color:#426296;stop-opacity:0;"
+         id="stop5436" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3793">
+      <stop
+         offset="0"
+         style="stop-color:#8cab2a;stop-opacity:0"
+         id="stop3795" />
+      <stop
+         offset="0.6127364"
+         style="stop-color:#b1c948;stop-opacity:1"
+         id="stop3797" />
+      <stop
+         offset="1"
+         style="stop-color:#d7e866;stop-opacity:1"
+         id="stop3799" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3480">
+      <stop
+         offset="0"
+         style="stop-color:#548820;stop-opacity:1"
+         id="stop3482" />
+      <stop
+         offset="1"
+         style="stop-color:#548820;stop-opacity:0"
+         id="stop3484" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3793"
+       id="linearGradient3768"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.5572773,0,0,-0.55176119,56.970924,39.384244)"
+       x1="62.952984"
+       y1="23.890968"
+       x2="2.4973762"
+       y2="23.890968" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3480"
+       id="linearGradient3770"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,1.095875,-1.1068307,0,120.9962,-18.518362)"
+       x1="40.808029"
+       y1="44.845047"
+       x2="40.808029"
+       y2="26.149443" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4222"
+       id="linearGradient3772"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.62721007,0,0,-0.58770295,85.560047,41.900382)"
+       x1="3.8877637"
+       y1="26.022909"
+       x2="-8.7979088"
+       y2="26.022909" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3840"
+       id="linearGradient3774"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.5572773,0,0,-0.55176119,105.74094,21.369801)"
+       x1="3.8738406"
+       y1="28.280676"
+       x2="62.400131"
+       y2="28.280676" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient5432"
+       id="linearGradient3776"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,1.095875,1.1068307,0,41.715669,-36.532804)"
+       x1="41.81702"
+       y1="45.610001"
+       x2="41.81702"
+       y2="26.597807" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4222"
+       id="linearGradient3778"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.62721007,0,0,-0.58770295,77.151823,23.885938)"
+       x1="3.8877637"
+       y1="26.022909"
+       x2="-8.7979088"
+       y2="26.022909" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4222"
+       id="linearGradient2882"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.62721007,0,0,-0.58770295,19.795891,29.580853)"
+       x1="3.8877637"
+       y1="26.022909"
+       x2="-8.7979088"
+       y2="26.022909" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3840"
+       id="linearGradient2885"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.5572773,0,0,-0.55176119,48.385008,27.064716)"
+       x1="3.8738406"
+       y1="28.280676"
+       x2="62.400131"
+       y2="28.280676" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient5432"
+       id="linearGradient2887"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,1.095875,1.1068307,0,-15.640263,-30.837889)"
+       x1="41.81702"
+       y1="45.610001"
+       x2="41.81702"
+       y2="26.597807" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4222"
+       id="linearGradient2890"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.62721007,0,0,-0.58770295,28.204115,47.595297)"
+       x1="3.8877637"
+       y1="26.022909"
+       x2="-8.7979088"
+       y2="26.022909" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3793"
+       id="linearGradient2893"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.5572773,0,0,-0.55176119,-0.385008,45.079159)"
+       x1="62.952984"
+       y1="23.890968"
+       x2="2.4973762"
+       y2="23.890968" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3480"
+       id="linearGradient2895"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,1.095875,-1.1068307,0,63.640268,-12.823447)"
+       x1="40.808029"
+       y1="44.845047"
+       x2="40.808029"
+       y2="26.149443" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3793"
+       id="linearGradient2909"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.5572773,0,0,-0.55176119,-0.385008,45.079159)"
+       x1="62.952984"
+       y1="23.890968"
+       x2="2.4973762"
+       y2="23.890968" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3480"
+       id="linearGradient2911"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,1.095875,-1.1068307,0,63.640268,-12.823447)"
+       x1="40.808029"
+       y1="44.845047"
+       x2="40.808029"
+       y2="26.149443" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4222"
+       id="linearGradient2913"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.62721007,0,0,-0.58770295,28.204115,47.595297)"
+       x1="3.8877637"
+       y1="26.022909"
+       x2="-8.7979088"
+       y2="26.022909" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4222"
+       id="linearGradient2916"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.62721007,0,0,-0.58770295,19.935396,29.595297)"
+       x1="3.8877637"
+       y1="26.022909"
+       x2="-8.7979088"
+       y2="26.022909" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3793"
+       id="linearGradient2919"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.5572773,0,0,-0.55176119,48.524519,27.079159)"
+       x1="62.952984"
+       y1="23.890968"
+       x2="2.4973762"
+       y2="23.890968" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3480"
+       id="linearGradient2921"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,1.095875,1.1068307,0,-15.500757,-30.823447)"
+       x1="40.808029"
+       y1="44.845047"
+       x2="40.808029"
+       y2="26.149443" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3793"
+       id="linearGradient2925"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.5572773,0,0,-0.55176119,-0.385008,45.079159)"
+       x1="62.952984"
+       y1="23.890968"
+       x2="2.4973762"
+       y2="23.890968" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3480"
+       id="linearGradient2927"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,1.095875,-1.1068307,0,63.640268,-12.823447)"
+       x1="40.808029"
+       y1="44.845047"
+       x2="40.808029"
+       y2="26.149443" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4222"
+       id="linearGradient2929"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.62721007,0,0,-0.58770295,28.204115,47.595297)"
+       x1="3.8877637"
+       y1="26.022909"
+       x2="-8.7979088"
+       y2="26.022909" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4222"
+       id="linearGradient2932"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.62721007,0,0,-0.58770295,28.204115,47.595297)"
+       x1="3.8877637"
+       y1="26.022909"
+       x2="-8.7979088"
+       y2="26.022909" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3793"
+       id="linearGradient2935"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.5572773,0,0,-0.55176119,-0.385008,45.079159)"
+       x1="62.952984"
+       y1="23.890968"
+       x2="2.4973762"
+       y2="23.890968" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3480"
+       id="linearGradient2937"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,1.095875,-1.1068307,0,63.640268,-12.823447)"
+       x1="40.808029"
+       y1="44.845047"
+       x2="40.808029"
+       y2="26.149443" />
+  </defs>
+  <g
+     id="layer1">
+    <g
+       id="g6334">
+      <path
+         d="m 73.25,4.625 c 0,2.0020323 -4.756974,3.6250001 -10.625,3.6250001 C 56.756974,8.2500001 52,6.6270323 52,4.625 52,2.6229677 56.756974,0.99999989 62.625,0.99999989 c 5.868026,0 10.625,1.62296781 10.625,3.62500011 l 0,0 z"
+         transform="matrix(1.9262213,0,0,2.1088276,-97.163508,29.602172)"
+         id="path8836"
+         style="opacity:0.4;fill:url(#radialGradient5729);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:0.49589729;marker:none;visibility:visible;display:inline;overflow:visible" />
+      <path
+         d="m 44.500921,23 c 0,11.316512 -9.178384,20.500922 -20.487463,20.500922 -11.30908,0 -20.4874629,-9.18441 -20.4874629,-20.500922 0,-11.316509 9.1783829,-20.5009224 20.4874629,-20.5009224 11.309079,0 20.487463,9.1844134 20.487463,20.5009224 z"
+         id="path1307"
+         style="fill:url(#radialGradient5551);fill-opacity:1;stroke:url(#linearGradient5553);stroke-width:0.99815506;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="M 43.219099,19.337303 43.03226,20.057842 C 42.479353,19.598341 41.858575,19.21192 41.228194,18.808339 l -1.383757,0.143595 -1.264237,-1.007844 0,1.247283 1.083135,0.577996 0.720932,0.57578 0.963449,-0.768406 c 0.242517,0.320344 0.481723,0.640687 0.722585,0.961031 l 0,0.95998 -1.08479,0.864133 -1.985167,0.961031 -1.503445,1.058044 -0.963448,-0.770739 0.481724,-0.864133 -0.961957,-0.768403 -1.62462,-2.448926 -1.383757,-1.103574 -0.362204,0.287307 0.54314,1.393213 1.021718,0.816269 c 0.583533,1.18798 1.160774,2.323424 1.927064,3.458986 1.188253,0 2.30847,-0.08896 3.48861,-0.193795 l 0,0.672677 -1.443683,2.497372 -1.323998,1.05571 -1.083133,1.634872 c 0,0.896122 0,1.792244 0,2.688249 l 0.362204,1.058043 -0.601411,0.478882 -1.325653,0.576827 -1.383756,0.816269 1.14455,0.912115 -1.564859,0.962198 0.300623,0.622477 -2.347372,1.874314 -1.563204,0 -1.323998,0.576828 -0.843926,0 0,-0.768404 -0.358894,-1.539144 c -0.465667,-0.964534 -0.950536,-1.92218 -1.443684,-2.879825 0,-0.70688 0.05976,-1.406872 0.119686,-2.113636 l 0.603068,-0.95998 -0.843929,-1.153773 0.06142,-1.584674 -1.14455,-0.912115 0.572274,-1.32025 -0.931169,-0.745056 -1.626273,0 -0.541485,-0.432068 -1.62462,0.721124 -0.661169,-0.529547 -1.5051,0.912582 c -1.02172,-0.816853 -2.045094,-1.633121 -3.068303,-2.44939 L 13.07,22.841935 l 1.083137,-1.151436 -0.601412,-0.479933 1.322342,-2.210651 c 1.086444,-0.953092 2.221227,-1.867425 3.369089,-2.785143 l 2.046584,-0.384204 2.285956,-0.191576 1.564859,0.288473 2.226032,1.583506 0.78251,-0.623643 1.081479,-0.09573 2.046584,0.479932 1.564861,0 1.083134,-0.672675 0.481723,-0.479932 -1.08479,-0.479932 -1.80572,-0.09573 c -0.501093,-0.490204 -0.966759,-1.005508 -1.561715,-1.441076 l -0.603065,0.191574 -0.240865,1.249502 -1.083133,-0.864131 -0.239207,-0.962199 -1.20282,-0.670338 -0.48338,0 1.20431,0.959978 -0.481723,0.864134 -0.961959,0.191576 0.60141,-0.864134 -1.084791,-0.383036 -0.960303,-0.768403 -1.807377,0.287304 -0.239206,0.383036 -1.083134,0.481099 -0.601411,1.056877 -1.503445,0.527797 -0.662824,-0.527797 -0.720932,0 0,-1.729435 1.564859,-0.576829 1.20282,0 -0.242517,-0.671507 -0.960303,-0.672675 1.62313,-0.240609 0.902032,-0.719371 0.720931,-0.8653012 1.325654,0 -0.362206,-0.6715064 0.843929,-0.3842031 0,0.7684043 1.804066,0.2873052 1.804067,-1.0557095 0.121174,-0.481099 1.563205,-0.7678216 c -0.56582,0.049618 -1.131638,0.08604 -1.684545,0.1921611 l 0,-0.8651834 0.601409,-0.9605654 -0.601409,0 -1.321678,0.8641345 -0.362207,0.4805153 0.362207,0.673259 -0.603067,1.1514366 -0.96196,-0.3842011 -0.840618,-0.6715065 -1.325651,0.6715065 -0.481725,-1.5362228 2.285956,-1.0562945 0,-0.5768291 L 25.223524,4.7847867 27.509479,4.4 l 1.56486,0.3847867 2.166268,0.9599803 -1.564858,0 1.564858,1.1526075 1.202823,-0.9599824 c 0,0 4.786235,2.4031505 7.258281,5.7266459 2.405352,3.233831 3.412213,6.909414 3.517388,7.673265 z"
+         id="path4023"
+         style="opacity:0.5;fill:#000000;fill-opacity:1;fill-rule:nonzero;stroke:none" />
+      <path
+         d="M 43.219099,18.237303 43.03226,18.957842 C 42.479353,18.498341 41.858575,18.11192 41.228194,17.708339 l -1.383757,0.143595 -1.264237,-1.007844 0,1.247283 1.083135,0.577996 0.720932,0.57578 0.963449,-0.768406 c 0.242517,0.320344 0.481723,0.640687 0.722585,0.961031 l 0,0.95998 -1.08479,0.864133 -1.985167,0.961031 -1.503445,1.058044 -0.963448,-0.770739 0.481724,-0.864133 -0.961957,-0.768403 -1.62462,-2.448926 -1.383757,-1.103574 -0.362204,0.287307 0.54314,1.393213 1.021718,0.816269 c 0.583533,1.18798 1.160774,2.323424 1.927064,3.458986 1.188253,0 2.30847,-0.08896 3.48861,-0.193795 l 0,0.672677 -1.443683,2.497372 -1.323998,1.05571 -1.083133,1.634872 c 0,0.896122 0,1.792244 0,2.688249 l 0.362204,1.058043 -0.601411,0.478882 -1.325653,0.576827 -1.383756,0.816269 1.14455,0.912115 -1.564859,0.962198 0.300623,0.622477 -2.347372,1.874314 -1.563204,0 -1.323998,0.576828 -0.843926,0 0,-0.768404 -0.358894,-1.539144 c -0.465667,-0.964534 -0.950536,-1.92218 -1.443684,-2.879825 0,-0.70688 0.05976,-1.406872 0.119686,-2.113636 l 0.603068,-0.95998 -0.843929,-1.153773 0.06142,-1.584674 -1.14455,-0.912115 0.572274,-1.32025 -0.931169,-0.745056 -1.626273,0 -0.541485,-0.432068 -1.62462,0.721124 -0.661169,-0.529547 -1.5051,0.912582 c -1.02172,-0.816853 -2.045094,-1.633121 -3.068303,-2.44939 L 13.07,21.741935 l 1.083137,-1.151436 -0.601412,-0.479933 1.322342,-2.210651 c 1.086444,-0.953092 2.221227,-1.867425 3.369089,-2.785143 l 2.046584,-0.384204 2.285956,-0.191576 1.564859,0.288473 2.226032,1.583506 0.78251,-0.623643 1.081479,-0.09573 2.046584,0.479932 1.564861,0 1.083134,-0.672675 0.481723,-0.479932 -1.08479,-0.479932 -1.80572,-0.09573 c -0.501093,-0.490204 -0.966759,-1.005508 -1.561715,-1.441076 l -0.603065,0.191574 -0.240865,1.249502 -1.083133,-0.864131 -0.239207,-0.962199 -1.20282,-0.670338 -0.48338,0 1.20431,0.959978 -0.481723,0.864134 -0.961959,0.191576 0.60141,-0.864134 -1.084791,-0.383036 -0.960303,-0.768403 -1.807377,0.287304 -0.239206,0.383036 -1.083134,0.481099 -0.601411,1.056877 -1.503445,0.527797 -0.662824,-0.527797 -0.720932,0 0,-1.729435 1.564859,-0.576829 1.20282,0 -0.242517,-0.671507 -0.960303,-0.672675 1.62313,-0.240609 0.902032,-0.719371 0.720931,-0.8653012 1.325654,0 -0.362206,-0.6715064 0.843929,-0.3842031 0,0.7684043 1.804066,0.2873052 1.804067,-1.0557095 0.121174,-0.481099 1.563205,-0.7678216 c -0.56582,0.049618 -1.131638,0.08604 -1.684545,0.1921611 l 0,-0.8651834 0.601409,-0.9605654 -0.601409,0 -1.321678,0.8641345 -0.362207,0.4805153 0.362207,0.673259 -0.603067,1.1514366 -0.96196,-0.3842011 -0.840618,-0.6715065 -1.325651,0.6715065 -0.481725,-1.5362228 2.285956,-1.0562945 0,-0.5768291 L 25.223524,3.6847867 27.509479,3.3 l 1.56486,0.3847867 2.166268,0.9599803 -1.564858,0 1.564858,1.1526075 1.202823,-0.9599824 c 0,0 4.786235,2.4031505 7.258281,5.7266459 2.405352,3.233831 3.412213,6.909414 3.517388,7.673265 z"
+         id="path6628"
+         style="fill:url(#radialGradient6332);fill-opacity:1;fill-rule:nonzero;stroke:none" />
+      <path
+         d="m 43.501763,23 c 0,10.764976 -8.736791,19.501764 -19.501765,19.501764 C 13.235024,42.501764 4.4982338,33.764976 4.4982338,23 c 0,-10.764974 8.7367902,-19.5017646 19.5017642,-19.5017646 10.764974,0 19.501765,8.7367906 19.501765,19.5017646 z"
+         id="path3164"
+         style="opacity:0.4;fill:none;stroke:url(#radialGradient5540);stroke-width:0.99647081;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="m 42.999998,16.746704 c 0,7.114117 -8.512001,11.02908 -18.999999,11.02908 -10.488002,0 -19.0000006,-3.914963 -19.0000006,-11.02908 C 4.9999984,9.632588 13.511997,2 23.999999,2 34.487997,2 42.999998,9.632588 42.999998,16.746704 z"
+         id="path3154"
+         style="opacity:0.4;fill:url(#radialGradient5537);fill-opacity:1;stroke:none" />
+      <path
+         d="m 46,24.25 c 0,9.664983 -7.835017,17.5 -17.5,17.5 -9.664983,0 -17.5,-7.835017 -17.5,-17.5 0,-9.664983 7.835017,-17.5 17.5,-17.5 9.664983,0 17.5,7.835017 17.5,17.5 l 0,0 z"
+         transform="matrix(1.076193,-0.2912862,0.1952728,0.7143165,-11.182741,14.979481)"
+         id="path2218"
+         style="opacity:0.6;fill:none;stroke:url(#linearGradient5745);stroke-width:1.09524393;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="m 46,24.25 c 0,9.664983 -7.835017,17.5 -17.5,17.5 -9.664983,0 -17.5,-7.835017 -17.5,-17.5 0,-9.664983 7.835017,-17.5 17.5,-17.5 9.664983,0 17.5,7.835017 17.5,17.5 l 0,0 z"
+         transform="matrix(1.1247273,-0.00679075,0.00112312,0.7429216,-7.8873839,2.6776872)"
+         id="path2230"
+         style="opacity:0.6;fill:none;stroke:url(#linearGradient5747);stroke-width:1.0902828;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="m 46,24.25 c 0,9.664983 -7.835017,17.5 -17.5,17.5 -9.664983,0 -17.5,-7.835017 -17.5,-17.5 0,-9.664983 7.835017,-17.5 17.5,-17.5 9.664983,0 17.5,7.835017 17.5,17.5 l 0,0 z"
+         transform="matrix(-0.09940095,-1.1197712,0.6946105,-0.03998764,8.1749534,56.475018)"
+         id="path2234"
+         style="opacity:0.6;fill:none;stroke:url(#linearGradient5749);stroke-width:1.12890089;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="m 46,24.25 c 0,9.664983 -7.835017,17.5 -17.5,17.5 -9.664983,0 -17.5,-7.835017 -17.5,-17.5 0,-9.664983 7.835017,-17.5 17.5,-17.5 9.664983,0 17.5,7.835017 17.5,17.5 l 0,0 z"
+         transform="matrix(-0.1600777,-1.1032472,0.4856389,0.01692093,16.935466,54.089297)"
+         id="path2240"
+         style="fill:none;stroke:url(#linearGradient5751);stroke-width:1.36711621;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="m 31.375,37.875 c 0,0.966498 -0.783502,1.75 -1.75,1.75 -0.966498,0 -1.75,-0.783502 -1.75,-1.75 0,-0.966498 0.783502,-1.75 1.75,-1.75 0.966498,0 1.75,0.783502 1.75,1.75 l 0,0 z"
+         transform="matrix(0.7873429,-0.2144143,0.2141677,0.7882494,1.2604149,11.541737)"
+         id="path2255"
+         style="opacity:0.8;fill:#ffffff;fill-opacity:1;stroke:none" />
+      <path
+         d="m 31.375,37.875 c 0,0.966498 -0.783502,1.75 -1.75,1.75 -0.966498,0 -1.75,-0.783502 -1.75,-1.75 0,-0.966498 0.783502,-1.75 1.75,-1.75 0.966498,0 1.75,0.783502 1.75,1.75 l 0,0 z"
+         transform="matrix(0.6748654,-0.1837837,0.2141677,0.7882494,-14.193998,12.29353)"
+         id="path2275"
+         style="opacity:0.5;fill:#ffffff;fill-opacity:1;stroke:none" />
+      <path
+         d="m 31.375,37.875 c 0,0.966498 -0.783502,1.75 -1.75,1.75 -0.966498,0 -1.75,-0.783502 -1.75,-1.75 0,-0.966498 0.783502,-1.75 1.75,-1.75 0.966498,0 1.75,0.783502 1.75,1.75 l 0,0 z"
+         transform="matrix(0.7873429,-0.2144143,0.324169,0.6373544,-8.3660962,-9.8985024)"
+         id="path2283"
+         style="opacity:0.8;fill:#ffffff;fill-opacity:1;stroke:none" />
+      <path
+         d="m 31.375,37.875 c 0,0.966498 -0.783502,1.75 -1.75,1.75 -0.966498,0 -1.75,-0.783502 -1.75,-1.75 0,-0.966498 0.783502,-1.75 1.75,-1.75 0.966498,0 1.75,0.783502 1.75,1.75 l 0,0 z"
+         transform="matrix(0.7873429,-0.2144143,-0.01326253,0.7292459,-10.705973,-10.742804)"
+         id="path2291"
+         style="opacity:0.5;fill:#ffffff;fill-opacity:1;stroke:none" />
+    </g>
+  </g>
+  <path
+     d="M 13.510432,43.897051 0.635437,32.397053 13.510432,20.897054 l 0,5.999999 20.874998,0 0,10.999999 -20.874998,0 0,5.999999 z"
+     id="path4348"
+     style="fill:url(#linearGradient2935);fill-opacity:1;fill-rule:nonzero;stroke:url(#linearGradient2937);stroke-width:0.99999988;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+  <path
+     d="M 12.510432,41.529717 2.17448,32.397053 l 10.335952,-9.242375 0,4.742375 20.839142,0 0.06052,8.999999 -20.899663,0 0,4.632665 z"
+     id="path4360"
+     style="opacity:0.35400008;fill:none;stroke:url(#linearGradient2932);stroke-width:0.99999988;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+  <path
+     style="fill:url(#linearGradient2919);fill-opacity:1;fill-rule:nonzero;stroke:url(#linearGradient2921);stroke-width:0.99999988;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible"
+     id="path2905"
+     d="M 34.629079,25.897051 47.504074,14.397053 34.629079,2.897054 l 0,5.999999 -20.874998,0 0,10.999999 20.874998,0 0,5.999999 z" />
+  <path
+     style="opacity:0.35400008;fill:none;stroke:url(#linearGradient2916);stroke-width:0.99999988;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible"
+     id="path2907"
+     d="m 35.629079,23.529717 10.335952,-9.132664 -10.335952,-9.242375 0,4.742375 -20.839142,0 -0.06052,8.999999 20.899663,0 0,4.632665 z" />
+  <path
+     d="m 35.629079,23.529717 10.335952,-9.132664 -10.335952,-9.242375 0,4.742375 -20.839142,0 -0.06052,8.999999 20.899663,0 0,4.632665 z"
+     id="path2923"
+     style="opacity:0.35400008;fill:none;stroke:url(#linearGradient2916);stroke-width:0.99999988;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+  <path
+     style="opacity:0.35400008;fill:none;stroke:url(#linearGradient2932);stroke-width:0.99999988;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible"
+     id="path2939"
+     d="M 12.510432,41.529717 2.17448,32.397053 l 10.335952,-9.242375 0,4.742375 20.839142,0 0.06052,8.999999 -20.899663,0 0,4.632665 z" />
+</svg>
diff -pruN 3.4.1-6/netspeed/data/misc/ok.svg 3.4.1+git20201022.a0d3415c-1/netspeed/data/misc/ok.svg
--- 3.4.1-6/netspeed/data/misc/ok.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/netspeed/data/misc/ok.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,107 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="256"
+   height="256"
+   id="svg2165"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   version="1.0"
+   sodipodi:docbase="/home/paradoxxx/svn/cairo-dock-plugin-dev-area/netspeed/data"
+   sodipodi:docname="ok.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <defs
+     id="defs2167">
+    <filter
+       inkscape:collect="always"
+       id="filter4270">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="3.3681571"
+         id="feGaussianBlur4272" />
+    </filter>
+    <filter
+       inkscape:collect="always"
+       id="filter7201">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="0.56135954"
+         id="feGaussianBlur7203" />
+    </filter>
+  </defs>
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="1.375"
+     inkscape:cx="100.43395"
+     inkscape:cy="123.07068"
+     inkscape:current-layer="layer1"
+     showgrid="true"
+     inkscape:document-units="px"
+     inkscape:grid-bbox="true"
+     width="256px"
+     height="256px"
+     inkscape:window-width="822"
+     inkscape:window-height="598"
+     inkscape:window-x="1192"
+     inkscape:window-y="123" />
+  <metadata
+     id="metadata2170">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     id="layer1"
+     inkscape:label="Layer 1"
+     inkscape:groupmode="layer">
+    <path
+       sodipodi:type="star"
+       style="fill:#abaeab;fill-opacity:1;fill-rule:nonzero;filter:url(#filter4270);opacity:1"
+       id="path2177"
+       sodipodi:sides="3"
+       sodipodi:cx="128.72726"
+       sodipodi:cy="127.27273"
+       sodipodi:r1="124.48904"
+       sodipodi:r2="43.571159"
+       sodipodi:arg1="0.52639236"
+       sodipodi:arg2="1.5735899"
+       inkscape:flatsided="false"
+       inkscape:rounded="-1.25"
+       inkscape:randomized="0"
+       d="M 236.36363,189.81818 C 305.07917,71.563519 -8.1637687,170.46164 128.60555,170.84372 C 265.37486,171.22579 -47.310638,70.579086 20.743132,189.21583 C 88.796901,307.85256 159.77009,-12.87284 91.05454,105.38182 C 22.338994,223.63648 265.84435,3.1662533 129.07503,2.7841772 C -7.6942795,2.4021011 234.57548,224.22938 166.52171,105.59265 C 98.467939,-13.044095 167.64808,308.07284 236.36363,189.81818 z "
+       transform="matrix(1.0748874,0,0,1.0748874,-8.9059276,7.791537)" />
+    <path
+       sodipodi:type="star"
+       style="fill:#24d41e;fill-opacity:1;fill-rule:nonzero;filter:url(#filter7201)"
+       id="path3291"
+       sodipodi:sides="3"
+       sodipodi:cx="128.72726"
+       sodipodi:cy="127.27273"
+       sodipodi:r1="124.48904"
+       sodipodi:r2="43.571159"
+       sodipodi:arg1="0.52639236"
+       sodipodi:arg2="1.5735899"
+       inkscape:flatsided="false"
+       inkscape:rounded="-1.25"
+       inkscape:randomized="0"
+       d="M 236.36363,189.81818 C 305.07917,71.563519 -8.1637687,170.46164 128.60555,170.84372 C 265.37486,171.22579 -47.310638,70.579086 20.743132,189.21583 C 88.796901,307.85256 159.77009,-12.87284 91.05454,105.38182 C 22.338994,223.63648 265.84435,3.1662533 129.07503,2.7841772 C -7.6942795,2.4021011 234.57548,224.22938 166.52171,105.59265 C 98.467939,-13.044095 167.64808,308.07284 236.36363,189.81818 z "
+       transform="matrix(0.9883932,0,0,0.9883932,1.5845996,18.207015)" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/netspeed/data/misc/unknown.svg 3.4.1+git20201022.a0d3415c-1/netspeed/data/misc/unknown.svg
--- 3.4.1-6/netspeed/data/misc/unknown.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/netspeed/data/misc/unknown.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,107 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="256"
+   height="256"
+   id="svg2165"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   version="1.0"
+   sodipodi:docbase="/home/paradoxxx/svn/cairo-dock-plugin-dev-area/netspeed/data"
+   sodipodi:docname="unknown.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <defs
+     id="defs2167">
+    <filter
+       inkscape:collect="always"
+       id="filter4270">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="3.3681571"
+         id="feGaussianBlur4272" />
+    </filter>
+    <filter
+       inkscape:collect="always"
+       id="filter7201">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="0.56135954"
+         id="feGaussianBlur7203" />
+    </filter>
+  </defs>
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="1.375"
+     inkscape:cx="100.43395"
+     inkscape:cy="123.07068"
+     inkscape:current-layer="layer1"
+     showgrid="true"
+     inkscape:document-units="px"
+     inkscape:grid-bbox="true"
+     width="256px"
+     height="256px"
+     inkscape:window-width="822"
+     inkscape:window-height="598"
+     inkscape:window-x="1192"
+     inkscape:window-y="123" />
+  <metadata
+     id="metadata2170">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     id="layer1"
+     inkscape:label="Layer 1"
+     inkscape:groupmode="layer">
+    <path
+       sodipodi:type="star"
+       style="fill:#abaeab;fill-opacity:1;fill-rule:nonzero;filter:url(#filter4270);opacity:1"
+       id="path2177"
+       sodipodi:sides="3"
+       sodipodi:cx="128.72726"
+       sodipodi:cy="127.27273"
+       sodipodi:r1="124.48904"
+       sodipodi:r2="43.571159"
+       sodipodi:arg1="0.52639236"
+       sodipodi:arg2="1.5735899"
+       inkscape:flatsided="false"
+       inkscape:rounded="-1.25"
+       inkscape:randomized="0"
+       d="M 236.36363,189.81818 C 305.07917,71.563519 -8.1637687,170.46164 128.60555,170.84372 C 265.37486,171.22579 -47.310638,70.579086 20.743132,189.21583 C 88.796901,307.85256 159.77009,-12.87284 91.05454,105.38182 C 22.338994,223.63648 265.84435,3.1662533 129.07503,2.7841772 C -7.6942795,2.4021011 234.57548,224.22938 166.52171,105.59265 C 98.467939,-13.044095 167.64808,308.07284 236.36363,189.81818 z "
+       transform="matrix(1.0748874,0,0,1.0748874,-8.9059276,7.791537)" />
+    <path
+       sodipodi:type="star"
+       style="fill:#fff800;fill-opacity:1;fill-rule:nonzero;filter:url(#filter7201)"
+       id="path3291"
+       sodipodi:sides="3"
+       sodipodi:cx="128.72726"
+       sodipodi:cy="127.27273"
+       sodipodi:r1="124.48904"
+       sodipodi:r2="43.571159"
+       sodipodi:arg1="0.52639236"
+       sodipodi:arg2="1.5735899"
+       inkscape:flatsided="false"
+       inkscape:rounded="-1.25"
+       inkscape:randomized="0"
+       d="M 236.36363,189.81818 C 305.07917,71.563519 -8.1637687,170.46164 128.60555,170.84372 C 265.37486,171.22579 -47.310638,70.579086 20.743132,189.21583 C 88.796901,307.85256 159.77009,-12.87284 91.05454,105.38182 C 22.338994,223.63648 265.84435,3.1662533 129.07503,2.7841772 C -7.6942795,2.4021011 234.57548,224.22938 166.52171,105.59265 C 98.467939,-13.044095 167.64808,308.07284 236.36363,189.81818 z "
+       transform="matrix(0.9883932,0,0,0.9883932,1.5845996,18.207015)" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/Network-Monitor/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/Network-Monitor/data/misc/icon.svg
--- 3.4.1-6/Network-Monitor/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Network-Monitor/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,775 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   version="1.0"
+   width="48"
+   height="48"
+   id="svg2"
+   inkscape:version="0.47pre4 r22446"
+   sodipodi:docname="link-0.svg">
+  <metadata
+     id="metadata46">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <dc:title></dc:title>
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <sodipodi:namedview
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1"
+     objecttolerance="10"
+     gridtolerance="10"
+     guidetolerance="10"
+     inkscape:pageopacity="0"
+     inkscape:pageshadow="2"
+     inkscape:window-width="1417"
+     inkscape:window-height="800"
+     id="namedview44"
+     showgrid="false"
+     inkscape:zoom="6.1300268"
+     inkscape:cx="7.092166"
+     inkscape:cy="23.568063"
+     inkscape:window-x="0"
+     inkscape:window-y="25"
+     inkscape:window-maximized="0"
+     inkscape:current-layer="svg2" />
+  <defs
+     id="defs4">
+    <inkscape:perspective
+       sodipodi:type="inkscape:persp3d"
+       inkscape:vp_x="0 : 24 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_z="48 : 24 : 1"
+       inkscape:persp3d-origin="24 : 16 : 1"
+       id="perspective48" />
+    <linearGradient
+       id="linearGradient6326">
+      <stop
+         id="stop6328"
+         style="stop-color:#da8813;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6330"
+         style="stop-color:#c56212;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3156">
+      <stop
+         id="stop3158"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3160"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6493">
+      <stop
+         id="stop6495"
+         style="stop-color:#cd8033;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6497"
+         style="stop-color:#bb5e12;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4103">
+      <stop
+         id="stop4105"
+         style="stop-color:#edd563;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4107"
+         style="stop-color:#e08223;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient8838">
+      <stop
+         id="stop8840"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop8842"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="62.625"
+       cy="4.625"
+       r="10.625"
+       fx="62.625"
+       fy="4.625"
+       id="radialGradient5729"
+       xlink:href="#linearGradient8838"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1,0,0,0.341176,0,3.047059)" />
+    <linearGradient
+       x1="24.335312"
+       y1="61.852856"
+       x2="28.290144"
+       y2="20.663898"
+       id="linearGradient5745"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="27.888655"
+       y1="-0.81503254"
+       x2="28.290144"
+       y2="20.663898"
+       id="linearGradient5747"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="28.220636"
+       y1="-2.3103411"
+       x2="28.290144"
+       y2="20.663898"
+       id="linearGradient5749"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="30.501778"
+       y1="55.647495"
+       x2="29.724815"
+       y2="24.653727"
+       id="linearGradient5751"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       cx="22.944935"
+       cy="11.222695"
+       r="14"
+       fx="22.944935"
+       fy="4.7612267"
+       id="radialGradient5537"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.3571044,0.01021839,-0.00631345,0.8384895,-10.874695,1.3057951)" />
+    <radialGradient
+       cx="22.125"
+       cy="10.874998"
+       r="20"
+       fx="22.125"
+       fy="10.874998"
+       id="radialGradient5540"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.0099925,-0.1119962,0.05668752,0.5112133,-5.8375646,1.7934718)" />
+    <radialGradient
+       cx="20.038782"
+       cy="12.610249"
+       r="22.463524"
+       fx="20.038782"
+       fy="12.610249"
+       id="radialGradient5551"
+       xlink:href="#linearGradient3242-187-536"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.9524671,-0.05018139,0.03650944,1.4214826,-20.408334,-5.9089096)" />
+    <linearGradient
+       x1="29.01346"
+       y1="29"
+       x2="29.75"
+       y2="50"
+       id="linearGradient5553"
+       xlink:href="#linearGradient6403"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-5.0000016,-6)" />
+    <radialGradient
+       cx="26"
+       cy="15.240479"
+       r="15.074549"
+       fx="26"
+       fy="15.240479"
+       id="radialGradient6332"
+       xlink:href="#linearGradient2490-182-124"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(2.2554569,0,-2.1857407e-8,2.0564463,-32.641879,-17.341228)" />
+    <inkscape:perspective
+       id="perspective7211"
+       inkscape:persp3d-origin="24 : 16 : 1"
+       inkscape:vp_z="48 : 24 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_x="0 : 24 : 1"
+       sodipodi:type="inkscape:persp3d" />
+    <linearGradient
+       gradientTransform="matrix(1.0408371,0,0,1.0332075,-1.5095624,-1.577785)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient2782"
+       id="linearGradient2471"
+       y2="57.84119"
+       x2="10.728143"
+       y1="9.965703"
+       x1="10.440458" />
+    <linearGradient
+       id="linearGradient2782">
+      <stop
+         offset="0"
+         style="stop-color:white;stop-opacity:1"
+         id="stop2784" />
+      <stop
+         offset="1"
+         style="stop-color:white;stop-opacity:0"
+         id="stop2786" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="matrix(1.0426124,0,0,1.0259981,0.1237342,-1.1239408)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient6403"
+       id="linearGradient2474"
+       y2="44.971333"
+       x2="12.35"
+       y1="3.0447822"
+       x1="12.350002" />
+    <linearGradient
+       gradientTransform="matrix(1.0408371,0,0,1.0332076,20.490446,-1.577786)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient2782"
+       id="linearGradient2481"
+       y2="57.84119"
+       x2="10.728143"
+       y1="9.965703"
+       x1="10.440458" />
+    <linearGradient
+       gradientTransform="matrix(1.0426124,0,0,1.0259979,22.123737,-1.1239411)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient6403"
+       id="linearGradient2484"
+       y2="44.971333"
+       x2="12.35"
+       y1="3.0447831"
+       x1="12.349999" />
+    <linearGradient
+       id="linearGradient6403">
+      <stop
+         offset="0"
+         style="stop-color:#eeeeec;stop-opacity:1"
+         id="stop6405" />
+      <stop
+         offset="1"
+         style="stop-color:#a1a59b;stop-opacity:1"
+         id="stop6409" />
+    </linearGradient>
+    <inkscape:perspective
+       id="perspective8012"
+       inkscape:persp3d-origin="24 : 16 : 1"
+       inkscape:vp_z="48 : 24 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_x="0 : 24 : 1"
+       sodipodi:type="inkscape:persp3d" />
+    <linearGradient
+       gradientTransform="matrix(1.0317991,-1.0287411,1.0317991,1.0287411,-59.146403,28.538123)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient1322"
+       id="linearGradient2179"
+       y2="46.420933"
+       x2="34.162975"
+       y1="30.701427"
+       x1="49.882484" />
+    <linearGradient
+       id="linearGradient1322">
+      <stop
+         offset="0"
+         style="stop-color:#b4b4b4;stop-opacity:1"
+         id="stop1324" />
+      <stop
+         offset="1"
+         style="stop-color:#505050;stop-opacity:1"
+         id="stop1326" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="matrix(1.0317991,-1.0287411,1.0317991,1.0287411,-26.552863,23.963668)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient7916"
+       id="linearGradient2181"
+       y2="32.849743"
+       x2="16.14513"
+       y1="17.130236"
+       x1="31.864639" />
+    <linearGradient
+       id="linearGradient7916">
+      <stop
+         offset="0"
+         style="stop-color:white;stop-opacity:1"
+         id="stop7918" />
+      <stop
+         offset="1"
+         style="stop-color:white;stop-opacity:0.34020618"
+         id="stop7920" />
+    </linearGradient>
+    <radialGradient
+       gradientTransform="matrix(0.914812,0.01265023,-0.00821502,0.213562,2.253914,27.18889)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient2091"
+       id="radialGradient2177"
+       fy="35.127438"
+       fx="23.070683"
+       r="10.31934"
+       cy="35.127438"
+       cx="23.070683" />
+    <linearGradient
+       id="linearGradient2091">
+      <stop
+         offset="0"
+         style="stop-color:black;stop-opacity:1"
+         id="stop2093" />
+      <stop
+         offset="1"
+         style="stop-color:black;stop-opacity:0"
+         id="stop2095" />
+    </linearGradient>
+    <inkscape:perspective
+       id="perspective8055"
+       inkscape:persp3d-origin="24 : 16 : 1"
+       inkscape:vp_z="48 : 24 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_x="0 : 24 : 1"
+       sodipodi:type="inkscape:persp3d" />
+    <linearGradient
+       gradientTransform="matrix(0,-0.8625289,0.8486552,0,3.2697061,51.022455)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient2187"
+       id="linearGradient2479"
+       y2="-0.43754432"
+       x2="20.483631"
+       y1="12.820101"
+       x1="20.483631" />
+    <linearGradient
+       id="linearGradient2187">
+      <stop
+         offset="0"
+         style="stop-color:#ffffff;stop-opacity:0.64341086"
+         id="stop2189" />
+      <stop
+         offset="1"
+         style="stop-color:#ffffff;stop-opacity:0"
+         id="stop2191" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="matrix(0.7241542,0,0,0.7359927,1.978684,11.204435)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3698"
+       id="linearGradient2482"
+       y2="15.5"
+       x2="-0.073089309"
+       y1="15.5"
+       x1="23.996828" />
+    <linearGradient
+       id="linearGradient3698">
+      <stop
+         offset="0"
+         style="stop-color:#7ea8ce;stop-opacity:1"
+         id="stop3700" />
+      <stop
+         offset="0.76278943"
+         style="stop-color:#568dc0;stop-opacity:0.81568629"
+         id="stop3702" />
+      <stop
+         offset="1"
+         style="stop-color:#c9e1f8;stop-opacity:0"
+         id="stop3704" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="matrix(0.7241542,0,0,0.7359927,1.978684,11.204435)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3914"
+       id="linearGradient2484-9"
+       y2="36"
+       x2="-0.097514458"
+       y1="36"
+       x1="36.5" />
+    <linearGradient
+       id="linearGradient3914">
+      <stop
+         offset="0"
+         style="stop-color:#2c79c0;stop-opacity:1"
+         id="stop3916" />
+      <stop
+         offset="0.79722267"
+         style="stop-color:#2970b3;stop-opacity:0.49803922"
+         id="stop3918" />
+      <stop
+         offset="1"
+         style="stop-color:#236098;stop-opacity:0"
+         id="stop3920" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="matrix(0.9976985,0,0,1.0406866,0.1638029,-1.1057939)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient8589"
+       id="linearGradient3312"
+       y2="5.4565363"
+       x2="36.358372"
+       y1="8.0590115"
+       x1="32.892288" />
+    <linearGradient
+       id="linearGradient8589">
+      <stop
+         offset="0"
+         style="stop-color:#fefefe;stop-opacity:1"
+         id="stop8591" />
+      <stop
+         offset="1"
+         style="stop-color:#cbcbcb;stop-opacity:1"
+         id="stop8593" />
+    </linearGradient>
+    <filter
+       id="filter3212"
+       x="-0.14846256"
+       width="1.2969251"
+       y="-0.16434373"
+       height="1.3286875">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="0.77391625"
+         id="feGaussianBlur3214" />
+    </filter>
+    <linearGradient
+       gradientTransform="matrix(1,0,0,0.9777778,0,-0.9666693)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3211"
+       id="linearGradient3316"
+       y2="46.01725"
+       x2="24"
+       y1="1.9999999"
+       x1="24" />
+    <linearGradient
+       id="linearGradient3211">
+      <stop
+         offset="0"
+         style="stop-color:#ffffff;stop-opacity:1"
+         id="stop3213" />
+      <stop
+         offset="1"
+         style="stop-color:#ffffff;stop-opacity:0"
+         id="stop3215" />
+    </linearGradient>
+    <radialGradient
+       gradientTransform="matrix(0.3617022,0,0,-0.3907784,0.8510637,47.517004)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#XMLID_8_"
+       id="radialGradient3319"
+       r="139.55859"
+       cy="112.3047"
+       cx="102" />
+    <radialGradient
+       gradientUnits="userSpaceOnUse"
+       id="XMLID_8_"
+       r="139.55859"
+       cy="112.3047"
+       cx="102">
+      <stop
+         offset="0"
+         style="stop-color:#b7b8b9;stop-opacity:1"
+         id="stop41" />
+      <stop
+         offset="0.18851049"
+         style="stop-color:#ececec;stop-opacity:1"
+         id="stop47" />
+      <stop
+         offset="0.25718147"
+         style="stop-color:#fafafa;stop-opacity:0"
+         id="stop49" />
+      <stop
+         offset="0.30111277"
+         style="stop-color:#ffffff;stop-opacity:0"
+         id="stop51" />
+      <stop
+         offset="0.53130001"
+         style="stop-color:#fafafa;stop-opacity:0"
+         id="stop53" />
+      <stop
+         offset="0.84490001"
+         style="stop-color:#ebecec;stop-opacity:0"
+         id="stop55" />
+      <stop
+         offset="1"
+         style="stop-color:#e1e2e3;stop-opacity:0"
+         id="stop57" />
+    </radialGradient>
+    <linearGradient
+       gradientTransform="matrix(1,0,0,0.9561695,-1.0064697e-7,-1.914922)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3600"
+       id="linearGradient3322"
+       y2="47.013336"
+       x2="25.132275"
+       y1="0.98520643"
+       x1="25.132275" />
+    <linearGradient
+       id="linearGradient3600">
+      <stop
+         offset="0"
+         style="stop-color:#f4f4f4;stop-opacity:1"
+         id="stop3602" />
+      <stop
+         offset="1"
+         style="stop-color:#dbdbdb;stop-opacity:1"
+         id="stop3604" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="matrix(0.8074968,0,0,0.8948322,59.410232,-2.9805533)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3104"
+       id="linearGradient3324"
+       y2="2.9062471"
+       x2="-51.786404"
+       y1="50.786446"
+       x1="-51.786404" />
+    <linearGradient
+       id="linearGradient3104">
+      <stop
+         offset="0"
+         style="stop-color:#aaaaaa;stop-opacity:1"
+         id="stop3106" />
+      <stop
+         offset="1"
+         style="stop-color:#c8c8c8;stop-opacity:1"
+         id="stop3108" />
+    </linearGradient>
+    <radialGradient
+       gradientTransform="matrix(2.3039948e-2,0,0,1.4700216e-2,26.360882,37.040176)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient5060"
+       id="radialGradient3327"
+       fy="486.64789"
+       fx="605.71429"
+       r="117.14286"
+       cy="486.64789"
+       cx="605.71429" />
+    <linearGradient
+       id="linearGradient5060">
+      <stop
+         offset="0"
+         style="stop-color:#000000;stop-opacity:1"
+         id="stop5062" />
+      <stop
+         offset="1"
+         style="stop-color:#000000;stop-opacity:0"
+         id="stop5064" />
+    </linearGradient>
+    <radialGradient
+       gradientTransform="matrix(-2.3039943e-2,0,0,1.4700216e-2,21.62311,37.040176)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient5060"
+       id="radialGradient3330"
+       fy="486.64789"
+       fx="605.71429"
+       r="117.14286"
+       cy="486.64789"
+       cx="605.71429" />
+    <linearGradient
+       gradientTransform="matrix(6.7324884e-2,0,0,1.4700216e-2,-0.3411391,37.040146)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient5048"
+       id="linearGradient3333"
+       y2="609.50507"
+       x2="302.85715"
+       y1="366.64789"
+       x1="302.85715" />
+    <linearGradient
+       id="linearGradient5048">
+      <stop
+         offset="0"
+         style="stop-color:#000000;stop-opacity:0"
+         id="stop5050" />
+      <stop
+         offset="0.5"
+         style="stop-color:#000000;stop-opacity:1"
+         id="stop5056" />
+      <stop
+         offset="1"
+         style="stop-color:#000000;stop-opacity:0"
+         id="stop5052" />
+    </linearGradient>
+    <inkscape:perspective
+       id="perspective8067"
+       inkscape:persp3d-origin="24 : 16 : 1"
+       inkscape:vp_z="48 : 24 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_x="0 : 24 : 1"
+       sodipodi:type="inkscape:persp3d" />
+    <linearGradient
+       gradientTransform="matrix(2.1153735,0,0,2.1153253,-107.57709,32.426559)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient4873"
+       id="linearGradient3526"
+       y2="5.4675598"
+       x2="63.397362"
+       y1="-12.489107"
+       x1="63.397362" />
+    <linearGradient
+       id="linearGradient4873">
+      <stop
+         offset="0"
+         style="stop-color:white;stop-opacity:1"
+         id="stop4875" />
+      <stop
+         offset="1"
+         style="stop-color:white;stop-opacity:0"
+         id="stop4877" />
+    </linearGradient>
+    <radialGradient
+       gradientTransform="matrix(0,2.2874593,-3.0194057,0,36.047437,-50.630156)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3242-187-536"
+       id="radialGradient3529"
+       fy="3.9900031"
+       fx="23.895569"
+       r="20.397499"
+       cy="3.9900031"
+       cx="23.895569" />
+    <linearGradient
+       id="linearGradient3242-187-536">
+      <stop
+         offset="0"
+         style="stop-color:#8badea;stop-opacity:1"
+         id="stop2778" />
+      <stop
+         offset="0.26238"
+         style="stop-color:#6396cd;stop-opacity:1"
+         id="stop2780" />
+      <stop
+         offset="0.66093999"
+         style="stop-color:#3b7caf;stop-opacity:1"
+         id="stop2782" />
+      <stop
+         offset="1"
+         style="stop-color:#194c70;stop-opacity:1"
+         id="stop2784-2" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="matrix(0.9584364,0,0,0.9584366,0.9975246,1.9975253)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient2490-182-124"
+       id="linearGradient3531"
+       y2="3.0816143"
+       x2="18.379412"
+       y1="44.980297"
+       x1="18.379412" />
+    <linearGradient
+       id="linearGradient2490-182-124">
+      <stop
+         offset="0"
+         style="stop-color:#1f4b6a;stop-opacity:1"
+         id="stop2788" />
+      <stop
+         offset="1"
+         style="stop-color:#4083c2;stop-opacity:1"
+         id="stop2790" />
+    </linearGradient>
+    <radialGradient
+       gradientTransform="matrix(2.1647059,0,0,0.7529402,-111.56471,36.517647)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient8838-1"
+       id="radialGradient3534"
+       fy="4.625"
+       fx="62.625"
+       r="10.625"
+       cy="4.625"
+       cx="62.625" />
+    <linearGradient
+       id="linearGradient8838-1">
+      <stop
+         offset="0"
+         style="stop-color:black;stop-opacity:1"
+         id="stop8840-0" />
+      <stop
+         offset="1"
+         style="stop-color:black;stop-opacity:0"
+         id="stop8842-2" />
+    </linearGradient>
+    <inkscape:perspective
+       id="perspective8163"
+       inkscape:persp3d-origin="24 : 16 : 1"
+       inkscape:vp_z="48 : 24 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_x="0 : 24 : 1"
+       sodipodi:type="inkscape:persp3d" />
+  </defs>
+  <g
+     id="layer1">
+    <g
+       id="g6334">
+      <path
+         d="m 73.25,4.625 c 0,2.0020323 -4.756974,3.6250001 -10.625,3.6250001 C 56.756974,8.2500001 52,6.6270323 52,4.625 52,2.6229677 56.756974,0.99999989 62.625,0.99999989 c 5.868026,0 10.625,1.62296781 10.625,3.62500011 l 0,0 z"
+         transform="matrix(1.9262213,0,0,2.1088276,-97.163508,29.602172)"
+         id="path8836"
+         style="opacity:0.4;fill:url(#radialGradient5729);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:0.49589729;marker:none;visibility:visible;display:inline;overflow:visible" />
+      <path
+         d="m 44.500921,23 c 0,11.316512 -9.178384,20.500922 -20.487463,20.500922 -11.30908,0 -20.4874629,-9.18441 -20.4874629,-20.500922 0,-11.316509 9.1783829,-20.5009224 20.4874629,-20.5009224 11.309079,0 20.487463,9.1844134 20.487463,20.5009224 z"
+         id="path1307"
+         style="fill:url(#radialGradient5551);fill-opacity:1;stroke:#1f4b6a;stroke-width:0.99815505999999998;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="M 43.219099,18.237303 43.03226,18.957842 C 42.479353,18.498341 41.858575,18.11192 41.228194,17.708339 l -1.383757,0.143595 -1.264237,-1.007844 0,1.247283 1.083135,0.577996 0.720932,0.57578 0.963449,-0.768406 c 0.242517,0.320344 0.481723,0.640687 0.722585,0.961031 l 0,0.95998 -1.08479,0.864133 -1.985167,0.961031 -1.503445,1.058044 -0.963448,-0.770739 0.481724,-0.864133 -0.961957,-0.768403 -1.62462,-2.448926 -1.383757,-1.103574 -0.362204,0.287307 0.54314,1.393213 1.021718,0.816269 c 0.583533,1.18798 1.160774,2.323424 1.927064,3.458986 1.188253,0 2.30847,-0.08896 3.48861,-0.193795 l 0,0.672677 -1.443683,2.497372 -1.323998,1.05571 -1.083133,1.634872 c 0,0.896122 0,1.792244 0,2.688249 l 0.362204,1.058043 -0.601411,0.478882 -1.325653,0.576827 -1.383756,0.816269 1.14455,0.912115 -1.564859,0.962198 0.300623,0.622477 -2.347372,1.874314 -1.563204,0 -1.323998,0.576828 -0.843926,0 0,-0.768404 -0.358894,-1.539144 c -0.465667,-0.964534 -0.950536,-1.92218 -1.443684,-2.879825 0,-0.70688 0.05976,-1.406872 0.119686,-2.113636 l 0.603068,-0.95998 -0.843929,-1.153773 0.06142,-1.584674 -1.14455,-0.912115 0.572274,-1.32025 -0.931169,-0.745056 -1.626273,0 -0.541485,-0.432068 -1.62462,0.721124 -0.661169,-0.529547 -1.5051,0.912582 c -1.02172,-0.816853 -2.045094,-1.633121 -3.068303,-2.44939 L 13.07,21.741935 l 1.083137,-1.151436 -0.601412,-0.479933 1.322342,-2.210651 c 1.086444,-0.953092 2.221227,-1.867425 3.369089,-2.785143 l 2.046584,-0.384204 2.285956,-0.191576 1.564859,0.288473 2.226032,1.583506 0.78251,-0.623643 1.081479,-0.09573 2.046584,0.479932 1.564861,0 1.083134,-0.672675 0.481723,-0.479932 -1.08479,-0.479932 -1.80572,-0.09573 c -0.501093,-0.490204 -0.966759,-1.005508 -1.561715,-1.441076 l -0.603065,0.191574 -0.240865,1.249502 -1.083133,-0.864131 -0.239207,-0.962199 -1.20282,-0.670338 -0.48338,0 1.20431,0.959978 -0.481723,0.864134 -0.961959,0.191576 0.60141,-0.864134 -1.084791,-0.383036 -0.960303,-0.768403 -1.807377,0.287304 -0.239206,0.383036 -1.083134,0.481099 -0.601411,1.056877 -1.503445,0.527797 -0.662824,-0.527797 -0.720932,0 0,-1.729435 1.564859,-0.576829 1.20282,0 -0.242517,-0.671507 -0.960303,-0.672675 1.62313,-0.240609 0.902032,-0.719371 0.720931,-0.8653012 1.325654,0 -0.362206,-0.6715064 0.843929,-0.3842031 0,0.7684043 1.804066,0.2873052 1.804067,-1.0557095 0.121174,-0.481099 1.563205,-0.7678216 c -0.56582,0.049618 -1.131638,0.08604 -1.684545,0.1921611 l 0,-0.8651834 0.601409,-0.9605654 -0.601409,0 -1.321678,0.8641345 -0.362207,0.4805153 0.362207,0.673259 -0.603067,1.1514366 -0.96196,-0.3842011 -0.840618,-0.6715065 -1.325651,0.6715065 -0.481725,-1.5362228 2.285956,-1.0562945 0,-0.5768291 L 25.223524,3.6847867 27.509479,3.3 l 1.56486,0.3847867 2.166268,0.9599803 -1.564858,0 1.564858,1.1526075 1.202823,-0.9599824 c 0,0 4.786235,2.4031505 7.258281,5.7266459 2.405352,3.233831 3.412213,6.909414 3.517388,7.673265 z"
+         id="path6628"
+         style="fill:url(#radialGradient6332);fill-opacity:1.0;fill-rule:nonzero;stroke:none" />
+      <path
+         d="m 43.501763,23 c 0,10.764976 -8.736791,19.501764 -19.501765,19.501764 C 13.235024,42.501764 4.4982338,33.764976 4.4982338,23 c 0,-10.764974 8.7367902,-19.5017646 19.5017642,-19.5017646 10.764974,0 19.501765,8.7367906 19.501765,19.5017646 z"
+         id="path3164"
+         style="opacity:0.7;fill:none;stroke:url(#radialGradient5540);stroke-width:0.99647081;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="m 42.999998,16.746704 c 0,7.114117 -8.512001,11.02908 -18.999999,11.02908 -10.488002,0 -19.0000006,-3.914963 -19.0000006,-11.02908 C 4.9999984,9.632588 13.511997,2 23.999999,2 34.487997,2 42.999998,9.632588 42.999998,16.746704 z"
+         id="path3154"
+         style="opacity:0.5;fill:url(#radialGradient5537);fill-opacity:1;stroke:none" />
+      <path
+         d="m 46,24.25 c 0,9.664983 -7.835017,17.5 -17.5,17.5 -9.664983,0 -17.5,-7.835017 -17.5,-17.5 0,-9.664983 7.835017,-17.5 17.5,-17.5 9.664983,0 17.5,7.835017 17.5,17.5 l 0,0 z"
+         transform="matrix(1.076193,-0.2912862,0.1952728,0.7143165,-11.182741,14.979481)"
+         id="path2218"
+         style="opacity:0.5;fill:none;stroke:url(#linearGradient5745);stroke-width:1.09524393;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="m 46,24.25 c 0,9.664983 -7.835017,17.5 -17.5,17.5 -9.664983,0 -17.5,-7.835017 -17.5,-17.5 0,-9.664983 7.835017,-17.5 17.5,-17.5 9.664983,0 17.5,7.835017 17.5,17.5 l 0,0 z"
+         transform="matrix(1.1247273,-0.00679075,0.00112312,0.7429216,-7.8873839,2.6776872)"
+         id="path2230"
+         style="opacity:0.5;fill:none;stroke:url(#linearGradient5747);stroke-width:1.0902828;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="m 46,24.25 c 0,9.664983 -7.835017,17.5 -17.5,17.5 -9.664983,0 -17.5,-7.835017 -17.5,-17.5 0,-9.664983 7.835017,-17.5 17.5,-17.5 9.664983,0 17.5,7.835017 17.5,17.5 l 0,0 z"
+         transform="matrix(-0.09940095,-1.1197712,0.6946105,-0.03998764,8.1749534,56.475018)"
+         id="path2234"
+         style="opacity:0.5;fill:none;stroke:url(#linearGradient5749);stroke-width:1.12890089;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="m 46,24.25 c 0,9.664983 -7.835017,17.5 -17.5,17.5 -9.664983,0 -17.5,-7.835017 -17.5,-17.5 0,-9.664983 7.835017,-17.5 17.5,-17.5 9.664983,0 17.5,7.835017 17.5,17.5 l 0,0 z"
+         transform="matrix(-0.1600777,-1.1032472,0.4856389,0.01692093,16.935466,54.089297)"
+         id="path2240"
+         style="opacity:0.5;fill:none;stroke:url(#linearGradient5751);stroke-width:1.36711621;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="m 31.375,37.875 c 0,0.966498 -0.783502,1.75 -1.75,1.75 -0.966498,0 -1.75,-0.783502 -1.75,-1.75 0,-0.966498 0.783502,-1.75 1.75,-1.75 0.966498,0 1.75,0.783502 1.75,1.75 l 0,0 z"
+         transform="matrix(0.7873429,-0.2144143,0.2141677,0.7882494,1.2604149,11.541737)"
+         id="path2255"
+         style="opacity:0.4;fill:white;fill-opacity:1;stroke:none" />
+      <path
+         d="m 31.375,37.875 c 0,0.966498 -0.783502,1.75 -1.75,1.75 -0.966498,0 -1.75,-0.783502 -1.75,-1.75 0,-0.966498 0.783502,-1.75 1.75,-1.75 0.966498,0 1.75,0.783502 1.75,1.75 l 0,0 z"
+         transform="matrix(0.6748654,-0.1837837,0.2141677,0.7882494,-14.193998,12.29353)"
+         id="path2275"
+         style="opacity:0.4;fill:white;fill-opacity:1;stroke:none" />
+      <path
+         d="m 31.375,37.875 c 0,0.966498 -0.783502,1.75 -1.75,1.75 -0.966498,0 -1.75,-0.783502 -1.75,-1.75 0,-0.966498 0.783502,-1.75 1.75,-1.75 0.966498,0 1.75,0.783502 1.75,1.75 l 0,0 z"
+         transform="matrix(0.7873429,-0.2144143,0.324169,0.6373544,-8.3660962,-9.8985024)"
+         id="path2283"
+         style="opacity:0.4;fill:white;fill-opacity:1;stroke:none" />
+      <path
+         d="m 31.375,37.875 c 0,0.966498 -0.783502,1.75 -1.75,1.75 -0.966498,0 -1.75,-0.783502 -1.75,-1.75 0,-0.966498 0.783502,-1.75 1.75,-1.75 0.966498,0 1.75,0.783502 1.75,1.75 l 0,0 z"
+         transform="matrix(0.7873429,-0.2144143,-0.01326253,0.7292459,-10.705973,-10.742804)"
+         id="path2291"
+         style="opacity:0.4;fill:white;fill-opacity:1;stroke:none" />
+    </g>
+  </g>
+</svg>
diff -pruN 3.4.1-6/po/da.po 3.4.1+git20201022.a0d3415c-1/po/da.po
--- 3.4.1-6/po/da.po	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/po/da.po	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,8827 @@
+# Danish translation for cairo-dock-plug-ins
+# Copyright (c) 2013 Rosetta Contributors and Canonical Ltd 2013
+# This file is distributed under the same license as the cairo-dock-plug-ins package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2013.
+#
+msgid ""
+msgstr ""
+"Project-Id-Version: cairo-dock-plug-ins\n"
+"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
+"POT-Creation-Date: 2014-10-19 00:22+0000\n"
+"PO-Revision-Date: 2015-11-05 11:58+0000\n"
+"Last-Translator: Morten Thiellesen <morten.nt92@gmail.com>\n"
+"Language-Team: Steen Jakobsen <mail@steen-jakobsen.dk>\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"X-Launchpad-Export-Date: 2015-11-06 05:14+0000\n"
+"X-Generator: Launchpad (build 17838)\n"
+"Language: da\n"
+
+#: ../Animated-icons/src/applet-blink.c:77 ../Animated-icons/data/messages:11
+#: ../Animated-icons/data/messages:31 ../Animated-icons/data/messages:55
+#: ../Animated-icons/data/messages:173
+msgid "Blink"
+msgstr "Blink"
+
+#: ../Animated-icons/src/applet-bounce.c:182 ../Animated-icons/data/messages:7
+#: ../Animated-icons/data/messages:27 ../Animated-icons/data/messages:51
+#: ../Animated-icons/data/messages:159
+msgid "Bounce"
+msgstr "Hoppende"
+
+#: ../Animated-icons/src/applet-busy.c:111 ../Animated-icons/data/messages:21
+#: ../Animated-icons/data/messages:41 ../Animated-icons/data/messages:65
+#: ../Animated-icons/data/messages:181
+msgid "Busy"
+msgstr "Travl"
+
+#: ../Animated-icons/src/applet-init.c:39
+msgid "Animated icons"
+msgstr "Animerede ikoner"
+
+#: ../Animated-icons/src/applet-init.c:42
+msgid "This plug-in provides many different animations for your icons."
+msgstr "Dette plug-in giver mange forskellige animationer til dine ikoner."
+
+#: ../Animated-icons/src/applet-pulse.c:106 ../Animated-icons/data/messages:13
+#: ../Animated-icons/data/messages:33 ../Animated-icons/data/messages:57
+#: ../Animated-icons/data/messages:147
+msgid "Pulse"
+msgstr "Pulserende"
+
+#: ../Animated-icons/src/applet-rotation.c:389
+#: ../Animated-icons/data/messages:9 ../Animated-icons/data/messages:29
+#: ../Animated-icons/data/messages:53
+msgid "Rotate"
+msgstr "rotere"
+
+#: ../Animated-icons/src/applet-spot.c:266 ../Animated-icons/data/messages:19
+#: ../Animated-icons/data/messages:39 ../Animated-icons/data/messages:63
+#: ../Animated-icons/data/messages:87 ../Animated-icons/data/messages:95
+msgid "Spot"
+msgstr "Observerende"
+
+#: ../Animated-icons/src/applet-wave.c:287 ../Animated-icons/data/messages:17
+#: ../Animated-icons/data/messages:37 ../Animated-icons/data/messages:61
+#: ../Animated-icons/data/messages:135
+msgid "Wave"
+msgstr "Bølgende"
+
+#: ../Animated-icons/src/applet-wobbly.c:532
+#: ../Animated-icons/data/messages:15 ../Animated-icons/data/messages:35
+#: ../Animated-icons/data/messages:59 ../Animated-icons/data/messages:119
+msgid "Wobbly"
+msgstr "Blævrende"
+
+#: ../Cairo-Penguin/src/applet-init.c:33
+msgid ""
+"Add a lively Penguin in your dock !\n"
+"Left click to change the animation,\n"
+"Middle-click to disturb him ^_^\n"
+"Tux images are taken from Pingus, some other characters are available or can "
+"be added easily."
+msgstr ""
+"Tilføj en livlig pingvin i din dock!\n"
+"Venstre Klik for at ændre animationen,\n"
+"Center-klik for at forstyrre ham ^_^\n"
+"Billeder af Tux er taget fra Pingus, der findes også andre karakterer, der "
+"nemt kan tilføjes."
+
+#: ../Cairo-Penguin/src/applet-init.c:39
+msgid "Cairo-Penguin"
+msgstr "Cairo-Penguin"
+
+#: ../Cairo-Penguin/src/applet-notifications.c:29
+msgid "Hey, I'm here!"
+msgstr "Hej, jeg er her!"
+
+#: ../Cairo-Penguin/src/applet-notifications.c:30
+msgid "Sorry but I'm busy right now."
+msgstr "Undskyld men jeg har travlt lige nu."
+
+#: ../Cairo-Penguin/src/applet-notifications.c:31
+msgid ""
+"I don't have time to play with you, I have to dig and mine all these icons."
+msgstr ""
+
+#: ../Cairo-Penguin/src/applet-notifications.c:32
+msgid "Your dock is so messy! Let me clean it."
+msgstr "Din dock er så rodet! Lad mig rydde op for dig."
+
+#: ../Cairo-Penguin/src/applet-notifications.c:33
+msgid "Admit my superiority on you as a penguin!"
+msgstr ""
+
+#: ../Cairo-Penguin/src/applet-notifications.c:34
+msgid "Wait, do you want to kill me?!"
+msgstr "Vent, ønsker du at slå mig ihjel ?!"
+
+#: ../Cairo-Penguin/src/applet-notifications.c:35
+msgid "Do you know how painful it is to be clicked on??"
+msgstr "Ved du, hvor smertefuldt det er at blive klikket på ??"
+
+#: ../Cairo-Penguin/src/applet-notifications.c:36
+msgid "It's my dock now, mwahahaha!"
+msgstr "Det er min dock nu, mwahahaha!"
+
+#: ../Cairo-Penguin/src/applet-notifications.c:37
+msgid "I want to be a pirate!"
+msgstr "Jeg vil være en pirat!"
+
+#: ../Cairo-Penguin/src/applet-notifications.c:38
+msgid "You shall not pass!"
+msgstr "Du kommer ikke forbi!"
+
+#: ../Cairo-Penguin/src/applet-notifications.c:39
+msgid "I'm your father!"
+msgstr "Jeg er din far!"
+
+#: ../Cairo-Penguin/src/applet-notifications.c:40
+msgid ""
+"- Gee, Brain, what do you want to do tonight?\n"
+"- The same thing we do every night, Pinky : try to take over the Dock!"
+msgstr ""
+
+#: ../Cairo-Penguin/src/applet-notifications.c:41
+msgid "For Aiur!"
+msgstr ""
+
+#: ../Cairo-Penguin/src/applet-notifications.c:139
+msgid "Wake up"
+msgstr "Vågn op"
+
+#: ../Cairo-Penguin/src/applet-notifications.c:143
+msgid "Keep quiet"
+msgstr "Vær stille"
+
+#: ../Cairo-Penguin/src/applet-notifications.c:158
+msgid "Start XPenguins"
+msgstr "Start XPenguins"
+
+#: ../Cairo-Penguin/src/applet-notifications.c:159
+msgid "Stop XPenguins"
+msgstr "Stop XPenguins"
+
+#: ../Cairo-Penguin/src/applet-notifications.c:182
+#: ../Cairo-Penguin/src/applet-notifications.c:184
+msgid "Zzzzz"
+msgstr "Zzzzz"
+
+#: ../Clipper/src/applet-init.c:32
+msgid ""
+"This applet keeps a trace of the clipboard and mouse selection,\n"
+"so that you can recall them quickly. It's a clone of the well-know Klipper.\n"
+"It supports clipboard and mouse selection, predefined actions, and "
+"persistent items.\n"
+"Left-click to popup the clipboard and mouse selection history,\n"
+"Drop text on the icon to create persistent items, and middle-clck to recall "
+"them."
+msgstr ""
+
+#: ../Clipper/src/applet-init.c:39
+msgid "Clipboard history"
+msgstr "Udklipsholder historie"
+
+#: ../Clipper/src/applet-init.c:87
+msgid "Pop-up the items menu"
+msgstr "Pop-op element menuen:"
+
+#: ../Clipper/src/applet-notifications.c:33
+msgid "The clipboard history is empty."
+msgstr "Udklipsholderens historik er tom:"
+
+#: ../Clipper/src/applet-notifications.c:89
+msgid "Clear clipboard History"
+msgstr "Ryd udklipsholderens Historik"
+
+#: ../Clipper/src/applet-notifications.c:91
+msgid "Paste all copied items"
+msgstr "Indsæt alle kopierede elementer"
+
+#: ../Clipper/src/applet-notifications.c:99
+msgid ""
+"No persistent items.\n"
+"You can add some by drag and dropping some text on the icon."
+msgstr ""
+
+#: ../Clipper/src/applet-notifications.c:143
+msgid "No items yet."
+msgstr "Ingen elementer endnu."
+
+#: ../Composite-Manager/src/applet-composite-manager.c:430
+#: ../Composite-Manager/src/applet-composite-manager.c:445
+msgid "No compositor is available."
+msgstr ""
+
+#: ../Composite-Manager/src/applet-composite-manager.c:453
+#: ../Composite-Manager/src/applet-composite-manager.c:468
+msgid "No fallback is available."
+msgstr ""
+
+#: ../Composite-Manager/src/applet-composite-manager.c:508
+#, c-format
+msgid "You need to install '%s'"
+msgstr "Du skal installere ‘%s’"
+
+#: ../Composite-Manager/src/applet-composite-manager.c:519
+msgid "No configuration tool is available."
+msgstr "Ingen konfigurations-værktøj til rådighed."
+
+#: ../Composite-Manager/src/applet-init.c:27
+msgid "Composite-Manager"
+msgstr "Komposit-manager"
+
+#: ../Composite-Manager/src/applet-init.c:30
+msgid ""
+"This applet allows you to <b>toggle the composite ON/OFF</b>.\n"
+"The composite is what allows transparency on the desktop, but it can slow "
+"down your PC, especially during games.\n"
+"<b>Click</b> on the icon to switch the composite ON/OFF. You can define a "
+"<b>shortcut</b> for this action.\n"
+"The applet also lets you acces to some actions of the Window-Manager, from "
+"<b>middle-click and the menu</b>.\n"
+"You can define in the configuration a Window-Manager that will provide the "
+"composite, and another as a fallback."
+msgstr ""
+
+#: ../Composite-Manager/src/applet-init.c:52
+msgid "Toggle the composite ON/OFF"
+msgstr "Tænd/Sluk Komposit-manageren"
+
+#: ../Composite-Manager/src/applet-notifications.c:43
+msgid "Toggle composite?"
+msgstr ""
+
+#: ../Composite-Manager/src/applet-notifications.c:120
+#: ../Composite-Manager/data/messages:125
+msgid "Edit Window-Manager settings"
+msgstr "Rediger indstillinger for Vindues-Manageren"
+
+#: ../Composite-Manager/src/applet-notifications.c:120
+#: ../Composite-Manager/src/applet-notifications.c:127
+#: ../Composite-Manager/src/applet-notifications.c:136
+#: ../Composite-Manager/src/applet-notifications.c:145
+#: ../Composite-Manager/src/applet-notifications.c:154
+#: ../Composite-Manager/src/applet-notifications.c:163
+#: ../Folders/src/applet-notifications.c:390
+#: ../GMenu/src/applet-notifications.c:76
+#: ../RSSreader/src/applet-notifications.c:129
+#: ../Screenshot/src/applet-notifications.c:61
+#: ../System-Monitor/src/applet-notifications.c:107
+#: ../Xgamma/src/applet-notifications.c:87
+#: ../alsaMixer/src/applet-notifications.c:85
+#: ../dustbin/src/applet-notifications.c:149
+#: ../mail/src/cd-mail-applet-notifications.c:153
+#: ../musicPlayer/src/applet-notifications.c:313
+#: ../netspeed/src/applet-notifications.c:105
+#: ../quick-browser/src/applet-notifications.c:41
+#: ../shortcuts/src/applet-notifications.c:321
+#: ../shortcuts/src/applet-notifications.c:366
+#: ../showDesktop/src/applet-notifications.c:181
+#: ../showDesktop/src/applet-notifications.c:193
+#: ../showDesktop/src/applet-notifications.c:205
+#: ../slider/src/applet-notifications.c:228
+#: ../slider/src/applet-notifications.c:270
+#: ../stack/src/applet-notifications.c:214
+#: ../switcher/src/applet-notifications.c:303
+#: ../switcher/src/applet-notifications.c:308
+#: ../switcher/src/applet-notifications.c:317
+#: ../switcher/src/applet-notifications.c:326
+#: ../tomboy/src/tomboy-notifications.c:217
+#: ../wifi/src/applet-notifications.c:88
+msgid "middle-click"
+msgstr "Center-klik"
+
+#: ../Composite-Manager/src/applet-notifications.c:127
+#: ../Composite-Manager/data/messages:127
+msgid "Reload Window-Manager"
+msgstr "Genindlæse Vindues-Manageren"
+
+#: ../Composite-Manager/src/applet-notifications.c:136
+#: ../showDesktop/src/applet-notifications.c:181
+#: ../showDesktop/src/applet-notifications.c:183
+#: ../Composite-Manager/data/messages:129 ../showDesktop/data/messages:99
+#: ../showDesktop/data/messages:113 ../switcher/data/messages:137
+msgid "Show desktop"
+msgstr "Vis skrivebord"
+
+#: ../Composite-Manager/src/applet-notifications.c:145
+#: ../showDesktop/src/applet-notifications.c:193
+#: ../showDesktop/src/applet-notifications.c:195
+#: ../switcher/src/applet-notifications.c:317
+#: ../Composite-Manager/data/messages:131 ../showDesktop/data/messages:107
+#: ../showDesktop/data/messages:121 ../switcher/data/messages:139
+msgid "Expose all the desktops"
+msgstr "Eksponer alle skriveborde"
+
+#: ../Composite-Manager/src/applet-notifications.c:154
+#: ../switcher/src/applet-notifications.c:326
+#: ../Composite-Manager/data/messages:133 ../switcher/data/messages:141
+msgid "Expose all the windows"
+msgstr "Eksponer alle vinduer"
+
+#: ../Composite-Manager/src/applet-notifications.c:163
+#: ../showDesktop/src/applet-notifications.c:205
+#: ../showDesktop/src/applet-notifications.c:207
+#: ../Composite-Manager/data/messages:135 ../showDesktop/data/messages:105
+#: ../showDesktop/data/messages:119
+msgid "Show the Widget Layer"
+msgstr ""
+
+#: ../Dbus/src/applet-init.c:36
+msgid ""
+"This plug-in lets extern applications interact on the dock.\n"
+"The communication between both sides is based on Dbus"
+msgstr ""
+
+#: ../Dbus/src/interface-applet-signals.c:428
+#: ../Dbus/src/interface-applet-signals.c:459
+msgid "Sorry, this module couldn't be added."
+msgstr "Beklager, modulet kunne ikke tilføjes."
+
+#: ../Dbus/src/interface-applet-signals.c:463
+#: ../Dbus/src/interface-applet-signals.c:469
+msgid "The module has been added, but couldn't be launched."
+msgstr "Modulet er tilføjet, men kunne ikke startes."
+
+#: ../Dbus/src/interface-applet-signals.c:472
+#, c-format
+msgid ""
+"The applet '%s' has been succefully updated and automatically reloaded"
+msgstr ""
+
+#: ../Dbus/src/interface-applet-signals.c:472
+#, c-format
+msgid ""
+"The applet '%s' has been succefully installed and automatically launched"
+msgstr ""
+
+#: ../Disks/src/applet-disks.c:45 ../Disks/src/applet-disks.c:53
+#: ../Network-Monitor/src/applet-netspeed.c:42
+#: ../Network-Monitor/src/applet-netspeed.c:50
+#: ../netspeed/src/applet-netspeed.c:48 ../netspeed/src/applet-netspeed.c:56
+msgid "B"
+msgstr "B"
+
+#: ../Disks/src/applet-disks.c:61 ../Folders/src/applet-notifications.c:140
+#: ../Network-Monitor/src/applet-netspeed.c:58
+#: ../netspeed/src/applet-netspeed.c:64
+msgid "KB"
+msgstr "KB"
+
+#: ../Disks/src/applet-disks.c:69 ../Folders/src/applet-notifications.c:138
+#: ../Network-Monitor/src/applet-netspeed.c:66
+#: ../netspeed/src/applet-netspeed.c:72
+#: ../netspeed/src/applet-notifications.c:37
+#: ../netspeed/src/applet-notifications.c:38
+msgid "MB"
+msgstr "MB"
+
+#: ../Disks/src/applet-disks.c:77 ../Network-Monitor/src/applet-netspeed.c:74
+#: ../netspeed/src/applet-netspeed.c:80
+msgid "GB"
+msgstr "GB"
+
+#: ../Disks/src/applet-disks.c:85 ../Network-Monitor/src/applet-netspeed.c:82
+#: ../netspeed/src/applet-netspeed.c:88
+msgid "TB"
+msgstr "TB"
+
+#: ../Disks/src/applet-disks.c:171
+msgid "r"
+msgstr "r"
+
+#: ../Disks/src/applet-disks.c:171
+msgid "w"
+msgstr "w"
+
+#: ../Disks/src/applet-disks.c:175
+msgid "N/A"
+msgstr "N/A"
+
+#: ../Disks/src/applet-init.c:29
+msgid "Disks"
+msgstr "Diske"
+
+#: ../Disks/src/applet-init.c:32
+msgid ""
+"<b><i>Monitors disks speed and space</i></b>.\n"
+"\n"
+"This applet show your disks informations. You can activate both options at "
+"once, but they're better separated in 2 or more instances of the applet.\n"
+"Using both in the same applet can cause problems with the speed display not "
+"scaling down.\n"
+"\n"
+"<b>Disk space</b> :  Show disk transfer rates. Up to 10 partitions\n"
+"  You need to configure the mount point of each monitored partition like / "
+"or /home\n"
+"  Better seen in a gauge, with 30 or 60s refresh rate and really short or no "
+"transition delay.\n"
+"\n"
+"<b>Disk speed</b> :  Show disk transfer rates. Up to 5 disks\n"
+"  You need to configure the name of each monitored disk with his device name "
+"like sda or sdb\n"
+"  Better seen in a graph, with 2 or 3s refresh rate and no delay between "
+"transitions.\n"
+"\n"
+"Second release, a lot more need to be done :\n"
+" <u>Free space :</u>\n"
+" - Popup with detailed informations.\n"
+" - Editable labels ?\n"
+" <u>Speed :</u>\n"
+" - All disks option.\n"
+" - Pop up showing disks info to know what to add in the list.\n"
+" - Editable labels ?\n"
+" - Get real block size for disks\n"
+" <u>Global</u>\n"
+" - Find actions : left, middle click, drop and wheel.\n"
+" - Fill menu with actions.\n"
+msgstr ""
+
+#: ../Disks/src/applet-notifications.c:72
+#: ../System-Monitor/src/applet-init.c:35
+msgid "System Monitor"
+msgstr "System Monitor"
+
+#: ../Doncky/src/applet-cpusage.c:67 ../System-Monitor/src/applet-cpusage.c:60
+#: ../System-Monitor/src/applet-cpusage.c:65
+msgid "day(s)"
+msgstr "dag(e)"
+
+#: ../Doncky/src/applet-init.c:35
+msgid ""
+"This applet allows you to write texts and monitor your system\n"
+"with a \"text style desklet\".\n"
+"USAGE:\n"
+"  - NEED TO BE DETACHED FROM THE DOCK TO WORK !\n"
+"  - Middle-clic to reload values"
+msgstr ""
+
+#: ../Doncky/src/applet-notifications.c:210
+msgid "It doesn't seem to be a valid XML file."
+msgstr ""
+
+#: ../Doncky/src/applet-xml.c:311
+msgid "Please wait..."
+msgstr "Vent venligst…"
+
+#: ../Folders/src/applet-init.c:29
+msgid "Folders"
+msgstr "Mapper"
+
+#: ../Folders/src/applet-init.c:32
+msgid ""
+"This applet imports folders inside the Dock\n"
+"You can have as many instances of this applet as you want, each one with a "
+"different folder.\n"
+"To add a folder in your dock:\n"
+" - activate the applet, open its configuration panel, and select a folder\n"
+" - or just drop a folder into the dock\n"
+"Middle-click on the main icon opens the folder.\n"
+msgstr ""
+
+#: ../Folders/src/applet-init.c:87 ../Folders/src/applet-init.c:150
+#: ../Folders/src/applet-notifications.c:42
+msgid "Open the configuration of the applet to choose a folder to import."
+msgstr ""
+
+#: ../Folders/src/applet-notifications.c:54
+msgid "Empty or unreadable folder."
+msgstr "Tom eller ulæselig mappe."
+
+#: ../Folders/src/applet-notifications.c:116
+msgid "Properties:"
+msgstr "Egenskaber:"
+
+#: ../Folders/src/applet-notifications.c:136 ../Folders/data/messages:115
+msgid "Size"
+msgstr "Størrelse"
+
+#: ../Folders/src/applet-notifications.c:136
+msgid "bytes"
+msgstr "bytes"
+
+#: ../Folders/src/applet-notifications.c:150
+msgid "Last Modification"
+msgstr "Seneste ændring"
+
+#: ../Folders/src/applet-notifications.c:159
+msgid "Mime Type"
+msgstr "Mime Type"
+
+#: ../Folders/src/applet-notifications.c:169
+msgid "User ID"
+msgstr "Bruger ID"
+
+#: ../Folders/src/applet-notifications.c:169
+msgid "Group ID"
+msgstr "Gruppe ID"
+
+#: ../Folders/src/applet-notifications.c:179
+msgid "Permissions"
+msgstr "Rettigheder"
+
+#: ../Folders/src/applet-notifications.c:179
+msgid "Read"
+msgstr "Læs"
+
+#: ../Folders/src/applet-notifications.c:180
+#: ../Folders/src/applet-notifications.c:181
+#: ../Folders/src/applet-notifications.c:182 ../Disks/data/messages:105
+#: ../System-Monitor/data/messages:115 ../alsaMixer/data/messages:129
+#: ../netspeed/data/messages:115 ../slider/data/messages:169
+msgid "Yes"
+msgstr "Ja"
+
+#: ../Folders/src/applet-notifications.c:180
+#: ../Folders/src/applet-notifications.c:181
+#: ../Folders/src/applet-notifications.c:182 ../Disks/data/messages:101
+#: ../Disks/data/messages:137 ../Messaging-Menu/data/messages:17
+#: ../Network-Monitor/data/messages:19 ../Network-Monitor/data/messages:117
+#: ../RSSreader/data/messages:111 ../Status-Notifier/data/messages:21
+#: ../System-Monitor/data/messages:17 ../System-Monitor/data/messages:111
+#: ../System-Monitor/data/messages:163 ../Toons/data/messages:17
+#: ../alsaMixer/data/messages:17 ../alsaMixer/data/messages:103
+#: ../alsaMixer/data/messages:125 ../clock/data/messages:19
+#: ../clock/data/messages:105 ../keyboard-indicator/data/messages:17
+#: ../mail/data/messages:17 ../musicPlayer/data/messages:19
+#: ../netspeed/data/messages:17 ../netspeed/data/messages:111
+#: ../netspeed/data/messages:159 ../powermanager/data/messages:19
+#: ../shortcuts/data/messages:117 ../slider/data/messages:17
+#: ../slider/data/messages:167 ../weather/data/messages:19
+#: ../wifi/data/messages:17
+msgid "No"
+msgstr "Nej"
+
+#: ../Folders/src/applet-notifications.c:180
+msgid "Write"
+msgstr "Skriv"
+
+#: ../Folders/src/applet-notifications.c:181
+#: ../Scooby-Do/src/applet-backend-command.c:95
+msgid "Execute"
+msgstr "Udfør"
+
+#: ../Folders/src/applet-notifications.c:207
+msgid ""
+"Warning: could not delete this file.\n"
+"Please check file permissions."
+msgstr ""
+"Advarsel: kunne ikke slette denne fil.\n"
+"Undersøg om du har de rette tilladelser dertil."
+
+#: ../Folders/src/applet-notifications.c:221
+#, c-format
+msgid ""
+"You're about deleting this file\n"
+"  (%s)\n"
+"from your hard-disk. Sure ?"
+msgstr ""
+"Du er ved at slette denne fil\n"
+"(%s)\n"
+"fra din harddisk. Sikker?"
+
+#: ../Folders/src/applet-notifications.c:240
+#, c-format
+msgid ""
+"Warning: could not rename %s.\n"
+"Check file permissions \n"
+"and that the new name does not already exist."
+msgstr ""
+"Advarsel: kunne ikke omdøbe %s.\n"
+"Tjek rettighederne for filen \n"
+"og at det nye navn ikke allerede findes."
+
+#: ../Folders/src/applet-notifications.c:249
+msgid "Rename to:"
+msgstr "Omdøb til:"
+
+#: ../Folders/src/applet-notifications.c:264
+#: ../Scooby-Do/src/applet-backend-files.c:390
+#: ../Screenshot/src/applet-screenshot.c:419
+msgid "Pick up a directory"
+msgstr ""
+
+#: ../Folders/src/applet-notifications.c:267
+#: ../Scooby-Do/src/applet-backend-files.c:393
+#: ../Screenshot/src/applet-screenshot.c:422
+msgid "Ok"
+msgstr "Ok"
+
+#: ../Folders/src/applet-notifications.c:269
+#: ../Scooby-Do/src/applet-backend-files.c:395
+#: ../Screenshot/src/applet-screenshot.c:424
+msgid "Cancel"
+msgstr "Annuller"
+
+#: ../Folders/src/applet-notifications.c:301
+#, c-format
+msgid ""
+"Warning: could not create %s.\n"
+"Check file permissions \n"
+"and that the new name does not already exist."
+msgstr ""
+
+#: ../Folders/src/applet-notifications.c:311
+msgid "Enter a file name:"
+msgstr "Indtast et filnavn:"
+
+#: ../Folders/src/applet-notifications.c:390
+msgid "Open the folder"
+msgstr "Åbn mappen"
+
+#: ../Folders/src/applet-notifications.c:397
+msgid "Rename this file"
+msgstr "Omdøb denne fil"
+
+#: ../Folders/src/applet-notifications.c:398
+msgid "Delete this file"
+msgstr "Slet denne fil"
+
+#: ../Folders/src/applet-notifications.c:399
+msgid "Move this file"
+msgstr "Flyt denne fil"
+
+#: ../Folders/src/applet-notifications.c:405
+#: ../Recent-Events/src/applet-dialog.c:292
+#: ../Screenshot/src/applet-screenshot.c:310
+#: ../quick-browser/src/applet-menu.c:316
+#: ../slider/src/applet-notifications.c:238
+msgid "Open with"
+msgstr "Åbn med"
+
+#: ../Folders/src/applet-notifications.c:438
+msgid "Properties"
+msgstr "Egenskaber:"
+
+#: ../Folders/src/applet-notifications.c:441
+msgid "Create a new file"
+msgstr "Opret ny fil"
+
+#: ../Folders/src/applet-notifications.c:442
+msgid "Create a new folder"
+msgstr "Opret ny mappe"
+
+#: ../Folders/src/applet-notifications.c:447
+msgid "Sort by"
+msgstr "Sorter efter"
+
+#: ../Folders/src/applet-notifications.c:448
+msgid "By name"
+msgstr "Efter navn"
+
+#: ../Folders/src/applet-notifications.c:449
+msgid "By date"
+msgstr "Efter dato"
+
+#: ../Folders/src/applet-notifications.c:450
+msgid "By size"
+msgstr "Efter størrelse"
+
+#: ../Folders/src/applet-notifications.c:451
+msgid "By type"
+msgstr "Efter type"
+
+#: ../Folders/src/applet-notifications.c:489
+msgid "The folder has been imported."
+msgstr "Mappen er blevet importeret."
+
+#: ../Folders/src/applet-notifications.c:544
+msgid "Do you want to import the content of the folder too?"
+msgstr "Ønsker du at importere indholdet af mappen også?"
+
+#: ../GMenu/src/applet-apps.c:114
+msgid "Launch this new application?"
+msgstr "Start denne nye applikation?"
+
+#: ../GMenu/src/applet-entry.c:456
+msgid "Launch this command"
+msgstr "Start denne kommando"
+
+#: ../GMenu/src/applet-init.c:31
+msgid ""
+"Displays the common Applications menu and the Recently used files.\n"
+"It is compatible with any XDG compliant menu (Gnome, XFCE, KDE, ...)\n"
+"Middle-click to open a dialog to quickly launch any command (you can set up "
+"a shortkey for it, like ALT+F2)\n"
+"You can also set up a shortkey to pop up the menu (like ALT+F1)"
+msgstr ""
+
+#: ../GMenu/src/applet-init.c:37
+msgid "Applications Menu"
+msgstr "Applikations Menu"
+
+#: ../GMenu/src/applet-init.c:63
+msgid "Show/hide the Applications menu"
+msgstr "Vis/Skjul Applikations menuen"
+
+#: ../GMenu/src/applet-init.c:68
+msgid "Show/hide the quick-launch dialog"
+msgstr "Vis/skjul dialogboksen hurtig-start"
+
+#: ../GMenu/src/applet-menu.c:148 ../GMenu/data/messages:115
+msgid "Logout"
+msgstr "Log ud"
+
+#: ../GMenu/src/applet-menu.c:151 ../GMenu/data/messages:117
+msgid "Shutdown"
+msgstr "Sluk"
+
+#: ../GMenu/src/applet-notifications.c:76
+msgid "Quick launch"
+msgstr "Hurtig start"
+
+#: ../GMenu/src/applet-notifications.c:97
+msgid "Configure menu"
+msgstr "Konfigurere menu"
+
+#: ../GMenu/src/applet-notifications.c:102
+msgid "None of these applications seems available:"
+msgstr "Ser ikke ud til at nogen af applikationerne er til rådighed:"
+
+#: ../GMenu/src/applet-notifications.c:110
+msgid "Clear recent"
+msgstr "Ryd seneste"
+
+#: ../GMenu/src/applet-recent.c:53
+msgid "Recent Documents"
+msgstr "Seneste dokumenter"
+
+#: ../GMenu/src/applet-recent.c:109
+msgid "Clear the list of the recently used documents?"
+msgstr "Ryd listen over seneste anvendte dokumenter?"
+
+#: ../GMenu/src/applet-run-dialog.c:360 ../Scooby-Do/data/messages:113
+msgid "Enter a command to launch:"
+msgstr "Start denne kommando"
+
+#: ../Global-Menu/src/applet-init.c:30
+msgid "Global Menu"
+msgstr "Hoved menu"
+
+#: ../Global-Menu/src/applet-init.c:33
+msgid ""
+"This applet allows you to control the current active window:\n"
+"  close, minimize, maximize, and display the application menu.To display the "
+"menu, applications have to support this feature, which is the case on Ubuntu "
+"by default.\n"
+"You can bind a shortkey to this action."
+msgstr ""
+
+#: ../Global-Menu/src/applet-init.c:112 ../Global-Menu/src/applet-init.c:211
+msgid "Show/hide the current application menu"
+msgstr ""
+
+#: ../Global-Menu/src/applet-notifications.c:99
+msgid "The application didn't send its menu to us."
+msgstr ""
+
+#: ../Impulse/src/applet-impulse.c:169
+msgid ""
+"There is something wrong with PulseAudio.\n"
+"Can you check its status (installed? running? version?) and report this bug "
+"(if any) to forum.glx-dock.org"
+msgstr ""
+
+#: ../Impulse/src/applet-init.c:32
+msgid ""
+"Did you know that your dock can dance? :)\n"
+"If you click on this icon, the dock will dance!\n"
+"In fact, you will have a graphical equalizer into the dock\n"
+"It will analyse the signal given by PulseAudio."
+msgstr ""
+
+#: ../Indicator-Generic/src/applet-init.c:30
+msgid "Indicator-Generic"
+msgstr "Indikator-Generel"
+
+#: ../Indicator-Generic/src/applet-init.c:33
+msgid ""
+"This plug-in can display all the available Indicators into your dock.\n"
+"Indicators provide information about something, and a menu to act on it:\n"
+"  for instance, an indicator to control the printer jobs.Idle Indicators are "
+"automatically hidden.\n"
+"You can also blacklist indicators you don't want to see."
+msgstr ""
+
+#: ../Indicator-Generic/src/applet-notifications.c:34
+#, c-format
+msgid ""
+"This indicator service did not reply.\n"
+"Please check that '%s' is correctly installed and its daemon is running."
+msgstr ""
+
+#: ../MeMenu/src/applet-init.c:30
+msgid "Me Menu"
+msgstr "Min menu"
+
+#: ../MeMenu/src/applet-init.c:33
+msgid ""
+"A menu that lets you access quickly to your information, your online status, "
+"your friends."
+msgstr ""
+
+#: ../MeMenu/src/applet-notifications.c:31
+msgid "It seems that the Me-Menu is not installed on your system"
+msgstr ""
+
+#: ../Messaging-Menu/src/applet-init.c:34
+msgid "Messaging Menu"
+msgstr ""
+
+#: ../Messaging-Menu/src/applet-init.c:37
+msgid ""
+"A menu that notices you about new messages from Mail or Chat applications.\n"
+"It handles Evolution, Pidgin, Empathy, etc\n"
+"It requires the Messaging service, which is available on Ubuntu by default."
+msgstr ""
+
+#: ../Messaging-Menu/src/applet-init.c:106
+msgid "Show/hide the Messaging menu"
+msgstr ""
+
+#: ../Messaging-Menu/src/applet-notifications.c:78
+msgid ""
+"The Messaging service did not reply.\n"
+"Please check that it is correctly installed."
+msgstr ""
+
+#: ../Network-Monitor/src/applet-dbus-callbacks.c:69
+msgid "Network connection state changed to inactive."
+msgstr ""
+
+#: ../Network-Monitor/src/applet-dbus-callbacks.c:75
+msgid "Connecting..."
+msgstr ""
+
+#: ../Network-Monitor/src/applet-dbus-callbacks.c:82
+msgid "Network connection is established."
+msgstr ""
+
+#: ../Network-Monitor/src/applet-dbus-callbacks.c:88
+msgid "Network connection state changed to disconnected."
+msgstr ""
+
+#: ../Network-Monitor/src/applet-dbus-callbacks.c:150
+msgid "A cable has been plugged"
+msgstr ""
+
+#: ../Network-Monitor/src/applet-dbus-callbacks.c:150
+msgid "A cable has been unplugged"
+msgstr ""
+
+#: ../Network-Monitor/src/applet-draw.c:128 ../wifi/src/applet-draw.c:130
+msgid ""
+"Checking connection...\n"
+"Please retry in a few seconds"
+msgstr ""
+
+#: ../Network-Monitor/src/applet-draw.c:136
+msgid "Wired Connection."
+msgstr ""
+
+#: ../Network-Monitor/src/applet-draw.c:138
+#: ../Network-Monitor/src/applet-draw.c:153 ../wifi/src/applet-draw.c:147
+msgid "Interface"
+msgstr ""
+
+#: ../Network-Monitor/src/applet-draw.c:139
+#: ../Network-Monitor/src/applet-draw.c:151
+msgid "Speed"
+msgstr ""
+
+#: ../Network-Monitor/src/applet-draw.c:148 ../wifi/src/applet-draw.c:143
+msgid "Wifi enabled."
+msgstr ""
+
+#: ../Network-Monitor/src/applet-draw.c:150 ../wifi/src/applet-draw.c:145
+msgid "Network ID"
+msgstr ""
+
+#: ../Network-Monitor/src/applet-draw.c:150
+#: ../musicPlayer/src/applet-draw.c:167 ../musicPlayer/src/applet-draw.c:169
+#: ../musicPlayer/src/applet-draw.c:171
+#: ../powermanager/src/powermanager-draw.c:260
+#: ../powermanager/src/powermanager-draw.c:315
+msgid "Unknown"
+msgstr ""
+
+#: ../Network-Monitor/src/applet-draw.c:152 ../wifi/src/applet-draw.c:146
+msgid "Access point"
+msgstr ""
+
+#: ../Network-Monitor/src/applet-draw.c:154 ../wifi/src/applet-draw.c:148
+msgid "Signal Quality"
+msgstr ""
+
+#: ../Network-Monitor/src/applet-init.c:34
+msgid ""
+"This applet allows you to monitor your network connection(s).\n"
+"It can display the download/upload speeds and the wifi signal quality.\n"
+"If you have network-manager running, it can also let you choose the current "
+"wifi network.\n"
+"Left-click to pop-up some info,Scroll on the icon to switch the display "
+"between net speed and wifi."
+msgstr ""
+
+#: ../Network-Monitor/src/applet-init.c:41
+msgid "Network Monitor"
+msgstr ""
+
+#: ../Network-Monitor/src/applet-netspeed.c:202
+#: ../System-Monitor/src/applet-monitor.c:97
+#: ../System-Monitor/src/applet-top.c:429
+#: ../netspeed/src/applet-netspeed.c:243
+msgid "Loading"
+msgstr ""
+
+#: ../Network-Monitor/src/applet-notifications.c:81
+#: ../wifi/src/applet-notifications.c:85
+msgid "Check for Wireless Extension"
+msgstr ""
+
+#: ../Network-Monitor/src/applet-notifications.c:82
+#: ../wifi/src/applet-notifications.c:92
+msgid "Network Administration"
+msgstr ""
+
+#: ../Network-Monitor/src/applet-notifications.c:86
+msgid "Activate network"
+msgstr ""
+
+#: ../Network-Monitor/src/applet-notifications.c:86
+msgid "Deactivate network"
+msgstr ""
+
+#: ../Network-Monitor/src/applet-notifications.c:90
+msgid "Deactivate wifi"
+msgstr ""
+
+#: ../Network-Monitor/src/applet-notifications.c:90
+msgid "Activate wifi"
+msgstr ""
+
+#: ../RSSreader/src/applet-init.c:31
+msgid "RSSreader"
+msgstr ""
+
+#: ../RSSreader/src/applet-init.c:34
+msgid ""
+"This applet is an RSS/Atom feed reader.\n"
+"You can instanciate it as many times as you want.\n"
+"USAGE:\n"
+" - Left-click : display the complete feed lines in a dialog.\n"
+" - Middle-click : refresh the feed.\n"
+" - Scroll on the desklet : make the feed lines scroll.\n"
+" - Drag and drop a valid URL on the icon to use it,\n"
+"    or copy it and use \"Paste a new RSS Url\" in the menu.\n"
+"    or edit the Configuration Panel."
+msgstr ""
+
+#: ../RSSreader/src/applet-init.c:65 ../RSSreader/src/applet-init.c:125
+#: ../RSSreader/src/applet-notifications.c:56
+msgid "Retrieving data..."
+msgstr ""
+
+#: ../RSSreader/src/applet-notifications.c:69
+msgid "It doesn't seem to be a valid URL."
+msgstr ""
+
+#: ../RSSreader/src/applet-notifications.c:124
+msgid "Paste a new RSS Url (drag and drop)"
+msgstr ""
+
+#: ../RSSreader/src/applet-notifications.c:128
+msgid "Open with your web browser"
+msgstr ""
+
+#: ../RSSreader/src/applet-notifications.c:129
+#: ../switcher/src/applet-notifications.c:335
+msgid "Refresh"
+msgstr ""
+
+#: ../RSSreader/src/applet-rss.c:400
+msgid "Warning: couldn't retrieve data last time we tried."
+msgstr ""
+
+#: ../RSSreader/src/applet-rss.c:436
+msgid "No URL is defined."
+msgstr ""
+
+#: ../RSSreader/src/applet-rss.c:437
+msgid "No data (no connection?)"
+msgstr ""
+
+#: ../RSSreader/src/applet-rss.c:468 ../RSSreader/src/applet-rss.c:487
+msgid "Invalid data (invalid RSS/Atom feed?)"
+msgstr ""
+
+#: ../RSSreader/src/applet-rss.c:551
+msgid "No data"
+msgstr ""
+
+#: ../RSSreader/src/applet-rss.c:589
+msgid "No modification"
+msgstr ""
+
+#: ../RSSreader/src/applet-rss.c:614
+msgid "This RSS feed has been modified..."
+msgstr ""
+
+#: ../RSSreader/src/applet-rss.c:780
+msgid ""
+"No URL is defined\n"
+"You can define one by copying the URL in the clipboard,\n"
+" and selecting \"Paste the URL\" in the menu."
+msgstr ""
+
+#: ../RSSreader/src/applet-rss.c:786
+msgid ""
+"No data\n"
+"Did you set a valid RSS feed?\n"
+"Is your connection alive?"
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:316
+#: ../Screenshot/src/applet-screenshot.c:319
+#: ../quick-browser/src/applet-menu.c:346
+#: ../stack/src/applet-notifications.c:212
+msgid "Open parent folder"
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:318
+#: ../Screenshot/src/applet-screenshot.c:281
+#: ../quick-browser/src/applet-menu.c:348
+msgid "Copy the location"
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:321
+msgid "Delete this event"
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:405
+msgid "All"
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:406
+msgid "Applications"
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:407
+msgid "Documents"
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:409 ../drop-indicator/data/messages:3
+msgid "Images"
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:410
+msgid "Audio"
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:411
+msgid "Videos"
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:412
+msgid "Web"
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:413
+msgid "Others"
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:414
+msgid "Top Results"
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:420
+msgid "Look for events"
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:428
+msgid ""
+"The default boolean operator is AND. Thus the query foo bar will be "
+"interpreted as foo AND bar. To exclude a term from the result set prepend it "
+"with a minus sign - eg foo -bar. Phrase queries can be done by double "
+"quoting the string \"foo is a bar\". You can truncate terms by appending a "
+"*. "
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:470
+#: ../Screenshot/src/applet-screenshot.c:479
+msgid "File name"
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:477
+msgid "Last access"
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:522
+msgid "You need to install the Zeitgeist data engine."
+msgstr ""
+
+#: ../Recent-Events/src/applet-dialog.c:570
+msgid "Browse and search in recent events"
+msgstr ""
+
+#: ../Recent-Events/src/applet-init.c:29
+msgid "Recent-Events"
+msgstr ""
+
+#: ../Recent-Events/src/applet-init.c:58
+msgid "Show/hide the Recent Events"
+msgstr ""
+
+#: ../Recent-Events/src/applet-notifications.c:74
+#, c-format
+msgid "%d event(s) deleted"
+msgstr ""
+
+#: ../Recent-Events/src/applet-notifications.c:114
+#: ../Scooby-Do/src/applet-backend-recent.c:213 ../Scooby-Do/data/messages:107
+msgid "Recent files"
+msgstr ""
+
+#: ../Recent-Events/src/applet-notifications.c:187
+msgid "Delete today's events"
+msgstr ""
+
+#: ../Recent-Events/src/applet-notifications.c:189
+msgid "Delete all events"
+msgstr ""
+
+#: ../Remote-Control/src/applet-init.c:32
+msgid ""
+"This plug-in lets you control your dock from the keyboard\n"
+"Press the shortcut (by default Super + Return), then either:\n"
+" - press the number of the icon that you want to activate - or use the "
+"arrows to navigate into the docks and sub-docks (Ctrl + Page up/down to "
+"change to another main dock)\n"
+" - or type the name of a launcher and press Tab to automatically jump to the "
+"next suitable launcher\n"
+"Press Enter to click on the icon, Shift+Enter for Shift+click, Alt+Enter for "
+"middle click, and Ctrl+Enter for left click\n"
+"Escape or the same shortkey will cancel."
+msgstr ""
+
+#: ../Remote-Control/src/applet-init.c:42
+msgid "Control from keyboard"
+msgstr ""
+
+#: ../Remote-Control/src/applet-init.c:49
+msgid "Enable/disable the keyboard control of the dock"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-command.c:63
+#, c-format
+msgid "The value %s has been copied into the clipboard."
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-files.c:161
+msgid "Open a terminal here"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-files.c:169
+msgid "Zip folder"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-files.c:177
+#: ../Scooby-Do/src/applet-backend-files.c:251
+msgid "Move to"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-files.c:185
+#: ../Scooby-Do/src/applet-backend-files.c:259
+#: ../Scooby-Do/src/applet-backend-firefox.c:373
+msgid "Copy URL"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-files.c:227
+#: ../Scooby-Do/src/applet-backend-recent.c:146
+msgid "Open location"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-files.c:235
+msgid "Zip file"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-files.c:243
+msgid "Mail file"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-files.c:524 ../Scooby-Do/data/messages:101
+msgid "Files"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-firefox.c:357
+#: ../Screenshot/src/applet-screenshot.c:283
+msgid "Open"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-firefox.c:365
+msgid "Open in new window"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-firefox.c:432
+#: ../dnd2share/src/applet-notifications.c:479
+msgid "Open file"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-firefox.c:495
+#: ../Scooby-Do/data/messages:105
+msgid "Firefox bookmarks"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-web.c:99
+msgid "Wikipedia"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-web.c:107
+msgid "Yahoo!"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-web.c:115
+msgid "Google"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-web.c:125
+msgid "Search on the web"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-web.c:139
+msgid "Mediadico"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-backend-web.c:147
+msgid "Amazon"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-init.c:73
+msgid "Enable/disable the Finder"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-listing.c:486
+msgid "(F1) Match case"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-listing.c:493
+msgid "(F2) Music"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-listing.c:500
+msgid "(F3) Image"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-listing.c:507
+msgid "(F4) Video"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-listing.c:514
+msgid "(F5) Text"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-listing.c:521
+msgid "(F6) Html"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-listing.c:528
+msgid "(F7) Sources"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-listing.c:647 ../Scooby-Do/src/applet-search.c:362
+msgid "No result"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-listing.c:651 ../Scooby-Do/src/applet-search.c:358
+#: ../tomboy/src/tomboy-draw.c:203
+msgid "results"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-listing.c:651 ../Scooby-Do/src/applet-search.c:358
+#: ../tomboy/src/tomboy-draw.c:203
+msgid "result"
+msgstr ""
+
+#: ../Scooby-Do/src/applet-search.c:132
+msgid "Searching ..."
+msgstr ""
+
+#: ../Scooby-Do/src/applet-session.c:70
+msgid "Enter your search"
+msgstr ""
+
+#: ../Screenshot/src/applet-init.c:31
+msgid ""
+"A simple applet to quickly take screenshots.\n"
+"<b>Click</b> to take a screenshot.\n"
+"<b>Middle-click</b> gives you more options.\n"
+"You can bind a <b>shortcut</b> to the action."
+msgstr ""
+
+#: ../Screenshot/src/applet-init.c:53
+msgid "Take a screenshot"
+msgstr ""
+
+#: ../Screenshot/src/applet-notifications.c:49
+msgid "Screenshot"
+msgstr ""
+
+#: ../Screenshot/src/applet-notifications.c:61
+msgid "Screenshot with options"
+msgstr ""
+
+#: ../Screenshot/src/applet-screenshot.c:164
+msgid "Screenshot from"
+msgstr ""
+
+#: ../Screenshot/src/applet-screenshot.c:333
+msgid "Unable to take a screenshot"
+msgstr ""
+
+#: ../Screenshot/src/applet-screenshot.c:450 ../Cairo-Penguin/data/messages:19
+#: ../Clipper/data/messages:137 ../Disks/data/messages:143
+#: ../Network-Monitor/data/messages:175 ../System-Monitor/data/messages:169
+#: ../System-Monitor/data/messages:215 ../Toons/data/messages:101
+#: ../dnd2share/data/messages:91 ../mail/data/messages:137
+#: ../musicPlayer/data/messages:153 ../netspeed/data/messages:149
+#: ../powermanager/data/messages:157 ../shortcuts/data/messages:127
+#: ../slider/data/messages:131 ../tomboy/data/messages:115
+#: ../wifi/data/messages:155
+msgid "in seconds."
+msgstr ""
+
+#: ../Screenshot/src/applet-screenshot.c:451
+msgid "Delay"
+msgstr ""
+
+#: ../Screenshot/src/applet-screenshot.c:469
+msgid "Grab the current window instead of the all screen"
+msgstr ""
+
+#: ../Screenshot/src/applet-screenshot.c:470
+msgid "Grab the current window"
+msgstr ""
+
+#: ../Screenshot/src/applet-screenshot.c:478
+#: ../Screenshot/src/applet-screenshot.c:487
+#: ../Status-Notifier/data/messages:11 ../mail/data/messages:107
+#: ../mail/data/messages:111 ../mail/data/messages:127
+msgid "Let empty to use the default one."
+msgstr ""
+
+#: ../Screenshot/src/applet-screenshot.c:488
+msgid "Directory"
+msgstr ""
+
+#: ../Sound-Effects/src/applet-init.c:29
+msgid "Sound Effects"
+msgstr ""
+
+#: ../Sound-Effects/src/applet-init.c:32
+msgid ""
+"This plug-in add sound effects on various events in the dock:\n"
+" When clicking an icon, when hovering an icon, etc"
+msgstr ""
+
+#: ../Status-Notifier/src/applet-init.c:33
+msgid ""
+"A <b>notification area</b> for your dock\n"
+"Programs can use it to display their current status.\n"
+"If a program doesn't appear inside when it should, it's probably because it "
+"doesn't support this feature yet. Please fill a bug report to the devs."
+msgstr ""
+
+#: ../Status-Notifier/src/applet-init.c:38
+msgid "Notification Area"
+msgstr ""
+
+#: ../System-Monitor/src/applet-cpusage.c:59
+msgid "Uptime"
+msgstr ""
+
+#: ../System-Monitor/src/applet-cpusage.c:64
+msgid "Activity time"
+msgstr ""
+
+#: ../System-Monitor/src/applet-cpusage.c:147
+msgid "CPU model"
+msgstr ""
+
+#: ../System-Monitor/src/applet-cpusage.c:148
+msgid "Frequency"
+msgstr ""
+
+#: ../System-Monitor/src/applet-cpusage.c:149
+msgid "core(s)"
+msgstr ""
+
+#: ../System-Monitor/src/applet-init.c:38
+msgid ""
+"This applet shows you the CPU load, RAM usage, graphic card temperature, "
+"etc.\n"
+"Middle click on the icon to get some valuable info.\n"
+"Left click on the icon to get a list of the most ressources using programs.\n"
+"You can instanciate this applet several times to show different values each "
+"time."
+msgstr ""
+
+#: ../System-Monitor/src/applet-notifications.c:40
+#: ../System-Monitor/src/applet-notifications.c:84
+msgid ""
+"The acquisition of one or more data has failed.\n"
+"You should remove the data that couldn't be fetched."
+msgstr ""
+
+#: ../System-Monitor/src/applet-notifications.c:105
+#: ../netspeed/src/applet-notifications.c:109
+msgid "Open the System-Monitor"
+msgstr ""
+
+#: ../System-Monitor/src/applet-notifications.c:107
+msgid "Show info"
+msgstr ""
+
+#: ../System-Monitor/src/applet-nvidia.c:146
+msgid "GPU model"
+msgstr ""
+
+#: ../System-Monitor/src/applet-nvidia.c:147
+msgid "Video Ram"
+msgstr ""
+
+#: ../System-Monitor/src/applet-nvidia.c:147
+#: ../System-Monitor/src/applet-rame.c:106
+#: ../System-Monitor/src/applet-top.c:296
+msgid "Mb"
+msgstr ""
+
+#: ../System-Monitor/src/applet-nvidia.c:148
+msgid "Driver Version"
+msgstr ""
+
+#: ../System-Monitor/src/applet-nvidia.c:149
+msgid "Core Temperature"
+msgstr ""
+
+#: ../System-Monitor/src/applet-nvidia.c:161
+#, c-format
+msgid "Alert! Graphic Card core temperature has reached %d°C"
+msgstr ""
+
+#: ../System-Monitor/src/applet-rame.c:106
+msgid "Gb"
+msgstr ""
+
+#: ../System-Monitor/src/applet-rame.c:118
+msgid "Memory"
+msgstr ""
+
+#: ../System-Monitor/src/applet-rame.c:121
+msgid "Available"
+msgstr ""
+
+#: ../System-Monitor/src/applet-rame.c:124
+msgid "Cached"
+msgstr ""
+
+#: ../System-Monitor/src/applet-rame.c:127
+msgid "Buffers"
+msgstr ""
+
+#: ../System-Monitor/src/applet-sensors.c:358
+msgid "min"
+msgstr ""
+
+#: ../System-Monitor/src/applet-sensors.c:360
+msgid "max"
+msgstr ""
+
+#: ../System-Monitor/src/applet-sensors.c:363
+#: ../System-Monitor/src/applet-sensors.c:396
+msgid "alarm"
+msgstr ""
+
+#: ../System-Monitor/src/applet-sensors.c:394
+msgid "rpm"
+msgstr ""
+
+#: ../System-Monitor/src/applet-sensors.c:413
+#, c-format
+msgid "CPU temperature has reached %d°C"
+msgstr ""
+
+#: ../System-Monitor/src/applet-sensors.c:427
+#, c-format
+msgid "Fan speed has reached %d rpm"
+msgstr ""
+
+#: ../Toons/src/applet-init.c:29
+msgid "Toons"
+msgstr ""
+
+#: ../Toons/src/applet-init.c:32
+msgid "This applet displays a toon that will look at your mouse."
+msgstr ""
+
+#: ../Xgamma/src/applet-init.c:44
+msgid ""
+"Setup the luminosity of your screen directly from your dock.\n"
+"Scroll up/down to increase/decrease the luminosity\n"
+"Left-click to open a dialog to setup the luminosity\n"
+"Middle-click to set it up for each color.\n"
+"You can also define a luminosity value that will be applied automatically on "
+"startup."
+msgstr ""
+
+#: ../Xgamma/src/applet-init.c:52
+msgid "Screen Luminosity"
+msgstr ""
+
+#: ../Xgamma/src/applet-init.c:64
+msgid "Increase the brightness"
+msgstr ""
+
+#: ../Xgamma/src/applet-init.c:68
+msgid "Decrease the brightness"
+msgstr ""
+
+#: ../Xgamma/src/applet-notifications.c:87
+msgid "Set up gamma correction"
+msgstr ""
+
+#: ../Xgamma/src/applet-notifications.c:91
+msgid "Apply current luminosity on startup"
+msgstr ""
+
+#: ../Xgamma/src/applet-xgamma.c:215
+msgid "Gamma :"
+msgstr ""
+
+#: ../Xgamma/src/applet-xgamma.c:217
+msgid "Red :"
+msgstr ""
+
+#: ../Xgamma/src/applet-xgamma.c:219
+msgid "Green :"
+msgstr ""
+
+#: ../Xgamma/src/applet-xgamma.c:221
+msgid "Blue :"
+msgstr ""
+
+#: ../Xgamma/src/applet-xgamma.c:247 ../Xgamma/src/applet-xgamma.c:320
+msgid "Set up gamma:"
+msgstr ""
+
+#: ../Xgamma/src/applet-xgamma.c:335
+msgid "Luminosity"
+msgstr ""
+
+#: ../alsaMixer/src/applet-backend-alsamixer.c:71
+#, c-format
+msgid "I couldn't open card '%s'"
+msgstr ""
+
+#: ../alsaMixer/src/applet-backend-alsamixer.c:77
+#, c-format
+msgid "Card '%s' opened but I couldn't get any info"
+msgstr ""
+
+#: ../alsaMixer/src/applet-backend-alsamixer.c:86
+msgid "I couldn't open the mixer"
+msgstr ""
+
+#: ../alsaMixer/src/applet-backend-alsamixer.c:95
+msgid "I couldn't attach the mixer to the card"
+msgstr ""
+
+#: ../alsaMixer/src/applet-backend-alsamixer.c:103
+msgid "I couldn't register options"
+msgstr ""
+
+#: ../alsaMixer/src/applet-backend-alsamixer.c:111
+msgid "I couldn't load the mixer"
+msgstr ""
+
+#: ../alsaMixer/src/applet-backend-alsamixer.c:319
+msgid "Set up volume:"
+msgstr ""
+
+#: ../alsaMixer/src/applet-draw.c:37
+msgid "Volume"
+msgstr ""
+
+#: ../alsaMixer/src/applet-init.c:32
+msgid ""
+"This applet lets you control the sound volume from the dock.\n"
+"Scroll up/down on the icon to increase/decrease the volume.\n"
+"Click on icon to show/hide the volume control (you can bind a keyboard "
+"shortcut for it)\n"
+"Middle-click to set or unset to mute, double-click to raise the channels "
+"mixer.\n"
+"The applet can either use the Ubuntu Sound-menu or the Alsa driver."
+msgstr ""
+
+#: ../alsaMixer/src/applet-init.c:40
+msgid "Sound Control"
+msgstr ""
+
+#: ../alsaMixer/src/applet-init.c:142
+msgid "Show/hide the Sound menu"
+msgstr ""
+
+#: ../alsaMixer/src/applet-notifications.c:80
+msgid "Adjust channels"
+msgstr ""
+
+#: ../alsaMixer/src/applet-notifications.c:80
+#: ../clock/src/applet-calendar.c:607
+msgid "double-click"
+msgstr ""
+
+#: ../alsaMixer/src/applet-notifications.c:85
+msgid "Unmute"
+msgstr ""
+
+#: ../alsaMixer/src/applet-notifications.c:85
+msgid "Mute"
+msgstr ""
+
+#: ../clock/src/applet-calendar.c:192 ../clock/src/applet-calendar.c:273
+#: ../clock/src/applet-calendar.c:527 ../clock/src/applet-calendar.c:532
+#: ../clock/src/applet-calendar.c:574 ../clock/src/applet-task-editor.c:118
+#: ../clock/src/applet-timer.c:88 ../clock/src/applet-timer.c:176
+#: ../clock/src/applet-timer.c:451 ../clock/src/applet-timer.c:465
+#: ../clock/src/applet-timer.c:494 ../tomboy/src/applet-backend-default.c:160
+#: ../tomboy/src/applet-notes.c:98 ../tomboy/src/applet-notes.c:101
+#: ../tomboy/src/applet-notes.c:406
+msgid "No title"
+msgstr ""
+
+#: ../clock/src/applet-calendar.c:528
+msgid "years"
+msgstr ""
+
+#: ../clock/src/applet-calendar.c:604 ../clock/src/applet-task-editor.c:155
+msgid "Add a new task"
+msgstr ""
+
+#: ../clock/src/applet-calendar.c:607
+msgid "Edit tasks"
+msgstr ""
+
+#: ../clock/src/applet-calendar.c:679
+msgid "Calendar and tasks"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36 ../clock/data/messages:187
+msgid "Alarm"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36
+msgid "Time you want to be notified:"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36
+msgid "In the form xx:xx. E.g.: 20:35 for 8:35pm"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36
+msgid "Never"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36
+msgid "Day"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36 ../weather/src/applet-load-icons.c:26
+msgid "Monday"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36 ../weather/src/applet-load-icons.c:26
+msgid "Tuesday"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36 ../weather/src/applet-load-icons.c:26
+msgid "Wednesday"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36 ../weather/src/applet-load-icons.c:26
+msgid "Thursday"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36 ../weather/src/applet-load-icons.c:26
+msgid "Friday"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36 ../weather/src/applet-load-icons.c:26
+msgid "Saturday"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36 ../weather/src/applet-load-icons.c:26
+msgid "Sunday"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36
+msgid "Week Day"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36
+msgid "Week End"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36
+msgid "Month"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36
+msgid "Repeat every:"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36
+msgid "If every month, which day of the month?"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36
+msgid "Message you want to use to be notified:"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36
+msgid "Tea Time!"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36
+msgid "Command to launch:"
+msgstr ""
+
+#: ../clock/src/applet-config.c:36
+msgid "E.g.:"
+msgstr ""
+
+#: ../clock/src/applet-config.c:490 ../weather/src/applet-config.c:213
+msgid "Search for your location :"
+msgstr ""
+
+#: ../clock/src/applet-init.c:35
+msgid "clock"
+msgstr ""
+
+#: ../clock/src/applet-init.c:38
+msgid ""
+"This applet displays time, date and a calandar.\n"
+"2 view are available : <b>numeric</b> and <b>analogic</b>.\n"
+" Analogic view is compatible with the Cairo-Clock's themes, and you can "
+"detach the applet to be a perfect clone of Cairo-Clock.\n"
+"It displays a <b>calendar</b> on left-click, which lets you <b>manage "
+"tasks</b>.\n"
+"It also supports alarms, and allows you to setup time and date.\n"
+"Left-click to show/hide the calendar, Middle-click to stop a notification,\n"
+"Double-click on a day to edit the tasks for this day."
+msgstr ""
+
+#: ../clock/src/applet-notifications.c:62
+msgid ""
+"No task is sheduled for today.\n"
+"\n"
+"You can add tasks by clicking on the applet to open the calendar, and then "
+"double-clicking on a day."
+msgstr ""
+
+#: ../clock/src/applet-notifications.c:84
+msgid ""
+"No task is sheduled for the next 7 days.\n"
+"\n"
+"You can add tasks by clicking on the applet to open the calendar, and then "
+"double-clicking on a day."
+msgstr ""
+
+#: ../clock/src/applet-notifications.c:103
+msgid "Show today's tasks"
+msgstr ""
+
+#: ../clock/src/applet-notifications.c:104
+msgid "Show this week's tasks"
+msgstr ""
+
+#: ../clock/src/applet-notifications.c:109
+msgid "Set up time and date"
+msgstr ""
+
+#: ../clock/src/applet-task-editor.c:176
+msgid "Delete this task"
+msgstr ""
+
+#: ../clock/src/applet-task-editor.c:214
+msgid "Don't repeat"
+msgstr ""
+
+#: ../clock/src/applet-task-editor.c:220
+msgid "Each month"
+msgstr ""
+
+#: ../clock/src/applet-task-editor.c:226
+msgid "Each year"
+msgstr ""
+
+#: ../clock/src/applet-task-editor.c:349
+msgid "each month"
+msgstr ""
+
+#: ../clock/src/applet-task-editor.c:352
+msgid "each year"
+msgstr ""
+
+#: ../clock/src/applet-task-editor.c:408
+msgid "Right-click to add a new task."
+msgstr ""
+
+#: ../clock/src/applet-task-editor.c:414 ../musicPlayer/src/applet-draw.c:168
+#: ../RSSreader/data/messages:133
+msgid "Title"
+msgstr ""
+
+#: ../clock/src/applet-task-editor.c:421
+#: ../dnd2share/src/applet-notifications.c:398 ../Doncky/data/messages:95
+#: ../RSSreader/data/messages:149 ../Scooby-Do/data/messages:27
+msgid "Text"
+msgstr ""
+
+#: ../clock/src/applet-task-editor.c:428
+msgid "Time"
+msgstr ""
+
+#: ../clock/src/applet-task-editor.c:442
+msgid "Freq."
+msgstr ""
+
+#: ../clock/src/applet-task-editor.c:449
+msgid "Tags"
+msgstr ""
+
+#: ../clock/src/applet-timer.c:54
+msgid "1mn"
+msgstr ""
+
+#: ../clock/src/applet-timer.c:59
+msgid "1h"
+msgstr ""
+
+#: ../clock/src/applet-timer.c:87
+msgid "The following task was scheduled at"
+msgstr ""
+
+#: ../clock/src/applet-timer.c:90 ../clock/src/applet-timer.c:453
+#: ../clock/src/applet-timer.c:496
+msgid "Repeat this message every:"
+msgstr ""
+
+#: ../clock/src/applet-timer.c:174
+msgid "The following task has felt due:"
+msgstr ""
+
+#: ../clock/src/applet-timer.c:450
+msgid "It's time for the following task:"
+msgstr ""
+
+#: ../clock/src/applet-timer.c:464
+msgid "This task will begin in 15 minutes:"
+msgstr ""
+
+#: ../clock/src/applet-timer.c:493
+msgid "Today is the following anniversary:"
+msgstr ""
+
+#: ../clock/src/applet-timer.c:493
+msgid "Tomorrow is the following anniversary:"
+msgstr ""
+
+#: ../desklet-rendering/src/rendering-desklet-decorations.c:46
+msgid "frame&reflects"
+msgstr ""
+
+#: ../desklet-rendering/src/rendering-desklet-decorations.c:55
+msgid "scotch sellotape"
+msgstr ""
+
+#: ../desklet-rendering/src/rendering-desklet-decorations.c:64
+msgid "frame with sellotape"
+msgstr ""
+
+#: ../desklet-rendering/src/rendering-desklet-decorations.c:73
+msgid "CD box"
+msgstr ""
+
+#: ../desklet-rendering/src/rendering-desklet-decorations.c:81
+msgid "dark"
+msgstr ""
+
+#: ../desklet-rendering/src/rendering-desklet-decorations.c:89
+msgid "clear"
+msgstr ""
+
+#: ../desklet-rendering/src/rendering-desklet-decorations.c:97
+msgid "light"
+msgstr ""
+
+#: ../desklet-rendering/src/rendering-desklet-decorations.c:105
+msgid "water drop"
+msgstr ""
+
+#: ../desklet-rendering/src/rendering-desklet-decorations.c:113
+msgid "water"
+msgstr ""
+
+#: ../desklet-rendering/src/rendering-desklet-decorations.c:121
+msgid "futuristic"
+msgstr ""
+
+#: ../desklet-rendering/src/rendering-desklet-decorations.c:129
+#: ../slider/data/messages:137
+msgid "none"
+msgstr ""
+
+#: ../desklet-rendering/src/rendering-desklet-decorations.c:137
+msgid "board"
+msgstr ""
+
+#: ../dialog-rendering/src/applet-decorator-3Dplane.h:26
+msgid "3Dplane"
+msgstr ""
+
+#: ../dialog-rendering/src/applet-decorator-comics.h:26
+msgid "comics"
+msgstr ""
+
+#: ../dialog-rendering/src/applet-decorator-curly.h:26
+msgid "curly"
+msgstr ""
+
+#: ../dialog-rendering/src/applet-decorator-modern.h:26
+msgid "modern"
+msgstr ""
+
+#: ../dialog-rendering/src/applet-decorator-tooltip.h:26
+msgid "tooltip"
+msgstr ""
+
+#: ../dnd2share/src/applet-backend-codepad.c:35
+#: ../dnd2share/src/applet-backend-custom.c:28
+#: ../dnd2share/src/applet-backend-dropbox.c:33
+#: ../dnd2share/src/applet-backend-free.c:33
+#: ../dnd2share/src/applet-backend-imagebin.c:32
+#: ../dnd2share/src/applet-backend-imgur.c:33
+#: ../dnd2share/src/applet-backend-paste-ubuntu.c:35
+#: ../dnd2share/src/applet-backend-pastebin-mozilla.c:36
+#: ../dnd2share/src/applet-backend-pastebin.c:38
+#: ../dnd2share/src/applet-backend-uppix.c:31
+#: ../dnd2share/src/applet-backend-videobin.c:32
+msgid "Direct Link"
+msgstr ""
+
+#: ../dnd2share/src/applet-backend-codepad.c:51
+#: ../dnd2share/src/applet-backend-custom.c:75
+#: ../dnd2share/src/applet-backend-paste-ubuntu.c:49
+#: ../dnd2share/src/applet-backend-pastebin-mozilla.c:52
+#: ../dnd2share/src/applet-backend-pastebin.c:45
+msgid "Your text is empty and couldn't be uploaded to this server"
+msgstr ""
+
+#: ../dnd2share/src/applet-backend-dropbox.c:63
+msgid "This directory seems not valid:"
+msgstr ""
+
+#: ../dnd2share/src/applet-backend-imgur.c:33
+msgid "Display Image"
+msgstr ""
+
+#: ../dnd2share/src/applet-backend-imgur.c:33
+msgid "Large"
+msgstr ""
+
+#: ../dnd2share/src/applet-backend-imgur.c:33
+#: ../dock-rendering/data/messages:41
+msgid "Small"
+msgstr ""
+
+#: ../dnd2share/src/applet-backend-uppix.c:31
+msgid "Thumbnail"
+msgstr ""
+
+#: ../dnd2share/src/applet-dnd2share.c:44
+msgid "No text"
+msgstr ""
+
+#: ../dnd2share/src/applet-dnd2share.c:55
+msgid "Text:"
+msgstr ""
+
+#: ../dnd2share/src/applet-dnd2share.c:317
+msgid ""
+"File has been uploaded.\n"
+"Just press CTRL+v to paste its URL anywhere."
+msgstr ""
+
+#: ../dnd2share/src/applet-dnd2share.c:370
+msgid ""
+"Please wait for the current upload to finish before starting a new one."
+msgstr ""
+
+#: ../dnd2share/src/applet-dnd2share.c:438
+msgid "This file is not readable."
+msgstr ""
+
+#: ../dnd2share/src/applet-dnd2share.c:664
+msgid "Tiny URL"
+msgstr ""
+
+#: ../dnd2share/src/applet-dnd2share.h:27
+msgid ""
+"Couldn't upload the file, check that your internet connection is active."
+msgstr ""
+
+#: ../dnd2share/src/applet-dnd2share.h:29
+#, c-format
+msgid ""
+"Couldn't upload the file to %s, check that your internet connection is "
+"active."
+msgstr ""
+
+#: ../dnd2share/src/applet-dnd2share.h:32
+#, c-format
+msgid ""
+"Couldn't upload the file to %s.\n"
+"Check that your internet connection is active and '%s' is correctly "
+"installed and running"
+msgstr ""
+
+#: ../dnd2share/src/applet-init.c:44
+msgid ""
+"This applet lets you share files easily:\n"
+"Drag-and-drop a file on the icon to upload it to one of the available "
+"hosting sites.\n"
+"You can upload text, image, video, files, and even the current clipboard\n"
+" and you can choose amongst many sites, like DropBox, Imageshack, pastebin, "
+"etc\n"
+"The resulting URL is automatically stored in the clipboard to be directly "
+"copied by CTRL+v.\n"
+"It can keep an history of your last uploads to retrieve them without "
+"registering on the sites.\n"
+"Press left-click to copy the latest URL into the clipboard, middle-click to "
+"copy it into the mouse selection.\n"
+"You'll need to install 'curl' and 'wget' to upload the data."
+msgstr ""
+
+#: ../dnd2share/src/applet-init.c:54
+msgid "Drop to share"
+msgstr ""
+
+#: ../dnd2share/src/applet-notifications.c:43
+msgid "Clear the list of the recently uploaded files?"
+msgstr ""
+
+#: ../dnd2share/src/applet-notifications.c:58
+msgid ""
+"The text has been pasted in the clipboard.\n"
+"You can retrieve it with CTRL+v."
+msgstr ""
+
+#: ../dnd2share/src/applet-notifications.c:80
+msgid "Sorry, couldn't find the original file nor a preview of it."
+msgstr ""
+
+#: ../dnd2share/src/applet-notifications.c:105
+msgid ""
+"The URL has been stored in the clipboard.\n"
+"Just use 'CTRL+v' to paste it anywhere."
+msgstr ""
+
+#: ../dnd2share/src/applet-notifications.c:120
+msgid ""
+"No uploaded file available\n"
+".Just drag'n drop a file on the icon to upload it"
+msgstr ""
+
+#: ../dnd2share/src/applet-notifications.c:121
+msgid ""
+"No uploaded file available.\n"
+"Consider activating the history if you want the applet to remember previous "
+"uploads."
+msgstr ""
+
+#: ../dnd2share/src/applet-notifications.c:138
+msgid ""
+"The current URL has been stored in the clipboard.\n"
+"Just use 'CTRL+v' to paste it anywhere."
+msgstr ""
+
+#: ../dnd2share/src/applet-notifications.c:139
+msgid ""
+"The current URL has been stored into the selection.\n"
+"Just middle-click to paste it anywhere."
+msgstr ""
+
+#: ../dnd2share/src/applet-notifications.c:398
+msgid "File"
+msgstr ""
+
+#: ../dnd2share/src/applet-notifications.c:401
+msgid "Click on the icon to copy the URL into the clipboard."
+msgstr ""
+
+#: ../dnd2share/src/applet-notifications.c:413
+msgid "Send the clipboard's content"
+msgstr ""
+
+#: ../dnd2share/src/applet-notifications.c:416
+msgid "History"
+msgstr ""
+
+#: ../dnd2share/src/applet-notifications.c:481
+msgid "Get text"
+msgstr ""
+
+#: ../dnd2share/src/applet-notifications.c:483
+msgid "Remove from history"
+msgstr ""
+
+#: ../dnd2share/src/applet-notifications.c:486
+msgid "Clear History"
+msgstr ""
+
+#: ../dnd2share/src/applet-notifications.c:491
+msgid "Use only a files hosting site"
+msgstr ""
+
+#: ../dock-rendering/src/rendering-init.c:34
+msgid "Caroussel"
+msgstr ""
+
+#: ../dock-rendering/src/rendering-init.c:35
+msgid "3D plane"
+msgstr ""
+
+#: ../dock-rendering/src/rendering-init.c:36
+#: ../dock-rendering/data/messages:91
+msgid "Parabolic"
+msgstr ""
+
+#: ../dock-rendering/src/rendering-init.c:37
+#: ../dock-rendering/data/messages:115
+msgid "Rainbow"
+msgstr ""
+
+#: ../dock-rendering/src/rendering-init.c:39
+#: ../dock-rendering/data/messages:29 ../shortcuts/data/messages:109
+#: ../stack/data/messages:101
+msgid "Slide"
+msgstr ""
+
+#: ../dock-rendering/src/rendering-init.c:40 ../dock-rendering/data/messages:7
+msgid "Curve"
+msgstr ""
+
+#: ../dock-rendering/src/rendering-init.c:41
+#: ../dock-rendering/data/messages:17
+msgid "Panel"
+msgstr ""
+
+#: ../drop-indicator/src/applet-init.c:28
+msgid "drop indicator"
+msgstr ""
+
+#: ../dustbin/src/applet-init.c:30
+msgid "dustbin"
+msgstr ""
+
+#: ../dustbin/src/applet-init.c:33
+msgid ""
+"This applet manages the dustbin\n"
+"You can threw files and unmount disks by drag-and-dropping them on the "
+"icon.\n"
+"Middle-click on the icon will empty the dustbin."
+msgstr ""
+
+#: ../dustbin/src/applet-notifications.c:40
+msgid "You're about to delete all files in all dustbins. Sure ?"
+msgstr ""
+
+#: ../dustbin/src/applet-notifications.c:103
+msgid "The trash contains"
+msgstr ""
+
+#: ../dustbin/src/applet-notifications.c:105
+msgid "files"
+msgstr ""
+
+#: ../dustbin/src/applet-notifications.c:105
+msgid "elements"
+msgstr ""
+
+#: ../dustbin/src/applet-notifications.c:107
+msgid "Mo"
+msgstr ""
+
+#: ../dustbin/src/applet-notifications.c:107
+msgid "Ko"
+msgstr ""
+
+#: ../dustbin/src/applet-notifications.c:126
+msgid "Counting total size and files number..."
+msgstr ""
+
+#: ../dustbin/src/applet-notifications.c:148
+msgid "Show Trash (click)"
+msgstr ""
+
+#: ../dustbin/src/applet-notifications.c:149
+msgid "Empty Trash"
+msgstr ""
+
+#: ../dustbin/src/applet-notifications.c:153
+msgid "Display dustbins information"
+msgstr ""
+
+#: ../dustbin/src/applet-notifications.c:163
+#, c-format
+msgid "%s successfully unmounted"
+msgstr ""
+
+#: ../dustbin/src/applet-notifications.c:167
+#: ../shortcuts/src/applet-notifications.c:44
+#: ../shortcuts/src/applet-notifications.c:82
+#, c-format
+msgid "Failed to unmount %s"
+msgstr ""
+
+#: ../dustbin/src/applet-notifications.c:191
+#: ../shortcuts/src/applet-notifications.c:180
+msgid "Unmouting this volume ..."
+msgstr ""
+
+#: ../dustbin/src/applet-trashes-manager.c:68
+msgid " trashe(s)"
+msgstr ""
+
+#: ../dustbin/src/applet-trashes-manager.c:72
+msgid " file(s)"
+msgstr ""
+
+#: ../dustbin/src/applet-trashes-manager.c:113
+#: ../dustbin/src/applet-trashes-manager.c:152
+msgid "calculating"
+msgstr ""
+
+#: ../icon-effect/src/applet-init.c:34
+msgid "icon effects"
+msgstr ""
+
+#: ../icon-effect/src/applet-init.c:37
+msgid "This plugin adds many special effects to your icons."
+msgstr ""
+
+#: ../icon-effect/src/applet-init.c:101 ../icon-effect/data/messages:7
+#: ../icon-effect/data/messages:23 ../icon-effect/data/messages:41
+#: ../icon-effect/data/messages:57
+msgid "Fire"
+msgstr ""
+
+#: ../icon-effect/src/applet-init.c:104 ../icon-effect/data/messages:9
+#: ../icon-effect/data/messages:25 ../icon-effect/data/messages:43
+#: ../icon-effect/data/messages:85
+msgid "Stars"
+msgstr ""
+
+#: ../icon-effect/src/applet-init.c:107 ../icon-effect/data/messages:11
+#: ../icon-effect/data/messages:27 ../icon-effect/data/messages:45
+#: ../icon-effect/data/messages:129
+msgid "Rain"
+msgstr ""
+
+#: ../icon-effect/src/applet-init.c:110 ../icon-effect/data/messages:13
+#: ../icon-effect/data/messages:29 ../icon-effect/data/messages:47
+#: ../icon-effect/data/messages:107
+msgid "Snow"
+msgstr ""
+
+#: ../icon-effect/src/applet-init.c:113 ../icon-effect/data/messages:15
+#: ../icon-effect/data/messages:31 ../icon-effect/data/messages:49
+#: ../icon-effect/data/messages:151
+msgid "Storm"
+msgstr ""
+
+#: ../icon-effect/src/applet-init.c:116 ../icon-effect/data/messages:17
+#: ../icon-effect/data/messages:33 ../icon-effect/data/messages:51
+#: ../icon-effect/data/messages:171
+msgid "Firework"
+msgstr ""
+
+#: ../illusion/src/applet-init.c:30
+msgid "illusion"
+msgstr ""
+
+#: ../illusion/src/applet-init.c:33
+msgid ""
+"This plugin provides animations for appearance & disappearance of icons."
+msgstr ""
+
+#: ../keyboard-indicator/src/applet-init.c:32
+msgid "keyboard indicator"
+msgstr ""
+
+#: ../keyboard-indicator/src/applet-init.c:35
+msgid ""
+"This applet lets you control the keyboard layout.\n"
+"\tIt can also display the current num and caps lock.\n"
+"\tLeft-click to switch to the next layout\n"
+"\tScroll up/down to select the previous/next layout\n"
+"\tRight-click gives you access to the list of available layouts."
+msgstr ""
+
+#: ../keyboard-indicator/src/applet-init.c:101
+msgid "Switch keyboard language"
+msgstr ""
+
+#: ../keyboard-indicator/src/applet-notifications.c:78
+msgid "Keyboard preferences"
+msgstr "Tastatur indstillinger"
+
+#: ../logout/src/applet-init.c:32
+msgid ""
+"This applet lets you manage the current session. You can either:\n"
+"shut down, restart, hibernate, suspend, log out, lock the screen, switch to "
+"another user, or program an automatic shutdown\n"
+"It will also tell you if your system needs to be restarted.\n"
+"<b>Click</b> on the icon to pop the menu up.\n"
+"You can bind a <b>shortcut</b> to it, and also to lock the screen."
+msgstr ""
+
+#: ../logout/src/applet-init.c:39 ../logout/src/applet-logout.c:309
+#: ../logout/data/messages:95
+msgid "Log out"
+msgstr "Log af"
+
+#: ../logout/src/applet-init.c:68
+msgid "Lock the screen"
+msgstr "Lås skærmen"
+
+#: ../logout/src/applet-init.c:72
+msgid "Show the log-out menu"
+msgstr "Vis log af menuen"
+
+#: ../logout/src/applet-logout.c:274 ../logout/data/messages:97
+msgid "Shut down"
+msgstr "Sluk"
+
+#: ../logout/src/applet-logout.c:281
+msgid "Restart"
+msgstr "Genstart"
+
+#: ../logout/src/applet-logout.c:287
+msgid "Hibernate"
+msgstr "Dvale"
+
+#: ../logout/src/applet-logout.c:288
+msgid "Your computer will not consume any energy."
+msgstr "Din computer vil ikke forbruge nogen energi."
+
+#: ../logout/src/applet-logout.c:294
+msgid "Hybrid Sleep"
+msgstr "Hybrid Slumring"
+
+#: ../logout/src/applet-logout.c:295
+msgid ""
+"Your computer will still consume a small amount of energy but after some "
+"time, the computer will suspend to disk and not consume any energy."
+msgstr ""
+"Din computer vil stadig forbruge en lille mængde af energi, men efter nogen "
+"tid, vil computeren gemme til disk og ikke forbruge noget energi."
+
+#: ../logout/src/applet-logout.c:300
+msgid "Suspend"
+msgstr "Slumre"
+
+#: ../logout/src/applet-logout.c:302
+msgid "Your computer will still consume a small amount of energy."
+msgstr "Din computer vil stadig forbruge en lille mængde energi."
+
+#: ../logout/src/applet-logout.c:311
+msgid "Close your session and allow to open a new one."
+msgstr "Luk din aktuelle session og tillad at åbne en ny."
+
+#: ../logout/src/applet-logout.c:322
+msgid "Switch user"
+msgstr "Skift bruger"
+
+#: ../logout/src/applet-logout.c:343
+msgid "Guest session"
+msgstr "Gæste session"
+
+#: ../logout/src/applet-logout.c:350 ../logout/data/messages:99
+msgid "Lock screen"
+msgstr "Lås skærm"
+
+#: ../logout/src/applet-logout.c:355
+msgid "Program an automatic shut-down"
+msgstr "Programmere en automatisk nedlukning"
+
+#: ../logout/src/applet-logout.c:426
+msgid "Logind has returned this error:"
+msgstr ""
+
+#: ../logout/src/applet-logout.c:428
+msgid ""
+"Please check that you can do this action\n"
+"(e.g. you can't power the computer off if another session is active)"
+msgstr ""
+
+#: ../logout/src/applet-logout.c:493
+#, c-format
+msgid "It will automatically shut-down in %ds"
+msgstr "Automatisk nedlukning om %ds"
+
+#: ../logout/src/applet-logout.c:494
+msgid "Shut down the computer?"
+msgstr "Sluk computeren?"
+
+#: ../logout/src/applet-logout.c:499
+msgid ""
+"It seems your system is being updated!\n"
+"Please be sure that you can shut down your computer right now."
+msgstr ""
+
+#: ../logout/src/applet-logout.c:574
+msgid "Restart the computer?"
+msgstr "Genstart computeren?"
+
+#: ../logout/src/applet-logout.c:627
+msgid "Close the current session?"
+msgstr "Luk den aktuelle session?"
+
+#: ../logout/src/applet-notifications.c:103
+msgid "Manage users"
+msgstr "Administrer brugere"
+
+#: ../logout/src/applet-reboot-required.c:62
+msgid "Please do that at the end of the update."
+msgstr "Gør venligst dette, når opdateringen er færdig."
+
+#: ../logout/src/applet-timer.c:50
+msgid "Your computer will shut-down in 1 minute."
+msgstr "Din computer vil lukke ned om 1 minut."
+
+#: ../logout/src/applet-timer.c:97
+msgid "Choose in how many minutes your PC will stop:"
+msgstr "Vælg i minutter, hvornår din computer skal slukke:"
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid "Server address:"
+msgstr "Server adresse:"
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid "myHost"
+msgstr "minHost"
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid "Username:"
+msgstr "Brugernavn:"
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid "Password:"
+msgstr "Adgangskode:"
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid "The password will be crypted."
+msgstr "Adgangskoden vil blive krypteret."
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid "Port:"
+msgstr "Port:"
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid ""
+"Enter 0 to use the default port. Default ports are 110 for POP3 or APOP and "
+"995 for POP3S."
+msgstr ""
+"Indtast 0 til at bruge standard-porten. Standard porte er 110 for POP3 eller "
+"APOP og 995 for POP3S."
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid ""
+"Enter 0 to use the default port. Default ports are 143 for IMAP4 and 993 for "
+"IMAP4 over SSL."
+msgstr ""
+"Indtast 0 til at bruge standard-porten. Standard porte er 143 for IMAP4 og "
+"993 for IMAP4 over SSL."
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid "Use a secure connection (SSL)"
+msgstr "Brug en sikker forbindelse (SSL)"
+
+#: ../mail/src/cd-mail-applet-accounts.c:39 ../RSSreader/data/messages:107
+#: ../netspeed/data/messages:151 ../powermanager/data/messages:159
+#: ../weather/data/messages:117
+msgid "Refresh time:"
+msgstr "Opdaterings tid:"
+
+#: ../mail/src/cd-mail-applet-accounts.c:39 ../RSSreader/data/messages:105
+#: ../weather/data/messages:115
+msgid "In minutes."
+msgstr "I minutter."
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid "Specific mail application"
+msgstr "Program til e-post"
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid "Leave empty to use the default mail application."
+msgstr "Efterlad tomt, for at bruge standard programmet til e-post."
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid "Specific icon file when using multiple accounts"
+msgstr ""
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid "Directory on server:"
+msgstr "Mappe på server:"
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid "Path of mbox file:"
+msgstr "Sti til mbox fil:"
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid "Path to Mail directory:"
+msgstr "Sti til e-post mappe:"
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid "Address of feed:"
+msgstr ""
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid "Remove this account"
+msgstr "Fjern denne konto"
+
+#: ../mail/src/cd-mail-applet-accounts.c:39
+msgid ""
+"Don't forget to enable IMAP (or POP) service from settings of your mail "
+"account."
+msgstr ""
+
+#: ../mail/src/cd-mail-applet-config.c:224
+msgid "Please choose an account type."
+msgstr "Vælg venligst en kontotype."
+
+#: ../mail/src/cd-mail-applet-config.c:229
+msgid "New account's name"
+msgstr "Nyt kontonavn"
+
+#: ../mail/src/cd-mail-applet-config.c:232
+msgid "Please enter a name for this account."
+msgstr "Skriv venligst et nyt kontonavn."
+
+#: ../mail/src/cd-mail-applet-config.c:242
+msgid ""
+"This account already exists.\n"
+"Please choose another name for the new account."
+msgstr ""
+
+#: ../mail/src/cd-mail-applet-config.c:373
+msgid "Enter a name for this account. You can give it any name you want."
+msgstr ""
+
+#: ../mail/src/cd-mail-applet-config.c:428
+msgid "Remove Account"
+msgstr "Fjern Konto"
+
+#: ../mail/src/cd-mail-applet-etpan.c:237 ../wifi/src/applet-draw.c:145
+msgid "unknown"
+msgstr "ukendt"
+
+#: ../mail/src/cd-mail-applet-etpan.c:237
+msgid "no subject"
+msgstr "intet emne"
+
+#: ../mail/src/cd-mail-applet-etpan.c:408
+msgid "No unread mail in your mailboxes"
+msgstr "Ingen ulæste mails i din postkasse"
+
+#: ../mail/src/cd-mail-applet-etpan.c:430
+#, c-format
+msgid "You have %d new mails:"
+msgstr "Du har %d nye mails:"
+
+#: ../mail/src/cd-mail-applet-etpan.c:432
+msgid "You have a new mail:"
+msgstr "Du har en ny mail:"
+
+#: ../mail/src/cd-mail-applet-init.c:33
+msgid "mail"
+msgstr "mail"
+
+#: ../mail/src/cd-mail-applet-init.c:36
+msgid ""
+"This applet is very useful to warn you when you get new e-mails\n"
+"It can check in any kind of mailbox (yahoo, gmail, etc)\n"
+"Left-click to launch the prefered mail application,\n"
+"Middle-click to refresh all the mailboxes."
+msgstr ""
+
+#: ../mail/src/cd-mail-applet-notifications.c:62
+#, c-format
+msgid ""
+"A problem occured\n"
+"If '%s' is not your usual mail application,\n"
+"you can change it in the configuration panel of this module"
+msgstr ""
+
+#: ../mail/src/cd-mail-applet-notifications.c:67
+msgid ""
+"No mail application is defined,\n"
+"you can define it in the configuration panel of this module"
+msgstr ""
+
+#: ../mail/src/cd-mail-applet-notifications.c:146
+msgid "Refresh a mail account"
+msgstr "Opdatere en mail konto"
+
+#: ../mail/src/cd-mail-applet-notifications.c:153
+msgid "Refresh all"
+msgstr "Opdater alle"
+
+#: ../mail/src/cd-mail-applet-notifications.c:160
+#, c-format
+msgid "Refresh %s"
+msgstr "Opdater %s"
+
+#: ../mail/src/cd-mail-applet-notifications.c:166
+msgid "Mark all emails as read"
+msgstr "Markere alle e-mails som læst"
+
+#: ../mail/src/cd-mail-applet-notifications.c:169
+#, c-format
+msgid "Launch %s"
+msgstr ""
+
+#: ../mail/src/cd-mail-applet-notifications.c:346
+msgid "Mail"
+msgstr "Mail"
+
+#: ../motion-blur/src/applet-init.c:28
+msgid "motion blur"
+msgstr ""
+
+#: ../motion-blur/src/applet-init.c:31
+msgid "This plugin adds a motion blur effect to docks."
+msgstr ""
+
+#: ../musicPlayer/src/applet-draw.c:59
+msgid "Unknown artist"
+msgstr "Ukendt kunstner"
+
+#: ../musicPlayer/src/applet-draw.c:59
+msgid "Unknown title"
+msgstr "Ukendt titel"
+
+#: ../musicPlayer/src/applet-draw.c:65 ../musicPlayer/src/applet-mpris.c:336
+msgid "Track"
+msgstr "Spor"
+
+#: ../musicPlayer/src/applet-draw.c:150
+msgid "Track n°"
+msgstr "Spor nr"
+
+#: ../musicPlayer/src/applet-draw.c:155
+msgid "Song n°"
+msgstr "Sang nr"
+
+#: ../musicPlayer/src/applet-draw.c:166
+msgid "Artist"
+msgstr "Kunstner"
+
+#: ../musicPlayer/src/applet-draw.c:170
+msgid "Album"
+msgstr "Album"
+
+#: ../musicPlayer/src/applet-draw.c:172
+msgid "Length"
+msgstr "Længde"
+
+#: ../musicPlayer/src/applet-draw.c:192
+msgid "Current song"
+msgstr "Aktuelle sang"
+
+#: ../musicPlayer/src/applet-draw.c:198
+msgid "There is no media playing."
+msgstr ""
+
+#: ../musicPlayer/src/applet-init.c:48
+msgid "musicPlayer"
+msgstr "musicPlayer"
+
+#: ../musicPlayer/src/applet-init.c:51
+msgid ""
+"This applet lets you control any music player.\n"
+"First choose the player you want to control.\n"
+"<b>click</b> to show/hide the player or pause,\n"
+"<b>middle-click</b> to pause or go to next song,\n"
+"<b>Scroll up/down</b> to change the song or control the volume.\n"
+"You can drag and drop songs on the icon to put them in the queue (depends on "
+"Player),\n"
+" and jpeg image to use as cover.\n"
+"Note: you may have to install or activate the MPRIS plug-in of the player."
+msgstr ""
+
+#: ../musicPlayer/src/applet-notifications.c:101
+msgid ""
+"Sorry, I couldn't detect any player.\n"
+"If it is running, it is maybe because its version is too old and does not "
+"offer such service."
+msgstr ""
+
+#: ../musicPlayer/src/applet-notifications.c:193
+msgid "Choose a music player to control"
+msgstr ""
+
+#: ../musicPlayer/src/applet-notifications.c:297
+msgid "Find opened player"
+msgstr ""
+
+#: ../musicPlayer/src/applet-notifications.c:301
+msgid "Choose a player"
+msgstr "Vælg en afspiller"
+
+#: ../musicPlayer/src/applet-notifications.c:307
+msgid "Previous"
+msgstr "Forrige"
+
+#: ../musicPlayer/src/applet-notifications.c:307
+msgid "scroll-up"
+msgstr "rul op"
+
+#: ../musicPlayer/src/applet-notifications.c:313
+msgid "Play/Pause"
+msgstr "Spil/Pause"
+
+#: ../musicPlayer/src/applet-notifications.c:313
+msgid "left-click"
+msgstr "venstre-klik"
+
+#: ../musicPlayer/src/applet-notifications.c:319
+msgid "Next"
+msgstr "Næste"
+
+#: ../musicPlayer/src/applet-notifications.c:319
+msgid "scroll-down"
+msgstr "rul ned"
+
+#: ../musicPlayer/src/applet-notifications.c:324
+msgid "Stop"
+msgstr "Stop"
+
+#: ../musicPlayer/src/applet-notifications.c:328
+msgid "Information"
+msgstr "Information"
+
+#: ../musicPlayer/src/applet-notifications.c:333
+msgid "Show JumpBox"
+msgstr "Vis JumpBox"
+
+#: ../musicPlayer/src/applet-notifications.c:336
+msgid "Shuffle"
+msgstr "Bland"
+
+#: ../musicPlayer/src/applet-notifications.c:344
+msgid "Repeat"
+msgstr "Gentag"
+
+#: ../musicPlayer/src/applet-notifications.c:352
+msgid "Rate this song"
+msgstr "Bedøm denne sang"
+
+#: ../musicPlayer/src/applet-notifications.c:356
+msgid "Show"
+msgstr "Vis"
+
+#: ../musicPlayer/src/applet-notifications.c:357
+msgid "Quit"
+msgstr "Afslut"
+
+#: ../netspeed/src/applet-init.c:29
+msgid "netspeed"
+msgstr "net hastighed"
+
+#: ../netspeed/src/applet-init.c:32
+msgid ""
+"This applet shows you the bit rate of your internet connection and some "
+"stats about it.\n"
+"Left-click on the icon to have the total amount of data transfered\n"
+"Middle-click to (de)activate the network (needs NetworManager)"
+msgstr ""
+
+#: ../netspeed/src/applet-notifications.c:36
+msgid "Total amount of data"
+msgstr "Samlet mængde data"
+
+#: ../netspeed/src/applet-notifications.c:37
+msgid "downloaded"
+msgstr "Hentet"
+
+#: ../netspeed/src/applet-notifications.c:38
+msgid "uploaded"
+msgstr "overført"
+
+#: ../netspeed/src/applet-notifications.c:44
+msgid ""
+"No interface found.\n"
+"Please be sure that at least one interface is available\n"
+" and that you have the right to monitor it"
+msgstr ""
+
+#: ../netspeed/src/applet-notifications.c:48
+#, c-format
+msgid ""
+"Interface '%s' doesn't seem to exist or is not readable.\n"
+"You may have to set up the interface you wish to monitor.\n"
+"Do you want to do it now?"
+msgstr ""
+
+#: ../netspeed/src/applet-notifications.c:105
+msgid "Enable/disable network"
+msgstr "Aktiver/deaktiver netværk"
+
+#: ../netspeed/src/applet-notifications.c:113
+msgid "Re-check interface"
+msgstr ""
+
+#: ../powermanager/src/powermanager-draw.c:190
+msgid "Battery charged"
+msgstr "Batteri opladet"
+
+#: ../powermanager/src/powermanager-draw.c:202
+msgid "h"
+msgstr "t"
+
+#: ../powermanager/src/powermanager-draw.c:204
+msgid "mn"
+msgstr "min"
+
+#: ../powermanager/src/powermanager-draw.c:213
+msgid "remaining"
+msgstr "resterende"
+
+#: ../powermanager/src/powermanager-draw.c:213
+msgid "until charged"
+msgstr "indtil opladet"
+
+#: ../powermanager/src/powermanager-draw.c:231 ../wifi/src/applet-draw.c:30
+#: ../Clipper/data/messages:97 ../GMenu/data/messages:113
+#: ../Network-Monitor/data/messages:221 ../dnd2share/data/messages:109
+#: ../dustbin/data/messages:101 ../wifi/data/messages:145
+msgid "None"
+msgstr "Ingen"
+
+#: ../powermanager/src/powermanager-draw.c:266
+msgid "Laptop on Battery."
+msgstr "Computeren kører nu på batteri."
+
+#: ../powermanager/src/powermanager-draw.c:267
+#: ../powermanager/src/powermanager-draw.c:276
+msgid "Battery charged at:"
+msgstr "Batteri opladet om:"
+
+#: ../powermanager/src/powermanager-draw.c:268
+msgid "Estimated time before empty:"
+msgstr "Anslået tid før afladet:"
+
+#: ../powermanager/src/powermanager-draw.c:275
+msgid "Laptop on Charge."
+msgstr "Computeren er under opladning."
+
+#: ../powermanager/src/powermanager-draw.c:277
+msgid "Estimated time before full:"
+msgstr "Anslået tid før fuld opladet:"
+
+#: ../powermanager/src/powermanager-draw.c:284
+msgid "Model:"
+msgstr "Model:"
+
+#: ../powermanager/src/powermanager-draw.c:290
+msgid "Technology:"
+msgstr "Teknologi:"
+
+#: ../powermanager/src/powermanager-draw.c:294
+msgid "Maximum capacity:"
+msgstr "Maksimal kapacitet:"
+
+#: ../powermanager/src/powermanager-draw.c:299
+msgid "No battery found."
+msgstr "Ingen batteri fundet."
+
+#: ../powermanager/src/powermanager-draw.c:321
+msgid ""
+"PowerManager.\n"
+"Battery charge seems to be low"
+msgstr ""
+
+#: ../powermanager/src/powermanager-draw.c:321
+msgid "Estimated time with charge:"
+msgstr "Anslået tid for opladning:"
+
+#: ../powermanager/src/powermanager-draw.c:321
+msgid "Please put your laptop on charge."
+msgstr "Sæt venligst din computer til opladning."
+
+#: ../powermanager/src/powermanager-draw.c:335
+msgid ""
+"PowerManager.\n"
+"Your battery is now charged"
+msgstr ""
+
+#: ../powermanager/src/powermanager-init.c:32
+msgid "PowerManager"
+msgstr "Strømstyring"
+
+#: ../powermanager/src/powermanager-init.c:35
+msgid ""
+"This applet displays the current state of your <b>laptop battery</b>: "
+"charge, time remaining, etc\n"
+"<b>Click</b> on the icon to have useful inforamtion,\n"
+"<b>Right-click</b> on the icon to hibernate or suspend the system."
+msgstr ""
+
+#: ../powermanager/src/powermanager-menu-functions.c:70
+msgid "Set up power management"
+msgstr "Opsætning af strømstyring"
+
+#: ../powermanager/src/powermanager-menu-functions.c:87
+msgid "Power statistics"
+msgstr ""
+
+#: ../quick-browser/src/applet-init.c:29
+msgid "Quick Browser"
+msgstr ""
+
+#: ../quick-browser/src/applet-init.c:32
+msgid ""
+"This applet lets you browse a folder and its sub-folders very quickly.\n"
+"You can set up a shortkey to pop up the menu.\n"
+"Midlle-click will open the main folder.\n"
+"This applet can be instanciated several times, if you want to browse "
+"different folders."
+msgstr ""
+
+#: ../quick-browser/src/applet-init.c:64
+msgid "Show/hide the folder menu"
+msgstr ""
+
+#: ../quick-browser/src/applet-menu.c:103
+msgid "Open this folder"
+msgstr "Åben denne mappe"
+
+#: ../quick-browser/src/applet-notifications.c:41
+msgid "Open folder"
+msgstr "Åbn mappe"
+
+#: ../shortcuts/src/applet-bookmarks.c:92
+#: ../shortcuts/src/applet-bookmarks.c:100
+#: ../shortcuts/src/applet-drives.c:291
+msgid "Unmounted"
+msgstr "Afmonteret"
+
+#: ../shortcuts/src/applet-bookmarks.c:422
+msgid "Home Folder"
+msgstr "Hjemmemappe"
+
+#: ../shortcuts/src/applet-disk-usage.c:183
+#: ../shortcuts/src/applet-disk-usage.c:212
+msgid "Mount point:"
+msgstr "Monterings punkt:"
+
+#: ../shortcuts/src/applet-disk-usage.c:184
+#: ../shortcuts/src/applet-disk-usage.c:213
+msgid "File system:"
+msgstr "Filsystem:"
+
+#: ../shortcuts/src/applet-disk-usage.c:185
+#: ../shortcuts/src/applet-disk-usage.c:214
+msgid "Device:"
+msgstr "Enhed:"
+
+#: ../shortcuts/src/applet-disk-usage.c:186
+#: ../shortcuts/src/applet-disk-usage.c:215
+msgid "Mount options:"
+msgstr "Monterings muligheder"
+
+#: ../shortcuts/src/applet-disk-usage.c:218
+msgid "Backup frequency:"
+msgstr "Backup frekvens:"
+
+#: ../shortcuts/src/applet-disk-usage.c:218
+msgid "days"
+msgstr "dage"
+
+#: ../shortcuts/src/applet-disk-usage.c:241
+#: ../shortcuts/src/applet-disk-usage.c:251
+#: ../shortcuts/src/applet-disk-usage.c:256
+msgid "Name:"
+msgstr "Navn:"
+
+#: ../shortcuts/src/applet-disk-usage.c:242
+msgid "Capacity:"
+msgstr "Kapacitet:"
+
+#: ../shortcuts/src/applet-disk-usage.c:243
+msgid "Free space:"
+msgstr "Ledig plads:"
+
+#: ../shortcuts/src/applet-disk-usage.c:251
+msgid "Not mounted"
+msgstr "Ikke monteret"
+
+#: ../shortcuts/src/applet-disk-usage.c:257 ../RSSreader/data/messages:97
+msgid "URL:"
+msgstr "URL:"
+
+#: ../shortcuts/src/applet-drives.c:132 ../shortcuts/src/applet-drives.c:200
+#, c-format
+msgid "%s is now mounted"
+msgstr "%s er nu monteret"
+
+#: ../shortcuts/src/applet-drives.c:132
+#: ../shortcuts/src/applet-load-icons.c:137
+#, c-format
+msgid "%s has been connected"
+msgstr "%s er blevet tilsluttet"
+
+#: ../shortcuts/src/applet-drives.c:200
+#, c-format
+msgid "%s is now unmounted"
+msgstr "%s er nu afmonteret"
+
+#: ../shortcuts/src/applet-init.c:32
+msgid "shortcuts"
+msgstr "genveje"
+
+#: ../shortcuts/src/applet-init.c:35
+msgid ""
+"An applet that let you access quickly to all of your shortcuts.\n"
+"It can manage disks, network points, and Nautilus bookmarks (even if you "
+"don't have Nautilus).\n"
+"Drag and drop a folder on the main icon or the sub-dock to add a bookmark.\n"
+"Middle-click on the main icon to show your home folder.\n"
+"Middle-click on a mounting point icon to (un)mount is quickly.\n"
+"The applet can also display valuable information about your disks, like free "
+"space, type, etc."
+msgstr ""
+
+#: ../shortcuts/src/applet-notifications.c:44
+#: ../shortcuts/src/applet-notifications.c:82
+#, c-format
+msgid "Failed to mount %s"
+msgstr "Kunne ikke montere %s"
+
+#: ../shortcuts/src/applet-notifications.c:101
+msgid "Sorry, this applet is not yet available for KDE."
+msgstr ""
+
+#: ../shortcuts/src/applet-notifications.c:104
+msgid "No disks or bookmarks were found."
+msgstr ""
+
+#: ../shortcuts/src/applet-notifications.c:234
+msgid "Enter a name for this bookmark:"
+msgstr "Indtast et navn til dette bogmærke:"
+
+#: ../shortcuts/src/applet-notifications.c:321
+msgid "Open Home directory"
+msgstr "Åbn Hjem mappen"
+
+#: ../shortcuts/src/applet-notifications.c:329
+msgid "Connect to Server..."
+msgstr "Forbind til server…"
+
+#: ../shortcuts/src/applet-notifications.c:333
+msgid "Browse Network"
+msgstr "Gennemse netværk"
+
+#: ../shortcuts/src/applet-notifications.c:336
+msgid "Browse recent files"
+msgstr "Gennemse seneste filer"
+
+#: ../shortcuts/src/applet-notifications.c:339
+msgid "Open Trash"
+msgstr "Åbn skraldespand"
+
+#: ../shortcuts/src/applet-notifications.c:347
+msgid "Rename this bookmark"
+msgstr "Omdøb dette bogmærke"
+
+#: ../shortcuts/src/applet-notifications.c:349
+msgid "Remove this bookmark"
+msgstr "Fjern dette bogmærke"
+
+#: ../shortcuts/src/applet-notifications.c:358
+msgid "Eject"
+msgstr "Skub ud"
+
+#: ../shortcuts/src/applet-notifications.c:366
+msgid "Unmount"
+msgstr ""
+
+#: ../shortcuts/src/applet-notifications.c:366
+msgid "Mount"
+msgstr ""
+
+#: ../shortcuts/src/applet-notifications.c:371
+msgid "Get disk info"
+msgstr "Se disk info"
+
+#: ../shortcuts/src/applet-notifications.c:399
+msgid "Only folders can be bookmarked."
+msgstr "Kun mapper kan bogmærkes"
+
+#: ../show-mouse/src/applet-init.c:28
+msgid "show mouse"
+msgstr "Vis mus"
+
+#: ../show-mouse/src/applet-init.c:31
+msgid ""
+"This plugin draws some animations around the cursor when it's inside a "
+"dock/desklet."
+msgstr ""
+
+#: ../showDesktop/src/applet-init.c:28
+msgid "showDesktop"
+msgstr "vis skrivebord"
+
+#: ../showDesktop/src/applet-init.c:31
+msgid ""
+"This applet adds an icon to show your desktop,\n"
+" and also : the desklets, the Widget Layer, or all the desktops at once.\n"
+"It can also be used to quickly change the screen's resolution from the right-"
+"click menu.\n"
+"Left-click to show/hide the desktop,\n"
+"Middle-click to show/hide either the desktop, the desklets, the Widget "
+"Layer, or all the desktops at once."
+msgstr ""
+
+#: ../showDesktop/src/applet-notifications.c:220
+msgid "Change screen resolution"
+msgstr "Ændr skærmopløsning"
+
+#: ../slider/src/applet-init.c:29
+msgid "slider"
+msgstr "skyder"
+
+#: ../slider/src/applet-init.c:32
+msgid ""
+"This applet is a basic image slider\n"
+" You just have to select a directory and a display effect and you're done\n"
+"Click to play/pause or to edit the current image.\n"
+"Middle-click to open the images folder."
+msgstr ""
+
+#: ../slider/src/applet-notifications.c:68
+msgid "You need to define the images folder first."
+msgstr ""
+
+#: ../slider/src/applet-notifications.c:220
+msgid "Play"
+msgstr "Afspil"
+
+#: ../slider/src/applet-notifications.c:220
+msgid "Pause"
+msgstr "Pause"
+
+#: ../slider/src/applet-notifications.c:228
+#: ../slider/src/applet-notifications.c:230
+msgid "Open current image"
+msgstr "Åbn aktuelle billede"
+
+#: ../slider/src/applet-notifications.c:270
+#: ../slider/src/applet-notifications.c:272
+msgid "Browse images folder"
+msgstr "Gennemse mappen billeder"
+
+#: ../slider/src/applet-notifications.c:275
+msgid "Refresh images list"
+msgstr "Opdatere billede listen"
+
+#: ../stack/src/applet-init.c:31
+msgid "stack"
+msgstr "Stak"
+
+#: ../stack/src/applet-init.c:34
+msgid ""
+"This applet allows you to build a stack of files, just like the Stacks "
+"applet of MacOS X.\n"
+"To add file into your stacks, you just have to drag and drop it on the "
+"Stacks icon and you're done.\n"
+"You can drop any file, or web URL, or even some piece of text\n"
+"You can quickly copy the path/url/text to the clipboard, or open it."
+msgstr ""
+
+#: ../stack/src/applet-notifications.c:54
+msgid ""
+"No items in the stack.\n"
+"You can add files, URL, and even a piece of text by dragging them onto the "
+"icon."
+msgstr ""
+
+#: ../stack/src/applet-notifications.c:92
+msgid "Clear the stack?"
+msgstr "Ryd stakken?"
+
+#: ../stack/src/applet-notifications.c:139
+msgid "Set new name for this item:"
+msgstr "Skriv et nyt navn for dette element:"
+
+#: ../stack/src/applet-notifications.c:202
+msgid "Paste (drag'n'drop)"
+msgstr "Indsæt (træk og slip)"
+
+#: ../stack/src/applet-notifications.c:204
+msgid "Clear the stack"
+msgstr "Ryd stakken"
+
+#: ../stack/src/applet-notifications.c:209
+msgid "Open (click)"
+msgstr "Åbn (klik)"
+
+#: ../stack/src/applet-notifications.c:214
+#: ../terminal/src/terminal-widget.c:402
+msgid "Copy"
+msgstr "Kopiér"
+
+#: ../stack/src/applet-notifications.c:217
+msgid "Cut"
+msgstr "Klip"
+
+#: ../stack/src/applet-notifications.c:220
+msgid "Rename this item"
+msgstr "Omdøb dette element"
+
+#: ../stack/src/applet-notifications.c:221
+msgid "Remove this item"
+msgstr "Fjern dette element"
+
+#: ../stack/src/applet-notifications.c:290
+msgid "The file has been added to the stack."
+msgstr "Filen er blevet tilføjet til stakken."
+
+#: ../stack/src/applet-notifications.c:291
+msgid "The URL has been added to the stack."
+msgstr "URL-adressen er blevet tilføjet til stakken."
+
+#: ../switcher/src/applet-draw.c:600 ../switcher/src/applet-draw.c:607
+#: ../switcher/src/applet-load-icons.c:54
+#: ../switcher/src/applet-notifications.c:411
+msgid "Current"
+msgstr "Aktuelle"
+
+#: ../switcher/src/applet-draw.c:607 ../switcher/src/applet-draw.c:609
+#: ../switcher/src/applet-load-icons.c:60
+#: ../switcher/src/applet-notifications.c:228
+#: ../switcher/src/applet-notifications.c:247
+#: ../switcher/src/applet-notifications.c:403
+#: ../switcher/src/applet-notifications.c:510
+msgid "Desktop"
+msgstr "Skrivebord"
+
+#: ../switcher/src/applet-init.c:32
+msgid "switcher"
+msgstr "omskifter"
+
+#: ../switcher/src/applet-init.c:35
+msgid ""
+"This applet allows you to interact with your workspaces :\n"
+" - switch between your workspaces (scroll up/down with the mouse),\n"
+" - name them (in the config),\n"
+" - quickly add/remove a workspace (in the menu),\n"
+" - show the desktop (middle-click or in the menu),\n"
+" - list all windows on each workspace ((middle-click or in the menu)\n"
+"It has 2 modes : compact (on 1 icon) and expanded (with a sub-dock)."
+msgstr ""
+
+#: ../switcher/src/applet-notifications.c:248
+#: ../switcher/src/applet-notifications.c:282
+msgid "Rename this workspace"
+msgstr "Omdøb dette arbejdsområde"
+
+#: ../switcher/src/applet-notifications.c:269
+msgid "Add a workspace"
+msgstr "Tilføj et arbejdsområde"
+
+#: ../switcher/src/applet-notifications.c:273
+msgid "Remove last workspace"
+msgstr "Fjern seneste arbejdsområde"
+
+#: ../switcher/src/applet-notifications.c:289
+msgid "Move current workspace to this workspace"
+msgstr ""
+
+#: ../switcher/src/applet-notifications.c:294
+msgid ""
+"This will move all windows from the current desktop to the one you clicked "
+"on."
+msgstr ""
+
+#: ../switcher/src/applet-notifications.c:303
+msgid "Windows List"
+msgstr "Windows liste"
+
+#: ../switcher/src/applet-notifications.c:308
+msgid "Show the desktop"
+msgstr "Vis skrivebord"
+
+#: ../systray/src/systray-init.c:35
+msgid ""
+"Add a systray to your dock.\n"
+"Left-click to show/hide the systray in a dialog (you can bind a keyboard "
+"shortcut for it.)\n"
+"But the best way to use it is to detach it from the dock, and place it "
+"somewhere, above other windows."
+msgstr ""
+
+#: ../systray/src/systray-init.c:41
+msgid "Notification Area Old"
+msgstr ""
+
+#: ../systray/src/systray-init.c:65
+msgid "Show/hide the systray"
+msgstr ""
+
+#: ../systray/src/systray-interface.c:74
+msgid ""
+"Another systray is already running (probably on your panel)\n"
+"Since there can only be one systray at once, you should remove it to avoid "
+"any conflict."
+msgstr ""
+
+#: ../template/src/applet-init.c:29
+msgid "CD_APPLET_NAME"
+msgstr "CD_APPLET_NAME"
+
+#: ../template/src/applet-init.c:32
+msgid ""
+"Useful description\n"
+"and manual"
+msgstr ""
+
+#: ../terminal/src/terminal-callbacks.c:82
+#: ../terminal/src/terminal-widget.c:404
+msgid "Paste"
+msgstr "Indsæt"
+
+#: ../terminal/src/terminal-init.c:31
+msgid "terminal"
+msgstr "terminal"
+
+#: ../terminal/src/terminal-init.c:34
+msgid ""
+"Add a terminal to your dock !\n"
+"Left-click to show/hide terminal (you can bind a keyboard shortcut for it.)\n"
+"You can drag'n'drop files or text and select an action.\n"
+"You can open many tabs, rename them, change their color (right-click on a "
+"tab to interact on it)\n"
+"To open a new tab : type 'CTRL+t' or double-click next to the last tab\n"
+"To close a tab : type 'CTRL+w' or middle-click on it."
+msgstr ""
+
+#: ../terminal/src/terminal-init.c:59
+msgid "Show/hide the terminal"
+msgstr ""
+
+#: ../terminal/src/terminal-menu-functions.c:77
+#: ../terminal/src/terminal-widget.c:410
+msgid "New Tab"
+msgstr "Nyt faneblad"
+
+#: ../terminal/src/terminal-menu-functions.c:78
+msgid "Rename current Tab"
+msgstr "Omdøb aktuelle faneblad"
+
+#: ../terminal/src/terminal-menu-functions.c:79
+msgid "Close current Tab"
+msgstr ""
+
+#: ../terminal/src/terminal-widget.c:49 ../terminal/data/messages:115
+msgid "Terminal"
+msgstr ""
+
+#: ../terminal/src/terminal-widget.c:177
+msgid "Set title for this tab:"
+msgstr ""
+
+#: ../terminal/src/terminal-widget.c:226
+msgid "Select a color"
+msgstr ""
+
+#: ../terminal/src/terminal-widget.c:364
+#, c-format
+msgid "You can recall the Terminal desklet by typing %s"
+msgstr ""
+
+#: ../terminal/src/terminal-widget.c:412
+msgid "Rename this Tab"
+msgstr ""
+
+#: ../terminal/src/terminal-widget.c:414
+msgid "Change this Tab's colour"
+msgstr ""
+
+#: ../terminal/src/terminal-widget.c:416
+msgid "Close this Tab"
+msgstr ""
+
+#: ../tomboy/src/applet-backend-default.c:159
+msgid "Note:"
+msgstr ""
+
+#: ../tomboy/src/applet-backend-default.c:207
+msgid "Title:"
+msgstr ""
+
+#: ../tomboy/src/tomboy-draw.c:188
+msgid "Open all"
+msgstr ""
+
+#: ../tomboy/src/tomboy-init.c:32
+msgid "Note-Taking"
+msgstr ""
+
+#: ../tomboy/src/tomboy-init.c:35
+msgid ""
+"Control your Gnote or TomBoy's notes directly in the dock !\n"
+"Click on a note to open it, Escape to close it.\n"
+"Middle-click to instantly create a new note.\n"
+"You can search inside notes and display their content on the icons."
+msgstr ""
+
+#: ../tomboy/src/tomboy-notifications.c:86
+msgid "Note name : "
+msgstr ""
+
+#: ../tomboy/src/tomboy-notifications.c:113
+msgid "Delete this note?"
+msgstr ""
+
+#: ../tomboy/src/tomboy-notifications.c:153
+msgid "Search for:"
+msgstr ""
+
+#: ../tomboy/src/tomboy-notifications.c:178
+msgid "Search for tag:"
+msgstr ""
+
+#: ../tomboy/src/tomboy-notifications.c:217
+msgid "Add a note"
+msgstr ""
+
+#: ../tomboy/src/tomboy-notifications.c:223
+msgid "Delete this note"
+msgstr ""
+
+#: ../tomboy/src/tomboy-notifications.c:226
+msgid "Reload notes"
+msgstr ""
+
+#: ../tomboy/src/tomboy-notifications.c:230
+msgid "Search"
+msgstr ""
+
+#: ../tomboy/src/tomboy-notifications.c:231
+msgid "Search for tag"
+msgstr ""
+
+#: ../tomboy/src/tomboy-notifications.c:233
+msgid "Search for today's note"
+msgstr ""
+
+#: ../tomboy/src/tomboy-notifications.c:234
+msgid "Search for this week's note"
+msgstr ""
+
+#: ../tomboy/src/tomboy-notifications.c:235
+msgid "Search for next week's note"
+msgstr ""
+
+#: ../tomboy/src/tomboy-notifications.c:245
+msgid "Reset marks"
+msgstr ""
+
+#: ../tomboy/src/tomboy-notifications.c:277
+msgid "No description"
+msgstr ""
+
+#: ../weather/src/applet-config.c:120
+msgid ""
+"I couldn't get the info\n"
+" Is connexion alive ?"
+msgstr ""
+
+#: ../weather/src/applet-config.c:126
+msgid "Couldn't get the location code (is connection alive?)"
+msgstr ""
+
+#: ../weather/src/applet-config.c:134
+msgid "I couldn't find this location"
+msgstr ""
+
+#: ../weather/src/applet-config.c:184
+msgid "Searching the location code..."
+msgstr ""
+
+#: ../weather/src/applet-config.c:217
+msgid ""
+"Enter the name of your location and press Enter to choose amongst results."
+msgstr ""
+
+#: ../weather/src/applet-init.c:29
+msgid "weather"
+msgstr "vejr"
+
+#: ../weather/src/applet-init.c:32
+msgid ""
+"This applet displays weather into your dock.\n"
+"Data are provided by www.weather.com, you can find your location in the "
+"config panel.\n"
+"It can detach itself to be a totally eye-candy 3D deskelt.\n"
+"Middle-click on the main icon to have current conditions information, left-"
+"click on a sub-icon to have forcast information.\n"
+msgstr ""
+
+#: ../weather/src/applet-load-icons.c:26
+msgid "Jan"
+msgstr "Jan"
+
+#: ../weather/src/applet-load-icons.c:26
+msgid "Feb"
+msgstr "Feb"
+
+#: ../weather/src/applet-load-icons.c:26
+msgid "Mar"
+msgstr "Mar"
+
+#: ../weather/src/applet-load-icons.c:26
+msgid "Apr"
+msgstr "Apr"
+
+#: ../weather/src/applet-load-icons.c:26
+msgid "May"
+msgstr "Maj"
+
+#: ../weather/src/applet-load-icons.c:26
+msgid "Jun"
+msgstr "Jun"
+
+#: ../weather/src/applet-load-icons.c:26
+msgid "Jui"
+msgstr "Jul"
+
+#: ../weather/src/applet-load-icons.c:26
+msgid "Aug"
+msgstr "Aug"
+
+#: ../weather/src/applet-load-icons.c:26
+msgid "Sep"
+msgstr "Sep"
+
+#: ../weather/src/applet-load-icons.c:26
+msgid "Oct"
+msgstr "Okt"
+
+#: ../weather/src/applet-load-icons.c:26
+msgid "Nov"
+msgstr "Nov"
+
+#: ../weather/src/applet-load-icons.c:26
+msgid "Dec"
+msgstr "Dec"
+
+#: ../weather/src/applet-notifications.c:65
+msgid "Data are being retrieved, please wait a moment."
+msgstr ""
+
+#: ../weather/src/applet-notifications.c:104
+msgid "Show current conditions (middle-click)"
+msgstr ""
+
+#: ../weather/src/applet-notifications.c:109
+msgid "Open weather.com (double-click)"
+msgstr ""
+
+#: ../weather/src/applet-notifications.c:111
+msgid "Reload now"
+msgstr ""
+
+#: ../weather/src/applet-notifications.c:144
+msgid ""
+"No data available\n"
+" is your connection alive?"
+msgstr ""
+
+#: ../weather/src/applet-notifications.c:164
+#: ../weather/src/applet-notifications.c:202
+msgid "Temperature"
+msgstr ""
+
+#: ../weather/src/applet-notifications.c:165
+msgid "Precipitation probability"
+msgstr ""
+
+#: ../weather/src/applet-notifications.c:166
+#: ../weather/src/applet-notifications.c:203
+msgid "Wind"
+msgstr ""
+
+#: ../weather/src/applet-notifications.c:167
+#: ../weather/src/applet-notifications.c:204
+msgid "Humidity"
+msgstr ""
+
+#: ../weather/src/applet-notifications.c:168
+#: ../weather/src/applet-notifications.c:205
+msgid "Sunrise"
+msgstr ""
+
+#: ../weather/src/applet-notifications.c:168
+#: ../weather/src/applet-notifications.c:205
+msgid "Sunset"
+msgstr ""
+
+#: ../weather/src/applet-notifications.c:178
+msgid "Data are being fetched, please re-try in a few seconds."
+msgstr ""
+
+#: ../weather/src/applet-notifications.c:188
+msgid ""
+"No data available\n"
+"Retrying now..."
+msgstr ""
+
+#: ../weather/src/applet-notifications.c:202
+msgid "Feels like"
+msgstr ""
+
+#: ../weather/src/applet-notifications.c:204
+msgid "Pressure"
+msgstr ""
+
+#: ../weblets/src/applet-init.c:28
+msgid "weblets"
+msgstr ""
+
+#: ../weblets/src/applet-init.c:31
+msgid ""
+"The weblets applet allows you to show an interactive web page on your "
+"desktop.\n"
+"You can select your web page, set the desired scrolling,\n"
+"and hide the scrollbars to get a real 'crop' of the page."
+msgstr ""
+
+#: ../weblets/src/applet-widget.c:58
+msgid "Weblets"
+msgstr ""
+
+#: ../wifi/src/applet-draw.c:30
+msgid "Very Low"
+msgstr ""
+
+#: ../wifi/src/applet-draw.c:30 ../Sound-Effects/data/messages:23
+msgid "Low"
+msgstr ""
+
+#: ../wifi/src/applet-draw.c:30
+msgid "Middle"
+msgstr ""
+
+#: ../wifi/src/applet-draw.c:30
+msgid "Good"
+msgstr "Godt"
+
+#: ../wifi/src/applet-draw.c:30
+msgid "Excellent"
+msgstr "Fremragende"
+
+#: ../wifi/src/applet-draw.c:138
+msgid "WiFi disabled."
+msgstr ""
+
+#: ../wifi/src/applet-init.c:33
+msgid ""
+"This applet shows you the signal strength of the first active wifi "
+"connection\n"
+"Left-click to pop-up some info,Middle-click to re-check immediately."
+msgstr ""
+
+#: ../wifi/src/applet-init.c:39 ../Network-Monitor/data/messages:179
+msgid "Wifi"
+msgstr "Wifi"
+
+#: ../wifi/src/applet-notifications.c:88
+msgid "Toggle wifi ON/OFF"
+msgstr ""
+
+#: ../gvfs-integration/cairo-dock-gio-vfs.c:345
+#: ../gvfs-integration/cairo-dock-gio-vfs.c:707
+msgid "File System"
+msgstr "Filsystem"
+
+#: ../Animated-icons/data/messages:1 ../icon-effect/data/messages:1
+#: ../illusion/data/messages:1
+msgid "Global"
+msgstr "Global"
+
+#: ../Animated-icons/data/messages:3 ../icon-effect/data/messages:3
+msgid "when hovering over an icon"
+msgstr ""
+
+#: ../Animated-icons/data/messages:5 ../icon-effect/data/messages:5
+msgid "Effects used:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:23 ../icon-effect/data/messages:19
+msgid "when clicking on an launcher"
+msgstr ""
+
+#: ../Animated-icons/data/messages:25 ../icon-effect/data/messages:21
+msgid "Effects used on launcher:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:43 ../Animated-icons/data/messages:67
+msgid "Number of times the animation will play:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:45 ../icon-effect/data/messages:35
+msgid "Repeat these effects until the corresponding application opens?"
+msgstr ""
+
+#: ../Animated-icons/data/messages:47 ../icon-effect/data/messages:37
+msgid "when clicking on an application"
+msgstr ""
+
+#: ../Animated-icons/data/messages:49 ../icon-effect/data/messages:39
+msgid "Effects used on applications:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:69
+msgid "Rotation"
+msgstr "Rotation"
+
+# Lidt fussy
+#: ../Animated-icons/data/messages:71 ../Animated-icons/data/messages:89
+#: ../Animated-icons/data/messages:137 ../Animated-icons/data/messages:149
+#: ../Animated-icons/data/messages:161 ../Animated-icons/data/messages:175
+#: ../Animated-icons/data/messages:183 ../Remote-Control/data/messages:11
+#: ../Scooby-Do/data/messages:17 ../Scooby-Do/data/messages:21
+#: ../Toons/data/messages:105 ../icon-effect/data/messages:87
+#: ../icon-effect/data/messages:109 ../icon-effect/data/messages:131
+#: ../icon-effect/data/messages:153 ../icon-effect/data/messages:173
+#: ../show-mouse/data/messages:19
+msgid "In ms."
+msgstr "I ms."
+
+#: ../Animated-icons/data/messages:73 ../Animated-icons/data/messages:91
+#: ../Animated-icons/data/messages:139 ../icon-effect/data/messages:61
+#: ../icon-effect/data/messages:89 ../icon-effect/data/messages:111
+#: ../icon-effect/data/messages:133 ../icon-effect/data/messages:155
+#: ../icon-effect/data/messages:175 ../illusion/data/messages:33
+#: ../illusion/data/messages:55 ../illusion/data/messages:59
+#: ../illusion/data/messages:69 ../illusion/data/messages:75
+#: ../mail/data/messages:143
+msgid "Duration of the animation:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:75 ../Animated-icons/data/messages:93
+#: ../Animated-icons/data/messages:141 ../Animated-icons/data/messages:153
+#: ../Animated-icons/data/messages:165 ../Animated-icons/data/messages:179
+#: ../Animated-icons/data/messages:187 ../icon-effect/data/messages:63
+#: ../icon-effect/data/messages:91 ../icon-effect/data/messages:113
+#: ../icon-effect/data/messages:135 ../icon-effect/data/messages:157
+#: ../icon-effect/data/messages:177
+msgid "Repeat while icon is pointed to?"
+msgstr ""
+
+#: ../Animated-icons/data/messages:77
+msgid "Type of mesh:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:79 ../Clipper/data/messages:43
+#: ../Composite-Manager/data/messages:41 ../Disks/data/messages:27
+#: ../Doncky/data/messages:43 ../Folders/data/messages:55
+#: ../GMenu/data/messages:43 ../Global-Menu/data/messages:37
+#: ../Impulse/data/messages:37 ../Indicator-Generic/data/messages:43
+#: ../MeMenu/data/messages:37 ../Messaging-Menu/data/messages:51
+#: ../Network-Monitor/data/messages:53 ../RSSreader/data/messages:45
+#: ../Recent-Events/data/messages:43 ../Screenshot/data/messages:43
+#: ../Status-Notifier/data/messages:55 ../System-Monitor/data/messages:51
+#: ../Toons/data/messages:51 ../Xgamma/data/messages:45
+#: ../alsaMixer/data/messages:51 ../clock/data/messages:53
+#: ../dnd2share/data/messages:39 ../dustbin/data/messages:41
+#: ../keyboard-indicator/data/messages:51 ../logout/data/messages:43
+#: ../mail/data/messages:51 ../musicPlayer/data/messages:53
+#: ../netspeed/data/messages:51 ../powermanager/data/messages:53
+#: ../quick-browser/data/messages:45 ../shortcuts/data/messages:43
+#: ../showDesktop/data/messages:45 ../slider/data/messages:51
+#: ../stack/data/messages:45 ../switcher/data/messages:43
+#: ../systray/data/messages:35 ../template/data/messages:43
+#: ../terminal/data/messages:43 ../tomboy/data/messages:55
+#: ../weather/data/messages:53 ../weblets/data/messages:43
+#: ../wifi/data/messages:51
+msgid "Normal"
+msgstr "Normal"
+
+#: ../Animated-icons/data/messages:81
+msgid "Cube"
+msgstr "Terning"
+
+#: ../Animated-icons/data/messages:83
+msgid "Capsule"
+msgstr ""
+
+#: ../Animated-icons/data/messages:85
+msgid "Colour of the sheen:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:97
+msgid "Image for the spotlight:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:99
+msgid "Image for the front spotlight:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:101
+msgid "Spot colour:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:103
+msgid "Halo colour:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:105
+msgid "Rays"
+msgstr ""
+
+#: ../Animated-icons/data/messages:107 ../icon-effect/data/messages:67
+#: ../icon-effect/data/messages:95 ../icon-effect/data/messages:117
+#: ../icon-effect/data/messages:139 ../icon-effect/data/messages:161
+#: ../illusion/data/messages:37 ../show-mouse/data/messages:27
+msgid "1st color of gradation :"
+msgstr ""
+
+#: ../Animated-icons/data/messages:109 ../icon-effect/data/messages:69
+#: ../icon-effect/data/messages:97 ../icon-effect/data/messages:119
+#: ../icon-effect/data/messages:141 ../icon-effect/data/messages:163
+#: ../illusion/data/messages:39 ../show-mouse/data/messages:29
+msgid "2nd color of gradation :"
+msgstr ""
+
+#: ../Animated-icons/data/messages:111 ../icon-effect/data/messages:71
+#: ../icon-effect/data/messages:99 ../icon-effect/data/messages:183
+#: ../illusion/data/messages:41 ../show-mouse/data/messages:31
+msgid "Random colours?"
+msgstr ""
+
+#: ../Animated-icons/data/messages:113
+msgid "Number of rays:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:115
+msgid "Ray size:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:117
+msgid "Ray speed:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:121
+msgid "Initial stretch:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:123
+msgid "Horizontal stretch"
+msgstr ""
+
+#: ../Animated-icons/data/messages:125
+msgid "Vertical stretch"
+msgstr ""
+
+#: ../Animated-icons/data/messages:127
+msgid "Corner stretch"
+msgstr ""
+
+#: ../Animated-icons/data/messages:129
+msgid "Spring constant:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:131
+msgid "Friction:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:133
+msgid "Number of points on the grid in each direction:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:143
+msgid "Wave width:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:145
+msgid "Wave amplitude:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:151
+msgid "Pulse duration:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:155
+msgid "Pulse max zoom:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:157
+msgid "Pulse follows icon shape?"
+msgstr ""
+
+#: ../Animated-icons/data/messages:163
+msgid "Bounce duration:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:167
+msgid "When bouncing, resize the icon by:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:169
+msgid "the lower the value, the more it will flatten."
+msgstr ""
+
+#: ../Animated-icons/data/messages:171
+msgid "How much the icon will flatten when hitting the ground:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:177
+msgid "Blink duration:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:185
+msgid "Busy duration:"
+msgstr ""
+
+#: ../Animated-icons/data/messages:189
+msgid ""
+"The image must contain all the frames of the animation, side by side, from "
+"left to right."
+msgstr ""
+
+#: ../Animated-icons/data/messages:191
+msgid "Image :"
+msgstr ""
+
+#: ../Animated-icons/data/messages:193
+msgid "Image size"
+msgstr ""
+
+#: ../Cairo-Penguin/data/messages:1 ../Cairo-Penguin/data/messages:3
+#: ../Clipper/data/messages:1 ../Clipper/data/messages:3
+#: ../Composite-Manager/data/messages:1 ../Composite-Manager/data/messages:3
+#: ../Disks/data/messages:1 ../Disks/data/messages:3 ../Doncky/data/messages:1
+#: ../Doncky/data/messages:3 ../Folders/data/messages:1
+#: ../Folders/data/messages:3 ../GMenu/data/messages:1
+#: ../GMenu/data/messages:3 ../Global-Menu/data/messages:1
+#: ../Global-Menu/data/messages:3 ../Impulse/data/messages:1
+#: ../Impulse/data/messages:3 ../Indicator-Generic/data/messages:1
+#: ../Indicator-Generic/data/messages:3 ../MeMenu/data/messages:1
+#: ../MeMenu/data/messages:3 ../Messaging-Menu/data/messages:1
+#: ../Messaging-Menu/data/messages:3 ../Network-Monitor/data/messages:1
+#: ../Network-Monitor/data/messages:3 ../RSSreader/data/messages:1
+#: ../RSSreader/data/messages:3 ../Recent-Events/data/messages:1
+#: ../Recent-Events/data/messages:3 ../Screenshot/data/messages:1
+#: ../Screenshot/data/messages:3 ../Status-Notifier/data/messages:1
+#: ../Status-Notifier/data/messages:3 ../System-Monitor/data/messages:1
+#: ../System-Monitor/data/messages:3 ../Toons/data/messages:1
+#: ../Toons/data/messages:3 ../Xgamma/data/messages:1
+#: ../Xgamma/data/messages:3 ../alsaMixer/data/messages:1
+#: ../alsaMixer/data/messages:3 ../alsaMixer/data/messages:111
+#: ../clock/data/messages:1 ../clock/data/messages:3
+#: ../dnd2share/data/messages:1 ../dnd2share/data/messages:3
+#: ../dustbin/data/messages:1 ../dustbin/data/messages:3
+#: ../keyboard-indicator/data/messages:1 ../keyboard-indicator/data/messages:3
+#: ../logout/data/messages:1 ../logout/data/messages:3 ../mail/data/messages:1
+#: ../mail/data/messages:3 ../musicPlayer/data/messages:1
+#: ../musicPlayer/data/messages:3 ../netspeed/data/messages:1
+#: ../netspeed/data/messages:3 ../powermanager/data/messages:1
+#: ../powermanager/data/messages:3 ../quick-browser/data/messages:1
+#: ../quick-browser/data/messages:3 ../shortcuts/data/messages:1
+#: ../shortcuts/data/messages:3 ../showDesktop/data/messages:1
+#: ../showDesktop/data/messages:3 ../slider/data/messages:1
+#: ../slider/data/messages:3 ../stack/data/messages:1 ../stack/data/messages:3
+#: ../switcher/data/messages:1 ../switcher/data/messages:3
+#: ../switcher/data/messages:123 ../systray/data/messages:1
+#: ../systray/data/messages:3 ../template/data/messages:1
+#: ../template/data/messages:3 ../terminal/data/messages:1
+#: ../terminal/data/messages:3 ../tomboy/data/messages:1
+#: ../tomboy/data/messages:3 ../weather/data/messages:1
+#: ../weather/data/messages:3 ../weblets/data/messages:1
+#: ../weblets/data/messages:3 ../wifi/data/messages:1 ../wifi/data/messages:3
+#: ../wifi/data/messages:135
+msgid "Icon"
+msgstr ""
+
+#: ../Cairo-Penguin/data/messages:5 ../Clipper/data/messages:5
+#: ../Composite-Manager/data/messages:5 ../Doncky/data/messages:5
+#: ../Folders/data/messages:5 ../GMenu/data/messages:5
+#: ../Global-Menu/data/messages:5 ../Impulse/data/messages:5
+#: ../Indicator-Generic/data/messages:5 ../MeMenu/data/messages:5
+#: ../Messaging-Menu/data/messages:5 ../Network-Monitor/data/messages:5
+#: ../RSSreader/data/messages:5 ../Recent-Events/data/messages:5
+#: ../Screenshot/data/messages:5 ../Status-Notifier/data/messages:5
+#: ../System-Monitor/data/messages:5 ../Toons/data/messages:5
+#: ../Xgamma/data/messages:5 ../alsaMixer/data/messages:5
+#: ../clock/data/messages:5 ../dnd2share/data/messages:5
+#: ../dustbin/data/messages:5 ../keyboard-indicator/data/messages:5
+#: ../logout/data/messages:5 ../mail/data/messages:5
+#: ../musicPlayer/data/messages:5 ../netspeed/data/messages:5
+#: ../powermanager/data/messages:5 ../quick-browser/data/messages:5
+#: ../shortcuts/data/messages:5 ../showDesktop/data/messages:5
+#: ../slider/data/messages:5 ../stack/data/messages:5
+#: ../switcher/data/messages:5 ../systray/data/messages:5
+#: ../template/data/messages:5 ../terminal/data/messages:5
+#: ../tomboy/data/messages:5 ../weather/data/messages:5
+#: ../weblets/data/messages:5 ../wifi/data/messages:5
+msgid "Name of the dock it belongs to:"
+msgstr ""
+
+#: ../Cairo-Penguin/data/messages:7 ../Clipper/data/messages:7
+#: ../Composite-Manager/data/messages:7 ../Disks/data/messages:7
+#: ../Doncky/data/messages:7 ../Folders/data/messages:9
+#: ../GMenu/data/messages:7 ../Indicator-Generic/data/messages:7
+#: ../Messaging-Menu/data/messages:7 ../Network-Monitor/data/messages:9
+#: ../RSSreader/data/messages:9 ../Recent-Events/data/messages:7
+#: ../Screenshot/data/messages:7 ../Status-Notifier/data/messages:7
+#: ../System-Monitor/data/messages:7 ../Toons/data/messages:7
+#: ../Xgamma/data/messages:9 ../alsaMixer/data/messages:7
+#: ../clock/data/messages:9 ../dnd2share/data/messages:7
+#: ../dustbin/data/messages:7 ../keyboard-indicator/data/messages:7
+#: ../logout/data/messages:7 ../mail/data/messages:7
+#: ../musicPlayer/data/messages:9 ../netspeed/data/messages:7
+#: ../powermanager/data/messages:9 ../quick-browser/data/messages:9
+#: ../shortcuts/data/messages:7 ../showDesktop/data/messages:7
+#: ../slider/data/messages:7 ../stack/data/messages:9
+#: ../switcher/data/messages:7 ../systray/data/messages:7
+#: ../template/data/messages:7 ../terminal/data/messages:7
+#: ../tomboy/data/messages:7 ../weather/data/messages:9
+#: ../weblets/data/messages:7 ../wifi/data/messages:7
+msgid "Name of the icon as it will appear in its caption in the dock:"
+msgstr ""
+
+#: ../Cairo-Penguin/data/messages:9 ../Clipper/data/messages:9
+#: ../Composite-Manager/data/messages:9 ../Disks/data/messages:9
+#: ../Doncky/data/messages:9 ../GMenu/data/messages:9
+#: ../GMenu/data/messages:109 ../Indicator-Generic/data/messages:9
+#: ../Messaging-Menu/data/messages:9 ../RSSreader/data/messages:11
+#: ../RSSreader/data/messages:129 ../Recent-Events/data/messages:9
+#: ../Screenshot/data/messages:9 ../Status-Notifier/data/messages:9
+#: ../System-Monitor/data/messages:9 ../System-Monitor/data/messages:189
+#: ../System-Monitor/data/messages:197 ../Toons/data/messages:9
+#: ../alsaMixer/data/messages:153 ../clock/data/messages:11
+#: ../clock/data/messages:129 ../dnd2share/data/messages:9
+#: ../dustbin/data/messages:9 ../keyboard-indicator/data/messages:9
+#: ../logout/data/messages:9 ../mail/data/messages:9
+#: ../netspeed/data/messages:9 ../shortcuts/data/messages:9
+#: ../showDesktop/data/messages:9 ../slider/data/messages:9
+#: ../stack/data/messages:11 ../switcher/data/messages:9
+#: ../systray/data/messages:9 ../template/data/messages:9
+#: ../terminal/data/messages:9 ../terminal/data/messages:127
+#: ../tomboy/data/messages:9 ../tomboy/data/messages:131
+#: ../tomboy/data/messages:143 ../weblets/data/messages:9
+msgid "Default"
+msgstr ""
+
+#: ../Cairo-Penguin/data/messages:11 ../Clipper/data/messages:13
+#: ../Composite-Manager/data/messages:11 ../Disks/data/messages:11
+#: ../Doncky/data/messages:13 ../Folders/data/messages:25
+#: ../GMenu/data/messages:13 ../Global-Menu/data/messages:7
+#: ../Impulse/data/messages:7 ../Indicator-Generic/data/messages:13
+#: ../MeMenu/data/messages:7 ../Messaging-Menu/data/messages:11
+#: ../Network-Monitor/data/messages:13 ../RSSreader/data/messages:15
+#: ../Recent-Events/data/messages:13 ../Screenshot/data/messages:13
+#: ../Status-Notifier/data/messages:15 ../System-Monitor/data/messages:11
+#: ../Toons/data/messages:11 ../Xgamma/data/messages:15
+#: ../alsaMixer/data/messages:11 ../clock/data/messages:13
+#: ../dnd2share/data/messages:13 ../dustbin/data/messages:11
+#: ../keyboard-indicator/data/messages:11 ../logout/data/messages:13
+#: ../mail/data/messages:11 ../musicPlayer/data/messages:13
+#: ../netspeed/data/messages:11 ../powermanager/data/messages:13
+#: ../quick-browser/data/messages:15 ../shortcuts/data/messages:13
+#: ../showDesktop/data/messages:15 ../slider/data/messages:11
+#: ../stack/data/messages:15 ../switcher/data/messages:13
+#: ../systray/data/messages:13 ../template/data/messages:13
+#: ../terminal/data/messages:13 ../tomboy/data/messages:25
+#: ../weather/data/messages:13 ../weblets/data/messages:13
+#: ../wifi/data/messages:11
+msgid "Set to 0 to use the default applet size"
+msgstr ""
+
+#: ../Cairo-Penguin/data/messages:13 ../Clipper/data/messages:15
+#: ../Composite-Manager/data/messages:13 ../Disks/data/messages:13
+#: ../Doncky/data/messages:15 ../Folders/data/messages:27
+#: ../GMenu/data/messages:15 ../Global-Menu/data/messages:9
+#: ../Impulse/data/messages:9 ../Indicator-Generic/data/messages:15
+#: ../MeMenu/data/messages:9 ../Messaging-Menu/data/messages:13
+#: ../Network-Monitor/data/messages:15 ../RSSreader/data/messages:17
+#: ../Recent-Events/data/messages:15 ../Screenshot/data/messages:15
+#: ../Status-Notifier/data/messages:17 ../System-Monitor/data/messages:13
+#: ../Toons/data/messages:13 ../Xgamma/data/messages:17
+#: ../alsaMixer/data/messages:13 ../clock/data/messages:15
+#: ../dnd2share/data/messages:15 ../dustbin/data/messages:13
+#: ../keyboard-indicator/data/messages:13 ../logout/data/messages:15
+#: ../mail/data/messages:13 ../musicPlayer/data/messages:15
+#: ../netspeed/data/messages:13 ../powermanager/data/messages:15
+#: ../quick-browser/data/messages:17 ../shortcuts/data/messages:15
+#: ../showDesktop/data/messages:17 ../slider/data/messages:13
+#: ../stack/data/messages:17 ../switcher/data/messages:15
+#: ../systray/data/messages:15 ../template/data/messages:15
+#: ../terminal/data/messages:15 ../tomboy/data/messages:27
+#: ../weather/data/messages:15 ../weblets/data/messages:15
+#: ../wifi/data/messages:13
+msgid "Desired icon size for this applet"
+msgstr ""
+
+#: ../Cairo-Penguin/data/messages:15 ../Clipper/data/messages:89
+#: ../Composite-Manager/data/messages:87 ../Dbus/data/messages:1
+#: ../Disks/data/messages:87 ../Doncky/data/messages:89
+#: ../Folders/data/messages:101 ../GMenu/data/messages:89
+#: ../Global-Menu/data/messages:83 ../Impulse/data/messages:83
+#: ../Indicator-Generic/data/messages:89 ../MeMenu/data/messages:83
+#: ../Messaging-Menu/data/messages:97 ../Network-Monitor/data/messages:99
+#: ../RSSreader/data/messages:91 ../Recent-Events/data/messages:89
+#: ../Remote-Control/data/messages:3 ../Scooby-Do/data/messages:3
+#: ../Screenshot/data/messages:89 ../Sound-Effects/data/messages:1
+#: ../Status-Notifier/data/messages:101 ../System-Monitor/data/messages:97
+#: ../Toons/data/messages:97 ../Xgamma/data/messages:91
+#: ../alsaMixer/data/messages:97 ../clock/data/messages:99
+#: ../dnd2share/data/messages:85 ../dustbin/data/messages:87
+#: ../keyboard-indicator/data/messages:97 ../logout/data/messages:89
+#: ../mail/data/messages:97 ../motion-blur/data/messages:1
+#: ../musicPlayer/data/messages:99 ../netspeed/data/messages:97
+#: ../powermanager/data/messages:99 ../quick-browser/data/messages:91
+#: ../shortcuts/data/messages:89 ../show-mouse/data/messages:1
+#: ../showDesktop/data/messages:91 ../slider/data/messages:97
+#: ../stack/data/messages:91 ../switcher/data/messages:89
+#: ../switcher/data/messages:91 ../systray/data/messages:81
+#: ../template/data/messages:89 ../terminal/data/messages:89
+#: ../tomboy/data/messages:101 ../weather/data/messages:99
+#: ../weather/data/messages:101 ../weblets/data/messages:89
+#: ../wifi/data/messages:97
+msgid "Configuration"
+msgstr "Konfiguration"
+
+#: ../Cairo-Penguin/data/messages:17 ../Disks/data/messages:97
+#: ../Network-Monitor/data/messages:147 ../Network-Monitor/data/messages:191
+#: ../Toons/data/messages:99 ../dustbin/data/messages:91
+#: ../mail/data/messages:105 ../netspeed/data/messages:107
+#: ../weather/data/messages:131
+msgid "Choose one of the available themes:"
+msgstr ""
+
+#: ../Cairo-Penguin/data/messages:21
+msgid "Delay between animation changes :"
+msgstr ""
+
+#: ../Cairo-Penguin/data/messages:23
+msgid "Penguin transparency:"
+msgstr ""
+
+#: ../Cairo-Penguin/data/messages:25
+msgid "Let the penguin wander everywhere in the dock?"
+msgstr ""
+
+#: ../Cairo-Penguin/data/messages:27 ../dock-rendering/data/messages:13
+#: ../dock-rendering/data/messages:107 ../show-mouse/data/messages:23
+msgid "in pixels."
+msgstr ""
+
+#: ../Cairo-Penguin/data/messages:29
+msgid "Ground offset:"
+msgstr ""
+
+#: ../Clipper/data/messages:11 ../Doncky/data/messages:11
+#: ../Folders/data/messages:23 ../GMenu/data/messages:11
+#: ../Indicator-Generic/data/messages:11 ../RSSreader/data/messages:13
+#: ../Recent-Events/data/messages:11 ../Screenshot/data/messages:11
+#: ../Xgamma/data/messages:13 ../dnd2share/data/messages:11
+#: ../logout/data/messages:11 ../quick-browser/data/messages:13
+#: ../shortcuts/data/messages:11 ../showDesktop/data/messages:11
+#: ../stack/data/messages:13 ../switcher/data/messages:11
+#: ../systray/data/messages:11 ../template/data/messages:11
+#: ../terminal/data/messages:11 ../weblets/data/messages:11
+msgid "Image filename:"
+msgstr ""
+
+#: ../Clipper/data/messages:17 ../Composite-Manager/data/messages:15
+#: ../Disks/data/messages:15 ../Doncky/data/messages:17
+#: ../Folders/data/messages:29 ../GMenu/data/messages:17
+#: ../Global-Menu/data/messages:11 ../Impulse/data/messages:11
+#: ../Indicator-Generic/data/messages:17 ../MeMenu/data/messages:11
+#: ../Messaging-Menu/data/messages:25 ../Network-Monitor/data/messages:27
+#: ../RSSreader/data/messages:19 ../Recent-Events/data/messages:17
+#: ../Screenshot/data/messages:17 ../Status-Notifier/data/messages:29
+#: ../System-Monitor/data/messages:25 ../Toons/data/messages:25
+#: ../Xgamma/data/messages:19 ../alsaMixer/data/messages:25
+#: ../clock/data/messages:27 ../dnd2share/data/messages:17
+#: ../dustbin/data/messages:15 ../keyboard-indicator/data/messages:25
+#: ../logout/data/messages:17 ../mail/data/messages:25
+#: ../musicPlayer/data/messages:27 ../netspeed/data/messages:25
+#: ../powermanager/data/messages:27 ../quick-browser/data/messages:19
+#: ../shortcuts/data/messages:17 ../show-mouse/data/messages:13
+#: ../showDesktop/data/messages:19 ../slider/data/messages:25
+#: ../stack/data/messages:19 ../switcher/data/messages:17
+#: ../systray/data/messages:17 ../template/data/messages:17
+#: ../terminal/data/messages:17 ../tomboy/data/messages:29
+#: ../weather/data/messages:27 ../weblets/data/messages:17
+#: ../wifi/data/messages:25
+msgid "Desklet"
+msgstr ""
+
+#: ../Clipper/data/messages:19 ../Composite-Manager/data/messages:17
+#: ../Disks/data/messages:39 ../Doncky/data/messages:19
+#: ../Folders/data/messages:31 ../GMenu/data/messages:19
+#: ../Global-Menu/data/messages:13 ../Impulse/data/messages:13
+#: ../Indicator-Generic/data/messages:19 ../MeMenu/data/messages:13
+#: ../Messaging-Menu/data/messages:27 ../Network-Monitor/data/messages:29
+#: ../RSSreader/data/messages:21 ../Recent-Events/data/messages:19
+#: ../Screenshot/data/messages:19 ../Status-Notifier/data/messages:31
+#: ../System-Monitor/data/messages:27 ../Toons/data/messages:27
+#: ../Xgamma/data/messages:21 ../alsaMixer/data/messages:27
+#: ../clock/data/messages:29 ../dnd2share/data/messages:19
+#: ../dustbin/data/messages:17 ../keyboard-indicator/data/messages:27
+#: ../logout/data/messages:19 ../mail/data/messages:27
+#: ../musicPlayer/data/messages:29 ../netspeed/data/messages:27
+#: ../powermanager/data/messages:29 ../quick-browser/data/messages:21
+#: ../shortcuts/data/messages:19 ../showDesktop/data/messages:21
+#: ../slider/data/messages:27 ../stack/data/messages:21
+#: ../switcher/data/messages:19 ../systray/data/messages:19
+#: ../template/data/messages:19 ../terminal/data/messages:19
+#: ../tomboy/data/messages:31 ../weather/data/messages:29
+#: ../weblets/data/messages:19 ../wifi/data/messages:27
+msgid "Position"
+msgstr ""
+
+#: ../Clipper/data/messages:21 ../Composite-Manager/data/messages:19
+#: ../Disks/data/messages:41 ../Doncky/data/messages:21
+#: ../Folders/data/messages:33 ../GMenu/data/messages:21
+#: ../Global-Menu/data/messages:15 ../Impulse/data/messages:15
+#: ../Indicator-Generic/data/messages:21 ../MeMenu/data/messages:15
+#: ../Messaging-Menu/data/messages:29 ../Network-Monitor/data/messages:31
+#: ../RSSreader/data/messages:23 ../Recent-Events/data/messages:21
+#: ../Screenshot/data/messages:21 ../Status-Notifier/data/messages:33
+#: ../System-Monitor/data/messages:29 ../Toons/data/messages:29
+#: ../Xgamma/data/messages:23 ../alsaMixer/data/messages:29
+#: ../clock/data/messages:31 ../dnd2share/data/messages:21
+#: ../dustbin/data/messages:19 ../keyboard-indicator/data/messages:29
+#: ../logout/data/messages:21 ../mail/data/messages:29
+#: ../musicPlayer/data/messages:31 ../netspeed/data/messages:29
+#: ../powermanager/data/messages:31 ../quick-browser/data/messages:23
+#: ../shortcuts/data/messages:21 ../showDesktop/data/messages:23
+#: ../slider/data/messages:29 ../stack/data/messages:23
+#: ../switcher/data/messages:21 ../systray/data/messages:21
+#: ../template/data/messages:21 ../terminal/data/messages:21
+#: ../tomboy/data/messages:33 ../weather/data/messages:31
+#: ../weblets/data/messages:21 ../wifi/data/messages:29
+msgid ""
+"If locked, the desklet cannot be moved by simply dragging it with the left "
+"mouse button. It can still be moved with ALT + left-click."
+msgstr ""
+
+#: ../Clipper/data/messages:23 ../Composite-Manager/data/messages:21
+#: ../Disks/data/messages:43 ../Doncky/data/messages:23
+#: ../Folders/data/messages:35 ../GMenu/data/messages:23
+#: ../Global-Menu/data/messages:17 ../Impulse/data/messages:17
+#: ../Indicator-Generic/data/messages:23 ../MeMenu/data/messages:17
+#: ../Messaging-Menu/data/messages:31 ../Network-Monitor/data/messages:33
+#: ../RSSreader/data/messages:25 ../Recent-Events/data/messages:23
+#: ../Screenshot/data/messages:23 ../Status-Notifier/data/messages:35
+#: ../System-Monitor/data/messages:31 ../Toons/data/messages:31
+#: ../Xgamma/data/messages:25 ../alsaMixer/data/messages:31
+#: ../clock/data/messages:33 ../dnd2share/data/messages:23
+#: ../dustbin/data/messages:21 ../keyboard-indicator/data/messages:31
+#: ../logout/data/messages:23 ../mail/data/messages:31
+#: ../musicPlayer/data/messages:33 ../netspeed/data/messages:31
+#: ../powermanager/data/messages:33 ../quick-browser/data/messages:25
+#: ../shortcuts/data/messages:23 ../showDesktop/data/messages:25
+#: ../slider/data/messages:31 ../stack/data/messages:25
+#: ../switcher/data/messages:23 ../systray/data/messages:23
+#: ../template/data/messages:23 ../terminal/data/messages:23
+#: ../tomboy/data/messages:35 ../weather/data/messages:33
+#: ../weblets/data/messages:23 ../wifi/data/messages:31
+msgid "Lock position?"
+msgstr ""
+
+#: ../Clipper/data/messages:25 ../Composite-Manager/data/messages:23
+#: ../Disks/data/messages:21 ../Doncky/data/messages:25
+#: ../Folders/data/messages:37 ../GMenu/data/messages:25
+#: ../Global-Menu/data/messages:19 ../Impulse/data/messages:19
+#: ../Indicator-Generic/data/messages:25 ../MeMenu/data/messages:19
+#: ../Messaging-Menu/data/messages:33 ../Network-Monitor/data/messages:35
+#: ../RSSreader/data/messages:27 ../Recent-Events/data/messages:25
+#: ../Screenshot/data/messages:25 ../Status-Notifier/data/messages:37
+#: ../System-Monitor/data/messages:33 ../Toons/data/messages:33
+#: ../Xgamma/data/messages:27 ../alsaMixer/data/messages:33
+#: ../clock/data/messages:35 ../dnd2share/data/messages:25
+#: ../dustbin/data/messages:23 ../keyboard-indicator/data/messages:33
+#: ../logout/data/messages:25 ../mail/data/messages:33
+#: ../musicPlayer/data/messages:35 ../netspeed/data/messages:33
+#: ../powermanager/data/messages:35 ../quick-browser/data/messages:27
+#: ../shortcuts/data/messages:25 ../showDesktop/data/messages:27
+#: ../slider/data/messages:33 ../stack/data/messages:27
+#: ../switcher/data/messages:25 ../template/data/messages:25
+#: ../terminal/data/messages:25 ../tomboy/data/messages:37
+#: ../weather/data/messages:35 ../weblets/data/messages:25
+#: ../wifi/data/messages:33
+msgid ""
+"Depending on your WindowManager, you may be able to resize this with ALT + "
+"middle-click or ALT + left-click."
+msgstr ""
+
+#: ../Clipper/data/messages:27 ../Composite-Manager/data/messages:25
+#: ../Disks/data/messages:23 ../Doncky/data/messages:27
+#: ../Folders/data/messages:39 ../GMenu/data/messages:27
+#: ../Global-Menu/data/messages:21 ../Impulse/data/messages:21
+#: ../Indicator-Generic/data/messages:27 ../MeMenu/data/messages:21
+#: ../Messaging-Menu/data/messages:35 ../Network-Monitor/data/messages:37
+#: ../RSSreader/data/messages:29 ../Recent-Events/data/messages:27
+#: ../Screenshot/data/messages:27 ../Status-Notifier/data/messages:39
+#: ../System-Monitor/data/messages:35 ../Toons/data/messages:35
+#: ../Xgamma/data/messages:29 ../alsaMixer/data/messages:35
+#: ../clock/data/messages:37 ../dnd2share/data/messages:27
+#: ../dustbin/data/messages:25 ../keyboard-indicator/data/messages:35
+#: ../logout/data/messages:27 ../mail/data/messages:35
+#: ../musicPlayer/data/messages:37 ../netspeed/data/messages:35
+#: ../powermanager/data/messages:37 ../quick-browser/data/messages:29
+#: ../shortcuts/data/messages:27 ../showDesktop/data/messages:29
+#: ../slider/data/messages:35 ../stack/data/messages:29
+#: ../switcher/data/messages:27 ../template/data/messages:27
+#: ../terminal/data/messages:27 ../tomboy/data/messages:39
+#: ../weather/data/messages:37 ../weblets/data/messages:27
+#: ../wifi/data/messages:35
+msgid "Desklet dimensions (width x height):"
+msgstr ""
+
+#: ../Clipper/data/messages:29 ../Disks/data/messages:45
+#: ../Doncky/data/messages:29 ../Folders/data/messages:41
+#: ../GMenu/data/messages:29 ../MeMenu/data/messages:23
+#: ../Messaging-Menu/data/messages:37 ../Network-Monitor/data/messages:39
+#: ../RSSreader/data/messages:31 ../System-Monitor/data/messages:37
+#: ../Toons/data/messages:37 ../Xgamma/data/messages:31
+#: ../dnd2share/data/messages:29 ../keyboard-indicator/data/messages:37
+#: ../logout/data/messages:29 ../mail/data/messages:37
+#: ../musicPlayer/data/messages:39 ../powermanager/data/messages:39
+#: ../quick-browser/data/messages:31 ../shortcuts/data/messages:29
+#: ../showDesktop/data/messages:31 ../slider/data/messages:37
+#: ../stack/data/messages:31 ../switcher/data/messages:29
+#: ../terminal/data/messages:29 ../weather/data/messages:39
+#: ../weblets/data/messages:29 ../wifi/data/messages:37
+msgid ""
+"Depending on your WindowManager, you may be able to move this with ALT + "
+"left-click."
+msgstr ""
+
+#: ../Clipper/data/messages:31 ../Composite-Manager/data/messages:29
+#: ../Disks/data/messages:47 ../Doncky/data/messages:31
+#: ../Folders/data/messages:43 ../GMenu/data/messages:31
+#: ../Global-Menu/data/messages:25 ../Impulse/data/messages:25
+#: ../Indicator-Generic/data/messages:31 ../MeMenu/data/messages:25
+#: ../Messaging-Menu/data/messages:39 ../Network-Monitor/data/messages:41
+#: ../RSSreader/data/messages:33 ../Recent-Events/data/messages:31
+#: ../Screenshot/data/messages:31 ../Status-Notifier/data/messages:43
+#: ../System-Monitor/data/messages:39 ../Toons/data/messages:39
+#: ../Xgamma/data/messages:33 ../alsaMixer/data/messages:39
+#: ../clock/data/messages:41 ../dnd2share/data/messages:31
+#: ../dustbin/data/messages:29 ../keyboard-indicator/data/messages:39
+#: ../logout/data/messages:31 ../mail/data/messages:39
+#: ../musicPlayer/data/messages:41 ../netspeed/data/messages:39
+#: ../powermanager/data/messages:41 ../quick-browser/data/messages:33
+#: ../shortcuts/data/messages:31 ../showDesktop/data/messages:33
+#: ../slider/data/messages:39 ../stack/data/messages:33
+#: ../switcher/data/messages:31 ../systray/data/messages:27
+#: ../template/data/messages:31 ../terminal/data/messages:31
+#: ../tomboy/data/messages:43 ../weather/data/messages:41
+#: ../weblets/data/messages:31 ../wifi/data/messages:39
+msgid "Desklet position (x, y):"
+msgstr ""
+
+#: ../Clipper/data/messages:33 ../Composite-Manager/data/messages:31
+#: ../Disks/data/messages:49 ../Doncky/data/messages:33
+#: ../Folders/data/messages:45 ../GMenu/data/messages:33
+#: ../Global-Menu/data/messages:27 ../Impulse/data/messages:27
+#: ../Indicator-Generic/data/messages:33 ../MeMenu/data/messages:27
+#: ../Messaging-Menu/data/messages:41 ../Network-Monitor/data/messages:43
+#: ../RSSreader/data/messages:35 ../Recent-Events/data/messages:33
+#: ../Screenshot/data/messages:33 ../Status-Notifier/data/messages:45
+#: ../System-Monitor/data/messages:41 ../Toons/data/messages:41
+#: ../Xgamma/data/messages:35 ../alsaMixer/data/messages:41
+#: ../clock/data/messages:43 ../dustbin/data/messages:31
+#: ../keyboard-indicator/data/messages:41 ../logout/data/messages:33
+#: ../mail/data/messages:41 ../musicPlayer/data/messages:43
+#: ../netspeed/data/messages:41 ../powermanager/data/messages:43
+#: ../quick-browser/data/messages:35 ../shortcuts/data/messages:33
+#: ../showDesktop/data/messages:35 ../slider/data/messages:41
+#: ../stack/data/messages:35 ../switcher/data/messages:33
+#: ../template/data/messages:33 ../terminal/data/messages:33
+#: ../tomboy/data/messages:45 ../weather/data/messages:43
+#: ../weblets/data/messages:33 ../wifi/data/messages:41
+msgid ""
+"You can quickly rotate the desklet with the mouse, by dragging the little "
+"buttons on its left and top sides."
+msgstr ""
+
+#: ../Clipper/data/messages:35 ../Composite-Manager/data/messages:33
+#: ../Disks/data/messages:51 ../Doncky/data/messages:35
+#: ../Folders/data/messages:47 ../GMenu/data/messages:35
+#: ../Global-Menu/data/messages:29 ../Impulse/data/messages:29
+#: ../Indicator-Generic/data/messages:35 ../MeMenu/data/messages:29
+#: ../Messaging-Menu/data/messages:43 ../Network-Monitor/data/messages:45
+#: ../RSSreader/data/messages:37 ../Recent-Events/data/messages:35
+#: ../Screenshot/data/messages:35 ../Status-Notifier/data/messages:47
+#: ../System-Monitor/data/messages:43 ../Toons/data/messages:43
+#: ../Xgamma/data/messages:37 ../alsaMixer/data/messages:43
+#: ../clock/data/messages:45 ../dustbin/data/messages:33
+#: ../keyboard-indicator/data/messages:43 ../logout/data/messages:35
+#: ../mail/data/messages:43 ../musicPlayer/data/messages:45
+#: ../netspeed/data/messages:43 ../powermanager/data/messages:45
+#: ../quick-browser/data/messages:37 ../shortcuts/data/messages:35
+#: ../showDesktop/data/messages:37 ../slider/data/messages:43
+#: ../stack/data/messages:37 ../switcher/data/messages:35
+#: ../template/data/messages:35 ../terminal/data/messages:35
+#: ../tomboy/data/messages:47 ../weather/data/messages:45
+#: ../weblets/data/messages:35 ../wifi/data/messages:43
+msgid "Rotation:"
+msgstr ""
+
+#: ../Clipper/data/messages:37 ../Composite-Manager/data/messages:35
+#: ../Doncky/data/messages:37 ../Folders/data/messages:49
+#: ../GMenu/data/messages:37 ../Global-Menu/data/messages:31
+#: ../Impulse/data/messages:31 ../Indicator-Generic/data/messages:37
+#: ../MeMenu/data/messages:31 ../Messaging-Menu/data/messages:45
+#: ../Network-Monitor/data/messages:47 ../RSSreader/data/messages:39
+#: ../Recent-Events/data/messages:37 ../Screenshot/data/messages:37
+#: ../Status-Notifier/data/messages:49 ../System-Monitor/data/messages:45
+#: ../Toons/data/messages:45 ../Xgamma/data/messages:39
+#: ../alsaMixer/data/messages:45 ../clock/data/messages:47
+#: ../dnd2share/data/messages:33 ../dustbin/data/messages:35
+#: ../keyboard-indicator/data/messages:45 ../logout/data/messages:37
+#: ../mail/data/messages:45 ../musicPlayer/data/messages:47
+#: ../netspeed/data/messages:45 ../powermanager/data/messages:47
+#: ../quick-browser/data/messages:39 ../shortcuts/data/messages:37
+#: ../showDesktop/data/messages:39 ../slider/data/messages:45
+#: ../stack/data/messages:39 ../switcher/data/messages:37
+#: ../systray/data/messages:29 ../template/data/messages:37
+#: ../terminal/data/messages:37 ../tomboy/data/messages:49
+#: ../weather/data/messages:47 ../weblets/data/messages:37
+#: ../wifi/data/messages:45
+msgid "Visibility"
+msgstr ""
+
+#: ../Clipper/data/messages:39 ../Composite-Manager/data/messages:37
+#: ../Disks/data/messages:19 ../Doncky/data/messages:39
+#: ../Folders/data/messages:51 ../GMenu/data/messages:39
+#: ../Global-Menu/data/messages:33 ../Impulse/data/messages:33
+#: ../Indicator-Generic/data/messages:39 ../MeMenu/data/messages:33
+#: ../Messaging-Menu/data/messages:47 ../Network-Monitor/data/messages:49
+#: ../RSSreader/data/messages:41 ../Recent-Events/data/messages:39
+#: ../Screenshot/data/messages:39 ../Status-Notifier/data/messages:51
+#: ../System-Monitor/data/messages:47 ../Toons/data/messages:47
+#: ../Xgamma/data/messages:41 ../alsaMixer/data/messages:47
+#: ../clock/data/messages:49 ../dnd2share/data/messages:35
+#: ../dustbin/data/messages:37 ../keyboard-indicator/data/messages:47
+#: ../logout/data/messages:39 ../mail/data/messages:47
+#: ../musicPlayer/data/messages:49 ../netspeed/data/messages:47
+#: ../powermanager/data/messages:49 ../quick-browser/data/messages:41
+#: ../shortcuts/data/messages:39 ../showDesktop/data/messages:41
+#: ../slider/data/messages:47 ../stack/data/messages:41
+#: ../switcher/data/messages:39 ../systray/data/messages:31
+#: ../template/data/messages:39 ../terminal/data/messages:39
+#: ../tomboy/data/messages:51 ../weather/data/messages:49
+#: ../weblets/data/messages:39 ../wifi/data/messages:47
+msgid "Is detached from the dock"
+msgstr ""
+
+#: ../Clipper/data/messages:41 ../Composite-Manager/data/messages:39
+#: ../Disks/data/messages:25 ../Doncky/data/messages:41
+#: ../Folders/data/messages:53 ../GMenu/data/messages:41
+#: ../Global-Menu/data/messages:35 ../Impulse/data/messages:35
+#: ../Indicator-Generic/data/messages:41 ../MeMenu/data/messages:35
+#: ../Messaging-Menu/data/messages:49 ../Network-Monitor/data/messages:51
+#: ../RSSreader/data/messages:43 ../Recent-Events/data/messages:41
+#: ../Screenshot/data/messages:41 ../Status-Notifier/data/messages:53
+#: ../System-Monitor/data/messages:49 ../Toons/data/messages:49
+#: ../Xgamma/data/messages:43 ../alsaMixer/data/messages:49
+#: ../clock/data/messages:51 ../dnd2share/data/messages:37
+#: ../dustbin/data/messages:39 ../keyboard-indicator/data/messages:49
+#: ../logout/data/messages:41 ../mail/data/messages:49
+#: ../musicPlayer/data/messages:51 ../netspeed/data/messages:49
+#: ../powermanager/data/messages:51 ../quick-browser/data/messages:43
+#: ../shortcuts/data/messages:41 ../showDesktop/data/messages:43
+#: ../slider/data/messages:49 ../stack/data/messages:43
+#: ../switcher/data/messages:41 ../systray/data/messages:33
+#: ../template/data/messages:41 ../terminal/data/messages:41
+#: ../tomboy/data/messages:53 ../weather/data/messages:51
+#: ../weblets/data/messages:41 ../wifi/data/messages:49
+msgid "Visibility:"
+msgstr ""
+
+#: ../Clipper/data/messages:45 ../Composite-Manager/data/messages:43
+#: ../Disks/data/messages:29 ../Doncky/data/messages:45
+#: ../Folders/data/messages:57 ../GMenu/data/messages:45
+#: ../Global-Menu/data/messages:39 ../Impulse/data/messages:39
+#: ../Indicator-Generic/data/messages:45 ../MeMenu/data/messages:39
+#: ../Messaging-Menu/data/messages:53 ../Network-Monitor/data/messages:55
+#: ../RSSreader/data/messages:47 ../Recent-Events/data/messages:45
+#: ../Screenshot/data/messages:45 ../Status-Notifier/data/messages:57
+#: ../System-Monitor/data/messages:53 ../Toons/data/messages:53
+#: ../Xgamma/data/messages:47 ../alsaMixer/data/messages:53
+#: ../clock/data/messages:55 ../dnd2share/data/messages:41
+#: ../dustbin/data/messages:43 ../keyboard-indicator/data/messages:53
+#: ../logout/data/messages:45 ../mail/data/messages:53
+#: ../musicPlayer/data/messages:55 ../netspeed/data/messages:53
+#: ../powermanager/data/messages:55 ../quick-browser/data/messages:47
+#: ../shortcuts/data/messages:45 ../showDesktop/data/messages:47
+#: ../slider/data/messages:53 ../stack/data/messages:47
+#: ../switcher/data/messages:45 ../systray/data/messages:37
+#: ../template/data/messages:45 ../terminal/data/messages:45
+#: ../tomboy/data/messages:57 ../weather/data/messages:55
+#: ../weblets/data/messages:45 ../wifi/data/messages:53
+msgid "Keep above"
+msgstr ""
+
+#: ../Clipper/data/messages:47 ../Composite-Manager/data/messages:45
+#: ../Disks/data/messages:31 ../Doncky/data/messages:47
+#: ../Folders/data/messages:59 ../GMenu/data/messages:47
+#: ../Global-Menu/data/messages:41 ../Impulse/data/messages:41
+#: ../Indicator-Generic/data/messages:47 ../MeMenu/data/messages:41
+#: ../Messaging-Menu/data/messages:55 ../Network-Monitor/data/messages:57
+#: ../RSSreader/data/messages:49 ../Recent-Events/data/messages:47
+#: ../Screenshot/data/messages:47 ../Status-Notifier/data/messages:59
+#: ../System-Monitor/data/messages:55 ../Toons/data/messages:55
+#: ../Xgamma/data/messages:49 ../alsaMixer/data/messages:55
+#: ../clock/data/messages:57 ../dnd2share/data/messages:43
+#: ../dustbin/data/messages:45 ../keyboard-indicator/data/messages:55
+#: ../logout/data/messages:47 ../mail/data/messages:55
+#: ../musicPlayer/data/messages:57 ../netspeed/data/messages:55
+#: ../powermanager/data/messages:57 ../quick-browser/data/messages:49
+#: ../shortcuts/data/messages:47 ../showDesktop/data/messages:49
+#: ../slider/data/messages:55 ../stack/data/messages:49
+#: ../switcher/data/messages:47 ../systray/data/messages:39
+#: ../template/data/messages:47 ../terminal/data/messages:47
+#: ../tomboy/data/messages:59 ../weather/data/messages:57
+#: ../weblets/data/messages:47 ../wifi/data/messages:55
+msgid "Keep below"
+msgstr ""
+
+#: ../Clipper/data/messages:49 ../Composite-Manager/data/messages:47
+#: ../Disks/data/messages:33 ../Doncky/data/messages:49
+#: ../Folders/data/messages:61 ../GMenu/data/messages:49
+#: ../Global-Menu/data/messages:43 ../Impulse/data/messages:43
+#: ../Indicator-Generic/data/messages:49 ../MeMenu/data/messages:43
+#: ../Messaging-Menu/data/messages:57 ../Network-Monitor/data/messages:59
+#: ../RSSreader/data/messages:51 ../Recent-Events/data/messages:49
+#: ../Screenshot/data/messages:49 ../Status-Notifier/data/messages:61
+#: ../System-Monitor/data/messages:57 ../Toons/data/messages:57
+#: ../Xgamma/data/messages:51 ../alsaMixer/data/messages:57
+#: ../clock/data/messages:59 ../dnd2share/data/messages:45
+#: ../dustbin/data/messages:47 ../keyboard-indicator/data/messages:57
+#: ../logout/data/messages:49 ../mail/data/messages:57
+#: ../musicPlayer/data/messages:59 ../netspeed/data/messages:57
+#: ../powermanager/data/messages:59 ../quick-browser/data/messages:51
+#: ../shortcuts/data/messages:49 ../showDesktop/data/messages:51
+#: ../slider/data/messages:57 ../stack/data/messages:51
+#: ../switcher/data/messages:49 ../systray/data/messages:41
+#: ../template/data/messages:49 ../terminal/data/messages:49
+#: ../tomboy/data/messages:61 ../weather/data/messages:59
+#: ../weblets/data/messages:49 ../wifi/data/messages:57
+msgid "Keep on widget layer"
+msgstr ""
+
+#: ../Clipper/data/messages:51 ../Composite-Manager/data/messages:49
+#: ../Disks/data/messages:35 ../Doncky/data/messages:51
+#: ../Folders/data/messages:63 ../GMenu/data/messages:51
+#: ../Global-Menu/data/messages:45 ../Impulse/data/messages:45
+#: ../Indicator-Generic/data/messages:51 ../MeMenu/data/messages:45
+#: ../Messaging-Menu/data/messages:59 ../Network-Monitor/data/messages:61
+#: ../RSSreader/data/messages:53 ../Recent-Events/data/messages:51
+#: ../Screenshot/data/messages:51 ../Status-Notifier/data/messages:63
+#: ../System-Monitor/data/messages:59 ../Toons/data/messages:59
+#: ../Xgamma/data/messages:53 ../alsaMixer/data/messages:59
+#: ../clock/data/messages:61 ../dnd2share/data/messages:47
+#: ../dustbin/data/messages:49 ../keyboard-indicator/data/messages:59
+#: ../logout/data/messages:51 ../mail/data/messages:59
+#: ../musicPlayer/data/messages:61 ../netspeed/data/messages:59
+#: ../powermanager/data/messages:61 ../quick-browser/data/messages:53
+#: ../shortcuts/data/messages:51 ../showDesktop/data/messages:53
+#: ../slider/data/messages:59 ../stack/data/messages:53
+#: ../switcher/data/messages:51 ../systray/data/messages:43
+#: ../template/data/messages:51 ../terminal/data/messages:51
+#: ../tomboy/data/messages:63 ../weather/data/messages:61
+#: ../weblets/data/messages:51 ../wifi/data/messages:59
+msgid "Reserve space"
+msgstr ""
+
+#: ../Clipper/data/messages:53 ../Composite-Manager/data/messages:51
+#: ../Disks/data/messages:37 ../Doncky/data/messages:53
+#: ../Folders/data/messages:65 ../GMenu/data/messages:53
+#: ../Global-Menu/data/messages:47 ../Impulse/data/messages:47
+#: ../Indicator-Generic/data/messages:53 ../MeMenu/data/messages:47
+#: ../Messaging-Menu/data/messages:61 ../Network-Monitor/data/messages:63
+#: ../RSSreader/data/messages:55 ../Recent-Events/data/messages:53
+#: ../Screenshot/data/messages:53 ../Status-Notifier/data/messages:65
+#: ../System-Monitor/data/messages:61 ../Toons/data/messages:61
+#: ../Xgamma/data/messages:55 ../alsaMixer/data/messages:61
+#: ../clock/data/messages:63 ../dnd2share/data/messages:49
+#: ../dustbin/data/messages:51 ../keyboard-indicator/data/messages:61
+#: ../logout/data/messages:53 ../mail/data/messages:61
+#: ../musicPlayer/data/messages:63 ../netspeed/data/messages:61
+#: ../powermanager/data/messages:63 ../quick-browser/data/messages:55
+#: ../shortcuts/data/messages:53 ../showDesktop/data/messages:55
+#: ../slider/data/messages:61 ../stack/data/messages:55
+#: ../switcher/data/messages:53 ../systray/data/messages:45
+#: ../template/data/messages:53 ../terminal/data/messages:53
+#: ../tomboy/data/messages:65 ../weather/data/messages:63
+#: ../weblets/data/messages:53 ../wifi/data/messages:61
+msgid "Should be visible on all desktops?"
+msgstr ""
+
+#: ../Clipper/data/messages:55 ../Composite-Manager/data/messages:53
+#: ../Disks/data/messages:53 ../Doncky/data/messages:55
+#: ../Folders/data/messages:67 ../GMenu/data/messages:55
+#: ../Global-Menu/data/messages:49 ../Impulse/data/messages:49
+#: ../Indicator-Generic/data/messages:55 ../MeMenu/data/messages:49
+#: ../Messaging-Menu/data/messages:63 ../Network-Monitor/data/messages:65
+#: ../RSSreader/data/messages:57 ../Recent-Events/data/messages:55
+#: ../Screenshot/data/messages:55 ../Status-Notifier/data/messages:67
+#: ../System-Monitor/data/messages:63 ../Toons/data/messages:63
+#: ../Xgamma/data/messages:57 ../alsaMixer/data/messages:63
+#: ../clock/data/messages:65 ../dnd2share/data/messages:51
+#: ../dustbin/data/messages:53 ../keyboard-indicator/data/messages:63
+#: ../logout/data/messages:55 ../mail/data/messages:63
+#: ../musicPlayer/data/messages:65 ../netspeed/data/messages:63
+#: ../powermanager/data/messages:65 ../quick-browser/data/messages:57
+#: ../shortcuts/data/messages:55 ../showDesktop/data/messages:57
+#: ../slider/data/messages:63 ../stack/data/messages:57
+#: ../switcher/data/messages:55 ../systray/data/messages:47
+#: ../template/data/messages:55 ../terminal/data/messages:55
+#: ../tomboy/data/messages:67 ../weather/data/messages:65
+#: ../weblets/data/messages:55 ../wifi/data/messages:63
+msgid "Decorations"
+msgstr ""
+
+#: ../Clipper/data/messages:57 ../Composite-Manager/data/messages:55
+#: ../Disks/data/messages:55 ../Doncky/data/messages:57
+#: ../Folders/data/messages:69 ../GMenu/data/messages:57
+#: ../Global-Menu/data/messages:51 ../Impulse/data/messages:51
+#: ../Indicator-Generic/data/messages:57 ../MeMenu/data/messages:51
+#: ../Messaging-Menu/data/messages:65 ../Network-Monitor/data/messages:67
+#: ../RSSreader/data/messages:59 ../Recent-Events/data/messages:57
+#: ../Screenshot/data/messages:57 ../Status-Notifier/data/messages:69
+#: ../System-Monitor/data/messages:65 ../Toons/data/messages:65
+#: ../Xgamma/data/messages:59 ../alsaMixer/data/messages:65
+#: ../clock/data/messages:67 ../dnd2share/data/messages:53
+#: ../dustbin/data/messages:55 ../keyboard-indicator/data/messages:65
+#: ../logout/data/messages:57 ../mail/data/messages:65
+#: ../musicPlayer/data/messages:67 ../netspeed/data/messages:65
+#: ../powermanager/data/messages:67 ../quick-browser/data/messages:59
+#: ../shortcuts/data/messages:57 ../showDesktop/data/messages:59
+#: ../slider/data/messages:65 ../stack/data/messages:59
+#: ../switcher/data/messages:57 ../systray/data/messages:49
+#: ../template/data/messages:57 ../terminal/data/messages:57
+#: ../tomboy/data/messages:69 ../weather/data/messages:67
+#: ../weblets/data/messages:57 ../wifi/data/messages:65
+msgid "Choose 'Custom decorations' to define your own decorations below."
+msgstr ""
+
+#: ../Clipper/data/messages:59 ../Composite-Manager/data/messages:57
+#: ../Disks/data/messages:57 ../Doncky/data/messages:59
+#: ../Folders/data/messages:71 ../GMenu/data/messages:59
+#: ../Global-Menu/data/messages:53 ../Impulse/data/messages:53
+#: ../Indicator-Generic/data/messages:59 ../MeMenu/data/messages:53
+#: ../Messaging-Menu/data/messages:67 ../Network-Monitor/data/messages:69
+#: ../RSSreader/data/messages:61 ../Recent-Events/data/messages:59
+#: ../Screenshot/data/messages:59 ../Status-Notifier/data/messages:71
+#: ../System-Monitor/data/messages:67 ../Toons/data/messages:67
+#: ../Xgamma/data/messages:61 ../alsaMixer/data/messages:67
+#: ../clock/data/messages:69 ../dnd2share/data/messages:55
+#: ../dustbin/data/messages:57 ../keyboard-indicator/data/messages:67
+#: ../logout/data/messages:59 ../mail/data/messages:67
+#: ../musicPlayer/data/messages:69 ../netspeed/data/messages:67
+#: ../powermanager/data/messages:69 ../quick-browser/data/messages:61
+#: ../shortcuts/data/messages:59 ../showDesktop/data/messages:61
+#: ../slider/data/messages:67 ../stack/data/messages:61
+#: ../switcher/data/messages:59 ../systray/data/messages:51
+#: ../template/data/messages:59 ../terminal/data/messages:59
+#: ../tomboy/data/messages:71 ../weather/data/messages:69
+#: ../weblets/data/messages:59 ../wifi/data/messages:67
+msgid "Choose a decoration theme for this desklet:"
+msgstr ""
+
+#: ../Clipper/data/messages:61 ../Composite-Manager/data/messages:59
+#: ../Disks/data/messages:59 ../Doncky/data/messages:61
+#: ../Folders/data/messages:73 ../GMenu/data/messages:61
+#: ../Global-Menu/data/messages:55 ../Impulse/data/messages:55
+#: ../Indicator-Generic/data/messages:61 ../MeMenu/data/messages:55
+#: ../Messaging-Menu/data/messages:69 ../Network-Monitor/data/messages:71
+#: ../RSSreader/data/messages:63 ../Recent-Events/data/messages:61
+#: ../Screenshot/data/messages:61 ../Status-Notifier/data/messages:73
+#: ../System-Monitor/data/messages:69 ../Toons/data/messages:69
+#: ../Xgamma/data/messages:63 ../alsaMixer/data/messages:69
+#: ../clock/data/messages:71 ../dnd2share/data/messages:57
+#: ../dustbin/data/messages:59 ../keyboard-indicator/data/messages:69
+#: ../logout/data/messages:61 ../mail/data/messages:69
+#: ../musicPlayer/data/messages:71 ../netspeed/data/messages:69
+#: ../powermanager/data/messages:71 ../quick-browser/data/messages:63
+#: ../shortcuts/data/messages:61 ../showDesktop/data/messages:63
+#: ../slider/data/messages:69 ../stack/data/messages:63
+#: ../switcher/data/messages:61 ../systray/data/messages:53
+#: ../template/data/messages:61 ../terminal/data/messages:61
+#: ../tomboy/data/messages:73 ../weather/data/messages:71
+#: ../weblets/data/messages:61 ../wifi/data/messages:69
+msgid ""
+"Image to be displayed below drawings, e.g. a frame. Leave empty for no image."
+msgstr ""
+
+#: ../Clipper/data/messages:63 ../Composite-Manager/data/messages:61
+#: ../Disks/data/messages:61 ../Doncky/data/messages:63
+#: ../Folders/data/messages:75 ../GMenu/data/messages:63
+#: ../Global-Menu/data/messages:57 ../Impulse/data/messages:57
+#: ../Indicator-Generic/data/messages:63 ../MeMenu/data/messages:57
+#: ../Messaging-Menu/data/messages:71 ../Network-Monitor/data/messages:73
+#: ../RSSreader/data/messages:65 ../Recent-Events/data/messages:63
+#: ../Screenshot/data/messages:63 ../Status-Notifier/data/messages:75
+#: ../System-Monitor/data/messages:71 ../Toons/data/messages:71
+#: ../Xgamma/data/messages:65 ../alsaMixer/data/messages:71
+#: ../clock/data/messages:73 ../clock/data/messages:179
+#: ../dnd2share/data/messages:59 ../dustbin/data/messages:61
+#: ../keyboard-indicator/data/messages:71
+#: ../keyboard-indicator/data/messages:135 ../logout/data/messages:63
+#: ../mail/data/messages:71 ../musicPlayer/data/messages:73
+#: ../netspeed/data/messages:71 ../powermanager/data/messages:73
+#: ../quick-browser/data/messages:65 ../shortcuts/data/messages:63
+#: ../showDesktop/data/messages:65 ../slider/data/messages:71
+#: ../stack/data/messages:65 ../switcher/data/messages:63
+#: ../systray/data/messages:55 ../template/data/messages:63
+#: ../terminal/data/messages:63 ../tomboy/data/messages:75
+#: ../weather/data/messages:73 ../weblets/data/messages:63
+#: ../wifi/data/messages:71
+msgid "Background image:"
+msgstr ""
+
+#: ../Clipper/data/messages:65 ../Composite-Manager/data/messages:63
+#: ../Disks/data/messages:63 ../Doncky/data/messages:65
+#: ../Folders/data/messages:77 ../GMenu/data/messages:65
+#: ../Global-Menu/data/messages:59 ../Impulse/data/messages:59
+#: ../Indicator-Generic/data/messages:65 ../MeMenu/data/messages:59
+#: ../Messaging-Menu/data/messages:73 ../Network-Monitor/data/messages:75
+#: ../RSSreader/data/messages:67 ../Recent-Events/data/messages:65
+#: ../Screenshot/data/messages:65 ../Status-Notifier/data/messages:77
+#: ../System-Monitor/data/messages:73 ../Toons/data/messages:73
+#: ../Xgamma/data/messages:67 ../alsaMixer/data/messages:73
+#: ../clock/data/messages:75 ../dnd2share/data/messages:61
+#: ../dustbin/data/messages:63 ../keyboard-indicator/data/messages:73
+#: ../logout/data/messages:65 ../mail/data/messages:73
+#: ../musicPlayer/data/messages:75 ../netspeed/data/messages:73
+#: ../powermanager/data/messages:75 ../quick-browser/data/messages:67
+#: ../shortcuts/data/messages:65 ../showDesktop/data/messages:67
+#: ../slider/data/messages:73 ../stack/data/messages:67
+#: ../switcher/data/messages:65 ../systray/data/messages:57
+#: ../template/data/messages:65 ../terminal/data/messages:65
+#: ../tomboy/data/messages:77 ../weather/data/messages:75
+#: ../weblets/data/messages:65 ../wifi/data/messages:73
+msgid "Background transparency:"
+msgstr ""
+
+#: ../Clipper/data/messages:67 ../Composite-Manager/data/messages:65
+#: ../Disks/data/messages:71 ../Doncky/data/messages:67
+#: ../Folders/data/messages:79 ../GMenu/data/messages:67
+#: ../Global-Menu/data/messages:61 ../Impulse/data/messages:61
+#: ../Indicator-Generic/data/messages:67 ../MeMenu/data/messages:61
+#: ../Messaging-Menu/data/messages:75 ../Network-Monitor/data/messages:77
+#: ../RSSreader/data/messages:69 ../Recent-Events/data/messages:67
+#: ../Screenshot/data/messages:67 ../Status-Notifier/data/messages:79
+#: ../System-Monitor/data/messages:75 ../Toons/data/messages:75
+#: ../Xgamma/data/messages:69 ../alsaMixer/data/messages:75
+#: ../clock/data/messages:77 ../dnd2share/data/messages:63
+#: ../dustbin/data/messages:65 ../keyboard-indicator/data/messages:75
+#: ../logout/data/messages:67 ../mail/data/messages:75
+#: ../musicPlayer/data/messages:77 ../netspeed/data/messages:75
+#: ../powermanager/data/messages:77 ../quick-browser/data/messages:69
+#: ../shortcuts/data/messages:67 ../showDesktop/data/messages:69
+#: ../slider/data/messages:75 ../stack/data/messages:69
+#: ../switcher/data/messages:67 ../systray/data/messages:59
+#: ../template/data/messages:67 ../terminal/data/messages:67
+#: ../tomboy/data/messages:79 ../weather/data/messages:77
+#: ../weblets/data/messages:67 ../wifi/data/messages:75
+msgid "in pixels. Use this to adjust the left position of drawings."
+msgstr ""
+
+#: ../Clipper/data/messages:69 ../Composite-Manager/data/messages:67
+#: ../Disks/data/messages:73 ../Doncky/data/messages:69
+#: ../Folders/data/messages:81 ../GMenu/data/messages:69
+#: ../Global-Menu/data/messages:63 ../Impulse/data/messages:63
+#: ../Indicator-Generic/data/messages:69 ../MeMenu/data/messages:63
+#: ../Messaging-Menu/data/messages:77 ../Network-Monitor/data/messages:79
+#: ../RSSreader/data/messages:71 ../Recent-Events/data/messages:69
+#: ../Screenshot/data/messages:69 ../Status-Notifier/data/messages:81
+#: ../System-Monitor/data/messages:77 ../Toons/data/messages:77
+#: ../Xgamma/data/messages:71 ../alsaMixer/data/messages:77
+#: ../clock/data/messages:79 ../dnd2share/data/messages:65
+#: ../dustbin/data/messages:67 ../keyboard-indicator/data/messages:77
+#: ../logout/data/messages:69 ../mail/data/messages:77
+#: ../musicPlayer/data/messages:79 ../netspeed/data/messages:77
+#: ../powermanager/data/messages:79 ../quick-browser/data/messages:71
+#: ../shortcuts/data/messages:69 ../showDesktop/data/messages:71
+#: ../slider/data/messages:77 ../stack/data/messages:71
+#: ../switcher/data/messages:69 ../systray/data/messages:61
+#: ../template/data/messages:69 ../terminal/data/messages:69
+#: ../tomboy/data/messages:81 ../weather/data/messages:79
+#: ../weblets/data/messages:69 ../wifi/data/messages:77
+msgid "Left offset:"
+msgstr ""
+
+#: ../Clipper/data/messages:71 ../Composite-Manager/data/messages:69
+#: ../Disks/data/messages:75 ../Doncky/data/messages:71
+#: ../Folders/data/messages:83 ../GMenu/data/messages:71
+#: ../Global-Menu/data/messages:65 ../Impulse/data/messages:65
+#: ../Indicator-Generic/data/messages:71 ../MeMenu/data/messages:65
+#: ../Messaging-Menu/data/messages:79 ../Network-Monitor/data/messages:81
+#: ../RSSreader/data/messages:73 ../Recent-Events/data/messages:71
+#: ../Screenshot/data/messages:71 ../Status-Notifier/data/messages:83
+#: ../System-Monitor/data/messages:79 ../Toons/data/messages:79
+#: ../Xgamma/data/messages:73 ../alsaMixer/data/messages:79
+#: ../clock/data/messages:81 ../dnd2share/data/messages:67
+#: ../dustbin/data/messages:69 ../keyboard-indicator/data/messages:79
+#: ../logout/data/messages:71 ../mail/data/messages:79
+#: ../musicPlayer/data/messages:81 ../netspeed/data/messages:79
+#: ../powermanager/data/messages:81 ../quick-browser/data/messages:73
+#: ../shortcuts/data/messages:71 ../showDesktop/data/messages:73
+#: ../slider/data/messages:79 ../stack/data/messages:73
+#: ../switcher/data/messages:71 ../systray/data/messages:63
+#: ../template/data/messages:71 ../terminal/data/messages:71
+#: ../tomboy/data/messages:83 ../weather/data/messages:81
+#: ../weblets/data/messages:71 ../wifi/data/messages:79
+msgid "in pixels. Use this to adjust the top position of drawings."
+msgstr ""
+
+#: ../Clipper/data/messages:73 ../Composite-Manager/data/messages:71
+#: ../Disks/data/messages:77 ../Doncky/data/messages:73
+#: ../Folders/data/messages:85 ../GMenu/data/messages:73
+#: ../Global-Menu/data/messages:67 ../Impulse/data/messages:67
+#: ../Indicator-Generic/data/messages:73 ../MeMenu/data/messages:67
+#: ../Messaging-Menu/data/messages:81 ../Network-Monitor/data/messages:83
+#: ../RSSreader/data/messages:75 ../Recent-Events/data/messages:73
+#: ../Screenshot/data/messages:73 ../Status-Notifier/data/messages:85
+#: ../System-Monitor/data/messages:81 ../Toons/data/messages:81
+#: ../Xgamma/data/messages:75 ../alsaMixer/data/messages:81
+#: ../clock/data/messages:83 ../dnd2share/data/messages:69
+#: ../dustbin/data/messages:71 ../keyboard-indicator/data/messages:81
+#: ../logout/data/messages:73 ../mail/data/messages:81
+#: ../musicPlayer/data/messages:83 ../netspeed/data/messages:81
+#: ../powermanager/data/messages:83 ../quick-browser/data/messages:75
+#: ../shortcuts/data/messages:73 ../showDesktop/data/messages:75
+#: ../slider/data/messages:81 ../stack/data/messages:75
+#: ../switcher/data/messages:73 ../systray/data/messages:65
+#: ../template/data/messages:73 ../terminal/data/messages:73
+#: ../tomboy/data/messages:85 ../weather/data/messages:83
+#: ../weblets/data/messages:73 ../wifi/data/messages:81
+msgid "Top offset:"
+msgstr ""
+
+#: ../Clipper/data/messages:75 ../Composite-Manager/data/messages:73
+#: ../Disks/data/messages:79 ../Doncky/data/messages:75
+#: ../Folders/data/messages:87 ../GMenu/data/messages:75
+#: ../Global-Menu/data/messages:69 ../Impulse/data/messages:69
+#: ../Indicator-Generic/data/messages:75 ../MeMenu/data/messages:69
+#: ../Messaging-Menu/data/messages:83 ../Network-Monitor/data/messages:85
+#: ../RSSreader/data/messages:77 ../Recent-Events/data/messages:75
+#: ../Screenshot/data/messages:75 ../Status-Notifier/data/messages:87
+#: ../System-Monitor/data/messages:83 ../Toons/data/messages:83
+#: ../Xgamma/data/messages:77 ../alsaMixer/data/messages:83
+#: ../clock/data/messages:85 ../dnd2share/data/messages:71
+#: ../dustbin/data/messages:73 ../keyboard-indicator/data/messages:83
+#: ../logout/data/messages:75 ../mail/data/messages:83
+#: ../musicPlayer/data/messages:85 ../netspeed/data/messages:83
+#: ../powermanager/data/messages:85 ../quick-browser/data/messages:77
+#: ../shortcuts/data/messages:75 ../showDesktop/data/messages:77
+#: ../slider/data/messages:83 ../stack/data/messages:77
+#: ../switcher/data/messages:75 ../systray/data/messages:67
+#: ../template/data/messages:75 ../terminal/data/messages:75
+#: ../tomboy/data/messages:87 ../weather/data/messages:85
+#: ../weblets/data/messages:75 ../wifi/data/messages:83
+msgid "in pixels. Use this to adjust the right position of drawings."
+msgstr ""
+
+#: ../Clipper/data/messages:77 ../Composite-Manager/data/messages:75
+#: ../Disks/data/messages:81 ../Doncky/data/messages:77
+#: ../Folders/data/messages:89 ../GMenu/data/messages:77
+#: ../Global-Menu/data/messages:71 ../Impulse/data/messages:71
+#: ../Indicator-Generic/data/messages:77 ../MeMenu/data/messages:71
+#: ../Messaging-Menu/data/messages:85 ../Network-Monitor/data/messages:87
+#: ../RSSreader/data/messages:79 ../Recent-Events/data/messages:77
+#: ../Screenshot/data/messages:77 ../Status-Notifier/data/messages:89
+#: ../System-Monitor/data/messages:85 ../Toons/data/messages:85
+#: ../Xgamma/data/messages:79 ../alsaMixer/data/messages:85
+#: ../clock/data/messages:87 ../dnd2share/data/messages:73
+#: ../dustbin/data/messages:75 ../keyboard-indicator/data/messages:85
+#: ../logout/data/messages:77 ../mail/data/messages:85
+#: ../musicPlayer/data/messages:87 ../netspeed/data/messages:85
+#: ../powermanager/data/messages:87 ../quick-browser/data/messages:79
+#: ../shortcuts/data/messages:77 ../showDesktop/data/messages:79
+#: ../slider/data/messages:85 ../stack/data/messages:79
+#: ../switcher/data/messages:77 ../systray/data/messages:69
+#: ../template/data/messages:77 ../terminal/data/messages:77
+#: ../tomboy/data/messages:89 ../weather/data/messages:87
+#: ../weblets/data/messages:77 ../wifi/data/messages:85
+msgid "Right offset:"
+msgstr ""
+
+#: ../Clipper/data/messages:79 ../Composite-Manager/data/messages:77
+#: ../Disks/data/messages:83 ../Doncky/data/messages:79
+#: ../Folders/data/messages:91 ../GMenu/data/messages:79
+#: ../Global-Menu/data/messages:73 ../Impulse/data/messages:73
+#: ../Indicator-Generic/data/messages:79 ../MeMenu/data/messages:73
+#: ../Messaging-Menu/data/messages:87 ../Network-Monitor/data/messages:89
+#: ../RSSreader/data/messages:81 ../Recent-Events/data/messages:79
+#: ../Screenshot/data/messages:79 ../Status-Notifier/data/messages:91
+#: ../System-Monitor/data/messages:87 ../Toons/data/messages:87
+#: ../Xgamma/data/messages:81 ../alsaMixer/data/messages:87
+#: ../clock/data/messages:89 ../dnd2share/data/messages:75
+#: ../dustbin/data/messages:77 ../keyboard-indicator/data/messages:87
+#: ../logout/data/messages:79 ../mail/data/messages:87
+#: ../musicPlayer/data/messages:89 ../netspeed/data/messages:87
+#: ../powermanager/data/messages:89 ../quick-browser/data/messages:81
+#: ../shortcuts/data/messages:79 ../showDesktop/data/messages:81
+#: ../slider/data/messages:87 ../stack/data/messages:81
+#: ../switcher/data/messages:79 ../systray/data/messages:71
+#: ../template/data/messages:79 ../terminal/data/messages:79
+#: ../tomboy/data/messages:91 ../weather/data/messages:89
+#: ../weblets/data/messages:79 ../wifi/data/messages:87
+msgid "in pixels. Use this to adjust the bottom position of drawings."
+msgstr ""
+
+#: ../Clipper/data/messages:81 ../Composite-Manager/data/messages:79
+#: ../Disks/data/messages:85 ../Doncky/data/messages:81
+#: ../Folders/data/messages:93 ../GMenu/data/messages:81
+#: ../Global-Menu/data/messages:75 ../Impulse/data/messages:75
+#: ../Indicator-Generic/data/messages:81 ../MeMenu/data/messages:75
+#: ../Messaging-Menu/data/messages:89 ../Network-Monitor/data/messages:91
+#: ../RSSreader/data/messages:83 ../Recent-Events/data/messages:81
+#: ../Screenshot/data/messages:81 ../Status-Notifier/data/messages:93
+#: ../System-Monitor/data/messages:89 ../Toons/data/messages:89
+#: ../Xgamma/data/messages:83 ../alsaMixer/data/messages:89
+#: ../clock/data/messages:91 ../dnd2share/data/messages:77
+#: ../dustbin/data/messages:79 ../keyboard-indicator/data/messages:89
+#: ../logout/data/messages:81 ../mail/data/messages:89
+#: ../musicPlayer/data/messages:91 ../netspeed/data/messages:89
+#: ../powermanager/data/messages:91 ../quick-browser/data/messages:83
+#: ../shortcuts/data/messages:81 ../showDesktop/data/messages:83
+#: ../slider/data/messages:89 ../stack/data/messages:83
+#: ../switcher/data/messages:81 ../systray/data/messages:73
+#: ../template/data/messages:81 ../terminal/data/messages:81
+#: ../tomboy/data/messages:93 ../weather/data/messages:91
+#: ../weblets/data/messages:81 ../wifi/data/messages:89
+msgid "Bottom offset:"
+msgstr ""
+
+#: ../Clipper/data/messages:83 ../Composite-Manager/data/messages:81
+#: ../Disks/data/messages:65 ../Doncky/data/messages:83
+#: ../Folders/data/messages:95 ../GMenu/data/messages:83
+#: ../Global-Menu/data/messages:77 ../Impulse/data/messages:77
+#: ../Indicator-Generic/data/messages:83 ../MeMenu/data/messages:77
+#: ../Messaging-Menu/data/messages:91 ../Network-Monitor/data/messages:93
+#: ../RSSreader/data/messages:85 ../Recent-Events/data/messages:83
+#: ../Screenshot/data/messages:83 ../Status-Notifier/data/messages:95
+#: ../System-Monitor/data/messages:91 ../Toons/data/messages:91
+#: ../Xgamma/data/messages:85 ../alsaMixer/data/messages:91
+#: ../clock/data/messages:93 ../dnd2share/data/messages:79
+#: ../dustbin/data/messages:81 ../keyboard-indicator/data/messages:91
+#: ../logout/data/messages:83 ../mail/data/messages:91
+#: ../musicPlayer/data/messages:93 ../netspeed/data/messages:91
+#: ../powermanager/data/messages:93 ../quick-browser/data/messages:85
+#: ../shortcuts/data/messages:83 ../showDesktop/data/messages:85
+#: ../slider/data/messages:91 ../stack/data/messages:85
+#: ../switcher/data/messages:83 ../systray/data/messages:75
+#: ../template/data/messages:83 ../terminal/data/messages:83
+#: ../tomboy/data/messages:95 ../weather/data/messages:93
+#: ../weblets/data/messages:83 ../wifi/data/messages:91
+msgid ""
+"Image to be displayed above the drawings, e.g. a reflection. Leave empty for "
+"no image."
+msgstr ""
+
+#: ../Clipper/data/messages:85 ../Composite-Manager/data/messages:83
+#: ../Disks/data/messages:67 ../Doncky/data/messages:85
+#: ../Folders/data/messages:97 ../GMenu/data/messages:85
+#: ../Global-Menu/data/messages:79 ../Impulse/data/messages:79
+#: ../Indicator-Generic/data/messages:85 ../MeMenu/data/messages:79
+#: ../Messaging-Menu/data/messages:93 ../Network-Monitor/data/messages:95
+#: ../RSSreader/data/messages:87 ../Recent-Events/data/messages:85
+#: ../Screenshot/data/messages:85 ../Status-Notifier/data/messages:97
+#: ../System-Monitor/data/messages:93 ../Toons/data/messages:93
+#: ../Xgamma/data/messages:87 ../alsaMixer/data/messages:93
+#: ../clock/data/messages:95 ../dnd2share/data/messages:81
+#: ../dustbin/data/messages:83 ../keyboard-indicator/data/messages:93
+#: ../logout/data/messages:85 ../mail/data/messages:93
+#: ../musicPlayer/data/messages:95 ../netspeed/data/messages:93
+#: ../powermanager/data/messages:95 ../quick-browser/data/messages:87
+#: ../shortcuts/data/messages:85 ../showDesktop/data/messages:87
+#: ../slider/data/messages:93 ../stack/data/messages:87
+#: ../switcher/data/messages:85 ../systray/data/messages:77
+#: ../template/data/messages:85 ../terminal/data/messages:85
+#: ../tomboy/data/messages:97 ../weather/data/messages:95
+#: ../weblets/data/messages:85 ../wifi/data/messages:93
+msgid "Foreground image:"
+msgstr ""
+
+#: ../Clipper/data/messages:87 ../Composite-Manager/data/messages:85
+#: ../Disks/data/messages:69 ../Doncky/data/messages:87
+#: ../Folders/data/messages:99 ../GMenu/data/messages:87
+#: ../Global-Menu/data/messages:81 ../Impulse/data/messages:81
+#: ../Indicator-Generic/data/messages:87 ../MeMenu/data/messages:81
+#: ../Messaging-Menu/data/messages:95 ../Network-Monitor/data/messages:97
+#: ../RSSreader/data/messages:89 ../Recent-Events/data/messages:87
+#: ../Screenshot/data/messages:87 ../Status-Notifier/data/messages:99
+#: ../System-Monitor/data/messages:95 ../Toons/data/messages:95
+#: ../Xgamma/data/messages:89 ../alsaMixer/data/messages:95
+#: ../clock/data/messages:97 ../dnd2share/data/messages:83
+#: ../dustbin/data/messages:85 ../keyboard-indicator/data/messages:95
+#: ../logout/data/messages:87 ../mail/data/messages:95
+#: ../musicPlayer/data/messages:97 ../netspeed/data/messages:95
+#: ../powermanager/data/messages:97 ../quick-browser/data/messages:89
+#: ../shortcuts/data/messages:87 ../showDesktop/data/messages:89
+#: ../slider/data/messages:95 ../stack/data/messages:89
+#: ../switcher/data/messages:87 ../systray/data/messages:79
+#: ../template/data/messages:87 ../terminal/data/messages:87
+#: ../tomboy/data/messages:99 ../weather/data/messages:97
+#: ../weblets/data/messages:87 ../wifi/data/messages:95
+msgid "Foreground tansparency:"
+msgstr ""
+
+#: ../Clipper/data/messages:91
+msgid "Items"
+msgstr ""
+
+#: ../Clipper/data/messages:93
+msgid ""
+"Clipboard items are those you get with CTRL+c. Selection items are those you "
+"get by selecting some text with the mouse."
+msgstr ""
+
+#: ../Clipper/data/messages:95
+msgid "Which items should be remembered?"
+msgstr ""
+
+#: ../Clipper/data/messages:99
+msgid "Clipboard"
+msgstr ""
+
+#: ../Clipper/data/messages:101
+msgid "Selection"
+msgstr ""
+
+#: ../Clipper/data/messages:103 ../GMenu/data/messages:119
+#: ../show-mouse/data/messages:15
+msgid "Both"
+msgstr ""
+
+#: ../Clipper/data/messages:105
+msgid "Number of items:"
+msgstr ""
+
+#: ../Clipper/data/messages:107
+msgid "Remember items between 2 sessions ?"
+msgstr ""
+
+#: ../Clipper/data/messages:109
+msgid ""
+"It is especially useful if you often select text with the mouse and don't "
+"want to loose your clipboard items due to too many items in the selection."
+msgstr ""
+
+#: ../Clipper/data/messages:111
+msgid "Separate clipboard and selection?"
+msgstr ""
+
+#: ../Clipper/data/messages:113
+msgid "If so, number of selection items:"
+msgstr ""
+
+#: ../Clipper/data/messages:115
+msgid ""
+"When you click on an item, its content will become accessible with CTRL+v"
+msgstr ""
+
+#: ../Clipper/data/messages:117
+msgid "Paste into Clipboard?"
+msgstr ""
+
+#: ../Clipper/data/messages:119
+msgid ""
+"When you click on an item, its content will become accessible with the "
+"middle-click"
+msgstr ""
+
+#: ../Clipper/data/messages:121
+msgid "Paste into Selection?"
+msgstr ""
+
+#: ../Clipper/data/messages:123
+msgid "Shortkey to pop-up the items menu:"
+msgstr ""
+
+#: ../Clipper/data/messages:125
+msgid "Pop-up menus at mouse position?"
+msgstr ""
+
+#: ../Clipper/data/messages:127
+msgid "Actions"
+msgstr ""
+
+#: ../Clipper/data/messages:129
+msgid ""
+"If some actions are associated with an item, they will be proposed when the "
+"item is created."
+msgstr ""
+
+#: ../Clipper/data/messages:131
+msgid "Enable actions?"
+msgstr ""
+
+#: ../Clipper/data/messages:133
+msgid "Display actions when selecting an item in the history."
+msgstr ""
+
+#: ../Clipper/data/messages:135
+msgid "Replay actions?"
+msgstr ""
+
+#: ../Clipper/data/messages:139
+msgid "Duration of the action menu:"
+msgstr ""
+
+#: ../Clipper/data/messages:141
+msgid "Persistent items"
+msgstr ""
+
+#: ../Clipper/data/messages:143
+msgid "A list of persistent items which can be accessed with middle-click:"
+msgstr ""
+
+#: ../Composite-Manager/data/messages:27 ../Global-Menu/data/messages:23
+#: ../Impulse/data/messages:23 ../Indicator-Generic/data/messages:29
+#: ../Recent-Events/data/messages:29 ../Screenshot/data/messages:29
+#: ../Status-Notifier/data/messages:41 ../alsaMixer/data/messages:37
+#: ../clock/data/messages:39 ../dustbin/data/messages:27
+#: ../netspeed/data/messages:37 ../systray/data/messages:25
+#: ../template/data/messages:29 ../tomboy/data/messages:41
+msgid ""
+"Depending on your WindowManager, you may be able to move this with ALT + "
+"left-click.. Negative values are counted from the right/bottom of the screen"
+msgstr ""
+
+#: ../Composite-Manager/data/messages:89 ../Impulse/data/messages:117
+#: ../clock/data/messages:133 ../clock/data/messages:151
+#: ../dock-rendering/data/messages:57 ../keyboard-indicator/data/messages:115
+#: ../switcher/data/messages:145
+msgid "Style"
+msgstr "Stil"
+
+#: ../Composite-Manager/data/messages:91
+msgid "Image when composite is active:"
+msgstr ""
+
+#: ../Composite-Manager/data/messages:93
+msgid "Image when composite is inactive:"
+msgstr ""
+
+#: ../Composite-Manager/data/messages:95 ../Global-Menu/data/messages:87
+#: ../RSSreader/data/messages:103 ../Status-Notifier/data/messages:117
+#: ../clock/data/messages:101 ../dnd2share/data/messages:95
+#: ../showDesktop/data/messages:93 ../slider/data/messages:115
+#: ../terminal/data/messages:101
+msgid "Behaviour"
+msgstr ""
+
+#: ../Composite-Manager/data/messages:97
+#: ../Composite-Manager/data/messages:109
+msgid ""
+"Let empty to use the default one. Alternatively, you can set any command you "
+"want."
+msgstr ""
+
+#: ../Composite-Manager/data/messages:99
+msgid "Composite window-manager:"
+msgstr "Komposit vindues-manager"
+
+#: ../Composite-Manager/data/messages:101
+#: ../Composite-Manager/data/messages:113
+msgid "Compiz"
+msgstr "Compiz"
+
+#: ../Composite-Manager/data/messages:103
+#: ../Composite-Manager/data/messages:115
+msgid "KWin"
+msgstr "KWin"
+
+#: ../Composite-Manager/data/messages:105
+#: ../Composite-Manager/data/messages:117
+msgid "Xfwm"
+msgstr "Xfwm"
+
+#: ../Composite-Manager/data/messages:107
+#: ../Composite-Manager/data/messages:119
+msgid "Metacity"
+msgstr "Metacity"
+
+#: ../Composite-Manager/data/messages:111
+msgid "Fallback window-manager:"
+msgstr ""
+
+#: ../Composite-Manager/data/messages:121
+msgid "Ask before switching:"
+msgstr ""
+
+#: ../Composite-Manager/data/messages:123 ../logout/data/messages:93
+#: ../showDesktop/data/messages:111 ../slider/data/messages:123
+#: ../switcher/data/messages:133
+msgid "Action on middle-click:"
+msgstr ""
+
+#: ../Composite-Manager/data/messages:137
+msgid "Shortkey to toggle the composite ON/OFF:"
+msgstr ""
+
+#: ../Dbus/data/messages:3
+msgid "Let external applications pop up dialogs in the dock?"
+msgstr ""
+
+#: ../Dbus/data/messages:5
+msgid "Let external applications reboot the dock?"
+msgstr ""
+
+#: ../Dbus/data/messages:7
+msgid "Let external applications quit the dock?"
+msgstr ""
+
+#: ../Dbus/data/messages:9
+msgid "Let external applications show/hide desklets?"
+msgstr ""
+
+#: ../Dbus/data/messages:11
+msgid "Let external applications reload applets?"
+msgstr ""
+
+#: ../Dbus/data/messages:13
+msgid "Let external applications show/hide docks?"
+msgstr ""
+
+#: ../Dbus/data/messages:15
+msgid "Let extern applications add launchers to the docks?"
+msgstr ""
+
+#: ../Dbus/data/messages:17
+msgid "Let external applications modify the labels of icons?"
+msgstr ""
+
+#: ../Dbus/data/messages:19
+msgid "Let extern applications modify the quick-infos on icons?"
+msgstr ""
+
+#: ../Dbus/data/messages:21
+msgid "Let extern applications modify the icons' image?"
+msgstr ""
+
+#: ../Dbus/data/messages:23
+msgid "Let extern applications animate icons?"
+msgstr ""
+
+#: ../Dbus/data/messages:25
+msgid "The dock will catch DBus signals to Launcher API and act as Unity"
+msgstr ""
+
+#: ../Dbus/data/messages:27
+msgid "Launch the Launcher API daemon?"
+msgstr ""
+
+#: ../Disks/data/messages:5
+msgid "Name of the container it belongs to:"
+msgstr ""
+
+#: ../Disks/data/messages:17
+msgid "Desklet mode"
+msgstr ""
+
+#: ../Disks/data/messages:89 ../Network-Monitor/data/messages:139
+#: ../netspeed/data/messages:99
+msgid "Choose the style of the display: "
+msgstr ""
+
+#: ../Disks/data/messages:91 ../Disks/data/messages:95
+#: ../Network-Monitor/data/messages:141 ../Network-Monitor/data/messages:145
+#: ../Network-Monitor/data/messages:183 ../Network-Monitor/data/messages:189
+#: ../System-Monitor/data/messages:101 ../System-Monitor/data/messages:105
+#: ../alsaMixer/data/messages:115 ../netspeed/data/messages:101
+#: ../netspeed/data/messages:105 ../powermanager/data/messages:103
+#: ../powermanager/data/messages:109 ../wifi/data/messages:101
+#: ../wifi/data/messages:107
+msgid "Gauge"
+msgstr ""
+
+#: ../Disks/data/messages:93 ../Disks/data/messages:107
+#: ../Network-Monitor/data/messages:143 ../Network-Monitor/data/messages:149
+#: ../Network-Monitor/data/messages:185 ../Network-Monitor/data/messages:193
+#: ../System-Monitor/data/messages:103 ../System-Monitor/data/messages:117
+#: ../netspeed/data/messages:103 ../netspeed/data/messages:117
+#: ../powermanager/data/messages:105 ../powermanager/data/messages:113
+#: ../wifi/data/messages:103 ../wifi/data/messages:111
+msgid "Graph"
+msgstr ""
+
+#: ../Disks/data/messages:99 ../System-Monitor/data/messages:109
+#: ../alsaMixer/data/messages:123 ../netspeed/data/messages:109
+msgid "Rotate applet theme :"
+msgstr ""
+
+#: ../Disks/data/messages:103 ../System-Monitor/data/messages:113
+#: ../alsaMixer/data/messages:127 ../netspeed/data/messages:113
+msgid "With dock orientation"
+msgstr ""
+
+#: ../Disks/data/messages:109 ../Network-Monitor/data/messages:151
+#: ../Network-Monitor/data/messages:195 ../System-Monitor/data/messages:119
+#: ../netspeed/data/messages:119 ../powermanager/data/messages:115
+#: ../wifi/data/messages:113
+msgid "Type of graphic :"
+msgstr ""
+
+#: ../Disks/data/messages:111 ../Network-Monitor/data/messages:153
+#: ../Network-Monitor/data/messages:197 ../System-Monitor/data/messages:121
+#: ../netspeed/data/messages:121 ../powermanager/data/messages:117
+#: ../wifi/data/messages:115
+msgid "Line"
+msgstr ""
+
+#: ../Disks/data/messages:113 ../Network-Monitor/data/messages:155
+#: ../Network-Monitor/data/messages:199 ../System-Monitor/data/messages:123
+#: ../netspeed/data/messages:123 ../powermanager/data/messages:119
+#: ../wifi/data/messages:117
+msgid "Plain"
+msgstr ""
+
+#: ../Disks/data/messages:115 ../Network-Monitor/data/messages:157
+#: ../Network-Monitor/data/messages:201 ../System-Monitor/data/messages:125
+#: ../netspeed/data/messages:125 ../powermanager/data/messages:121
+#: ../wifi/data/messages:119
+msgid "Bar"
+msgstr ""
+
+#: ../Disks/data/messages:117 ../Network-Monitor/data/messages:159
+#: ../Network-Monitor/data/messages:203 ../System-Monitor/data/messages:127
+#: ../netspeed/data/messages:127 ../powermanager/data/messages:123
+#: ../wifi/data/messages:121
+msgid "Circle"
+msgstr ""
+
+#: ../Disks/data/messages:119 ../Network-Monitor/data/messages:161
+#: ../Network-Monitor/data/messages:205 ../System-Monitor/data/messages:129
+#: ../netspeed/data/messages:129 ../powermanager/data/messages:125
+#: ../wifi/data/messages:123
+msgid "Plain Circle"
+msgstr ""
+
+#: ../Disks/data/messages:121 ../netspeed/data/messages:131
+msgid "It's the colour of the graphic for high rate values."
+msgstr ""
+
+#: ../Disks/data/messages:123 ../Network-Monitor/data/messages:165
+#: ../Network-Monitor/data/messages:209 ../System-Monitor/data/messages:133
+#: ../netspeed/data/messages:133 ../powermanager/data/messages:129
+#: ../wifi/data/messages:127
+msgid "High value's colour :"
+msgstr ""
+
+#: ../Disks/data/messages:125 ../netspeed/data/messages:135
+msgid "Graph colour for low rate vaues:"
+msgstr ""
+
+#: ../Disks/data/messages:127 ../Network-Monitor/data/messages:169
+#: ../Network-Monitor/data/messages:213 ../System-Monitor/data/messages:137
+#: ../netspeed/data/messages:137 ../powermanager/data/messages:133
+#: ../wifi/data/messages:131
+msgid "Low value's colour :"
+msgstr ""
+
+#: ../Disks/data/messages:129 ../Network-Monitor/data/messages:171
+#: ../Network-Monitor/data/messages:215 ../System-Monitor/data/messages:139
+#: ../netspeed/data/messages:139 ../powermanager/data/messages:135
+#: ../wifi/data/messages:133
+msgid "Background colour of the graphic :"
+msgstr ""
+
+#: ../Disks/data/messages:131 ../System-Monitor/data/messages:141
+#: ../netspeed/data/messages:141
+msgid "Show all values on same graph?"
+msgstr ""
+
+#: ../Disks/data/messages:133 ../Impulse/data/messages:85
+#: ../Status-Notifier/data/messages:103 ../alsaMixer/data/messages:99
+#: ../keyboard-indicator/data/messages:113 ../mail/data/messages:103
+#: ../musicPlayer/data/messages:159 ../shortcuts/data/messages:91
+#: ../shortcuts/data/messages:101 ../slider/data/messages:163
+#: ../stack/data/messages:93 ../tomboy/data/messages:103
+#: ../weather/data/messages:129
+msgid "Display"
+msgstr ""
+
+#: ../Disks/data/messages:135
+msgid "Display values"
+msgstr ""
+
+#: ../Disks/data/messages:139 ../Network-Monitor/data/messages:119
+#: ../System-Monitor/data/messages:165 ../alsaMixer/data/messages:107
+#: ../clock/data/messages:107 ../netspeed/data/messages:161
+msgid "On icon"
+msgstr ""
+
+#: ../Disks/data/messages:141 ../Network-Monitor/data/messages:121
+#: ../System-Monitor/data/messages:167 ../alsaMixer/data/messages:105
+#: ../clock/data/messages:109 ../netspeed/data/messages:163
+msgid "On label"
+msgstr ""
+
+#: ../Disks/data/messages:145
+msgid "Refresh time"
+msgstr ""
+
+#: ../Disks/data/messages:147 ../netspeed/data/messages:153
+msgid ""
+"You need OpenGL for this option. Set it to 0 to disable it, 1 means the "
+"transition is continue."
+msgstr ""
+
+#: ../Disks/data/messages:149
+msgid "Fluidity of the transition between 2 values"
+msgstr ""
+
+#: ../Disks/data/messages:151
+msgid "Partitions monitored : Size"
+msgstr ""
+
+#: ../Disks/data/messages:153
+msgid "E.g. sda1, sdb5..."
+msgstr ""
+
+#: ../Disks/data/messages:155
+msgid "Disks monitored : Speed"
+msgstr ""
+
+#: ../Disks/data/messages:157
+msgid "E.g. sda, sdb... Up to 5 values allowed"
+msgstr ""
+
+#: ../Disks/data/messages:159
+msgid "Preferences"
+msgstr ""
+
+#: ../Disks/data/messages:161 ../Network-Monitor/data/messages:133
+#: ../netspeed/data/messages:165
+msgid "Leave empty to use the default."
+msgstr ""
+
+#: ../Disks/data/messages:163
+msgid "System monitor command"
+msgstr ""
+
+#: ../Doncky/data/messages:91
+msgid "Specify the xml file to be used :"
+msgstr ""
+
+#: ../Doncky/data/messages:93 ../RSSreader/data/messages:131
+#: ../terminal/data/messages:91
+msgid "Appearance"
+msgstr ""
+
+#: ../Doncky/data/messages:97
+msgid "Font to be used by default if none is specify in the .xml"
+msgstr ""
+
+#: ../Doncky/data/messages:99
+msgid "Default Font:"
+msgstr ""
+
+#: ../Doncky/data/messages:101
+msgid "Color to be used by default if none is specify in the .xml"
+msgstr ""
+
+#: ../Doncky/data/messages:103 ../icon-effect/data/messages:181
+msgid "Default colour:"
+msgstr ""
+
+#: ../Doncky/data/messages:105
+msgid "Margin to be used on left, right and top of the desklet"
+msgstr ""
+
+#: ../Doncky/data/messages:107
+msgid "Margin all around the desklet:"
+msgstr ""
+
+#: ../Doncky/data/messages:109
+msgid "Use this to increase the space between the lines"
+msgstr ""
+
+#: ../Doncky/data/messages:111
+msgid "Space between lines:"
+msgstr ""
+
+#: ../Doncky/data/messages:113 ../RSSreader/data/messages:177
+msgid "Background"
+msgstr ""
+
+#: ../Doncky/data/messages:115 ../RSSreader/data/messages:179
+msgid ""
+"You can have more attractive backgrounds using the Desklet decorations"
+msgstr ""
+
+#: ../Doncky/data/messages:117 ../RSSreader/data/messages:181
+msgid "Display a simple background?"
+msgstr ""
+
+#: ../Doncky/data/messages:119 ../RSSreader/data/messages:183
+msgid "first colour of the gradation"
+msgstr ""
+
+#: ../Doncky/data/messages:121 ../RSSreader/data/messages:185
+msgid "Background first colour :"
+msgstr ""
+
+#: ../Doncky/data/messages:123 ../RSSreader/data/messages:187
+msgid "second colour of the gradation"
+msgstr ""
+
+#: ../Doncky/data/messages:125 ../RSSreader/data/messages:189
+msgid "Background second colour:"
+msgstr ""
+
+#: ../Doncky/data/messages:127 ../RSSreader/data/messages:191
+msgid "Set the radius corner to 0 for no radius"
+msgstr ""
+
+#: ../Doncky/data/messages:129 ../RSSreader/data/messages:193
+msgid "Background radius corner:"
+msgstr ""
+
+#: ../Doncky/data/messages:131 ../RSSreader/data/messages:195
+msgid "Set the thickness to 0 for no border"
+msgstr ""
+
+#: ../Doncky/data/messages:133 ../RSSreader/data/messages:197
+msgid "Border thickness:"
+msgstr ""
+
+#: ../Doncky/data/messages:135 ../RSSreader/data/messages:199
+msgid "Border colour"
+msgstr ""
+
+#: ../Doncky/data/messages:137 ../RSSreader/data/messages:201
+msgid "Border colour :"
+msgstr ""
+
+#: ../Folders/data/messages:7
+msgid "Let empty to use the name of the folder."
+msgstr ""
+
+#: ../Folders/data/messages:11 ../quick-browser/data/messages:11
+msgid "Folder name"
+msgstr ""
+
+#: ../Folders/data/messages:13
+msgid "How to render the icon :"
+msgstr ""
+
+#: ../Folders/data/messages:15
+msgid "Use an image"
+msgstr ""
+
+#: ../Folders/data/messages:17
+msgid "Draw sub-dock's content as emblems"
+msgstr ""
+
+#: ../Folders/data/messages:19
+msgid "Draw sub-dock's content as stack"
+msgstr ""
+
+#: ../Folders/data/messages:21
+msgid "Draw sub-dock's content inside a box"
+msgstr ""
+
+#: ../Folders/data/messages:103
+msgid "Folder's path:"
+msgstr ""
+
+#: ../Folders/data/messages:105
+msgid ""
+"Allow to show the files of the folder in a sub-dock. If disabled, the applet "
+"behaves as a mere launcher."
+msgstr ""
+
+#: ../Folders/data/messages:107
+msgid "Show folder's content?"
+msgstr ""
+
+#: ../Folders/data/messages:109
+msgid "Sort files by :"
+msgstr ""
+
+#: ../Folders/data/messages:111 ../stack/data/messages:127
+msgid "Name"
+msgstr "Navn"
+
+#: ../Folders/data/messages:113 ../stack/data/messages:129
+msgid "Date"
+msgstr "Dato"
+
+#: ../Folders/data/messages:117
+msgid "Sort folders before files?"
+msgstr ""
+
+#: ../Folders/data/messages:119 ../Scooby-Do/data/messages:103
+#: ../quick-browser/data/messages:101
+msgid "Show hidden files?"
+msgstr ""
+
+#: ../GMenu/data/messages:91 ../Messaging-Menu/data/messages:101
+#: ../quick-browser/data/messages:109
+msgid "Shortkey to show/hide the menu:"
+msgstr ""
+
+#: ../GMenu/data/messages:93
+msgid "Shortkey to show/hide the quick-launch dialog:"
+msgstr ""
+
+#: ../GMenu/data/messages:95
+msgid "Show recent documents?"
+msgstr ""
+
+#: ../GMenu/data/messages:97
+msgid "Number of items to display"
+msgstr ""
+
+#: ../GMenu/data/messages:99
+msgid ""
+"The settings menu file is sometimes available in a settings.menu file but "
+"its content can also be available in the main .menu file used by the dock"
+msgstr ""
+
+#: ../GMenu/data/messages:101
+msgid "Load settings' menu?"
+msgstr ""
+
+#: ../GMenu/data/messages:103
+msgid "Display the description in search's results?"
+msgstr ""
+
+#: ../GMenu/data/messages:105
+msgid "Display a notification to quickly launch new applications?"
+msgstr ""
+
+#: ../GMenu/data/messages:107
+msgid "Command to use for configuring the menu:"
+msgstr ""
+
+#: ../GMenu/data/messages:111
+msgid "Show Logout and/or Shutdown : "
+msgstr ""
+
+#: ../Global-Menu/data/messages:85
+msgid ""
+"The applet can steal the top border of maximized windows, in which case it "
+"will display the window control buttons.\n"
+" The applet can steal the menu from the windows, in which case it will "
+"display a button to pop up the menu of the current window."
+msgstr ""
+
+#: ../Global-Menu/data/messages:89
+msgid "Steal window menu"
+msgstr ""
+
+#: ../Global-Menu/data/messages:91
+msgid "Steal window decoration"
+msgstr ""
+
+#: ../Global-Menu/data/messages:93
+msgid "Steal window menu and border"
+msgstr ""
+
+#: ../Global-Menu/data/messages:95
+msgid "Shortkey to pop up the menu"
+msgstr ""
+
+#: ../Global-Menu/data/messages:97
+msgid "Pop up the menu at mouse position"
+msgstr ""
+
+#: ../Global-Menu/data/messages:99
+msgid "Compact mode"
+msgstr ""
+
+#: ../Global-Menu/data/messages:101
+msgid "Order of the buttons: "
+msgstr ""
+
+#: ../Global-Menu/data/messages:103
+msgid "Auto"
+msgstr "Auto"
+
+#: ../Global-Menu/data/messages:105
+msgid "Close button at the end"
+msgstr ""
+
+#: ../Global-Menu/data/messages:107
+msgid "Close button at first"
+msgstr ""
+
+#: ../Global-Menu/data/messages:109
+msgid "Image for the 'minimize' button"
+msgstr ""
+
+#: ../Global-Menu/data/messages:111
+msgid "Image for the 'maximize' button"
+msgstr ""
+
+#: ../Global-Menu/data/messages:113
+msgid "Image for the 'restore' button"
+msgstr ""
+
+#: ../Global-Menu/data/messages:115
+msgid "Image for the 'close' button"
+msgstr ""
+
+#: ../Impulse/data/messages:87
+msgid "Animation of the icons:"
+msgstr ""
+
+#: ../Impulse/data/messages:89
+msgid ""
+"Do we have to stop the animation on a icon which doesn't have to be animated "
+"each refresh?"
+msgstr ""
+
+#: ../Impulse/data/messages:91
+msgid "Stop animations sooner?"
+msgstr ""
+
+#: ../Impulse/data/messages:93 ../alsaMixer/data/messages:133
+msgid "Control"
+msgstr ""
+
+#: ../Impulse/data/messages:95
+msgid ""
+"It's the sensitivity in order to know if the animation is played or not."
+msgstr ""
+
+#: ../Impulse/data/messages:97
+msgid "Sensitivity of the animation:"
+msgstr ""
+
+#: ../Impulse/data/messages:99 ../Impulse/data/messages:109
+msgid "More"
+msgstr "Mere"
+
+#: ../Impulse/data/messages:101 ../Impulse/data/messages:107
+msgid "Less"
+msgstr "Mindre"
+
+#: ../Impulse/data/messages:103
+msgid "in ms."
+msgstr ""
+
+#: ../Impulse/data/messages:105
+msgid "Time between two animations:"
+msgstr ""
+
+#: ../Impulse/data/messages:111
+msgid "Action at Startup"
+msgstr ""
+
+#: ../Impulse/data/messages:113
+msgid "Launch automatically at startup?"
+msgstr ""
+
+#: ../Impulse/data/messages:115
+msgid "Hide the icon?"
+msgstr ""
+
+#: ../Impulse/data/messages:119
+msgid "Image when the applet is active:"
+msgstr ""
+
+#: ../Impulse/data/messages:121
+msgid "Image when the applet is inactive:"
+msgstr ""
+
+#: ../Impulse/data/messages:123 ../musicPlayer/data/messages:205
+#: ../tomboy/data/messages:23
+msgid "'Broken' icon image name:"
+msgstr ""
+
+#: ../Impulse/data/messages:125
+msgid "PulseAudio"
+msgstr ""
+
+#: ../Impulse/data/messages:127
+msgid "0 in most cases"
+msgstr ""
+
+#: ../Impulse/data/messages:129
+msgid "Index of the source:"
+msgstr ""
+
+#: ../Indicator-Generic/data/messages:91
+msgid "Separated by a semi-colon ';'"
+msgstr ""
+
+#: ../Indicator-Generic/data/messages:93
+msgid "Blacklist these indicators:"
+msgstr ""
+
+#: ../Messaging-Menu/data/messages:15 ../Network-Monitor/data/messages:17
+#: ../Status-Notifier/data/messages:19 ../System-Monitor/data/messages:15
+#: ../Toons/data/messages:15 ../alsaMixer/data/messages:15
+#: ../clock/data/messages:17 ../keyboard-indicator/data/messages:15
+#: ../mail/data/messages:15 ../musicPlayer/data/messages:17
+#: ../netspeed/data/messages:15 ../powermanager/data/messages:17
+#: ../slider/data/messages:15 ../weather/data/messages:17
+#: ../wifi/data/messages:15
+msgid "Always display the icon, even when the dock is hidden?"
+msgstr ""
+
+#: ../Messaging-Menu/data/messages:19 ../Network-Monitor/data/messages:21
+#: ../Status-Notifier/data/messages:23 ../System-Monitor/data/messages:19
+#: ../Toons/data/messages:19 ../alsaMixer/data/messages:19
+#: ../clock/data/messages:21 ../keyboard-indicator/data/messages:19
+#: ../mail/data/messages:19 ../musicPlayer/data/messages:21
+#: ../netspeed/data/messages:19 ../powermanager/data/messages:21
+#: ../slider/data/messages:19 ../weather/data/messages:21
+#: ../wifi/data/messages:19
+msgid "With default background"
+msgstr ""
+
+#: ../Messaging-Menu/data/messages:21 ../Network-Monitor/data/messages:23
+#: ../Status-Notifier/data/messages:25 ../System-Monitor/data/messages:21
+#: ../Toons/data/messages:21 ../alsaMixer/data/messages:21
+#: ../clock/data/messages:23 ../keyboard-indicator/data/messages:21
+#: ../mail/data/messages:21 ../musicPlayer/data/messages:23
+#: ../netspeed/data/messages:21 ../powermanager/data/messages:23
+#: ../slider/data/messages:21 ../weather/data/messages:23
+#: ../wifi/data/messages:21
+msgid "With custom background"
+msgstr ""
+
+#: ../Messaging-Menu/data/messages:23 ../Network-Monitor/data/messages:25
+#: ../Status-Notifier/data/messages:27 ../System-Monitor/data/messages:23
+#: ../Toons/data/messages:23 ../alsaMixer/data/messages:23
+#: ../clock/data/messages:25 ../keyboard-indicator/data/messages:23
+#: ../mail/data/messages:23 ../musicPlayer/data/messages:25
+#: ../netspeed/data/messages:23 ../powermanager/data/messages:25
+#: ../slider/data/messages:23 ../weather/data/messages:25
+#: ../wifi/data/messages:23
+msgid "Background color to add in this case"
+msgstr ""
+
+#: ../Messaging-Menu/data/messages:99
+msgid ""
+"Animation of the icon when one of the application demands your attention :"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:7
+msgid "Leave empty to use the connection name."
+msgstr ""
+
+#: ../Network-Monitor/data/messages:11 ../wifi/data/messages:9
+msgid "Connection name"
+msgstr "Forbindelsens navn"
+
+#: ../Network-Monitor/data/messages:101 ../Network-Monitor/data/messages:173
+#: ../Network-Monitor/data/messages:261 ../System-Monitor/data/messages:143
+#: ../netspeed/data/messages:143 ../powermanager/data/messages:143
+#: ../tomboy/data/messages:123 ../wifi/data/messages:153
+msgid "Parameters"
+msgstr "Parametre"
+
+#: ../Network-Monitor/data/messages:103
+msgid "You can quickly switch to the other mode by scrolling on the icon."
+msgstr ""
+
+#: ../Network-Monitor/data/messages:105
+msgid "Info displayed by the icon:"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:107
+msgid "Wifi signal"
+msgstr "Wifi signal"
+
+#: ../Network-Monitor/data/messages:109
+msgid "Connexion speed"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:111
+msgid "By default the first active interface is used."
+msgstr ""
+
+#: ../Network-Monitor/data/messages:113
+msgid "Connection interface to monitor:"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:115
+msgid "Display numeric values:"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:123 ../System-Monitor/data/messages:173
+#: ../wifi/data/messages:159
+msgid ""
+"You need OpenGL for this option. Set it to 0 means not used, 1 means the "
+"movement is continue."
+msgstr ""
+
+#: ../Network-Monitor/data/messages:125
+msgid "Fluidity of the transition animation between 2 values:"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:127
+msgid "Animation of the icon when connecting:"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:129
+msgid ""
+"Allow you to overwrite applet's default command line and launch your "
+"preferred wireless configuration interface."
+msgstr ""
+
+#: ../Network-Monitor/data/messages:131
+msgid "User command to show Wireless Configuration:"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:135 ../System-Monitor/data/messages:187
+#: ../netspeed/data/messages:167
+msgid "User command to display a system monitor:"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:137
+msgid "Net Speed"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:163 ../Network-Monitor/data/messages:207
+#: ../wifi/data/messages:125
+msgid "It's the colour of the graphic for high quality signal."
+msgstr ""
+
+#: ../Network-Monitor/data/messages:167 ../Network-Monitor/data/messages:211
+#: ../wifi/data/messages:129
+msgid "It's the colour of the graphic for low quality signal."
+msgstr ""
+
+#: ../Network-Monitor/data/messages:177
+msgid "Delays between net speed checks:"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:181
+msgid "Choose the style of the display:"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:187 ../Network-Monitor/data/messages:217
+#: ../powermanager/data/messages:137
+msgid "Icons"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:219
+msgid "Effect to apply on the icon according to strength :"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:223
+msgid "Zoom"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:225
+msgid "Transparency"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:227
+msgid "Draw Bar"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:229 ../Network-Monitor/data/messages:233
+#: ../Network-Monitor/data/messages:237 ../Network-Monitor/data/messages:241
+#: ../Network-Monitor/data/messages:245 ../Network-Monitor/data/messages:249
+#: ../Network-Monitor/data/messages:253 ../Network-Monitor/data/messages:257
+#: ../logout/data/messages:109 ../musicPlayer/data/messages:187
+#: ../musicPlayer/data/messages:191 ../musicPlayer/data/messages:195
+#: ../musicPlayer/data/messages:199 ../musicPlayer/data/messages:203
+#: ../tomboy/data/messages:13 ../tomboy/data/messages:17
+#: ../tomboy/data/messages:21 ../tomboy/data/messages:105
+msgid "Leave empty to use the default icon."
+msgstr ""
+
+#: ../Network-Monitor/data/messages:231
+msgid "Name of the image for the 'No signal' icon :"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:235
+msgid "Name of the image for the 'Very low' icon :"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:239
+msgid "Name of the image for the 'Low' icon :"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:243
+msgid "Name of the image for the 'Middle' icon :"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:247
+msgid "Name of an image for the 'Good' icon :"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:251
+msgid "Name of the image for the 'Excellent' icon :"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:255
+msgid "Name of the image for the 'Not connected' icon :"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:259
+msgid "Name of the image for the 'Wired connection' icon :"
+msgstr ""
+
+#: ../Network-Monitor/data/messages:263
+msgid "in seconds. if you don't have Network-Manager."
+msgstr ""
+
+#: ../Network-Monitor/data/messages:265
+msgid "Delays between wifi signal checks:"
+msgstr ""
+
+#: ../RSSreader/data/messages:7
+msgid "Leave empty to use the title of the RSS feed."
+msgstr ""
+
+#: ../RSSreader/data/messages:93
+msgid "RSS Feed"
+msgstr ""
+
+#: ../RSSreader/data/messages:95
+msgid "Enter a valid atom/rss feed"
+msgstr ""
+
+#: ../RSSreader/data/messages:99
+msgid "RSS login (optional):"
+msgstr ""
+
+#: ../RSSreader/data/messages:101
+msgid "RSS password (optional):"
+msgstr ""
+
+#: ../RSSreader/data/messages:109
+msgid "Notify about feed updates:"
+msgstr ""
+
+#: ../RSSreader/data/messages:113 ../powermanager/data/messages:189
+msgid "Icon animation"
+msgstr ""
+
+#: ../RSSreader/data/messages:115 ../powermanager/data/messages:191
+msgid "Dialog bubble"
+msgstr ""
+
+#: ../RSSreader/data/messages:117 ../powermanager/data/messages:193
+msgid "Icon animation + Dialog bubble"
+msgstr ""
+
+#: ../RSSreader/data/messages:119 ../powermanager/data/messages:195
+msgid "Let empty to use the default notification animation."
+msgstr ""
+
+#: ../RSSreader/data/messages:121 ../powermanager/data/messages:197
+msgid "Animation of the icon:"
+msgstr ""
+
+#: ../RSSreader/data/messages:123 ../powermanager/data/messages:199
+msgid ""
+"In seconds. Set to 0 for infinite time (need to click on dialog to close it)."
+msgstr ""
+
+#: ../RSSreader/data/messages:125 ../powermanager/data/messages:201
+msgid "Duration of the notification:"
+msgstr ""
+
+#: ../RSSreader/data/messages:127
+msgid "Open the feed with the following program:"
+msgstr ""
+
+#: ../RSSreader/data/messages:135
+msgid "Font to be used for the title"
+msgstr ""
+
+#: ../RSSreader/data/messages:137
+msgid "Title font:"
+msgstr "Titel skrifttype:"
+
+#: ../RSSreader/data/messages:139
+msgid "Colour to be used for the title"
+msgstr ""
+
+#: ../RSSreader/data/messages:141
+msgid "Title colour:"
+msgstr ""
+
+#: ../RSSreader/data/messages:143
+msgid "Alignment of the title:"
+msgstr ""
+
+#: ../RSSreader/data/messages:145
+msgid "left"
+msgstr "venstre"
+
+#: ../RSSreader/data/messages:147
+msgid "right"
+msgstr "højre"
+
+#: ../RSSreader/data/messages:151
+msgid "Font to be used for the feed lines"
+msgstr ""
+
+#: ../RSSreader/data/messages:153
+msgid "Feed lines font:"
+msgstr ""
+
+#: ../RSSreader/data/messages:155
+msgid "Colour to be used for the feed lines"
+msgstr ""
+
+#: ../RSSreader/data/messages:157
+msgid "Feed lines colour:"
+msgstr ""
+
+#: ../RSSreader/data/messages:159
+msgid "Left margin for the feed lines:"
+msgstr ""
+
+#: ../RSSreader/data/messages:161
+msgid "Space between 2 feed lines:"
+msgstr ""
+
+#: ../RSSreader/data/messages:163
+msgid "Logo"
+msgstr "Logo"
+
+#: ../RSSreader/data/messages:165
+msgid "The default logo is the applet's icon"
+msgstr ""
+
+#: ../RSSreader/data/messages:167
+msgid "Display the logo?"
+msgstr ""
+
+#: ../RSSreader/data/messages:169
+msgid "Adjust to increase/decrease the logo's size"
+msgstr ""
+
+#: ../RSSreader/data/messages:171
+msgid "Logo size:"
+msgstr "Logo størrelse:"
+
+#: ../RSSreader/data/messages:173 ../dock-rendering/data/messages:47
+#: ../keyboard-indicator/data/messages:133
+msgid "normal"
+msgstr "normal"
+
+#: ../RSSreader/data/messages:175 ../dock-rendering/data/messages:49
+msgid "big"
+msgstr "stor"
+
+#: ../Recent-Events/data/messages:91
+msgid "Shortkey to show/hide the search dialog"
+msgstr ""
+
+#: ../Recent-Events/data/messages:93
+msgid "Max number of results to show"
+msgstr ""
+
+#: ../Remote-Control/data/messages:1 ../Scooby-Do/data/messages:1
+msgid "Help"
+msgstr "Hjælp"
+
+#: ../Remote-Control/data/messages:5
+msgid "Shortkey to trigger the applet:"
+msgstr ""
+
+#: ../Remote-Control/data/messages:7
+msgid "Dock to control initially"
+msgstr ""
+
+#: ../Remote-Control/data/messages:9 ../Scooby-Do/data/messages:25
+msgid "Animation of the current icon :"
+msgstr ""
+
+#: ../Remote-Control/data/messages:13 ../Scooby-Do/data/messages:23
+msgid "Duration of the stop animation :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:5
+msgid "Shortkey to enable/disable the finder mode:"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:7
+msgid ""
+"Maximum number of mails that will be previewed. Put -1 to show the maximum "
+"possible."
+msgstr ""
+
+#: ../Scooby-Do/data/messages:9
+msgid "Maximum number of results :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:11
+msgid ""
+"Number of lines of the listing. If there are more results, the listing will "
+"scroll when you go up or down with the arrows."
+msgstr ""
+
+#: ../Scooby-Do/data/messages:13
+msgid "Number of lines to display :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:15
+msgid "Animations"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:19
+msgid "Duration of the appearance animation :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:29
+msgid "Font used to display what you type:"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:31
+msgid "Color of the text's frame  :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:33
+msgid "Font size, relative to the dock size:"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:35
+msgid "between 1 and 9, the higher, the bigger."
+msgstr ""
+
+#: ../Scooby-Do/data/messages:37
+msgid "Text size:"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:39 ../keyboard-indicator/data/messages:123
+msgid "Outline text?"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:41 ../clock/data/messages:157
+#: ../keyboard-indicator/data/messages:121
+msgid "Text colour"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:43
+msgid "Character background colour:"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:45
+msgid "Write text on the top of the dock?"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:47
+msgid "Favorite applications"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:49
+msgid "FAvorite applications starting with 'a' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:51
+msgid "Favorite application starting with 'b' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:53
+msgid "Favorite application(s) starting with 'c' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:55
+msgid "Favorite application(s starting with 'd' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:57
+msgid "Favorite application(s) starting with 'e' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:59
+msgid "Favorite application(s) starting with 'f' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:61
+msgid "Favorite application(s) starting with 'g' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:63
+msgid "Favorite application(s) starting with 'h' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:65
+msgid "Favorite application(s) starting with 'i' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:67
+msgid "Favorite application(s) starting with 'j' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:69
+msgid "Favorite application(s) starting with 'k' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:71
+msgid "Favorite application(s) starting with 'l' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:73
+msgid "Favorite application(s) starting with 'm' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:75
+msgid "Favorite application(s) starting with 'n' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:77
+msgid "Favorite application(s) starting with 'o' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:79
+msgid "Favorite application(s) starting with 'p' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:81
+msgid "Favorite application(s) starting with 'q' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:83
+msgid "Favorite application(s) starting with 'r' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:85
+msgid "Favorite application(s) starting with 's' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:87
+msgid "Favorite application(s) starting with 't' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:89
+msgid "Favorite application(s) starting with 'u' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:91
+msgid "Favorite application(s) starting with 'v' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:93
+msgid "Favorite application(s) starting with 'w' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:95
+msgid "Favorite application(s) starting with 'x' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:97
+msgid "Favorite application(s) starting with 'y' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:99
+msgid "Favorite application(s) starting with 'z' :"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:109
+msgid "Propose some web search engines ?"
+msgstr ""
+
+#: ../Scooby-Do/data/messages:111
+msgid "It can launch commands and even do some calculations."
+msgstr ""
+
+#: ../Screenshot/data/messages:91
+msgid "Shortkey to take a screenshot"
+msgstr ""
+
+#: ../Screenshot/data/messages:93
+msgid "Save image in"
+msgstr ""
+
+#: ../Sound-Effects/data/messages:3
+msgid "Play a sound on click ?"
+msgstr ""
+
+#: ../Sound-Effects/data/messages:5 ../Sound-Effects/data/messages:11
+#: ../Sound-Effects/data/messages:17
+msgid "A .wav file encoded in PCM."
+msgstr ""
+
+#: ../Sound-Effects/data/messages:7 ../Sound-Effects/data/messages:13
+#: ../Sound-Effects/data/messages:19
+msgid "Sound file"
+msgstr ""
+
+#: ../Sound-Effects/data/messages:9
+msgid "Play a sound on middle click ?"
+msgstr ""
+
+#: ../Sound-Effects/data/messages:15
+msgid "Play a sound on mouse hover ?"
+msgstr ""
+
+#: ../Sound-Effects/data/messages:21
+msgid "Volume:"
+msgstr "Lydstyrke:"
+
+#: ../Sound-Effects/data/messages:25
+msgid "High"
+msgstr "Høj"
+
+#: ../Status-Notifier/data/messages:13
+msgid "Image's filename :"
+msgstr ""
+
+#: ../Status-Notifier/data/messages:105
+msgid "Hide inactive items"
+msgstr ""
+
+#: ../Status-Notifier/data/messages:107
+msgid "How to display items:"
+msgstr ""
+
+#: ../Status-Notifier/data/messages:109
+msgid "Compact"
+msgstr "Kompakt"
+
+#: ../Status-Notifier/data/messages:111
+msgid "Sub-dock"
+msgstr "Underliggende-dock"
+
+#: ../Status-Notifier/data/messages:113
+msgid "Allow the icon to automatically resize itself?"
+msgstr ""
+
+#: ../Status-Notifier/data/messages:115
+msgid "Number of lines to pack items in:"
+msgstr ""
+
+#: ../Status-Notifier/data/messages:119
+msgid "Left click pops up the items' menu"
+msgstr ""
+
+#: ../System-Monitor/data/messages:99 ../alsaMixer/data/messages:109
+#: ../powermanager/data/messages:101 ../wifi/data/messages:99
+msgid "Display style"
+msgstr ""
+
+#: ../System-Monitor/data/messages:107 ../alsaMixer/data/messages:121
+#: ../powermanager/data/messages:111 ../wifi/data/messages:109
+msgid "Gauge theme"
+msgstr ""
+
+#: ../System-Monitor/data/messages:131 ../powermanager/data/messages:127
+msgid "It's the colour of the graphic for high values."
+msgstr ""
+
+#: ../System-Monitor/data/messages:135 ../powermanager/data/messages:131
+msgid "It's the colour of the graphic for low values."
+msgstr ""
+
+#: ../System-Monitor/data/messages:145
+msgid "Show CPU usage?"
+msgstr ""
+
+#: ../System-Monitor/data/messages:147
+msgid "Show RAM usage ?"
+msgstr ""
+
+#: ../System-Monitor/data/messages:149
+msgid "Show SWAP too?"
+msgstr ""
+
+#: ../System-Monitor/data/messages:151
+msgid "You need an nVidia card and the 'nvidia-settings' tool."
+msgstr ""
+
+#: ../System-Monitor/data/messages:153
+msgid "Show graphic card's temperature?"
+msgstr ""
+
+#: ../System-Monitor/data/messages:155
+msgid "Show CPU temperature?"
+msgstr ""
+
+#: ../System-Monitor/data/messages:157
+msgid "Show fan speed?"
+msgstr ""
+
+#: ../System-Monitor/data/messages:159
+msgid "Show free memory instead of used memory?"
+msgstr ""
+
+#: ../System-Monitor/data/messages:161
+msgid "Display values :"
+msgstr ""
+
+#: ../System-Monitor/data/messages:171
+msgid "Delay between refreshes:"
+msgstr ""
+
+#: ../System-Monitor/data/messages:175 ../wifi/data/messages:161
+msgid "How smooth is the movement?"
+msgstr ""
+
+#: ../System-Monitor/data/messages:177
+msgid "Alerts"
+msgstr ""
+
+#: ../System-Monitor/data/messages:179
+msgid "Show alerts?"
+msgstr ""
+
+#: ../System-Monitor/data/messages:181
+msgid "Play a sound when displaying warning?"
+msgstr ""
+
+#: ../System-Monitor/data/messages:183
+msgid "Path to sound file:"
+msgstr ""
+
+#: ../System-Monitor/data/messages:185
+msgid "System-Monitor"
+msgstr ""
+
+#: ../System-Monitor/data/messages:191
+msgid ""
+"It will prevent the system monitor's icon to show in the taskbar. The "
+"applet's icon will then behave as a launcher, an application, and an applet."
+msgstr ""
+
+#: ../System-Monitor/data/messages:193
+msgid "Steal the system monitor's icon from the taskbar?"
+msgstr ""
+
+#: ../System-Monitor/data/messages:195
+msgid "Class of the system monitor program:"
+msgstr ""
+
+#: ../System-Monitor/data/messages:199
+msgid "Top List"
+msgstr ""
+
+#: ../System-Monitor/data/messages:201
+msgid ""
+"When you left-click on the icon, you will get the list of the N most CPU/RAM-"
+"intensive programs."
+msgstr ""
+
+#: ../System-Monitor/data/messages:203
+msgid "Number of programs to display in the top list:"
+msgstr ""
+
+#: ../System-Monitor/data/messages:205
+msgid "The first colour of the gradient used to display the top list."
+msgstr ""
+
+#: ../System-Monitor/data/messages:207
+msgid "Top list start colour:"
+msgstr ""
+
+#: ../System-Monitor/data/messages:209
+msgid "The second colour of the gradient used to display the top list."
+msgstr ""
+
+#: ../System-Monitor/data/messages:211
+msgid "Top list stop colour:"
+msgstr ""
+
+#: ../System-Monitor/data/messages:213
+msgid "Show top memory usage in %?"
+msgstr ""
+
+#: ../System-Monitor/data/messages:217
+msgid "Delay between top list refreshes:"
+msgstr ""
+
+#: ../System-Monitor/data/messages:219
+msgid "Graphic Card temperature"
+msgstr ""
+
+#: ../System-Monitor/data/messages:221 ../System-Monitor/data/messages:225
+msgid ""
+"in Celsius. The temperature will be displayed between this value and the "
+"upper limit."
+msgstr ""
+
+#: ../System-Monitor/data/messages:223
+msgid "Lower limit of graphic card temperature:"
+msgstr ""
+
+#: ../System-Monitor/data/messages:227
+msgid "Upper limit of graphic card temperature:"
+msgstr ""
+
+#: ../System-Monitor/data/messages:229
+msgid "in celcius."
+msgstr ""
+
+#: ../System-Monitor/data/messages:231
+msgid "Notification limit of graphic card temperature:"
+msgstr ""
+
+#: ../Toons/data/messages:103
+msgid "Mean delay between winks:"
+msgstr ""
+
+#: ../Toons/data/messages:107
+msgid "Wink duration:"
+msgstr ""
+
+#: ../Toons/data/messages:109
+msgid "Keep ratio?"
+msgstr ""
+
+#: ../Toons/data/messages:111
+msgid "A high refresh frequency will use more CPU."
+msgstr ""
+
+#: ../Toons/data/messages:113
+msgid "High refresh frequency?"
+msgstr ""
+
+#: ../Xgamma/data/messages:7
+msgid "Leave empty to display the current luminosity."
+msgstr ""
+
+#: ../Xgamma/data/messages:11
+msgid "Current luminosity"
+msgstr ""
+
+#: ../Xgamma/data/messages:93 ../alsaMixer/data/messages:137
+msgid "Variation for 1 mouse scroll, in %:"
+msgstr ""
+
+#: ../Xgamma/data/messages:95
+msgid "Use 0 for none."
+msgstr ""
+
+#: ../Xgamma/data/messages:97
+msgid "Brightness to apply automatically on startup:"
+msgstr ""
+
+#: ../Xgamma/data/messages:99
+msgid "Shortkey to increase the brightness:"
+msgstr ""
+
+#: ../Xgamma/data/messages:101
+msgid "Shortkey to decrease the brightness:"
+msgstr ""
+
+#: ../alsaMixer/data/messages:9
+msgid "Sound card name"
+msgstr ""
+
+#: ../alsaMixer/data/messages:101
+msgid "Display volume :"
+msgstr ""
+
+#: ../alsaMixer/data/messages:113 ../powermanager/data/messages:107
+#: ../wifi/data/messages:105
+msgid "Icon with progress bar"
+msgstr ""
+
+#: ../alsaMixer/data/messages:117 ../wifi/data/messages:137
+msgid "Default icon:"
+msgstr ""
+
+#: ../alsaMixer/data/messages:119
+msgid "Mute icon:"
+msgstr ""
+
+#: ../alsaMixer/data/messages:131
+msgid "Broken icon:"
+msgstr ""
+
+#: ../alsaMixer/data/messages:135
+msgid "Shortkey to show/hide the sound control dialog:"
+msgstr ""
+
+#: ../alsaMixer/data/messages:139
+msgid "Hide the scale when mouse leaves the desklet?"
+msgstr ""
+
+#: ../alsaMixer/data/messages:141
+msgid "Alsa"
+msgstr ""
+
+#: ../alsaMixer/data/messages:143
+msgid "Sound card:"
+msgstr ""
+
+#: ../alsaMixer/data/messages:145
+msgid "Select channel:"
+msgstr ""
+
+#: ../alsaMixer/data/messages:147
+msgid ""
+"On some cards, a channel only controls 1 side (right or left). You will then "
+"need to specify a second channel here, to control both sides. Most of the "
+"time, you should just leave this empty."
+msgstr ""
+
+#: ../alsaMixer/data/messages:149
+msgid "Choose a second channel to control (optional):"
+msgstr ""
+
+#: ../alsaMixer/data/messages:151
+msgid "Specific command to run to show an advanced sound mixer:"
+msgstr ""
+
+#: ../clock/data/messages:7
+msgid "Leave empty to use the location name if available."
+msgstr ""
+
+#: ../clock/data/messages:103
+msgid "Show the date:"
+msgstr ""
+
+#: ../clock/data/messages:111
+msgid "for digital format only."
+msgstr ""
+
+#: ../clock/data/messages:113
+msgid "Display the time in a 24h format?"
+msgstr "Vis tiden i 24-timers format?"
+
+#: ../clock/data/messages:115
+msgid ""
+"if not, then the applet will update the time once a minute, saving CPU power."
+msgstr ""
+
+#: ../clock/data/messages:117
+msgid "Show seconds?"
+msgstr "Vis sekunder"
+
+#: ../clock/data/messages:119
+msgid ""
+"In ms. Set 0 for non-smooth animation, set 1000 to have a continuous "
+"animation. Requires OpenGL."
+msgstr ""
+
+#: ../clock/data/messages:121
+msgid "Display seconds with smooth animation for a duration of:"
+msgstr ""
+
+#: ../clock/data/messages:123
+msgid "E.g. :Europe/Paris, :Japan, etc. Leave empty for local time."
+msgstr "Eks: Europe / Paris, :Japan o.s.v. Efterlad tomt for lokal tid."
+
+#: ../clock/data/messages:125
+msgid "Timezone:"
+msgstr "Tidszone:"
+
+#: ../clock/data/messages:127
+msgid "Use the tasks from the following task-manager:"
+msgstr ""
+
+#: ../clock/data/messages:131
+msgid "iCal"
+msgstr "iCal"
+
+#: ../clock/data/messages:135
+msgid ""
+"The analogue view is based on CairoClock; otherwise it will be displayed in "
+"digital format."
+msgstr ""
+
+#: ../clock/data/messages:137
+msgid "Select the view :"
+msgstr ""
+
+#: ../clock/data/messages:139
+msgid "Analogue"
+msgstr "Analog"
+
+#: ../clock/data/messages:141
+msgid "Digital"
+msgstr "Digital"
+
+#: ../clock/data/messages:143
+msgid "Analogue View"
+msgstr "Analog visning"
+
+#: ../clock/data/messages:145
+msgid "List of available themes for analogue display:"
+msgstr "Liste over tilgængelige temaer for analog visning:"
+
+#: ../clock/data/messages:147
+msgid "Date text colour:"
+msgstr "Tekstfarve for Dato:"
+
+#: ../clock/data/messages:149
+msgid "Digital View"
+msgstr "Digital visning"
+
+#: ../clock/data/messages:153 ../clock/data/messages:171
+#: ../dock-rendering/data/messages:59 ../keyboard-indicator/data/messages:117
+#: ../switcher/data/messages:101 ../switcher/data/messages:115
+#: ../switcher/data/messages:147
+msgid "Automatic"
+msgstr "Automatisk"
+
+#: ../clock/data/messages:155 ../dnd2share/data/messages:127
+#: ../dnd2share/data/messages:139 ../dnd2share/data/messages:149
+#: ../dnd2share/data/messages:155 ../dock-rendering/data/messages:61
+#: ../keyboard-indicator/data/messages:119 ../switcher/data/messages:149
+msgid "Custom"
+msgstr "Brugerdefineret"
+
+#: ../clock/data/messages:159 ../keyboard-indicator/data/messages:125
+msgid "Use a custom font"
+msgstr "Brug, brugerdefineret font"
+
+#: ../clock/data/messages:161 ../keyboard-indicator/data/messages:127
+msgid "Font:"
+msgstr "Skrifttype:"
+
+#: ../clock/data/messages:163
+msgid "Set to 0 to not have it"
+msgstr ""
+
+#: ../clock/data/messages:165
+msgid "Outline thickness:"
+msgstr ""
+
+#: ../clock/data/messages:167
+msgid "Outline colour:"
+msgstr ""
+
+#: ../clock/data/messages:169
+msgid "Layout of the text:"
+msgstr ""
+
+#: ../clock/data/messages:173
+msgid "On 1 line"
+msgstr ""
+
+#: ../clock/data/messages:175
+msgid "On 2 lines"
+msgstr ""
+
+#: ../clock/data/messages:177
+msgid "Ratio to apply on text :"
+msgstr ""
+
+#: ../clock/data/messages:181
+msgid "Configure time and date"
+msgstr ""
+
+#: ../clock/data/messages:183 ../logout/data/messages:121
+msgid "Leave empty to execute the default command."
+msgstr ""
+
+#: ../clock/data/messages:185
+msgid "Specific command to run:"
+msgstr ""
+
+#: ../clock/data/messages:189
+msgid ""
+"The new alarm will be added to the end / the last alarm will be removed."
+msgstr ""
+
+#: ../clock/data/messages:191
+msgid "Add or remove an alarm:"
+msgstr ""
+
+#: ../dnd2share/data/messages:87
+msgid "Info-bubbles"
+msgstr ""
+
+#: ../dnd2share/data/messages:89
+msgid "Enable info-bubbles?"
+msgstr ""
+
+#: ../dnd2share/data/messages:93
+msgid "Duration of the info-bubbles :"
+msgstr ""
+
+#: ../dnd2share/data/messages:97
+msgid "Number of items to keep in the history :"
+msgstr ""
+
+#: ../dnd2share/data/messages:99
+msgid "Keep a copy of each uploaded image?"
+msgstr ""
+
+#: ../dnd2share/data/messages:101
+msgid "This will override the image setting."
+msgstr ""
+
+#: ../dnd2share/data/messages:103
+msgid "If so, display the last image on the icon?"
+msgstr ""
+
+#: ../dnd2share/data/messages:105
+msgid "Animation of the icon during upload :"
+msgstr ""
+
+#: ../dnd2share/data/messages:107
+msgid "Use the following service to make the URL smaller:"
+msgstr ""
+
+#: ../dnd2share/data/messages:111
+msgid "Tiny-URL"
+msgstr ""
+
+#: ../dnd2share/data/messages:113
+msgid "Shorter-Link"
+msgstr ""
+
+#: ../dnd2share/data/messages:115
+msgid "Use the tiny URL by default?"
+msgstr ""
+
+#: ../dnd2share/data/messages:117
+msgid "in KB/s - 0 means unlimited"
+msgstr ""
+
+#: ../dnd2share/data/messages:119
+msgid "Maximum upload rate:"
+msgstr ""
+
+#: ../dnd2share/data/messages:121
+msgid "Sites"
+msgstr "Steder"
+
+#: ../dnd2share/data/messages:123
+msgid "Use files hosting site for any kind of files?"
+msgstr "Brug fil hostings sted for alle slags filer?"
+
+#: ../dnd2share/data/messages:125
+msgid "Preferred site for texts hosting :"
+msgstr "Foretrukne sted for hosting af tekst:"
+
+#: ../dnd2share/data/messages:129
+msgid "Pastebin.com"
+msgstr "Pastebin.com"
+
+#: ../dnd2share/data/messages:131
+msgid "Paste-ubuntu.com"
+msgstr ""
+
+#: ../dnd2share/data/messages:133
+msgid "Pastebin.mozilla.org"
+msgstr "Pastebin.mozilla.org"
+
+#: ../dnd2share/data/messages:135
+msgid "Codepad.org"
+msgstr "Codepad.org"
+
+#: ../dnd2share/data/messages:137
+msgid "Preferred site for images hosting :"
+msgstr "Foretrukne sted for hosting af billeder:"
+
+#: ../dnd2share/data/messages:141
+msgid "Uppix.com"
+msgstr "Uppix.com"
+
+#: ../dnd2share/data/messages:143
+msgid "Imagebin.ca"
+msgstr "Imagebin.ca"
+
+#: ../dnd2share/data/messages:145
+msgid "Imgur.com"
+msgstr "Imgur.com"
+
+#: ../dnd2share/data/messages:147
+msgid "Preferred site for videos hosting :"
+msgstr "Foretrukne sted for hosting af videoer:"
+
+#: ../dnd2share/data/messages:151
+msgid "VideoBin.org"
+msgstr "VideoBin.org"
+
+#: ../dnd2share/data/messages:153
+msgid "Preferred site for files hosting :"
+msgstr "Foretrukne sted for hosting af filer:"
+
+#: ../dnd2share/data/messages:157
+msgid "dl.free.fr"
+msgstr "dl.free.fr"
+
+#: ../dnd2share/data/messages:159
+msgid "DropBox"
+msgstr "DropBox"
+
+#: ../dnd2share/data/messages:161 ../dnd2share/data/messages:165
+#: ../dnd2share/data/messages:169 ../dnd2share/data/messages:173
+msgid ""
+"The script takes the file path as a parameter, and write the resulting URL "
+"on the standard output."
+msgstr ""
+
+#: ../dnd2share/data/messages:163
+msgid "Custom script for text upload :"
+msgstr ""
+
+#: ../dnd2share/data/messages:167
+msgid "Custom script for image upload :"
+msgstr ""
+
+#: ../dnd2share/data/messages:171
+msgid "Custom script for video upload :"
+msgstr ""
+
+#: ../dnd2share/data/messages:175
+msgid "Custom script for file upload :"
+msgstr ""
+
+#: ../dnd2share/data/messages:177
+msgid ""
+"Leave empty to upload files into '~/Dropbox/Public' or '~/Ubuntu One'."
+msgstr ""
+
+#: ../dnd2share/data/messages:179
+msgid "Path of a custom DropBox / UbuntuOne folder :"
+msgstr ""
+
+#: ../dnd2share/data/messages:181
+msgid "Otherwise, your user name will be used when possible."
+msgstr ""
+
+#: ../dnd2share/data/messages:183
+msgid "Post text as Anonymous ?"
+msgstr ""
+
+#: ../dock-rendering/data/messages:1
+msgid "Inclinated Plane"
+msgstr ""
+
+#: ../dock-rendering/data/messages:3
+msgid "The lower the value, the lower the point of view on the plane."
+msgstr ""
+
+#: ../dock-rendering/data/messages:5
+msgid "Height of the vanishing point:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:9
+msgid "The lower the value, the flatter the curve will appear."
+msgstr ""
+
+#: ../dock-rendering/data/messages:11
+msgid "Curvature of the curve in percent:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:15
+msgid "Amplitude of the curve:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:19
+msgid "Physically separate groups of icons"
+msgstr ""
+
+#: ../dock-rendering/data/messages:21
+msgid "At 1, the icons will have the same size as in other views."
+msgstr ""
+
+#: ../dock-rendering/data/messages:23
+msgid "Ratio to apply on icons' size :"
+msgstr ""
+
+#: ../dock-rendering/data/messages:25
+msgid "smaller icons"
+msgstr "mindre ikoner"
+
+#: ../dock-rendering/data/messages:27
+msgid "normal icons"
+msgstr "normale ikoner"
+
+#: ../dock-rendering/data/messages:31
+msgid "Grid"
+msgstr "Gitter"
+
+#: ../dock-rendering/data/messages:33
+msgid "Space between columns:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:35 ../dock-rendering/data/messages:117
+msgid "Space between rows:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:37
+msgid "Only for sub-docks."
+msgstr ""
+
+#: ../dock-rendering/data/messages:39
+msgid "Maximum size of the dock:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:43
+msgid "Full screen"
+msgstr ""
+
+#: ../dock-rendering/data/messages:45
+msgid "Zoom when mouse hovers an icon:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:51
+msgid "Sinusoidal wave radius:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:53
+msgid "Use a linear wave rather than a sinusoidal wave?"
+msgstr ""
+
+#: ../dock-rendering/data/messages:55
+msgid "Display text for all icons?"
+msgstr ""
+
+#: ../dock-rendering/data/messages:63 ../slider/data/messages:171
+msgid "Frame"
+msgstr "Ramme"
+
+#: ../dock-rendering/data/messages:65
+msgid "First gradient colour :"
+msgstr ""
+
+#: ../dock-rendering/data/messages:67
+msgid "Second gradient colour :"
+msgstr ""
+
+#: ../dock-rendering/data/messages:69
+msgid "Top to bottom gradient?"
+msgstr ""
+
+#: ../dock-rendering/data/messages:71
+msgid "Left to right gradient?"
+msgstr ""
+
+#: ../dock-rendering/data/messages:73
+msgid "Corner radius:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:75
+msgid "Border line width :"
+msgstr ""
+
+#: ../dock-rendering/data/messages:77
+msgid "Border line colour :"
+msgstr ""
+
+#: ../dock-rendering/data/messages:79
+msgid "Arrow width :"
+msgstr ""
+
+#: ../dock-rendering/data/messages:81
+msgid "Arrow height:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:83
+msgid "Scroll bar"
+msgstr ""
+
+#: ../dock-rendering/data/messages:85
+msgid "Color of the scroll bar's outline:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:87
+msgid "Color of the scroll bar's inside:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:89
+msgid "Color of the scroll grip:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:93
+msgid "The higher this value, the sooner the parabola will be curved."
+msgstr ""
+
+#: ../dock-rendering/data/messages:95
+msgid "Curvature:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:97
+msgid "The parabola will be restricted to a rectangle of this proportion."
+msgstr ""
+
+#: ../dock-rendering/data/messages:99
+msgid "Height/width ratio:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:101
+msgid "0 represents a flat wave, 1 represents maximum wave curvature."
+msgstr ""
+
+#: ../dock-rendering/data/messages:103 ../dock-rendering/data/messages:123
+msgid "Magnitude of the wave:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:105
+msgid "Curve towards the outside?"
+msgstr ""
+
+#: ../dock-rendering/data/messages:109
+msgid "Space between icons and their captions:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:111
+msgid ""
+"This may recquire more CPU during the unfolding animation, except if you "
+"launch Cairo-Dock with OpenGL."
+msgstr ""
+
+#: ../dock-rendering/data/messages:113
+msgid "Draw captions while unfolding?"
+msgstr ""
+
+#: ../dock-rendering/data/messages:119
+msgid "Space between icons:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:121
+msgid ""
+"0 represents a flat wave, 1 means the wave is identical to other views."
+msgstr ""
+
+#: ../dock-rendering/data/messages:125
+msgid "Number of icons on the first row:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:127
+msgid ""
+"in degrees. The lower the value, the narrower the cone. 180° represents a "
+"wide open cone."
+msgstr ""
+
+#: ../dock-rendering/data/messages:129
+msgid "Cone width:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:131
+msgid "Set transparency to 0 to not use it. This is quite slow with cairo."
+msgstr ""
+
+#: ../dock-rendering/data/messages:133
+msgid "Bow colour:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:135
+msgid "Line colour:"
+msgstr ""
+
+#: ../dock-rendering/data/messages:138
+msgid ""
+"<b>A 3D plane view</b>\n"
+"This is the closest view to MacOSX's dock.\n"
+"You can choose to display separators as a line\n"
+" or a physical hole on the plane."
+msgstr ""
+
+#: ../dock-rendering/data/messages:140
+msgid ""
+"<b>A 3D caroussel view</b>\n"
+"Icons scroll with mouse position."
+msgstr ""
+
+#: ../dock-rendering/data/messages:142
+msgid ""
+"<b>Curved view</b>\n"
+"Allow you to curve your dock !\n"
+"You can choose to display separators as a line\n"
+" or a physical hole on the plane."
+msgstr ""
+
+#: ../dock-rendering/data/messages:144
+msgid ""
+"<b>Slide view</b>\n"
+"A brand new view, especially designed for big subdocks."
+msgstr ""
+
+#: ../dock-rendering/data/messages:146
+msgid ""
+"<b>Panel view</b>\n"
+"This view will display your dock like a gnome-panel or a KDE-panel.\n"
+"Icons are not zoomed on mouse over.\n"
+"Separators are rendered as spaces between the different groups of icons."
+msgstr ""
+
+#: ../dock-rendering/data/messages:148
+msgid ""
+"<b>A parabolic view</b>\n"
+"Perfect for medium sub-docks with 3 to 10 icons.\n"
+"Labels are also clickable."
+msgstr ""
+
+#: ../dock-rendering/data/messages:150
+msgid ""
+"<b>Rainbow view</b>\n"
+"An original view, designed for sub-docks with few icons.\n"
+"Icons' labels can be displayed horizontally or not."
+msgstr ""
+
+#: ../dock-rendering/data/messages:152
+msgid ""
+"<b>Slide view</b>\n"
+"This view is specially adapted to large sub-docks.\n"
+"You can choose to display all icons' labels."
+msgstr ""
+
+#: ../drop-indicator/data/messages:1
+msgid "Drag and drop indicator"
+msgstr ""
+
+#: ../drop-indicator/data/messages:5
+msgid ""
+"Typically an arrow, this will be displayed when you try to drop a new "
+"launcher into the dock. Leave this empty to use the default."
+msgstr ""
+
+#: ../drop-indicator/data/messages:7
+msgid "Image for the drag & drop animation:"
+msgstr ""
+
+#: ../drop-indicator/data/messages:9
+msgid ""
+"An emblem that will be displayed when you try to drop something on an icon. "
+"Leave empty to use the default one."
+msgstr ""
+
+#: ../drop-indicator/data/messages:11
+msgid "Image when hovering an icon :"
+msgstr ""
+
+#: ../drop-indicator/data/messages:13
+msgid "Animation"
+msgstr ""
+
+#: ../drop-indicator/data/messages:15
+msgid "Speed:"
+msgstr ""
+
+#: ../drop-indicator/data/messages:17
+msgid "Number of round per second."
+msgstr ""
+
+#: ../drop-indicator/data/messages:19 ../illusion/data/messages:79
+#: ../show-mouse/data/messages:7
+msgid "Rotation speed :"
+msgstr ""
+
+#: ../dustbin/data/messages:89
+msgid "Theme"
+msgstr "Tema"
+
+#: ../dustbin/data/messages:93
+msgid "Name of the image to overwrite the theme's empty image :"
+msgstr ""
+
+#: ../dustbin/data/messages:95
+msgid "Name of the image to overwrite the theme's full image :"
+msgstr ""
+
+#: ../dustbin/data/messages:97
+msgid "Config"
+msgstr "Opsætning"
+
+#: ../dustbin/data/messages:99
+msgid "Display the following quick info :"
+msgstr ""
+
+#: ../dustbin/data/messages:103
+msgid "Number of files"
+msgstr "Antal filer"
+
+#: ../dustbin/data/messages:105
+msgid "Total number of files"
+msgstr ""
+
+#: ../dustbin/data/messages:107
+msgid "Total weight"
+msgstr ""
+
+#: ../dustbin/data/messages:109
+msgid "Ask confirmation before emptying Dustbin?"
+msgstr ""
+
+#: ../icon-effect/data/messages:53
+msgid "Draw in background?"
+msgstr ""
+
+#: ../icon-effect/data/messages:55
+msgid "Rotate effects with dock?"
+msgstr ""
+
+#: ../icon-effect/data/messages:59
+msgid "In ms. Set 0 to not use this effect."
+msgstr ""
+
+#: ../icon-effect/data/messages:65 ../icon-effect/data/messages:93
+#: ../icon-effect/data/messages:115 ../icon-effect/data/messages:137
+#: ../icon-effect/data/messages:159 ../icon-effect/data/messages:179
+#: ../illusion/data/messages:35
+msgid "Colours"
+msgstr "Farver"
+
+#: ../icon-effect/data/messages:73
+msgid ""
+"This will slightly alter your colours, so you may have to modify them."
+msgstr ""
+
+#: ../icon-effect/data/messages:75 ../icon-effect/data/messages:187
+msgid "Add luminance?"
+msgstr ""
+
+#: ../icon-effect/data/messages:77 ../icon-effect/data/messages:101
+#: ../icon-effect/data/messages:121 ../icon-effect/data/messages:143
+#: ../icon-effect/data/messages:165 ../icon-effect/data/messages:189
+#: ../illusion/data/messages:43
+msgid "Particles"
+msgstr ""
+
+#: ../icon-effect/data/messages:79 ../icon-effect/data/messages:103
+#: ../icon-effect/data/messages:123 ../icon-effect/data/messages:145
+#: ../icon-effect/data/messages:167 ../illusion/data/messages:45
+msgid "Number of particles:"
+msgstr ""
+
+#: ../icon-effect/data/messages:81 ../icon-effect/data/messages:105
+#: ../icon-effect/data/messages:125 ../icon-effect/data/messages:147
+#: ../icon-effect/data/messages:169 ../icon-effect/data/messages:199
+#: ../illusion/data/messages:47 ../show-mouse/data/messages:25
+msgid "Particle size:"
+msgstr ""
+
+#: ../icon-effect/data/messages:83 ../icon-effect/data/messages:127
+#: ../icon-effect/data/messages:149 ../illusion/data/messages:49
+msgid "Particle speed:"
+msgstr ""
+
+#: ../icon-effect/data/messages:185
+msgid "It particularily fits a dark wallpaper or a dark theme."
+msgstr ""
+
+#: ../icon-effect/data/messages:191 ../show-mouse/data/messages:3
+msgid "Number of sources:"
+msgstr ""
+
+#: ../icon-effect/data/messages:193 ../show-mouse/data/messages:17
+msgid "Number of particles per source:"
+msgstr ""
+
+#: ../icon-effect/data/messages:195
+msgid "In percentage of the icon's size."
+msgstr ""
+
+#: ../icon-effect/data/messages:197
+msgid "Radius of the explosion:"
+msgstr ""
+
+#: ../icon-effect/data/messages:201
+msgid "Show the launching?"
+msgstr ""
+
+#: ../icon-effect/data/messages:203
+msgid "Particle friction:"
+msgstr ""
+
+#: ../illusion/data/messages:3
+msgid "Animation on disappearance:"
+msgstr ""
+
+#: ../illusion/data/messages:5 ../illusion/data/messages:19
+#: ../illusion/data/messages:31
+msgid "Evaporate"
+msgstr ""
+
+#: ../illusion/data/messages:7 ../illusion/data/messages:21
+#: ../illusion/data/messages:53
+msgid "Fade out"
+msgstr ""
+
+#: ../illusion/data/messages:9 ../illusion/data/messages:23
+#: ../illusion/data/messages:57
+msgid "Explode"
+msgstr ""
+
+#: ../illusion/data/messages:11 ../illusion/data/messages:25
+#: ../illusion/data/messages:67
+msgid "Break"
+msgstr ""
+
+#: ../illusion/data/messages:13 ../illusion/data/messages:27
+#: ../illusion/data/messages:73
+msgid "Black Hole"
+msgstr ""
+
+#: ../illusion/data/messages:15 ../illusion/data/messages:29
+msgid "Random"
+msgstr ""
+
+#: ../illusion/data/messages:17
+msgid "Animation on appearance:"
+msgstr ""
+
+#: ../illusion/data/messages:51
+msgid "Evaporate upwards?"
+msgstr ""
+
+#: ../illusion/data/messages:61 ../illusion/data/messages:71
+msgid "Number of pieces:"
+msgstr ""
+
+#: ../illusion/data/messages:63
+msgid "Explosion radius:"
+msgstr ""
+
+#: ../illusion/data/messages:65
+msgid "Break the icon into cubes?"
+msgstr ""
+
+#: ../illusion/data/messages:77
+msgid "in round per second."
+msgstr ""
+
+#: ../illusion/data/messages:81
+msgid "The greater, the faster the icon will collapse to the center."
+msgstr ""
+
+#: ../illusion/data/messages:83
+msgid "Attraction of the Black Hole:"
+msgstr ""
+
+#: ../keyboard-indicator/data/messages:99
+msgid "General"
+msgstr ""
+
+#: ../keyboard-indicator/data/messages:101
+msgid "caps lock, num lock, etc."
+msgstr ""
+
+#: ../keyboard-indicator/data/messages:103
+msgid "Display keyboard locks as quick-info?"
+msgstr ""
+
+#: ../keyboard-indicator/data/messages:105
+msgid "Icon image name for NumLock status:"
+msgstr ""
+
+#: ../keyboard-indicator/data/messages:107
+msgid "Icon image name for CapsLock status:"
+msgstr ""
+
+#: ../keyboard-indicator/data/messages:109
+msgid ""
+"in ms. Set to 0 if you don't want an animation when the keyboard layout "
+"changes."
+msgstr ""
+
+#: ../keyboard-indicator/data/messages:111
+msgid "Duration of the transition animation:"
+msgstr ""
+
+#: ../keyboard-indicator/data/messages:129
+msgid "Relative size of the text :"
+msgstr ""
+
+#: ../keyboard-indicator/data/messages:131
+msgid "smaller"
+msgstr ""
+
+#: ../keyboard-indicator/data/messages:137
+msgid "Number of letters to draw on the icon."
+msgstr ""
+
+#: ../logout/data/messages:91
+msgid "Action"
+msgstr "Handling"
+
+#: ../logout/data/messages:101
+msgid "Shortkey to lock the screen"
+msgstr ""
+
+#: ../logout/data/messages:103
+msgid "Shortkey to show the menu"
+msgstr ""
+
+#: ../logout/data/messages:105
+msgid "Demand confirmation before closing"
+msgstr ""
+
+#: ../logout/data/messages:107 ../musicPlayer/data/messages:185
+#: ../tomboy/data/messages:11
+msgid "Customisation"
+msgstr ""
+
+#: ../logout/data/messages:111
+msgid "Icon image name to use when the system has to be rebooted:"
+msgstr ""
+
+#: ../logout/data/messages:113
+msgid ""
+"Display this image as an emblem or replace applet's icon with this image?"
+msgstr ""
+
+#: ../logout/data/messages:115
+msgid "Emblem"
+msgstr "Emblem"
+
+#: ../logout/data/messages:117
+msgid "Image"
+msgstr ""
+
+#: ../logout/data/messages:119
+msgid "Commands"
+msgstr "Kommandoer"
+
+#: ../logout/data/messages:123
+msgid ""
+"Fallback user-defined command to execute for logout in case of problem:"
+msgstr ""
+
+#: ../logout/data/messages:125
+msgid ""
+"This will be available when middle-clicking. Leave empty to execute the "
+"default command, which depends on your distribution. In some cases the "
+"command to shutdown is the same as the one to log out."
+msgstr ""
+
+#: ../logout/data/messages:127
+msgid ""
+"Fallback user-defined command to execute for shutdown in case of problem:"
+msgstr ""
+
+#: ../logout/data/messages:129
+msgid ""
+"Leave empty to execute the default command. If not empty, it will execute "
+"this command with the name of the user (or nothing for guest session)"
+msgstr ""
+
+#: ../logout/data/messages:131
+msgid "User-defined command to execute for changing user:"
+msgstr ""
+
+#: ../mail/data/messages:99
+msgid ""
+"If you have any problem with the applet, uncheck this option during the "
+"maintenance mode, then after the dock has relaunched, remove/modify the mail "
+"accounts you want."
+msgstr ""
+
+#: ../mail/data/messages:101
+msgid "Check mail account on startup?"
+msgstr ""
+
+#: ../mail/data/messages:109
+msgid "Name of the file for the \"no mail\" image :"
+msgstr ""
+
+#: ../mail/data/messages:113
+msgid "Name of the file for the \"has mail\" image :"
+msgstr ""
+
+#: ../mail/data/messages:115
+msgid ""
+"If checked, the number of mails will be shown even if there is no mail."
+msgstr ""
+
+#: ../mail/data/messages:117
+msgid "Show '0' if there is no mail?"
+msgstr ""
+
+#: ../mail/data/messages:119 ../shortcuts/data/messages:103
+#: ../stack/data/messages:95 ../switcher/data/messages:189
+#: ../tomboy/data/messages:119 ../weather/data/messages:133
+msgid "Leave empty to use default sub-dock view."
+msgstr ""
+
+#: ../mail/data/messages:121 ../shortcuts/data/messages:105
+#: ../stack/data/messages:97 ../switcher/data/messages:191
+#: ../tomboy/data/messages:121 ../weather/data/messages:135
+msgid "Sub-dock view name:"
+msgstr ""
+
+#: ../mail/data/messages:123
+msgid "Action on new mail"
+msgstr ""
+
+#: ../mail/data/messages:125
+msgid "Play sound when a new e-mail is received?"
+msgstr ""
+
+#: ../mail/data/messages:129
+msgid "Name of the file for the \"new mail\" sound :"
+msgstr ""
+
+#: ../mail/data/messages:131
+msgid "Show new messages' content?"
+msgstr ""
+
+#: ../mail/data/messages:133
+msgid "Maximum number of mails that will be previewed."
+msgstr ""
+
+#: ../mail/data/messages:135
+msgid "Maximum of new messages shown?"
+msgstr ""
+
+#: ../mail/data/messages:139 ../tomboy/data/messages:117
+msgid "Duration of the dialog:"
+msgstr ""
+
+#: ../mail/data/messages:141
+msgid "Animation when new message arrives:"
+msgstr ""
+
+#: ../mail/data/messages:145
+msgid "Mail application"
+msgstr "Program til e-post"
+
+#: ../mail/data/messages:147
+msgid "for instance \"thunderbird\" or \"firefox mail.google.com\""
+msgstr ""
+
+#: ../mail/data/messages:149
+msgid "Preferred mail application to launch on left-click :"
+msgstr ""
+
+#: ../mail/data/messages:151
+msgid "Add a mail account (you've to launch the applet)"
+msgstr ""
+
+#: ../mail/data/messages:153
+msgid "The new account will be created with the specified type and name."
+msgstr ""
+
+#: ../mail/data/messages:155
+msgid "Add an account with specified type and name:"
+msgstr ""
+
+#: ../motion-blur/data/messages:3
+msgid "Also blur on mouse movement?"
+msgstr ""
+
+#: ../motion-blur/data/messages:5
+msgid "Blur amount:"
+msgstr ""
+
+#: ../musicPlayer/data/messages:7
+msgid ""
+"Leave it empty to display the name of the player currently controlled."
+msgstr ""
+
+#: ../musicPlayer/data/messages:11
+msgid "Player name"
+msgstr "Afspillerens navn"
+
+#: ../musicPlayer/data/messages:101
+msgid "Audio Player"
+msgstr "Musikafspiller"
+
+#: ../musicPlayer/data/messages:103
+msgid "Player to control:"
+msgstr "Styring af Afspiller"
+
+#: ../musicPlayer/data/messages:105
+msgid "Amarok 2"
+msgstr "Amarok 2"
+
+#: ../musicPlayer/data/messages:107
+msgid "Audacious"
+msgstr "Audacious"
+
+#: ../musicPlayer/data/messages:109
+msgid "Banshee"
+msgstr "Banshee"
+
+#: ../musicPlayer/data/messages:111
+msgid "Clementine"
+msgstr "Clementine"
+
+#: ../musicPlayer/data/messages:113
+msgid "Exaile"
+msgstr "Exaile"
+
+#: ../musicPlayer/data/messages:115
+msgid "Exaile 0.3"
+msgstr "Exaile 0.3"
+
+#: ../musicPlayer/data/messages:117
+msgid "GMusicBrowser"
+msgstr "GMusicBrowser"
+
+#: ../musicPlayer/data/messages:119
+msgid "Guayadeque"
+msgstr "Guayadeque"
+
+#: ../musicPlayer/data/messages:121
+msgid "Listen"
+msgstr "Listen"
+
+#: ../musicPlayer/data/messages:123
+msgid "Qmmp"
+msgstr "Qmmp"
+
+#: ../musicPlayer/data/messages:125
+msgid "QuodLibet"
+msgstr "QuodLibet"
+
+#: ../musicPlayer/data/messages:127
+msgid "Rhythmbox"
+msgstr "Rhythmbox"
+
+#: ../musicPlayer/data/messages:129
+msgid "Songbird"
+msgstr "Songbird"
+
+#: ../musicPlayer/data/messages:131
+msgid "XMMS 2"
+msgstr "XMMS 2"
+
+#: ../musicPlayer/data/messages:133
+msgid ""
+"This will prevent the player icon appearing in the taskbar. The applet's "
+"icon will then behave as a launcher, an application and an applet."
+msgstr ""
+
+#: ../musicPlayer/data/messages:135
+msgid "Steal the player's icon from the taskbar?"
+msgstr ""
+
+#: ../musicPlayer/data/messages:137
+msgid "Actions on click and middle-click :"
+msgstr ""
+
+#: ../musicPlayer/data/messages:139
+msgid "Play/Pause on click, Next on middle-click"
+msgstr ""
+
+#: ../musicPlayer/data/messages:141
+msgid "Show/Hide player on click, Play/Pause on middle-click"
+msgstr ""
+
+#: ../musicPlayer/data/messages:143
+msgid "Actions on scroll up/down:"
+msgstr ""
+
+#: ../musicPlayer/data/messages:145
+msgid "Next/previous song"
+msgstr ""
+
+#: ../musicPlayer/data/messages:147
+msgid "Control the volume"
+msgstr ""
+
+#: ../musicPlayer/data/messages:149
+msgid "Action on music change"
+msgstr ""
+
+#: ../musicPlayer/data/messages:151
+msgid "Show tooltips?"
+msgstr ""
+
+#: ../musicPlayer/data/messages:155
+msgid "Time length of tooltips:"
+msgstr ""
+
+#: ../musicPlayer/data/messages:157
+msgid "Animation when music changes:"
+msgstr ""
+
+#: ../musicPlayer/data/messages:161 ../powermanager/data/messages:145
+#: ../wifi/data/messages:143
+msgid "Information to display on the icon :"
+msgstr ""
+
+#: ../musicPlayer/data/messages:163 ../powermanager/data/messages:147
+msgid "Nothing"
+msgstr ""
+
+#: ../musicPlayer/data/messages:165
+msgid "Time Elapsed"
+msgstr ""
+
+#: ../musicPlayer/data/messages:167
+msgid "Time Remaining"
+msgstr ""
+
+#: ../musicPlayer/data/messages:169
+msgid "Track number"
+msgstr ""
+
+#: ../musicPlayer/data/messages:171
+msgid "Display album's cover?"
+msgstr ""
+
+#: ../musicPlayer/data/messages:173
+msgid "You need to be connected to the Internet."
+msgstr ""
+
+#: ../musicPlayer/data/messages:175
+msgid "Allow Cairo-Dock to download missing covers?"
+msgstr ""
+
+#: ../musicPlayer/data/messages:177 ../musicPlayer/data/messages:181
+msgid "requires OpenGL."
+msgstr ""
+
+#: ../musicPlayer/data/messages:179
+msgid "Use 3D themes?"
+msgstr ""
+
+#: ../musicPlayer/data/messages:183
+msgid "List of available 3D themes for covers :"
+msgstr ""
+
+#: ../musicPlayer/data/messages:189 ../tomboy/data/messages:15
+msgid "'Default' icon image name:"
+msgstr ""
+
+#: ../musicPlayer/data/messages:193
+msgid "Name of the image for the 'play' icon :"
+msgstr ""
+
+#: ../musicPlayer/data/messages:197
+msgid "Name of the image for the 'stop' icon :"
+msgstr ""
+
+#: ../musicPlayer/data/messages:201
+msgid "Name of the image for the 'pause' icon :"
+msgstr ""
+
+#: ../netspeed/data/messages:145
+msgid "By default all interfaces will be monitored."
+msgstr ""
+
+#: ../netspeed/data/messages:147
+msgid "interface:"
+msgstr ""
+
+#: ../netspeed/data/messages:155
+msgid "Fluidity of the transition between 2 values :"
+msgstr ""
+
+#: ../netspeed/data/messages:157
+msgid "Display rate values :"
+msgstr ""
+
+#: ../powermanager/data/messages:7
+msgid "Leave empty to display the current status information."
+msgstr ""
+
+#: ../powermanager/data/messages:11
+msgid "Current status"
+msgstr ""
+
+#: ../powermanager/data/messages:139
+msgid "'On-battery' icon filename:"
+msgstr ""
+
+#: ../powermanager/data/messages:141
+msgid "Icon's filename when on charge :"
+msgstr ""
+
+#: ../powermanager/data/messages:149
+msgid "charge"
+msgstr ""
+
+#: ../powermanager/data/messages:151
+msgid "Timelength"
+msgstr ""
+
+#: ../powermanager/data/messages:153
+msgid "Emblem icon's filename when on charge:"
+msgstr ""
+
+#: ../powermanager/data/messages:155
+msgid "Hide the icon when not on battery?"
+msgstr ""
+
+#: ../powermanager/data/messages:161
+msgid "Notification"
+msgstr ""
+
+#: ../powermanager/data/messages:163
+msgid "Notification when battery charged ?"
+msgstr ""
+
+#: ../powermanager/data/messages:165 ../powermanager/data/messages:175
+#: ../powermanager/data/messages:183
+msgid "Leave it empty for no sound"
+msgstr ""
+
+#: ../powermanager/data/messages:167 ../powermanager/data/messages:177
+#: ../powermanager/data/messages:185
+msgid "Play a sound:"
+msgstr ""
+
+#: ../powermanager/data/messages:169
+msgid "Notification when low battery ?"
+msgstr ""
+
+#: ../powermanager/data/messages:171
+msgid "in percent."
+msgstr ""
+
+#: ../powermanager/data/messages:173
+msgid "Battery level:"
+msgstr ""
+
+#: ../powermanager/data/messages:179
+msgid "When battery level is under 4%"
+msgstr ""
+
+#: ../powermanager/data/messages:181
+msgid "Notification when battery charge is critical ?"
+msgstr ""
+
+#: ../powermanager/data/messages:187
+msgid "Notification type:"
+msgstr ""
+
+#: ../quick-browser/data/messages:7
+msgid "Leave empty to use the folder's name."
+msgstr ""
+
+#: ../quick-browser/data/messages:93 ../slider/data/messages:99
+msgid "Folder"
+msgstr ""
+
+#: ../quick-browser/data/messages:95
+msgid "Folder to browse :"
+msgstr ""
+
+#: ../quick-browser/data/messages:97
+msgid "List folders first?"
+msgstr ""
+
+#: ../quick-browser/data/messages:99
+msgid "Ignore case?"
+msgstr ""
+
+#: ../quick-browser/data/messages:103
+msgid "Menu"
+msgstr ""
+
+#: ../quick-browser/data/messages:105
+msgid "It can be CPU intense to load a lot of icons."
+msgstr ""
+
+#: ../quick-browser/data/messages:107
+msgid "Display icons in the menu?"
+msgstr ""
+
+#: ../quick-browser/data/messages:111
+msgid ""
+"Number of items loaded at once. Setting a high value speeds up loading a "
+"little but will hang the application for longer."
+msgstr ""
+
+#: ../quick-browser/data/messages:113
+msgid "Build menu gradually:"
+msgstr ""
+
+#: ../shortcuts/data/messages:93
+msgid "List drives and volumes?"
+msgstr ""
+
+#: ../shortcuts/data/messages:95
+msgid "List networks?"
+msgstr ""
+
+#: ../shortcuts/data/messages:97
+msgid "GTK bookmarks, that are used by Nautilus for exemple."
+msgstr ""
+
+#: ../shortcuts/data/messages:99
+msgid "List bookmarks?"
+msgstr ""
+
+#: ../shortcuts/data/messages:107 ../stack/data/messages:99
+msgid "Type of view for the desklet mode :"
+msgstr ""
+
+#: ../shortcuts/data/messages:111 ../stack/data/messages:103
+msgid "Tree"
+msgstr ""
+
+#: ../shortcuts/data/messages:113
+msgid "Disk usage"
+msgstr ""
+
+#: ../shortcuts/data/messages:115
+msgid "Show disk usage :"
+msgstr ""
+
+#: ../shortcuts/data/messages:119
+msgid "Free space"
+msgstr ""
+
+#: ../shortcuts/data/messages:121
+msgid "Used space"
+msgstr ""
+
+#: ../shortcuts/data/messages:123
+msgid "Free space (in percent)"
+msgstr ""
+
+#: ../shortcuts/data/messages:125
+msgid "Used space (in percent)"
+msgstr ""
+
+#: ../shortcuts/data/messages:129
+msgid "Delay between disk usage refresh :"
+msgstr ""
+
+#: ../shortcuts/data/messages:131
+msgid "Display disk usage with a bar?"
+msgstr ""
+
+#: ../show-mouse/data/messages:5
+msgid "In rotations per second."
+msgstr ""
+
+#: ../show-mouse/data/messages:9
+msgid "Show mouse on:"
+msgstr ""
+
+#: ../show-mouse/data/messages:11
+msgid "Dock"
+msgstr ""
+
+#: ../show-mouse/data/messages:21
+msgid "Particle life time:"
+msgstr ""
+
+#: ../show-mouse/data/messages:33
+msgid ""
+"The higher the value, the more particles will scatter from their source."
+msgstr ""
+
+#: ../show-mouse/data/messages:35
+msgid "Scattering:"
+msgstr ""
+
+#: ../showDesktop/data/messages:13
+msgid "Image when the applet is active :"
+msgstr ""
+
+#: ../showDesktop/data/messages:95 ../showDesktop/data/messages:109
+msgid ""
+"You need to activate the Dbus plug-in in Compiz for the last 2 actions. "
+"Showing desktop and desklets can fail on some Window Manager (like Metacity)."
+msgstr ""
+
+#: ../showDesktop/data/messages:97 ../slider/data/messages:117
+msgid "Action on left-click:"
+msgstr ""
+
+#: ../showDesktop/data/messages:101 ../showDesktop/data/messages:115
+msgid "Show the desklets"
+msgstr ""
+
+#: ../showDesktop/data/messages:103 ../showDesktop/data/messages:117
+msgid "Show desktop and desklets"
+msgstr ""
+
+#: ../showDesktop/data/messages:123
+msgid "Shortkey for the middle-click action:"
+msgstr ""
+
+#: ../slider/data/messages:101
+msgid "Folder for the images:"
+msgstr ""
+
+#: ../slider/data/messages:103
+msgid "Scan sub direcotries?"
+msgstr ""
+
+#: ../slider/data/messages:105
+msgid "Randomly browse files?"
+msgstr ""
+
+#: ../slider/data/messages:107
+msgid "Display image name as quickinfo?"
+msgstr ""
+
+#: ../slider/data/messages:109
+msgid ""
+"This will prevent the dock from freezing during image loading, but works "
+"only with OpenGL."
+msgstr ""
+
+#: ../slider/data/messages:111
+msgid "Use another thread to load images?"
+msgstr ""
+
+#: ../slider/data/messages:113
+msgid "Read all images properties on startup?"
+msgstr ""
+
+#: ../slider/data/messages:119 ../slider/data/messages:125
+msgid "play/pause"
+msgstr ""
+
+#: ../slider/data/messages:121 ../slider/data/messages:127
+msgid "open image"
+msgstr ""
+
+#: ../slider/data/messages:129
+msgid "open parent folder"
+msgstr ""
+
+#: ../slider/data/messages:133
+msgid "Sliding delay:"
+msgstr ""
+
+#: ../slider/data/messages:135
+msgid "Effect while changing image:"
+msgstr ""
+
+#: ../slider/data/messages:139
+msgid "fade"
+msgstr ""
+
+#: ../slider/data/messages:141
+msgid "blank fade"
+msgstr ""
+
+#: ../slider/data/messages:143
+msgid "fade in/out"
+msgstr ""
+
+#: ../slider/data/messages:145
+msgid "side kick"
+msgstr ""
+
+#: ../slider/data/messages:147
+msgid "slideshow"
+msgstr ""
+
+#: ../slider/data/messages:149
+msgid "grow up"
+msgstr ""
+
+#: ../slider/data/messages:151
+msgid "shrink"
+msgstr ""
+
+#: ../slider/data/messages:153
+msgid "cube"
+msgstr ""
+
+#: ../slider/data/messages:155
+msgid "random"
+msgstr ""
+
+#: ../slider/data/messages:157
+msgid "Number of steps for transitions:"
+msgstr ""
+
+#: ../slider/data/messages:159
+msgid "fast"
+msgstr ""
+
+#: ../slider/data/messages:161
+msgid "slow"
+msgstr ""
+
+#: ../slider/data/messages:165
+msgid "Add a background to the image?"
+msgstr ""
+
+#: ../slider/data/messages:173
+msgid ""
+"Set the transparency channel to 0 if you just don't want to have a "
+"background."
+msgstr ""
+
+#: ../slider/data/messages:175
+msgid "Choose a background colour :"
+msgstr ""
+
+#: ../slider/data/messages:177
+msgid "Frame width:"
+msgstr ""
+
+#: ../slider/data/messages:179
+msgid "Gives better image rendering."
+msgstr ""
+
+#: ../slider/data/messages:181
+msgid "Keep width/height ratio?"
+msgstr ""
+
+#: ../slider/data/messages:183
+msgid "If the image is too small, it will be stretched."
+msgstr ""
+
+#: ../slider/data/messages:185
+msgid "Force the image to fill the icon/desklet?"
+msgstr ""
+
+#: ../stack/data/messages:7
+msgid "Leave empty to use a default name"
+msgstr ""
+
+#: ../stack/data/messages:105
+msgid "They are items created by dropping a text into the Stack."
+msgstr ""
+
+#: ../stack/data/messages:107
+msgid "Image for 'text' items:"
+msgstr ""
+
+#: ../stack/data/messages:109
+msgid "These are items created by dropping a URL into the Stack."
+msgstr ""
+
+#: ../stack/data/messages:111
+msgid "Image for 'URL' items:"
+msgstr ""
+
+#: ../stack/data/messages:113
+msgid "Options"
+msgstr ""
+
+#: ../stack/data/messages:115
+msgid "Separate the items by type (file/web page/text)"
+msgstr ""
+
+#: ../stack/data/messages:117
+msgid ""
+"These options allow you to prevent some files from displaying in stacks "
+"based on their type (video, image, etc.)"
+msgstr ""
+
+#: ../stack/data/messages:119
+msgid "Filter files on MIME type?"
+msgstr ""
+
+#: ../stack/data/messages:121
+msgid "E.g. image, text, video, audio, application..."
+msgstr ""
+
+#: ../stack/data/messages:123
+msgid "Here you can specify a list of MIME types to ignore:"
+msgstr ""
+
+#: ../stack/data/messages:125
+msgid "Sort items by:"
+msgstr ""
+
+#: ../stack/data/messages:131
+msgid "Type"
+msgstr ""
+
+#: ../stack/data/messages:133
+msgid "Manual order"
+msgstr ""
+
+#: ../switcher/data/messages:93
+msgid "How to display all desktops?"
+msgstr ""
+
+#: ../switcher/data/messages:95
+msgid "A sub-dock with all desktops"
+msgstr ""
+
+#: ../switcher/data/messages:97
+msgid "All desktops drawn on the main icon"
+msgstr ""
+
+#: ../switcher/data/messages:99
+msgid "Desktops layout"
+msgstr ""
+
+#: ../switcher/data/messages:103
+msgid "On a single line"
+msgstr ""
+
+#: ../switcher/data/messages:105
+msgid "Preserve the ratio of the screen?"
+msgstr ""
+
+#: ../switcher/data/messages:107
+msgid "Background for each desktop"
+msgstr ""
+
+#: ../switcher/data/messages:109
+msgid "Wallpaper"
+msgstr ""
+
+#: ../switcher/data/messages:111 ../switcher/data/messages:117
+msgid "Custom image"
+msgstr ""
+
+#: ../switcher/data/messages:113 ../switcher/data/messages:121
+msgid "Custom colour"
+msgstr ""
+
+#: ../switcher/data/messages:119 ../switcher/data/messages:153
+#: ../switcher/data/messages:159 ../switcher/data/messages:163
+#: ../switcher/data/messages:167 ../switcher/data/messages:183
+msgid "r, g, b, a"
+msgstr ""
+
+#: ../switcher/data/messages:125
+msgid "Show desktop number on icons?"
+msgstr ""
+
+#: ../switcher/data/messages:127
+msgid "Draw windows on icons?"
+msgstr ""
+
+#: ../switcher/data/messages:129
+msgid "Draw hidden windows?"
+msgstr ""
+
+#: ../switcher/data/messages:131
+msgid "Draw icons of windows?"
+msgstr ""
+
+#: ../switcher/data/messages:135
+msgid "Show windows' list"
+msgstr ""
+
+#: ../switcher/data/messages:143
+msgid "Display options"
+msgstr ""
+
+#: ../switcher/data/messages:151
+msgid "Size of the inside lines :"
+msgstr ""
+
+#: ../switcher/data/messages:155
+msgid "Internal line colour:"
+msgstr ""
+
+#: ../switcher/data/messages:157
+msgid "External line size:"
+msgstr ""
+
+#: ../switcher/data/messages:161
+msgid "External line colour:"
+msgstr ""
+
+#: ../switcher/data/messages:165
+msgid "Active window colour:"
+msgstr ""
+
+#: ../switcher/data/messages:169
+msgid "Current desktop colour:"
+msgstr ""
+
+#: ../switcher/data/messages:171
+msgid "How to draw the current desktop:"
+msgstr ""
+
+#: ../switcher/data/messages:173
+msgid "draw a frame"
+msgstr ""
+
+#: ../switcher/data/messages:175
+msgid "fill"
+msgstr ""
+
+#: ../switcher/data/messages:177
+msgid "fill others"
+msgstr ""
+
+#: ../switcher/data/messages:179
+msgid "All windows can be filled with one colour"
+msgstr ""
+
+#: ../switcher/data/messages:181
+msgid "Fill all windows?"
+msgstr ""
+
+#: ../switcher/data/messages:185
+msgid "Colour of these windows:"
+msgstr ""
+
+#: ../switcher/data/messages:187
+msgid "Sub-Dock"
+msgstr ""
+
+#: ../systray/data/messages:83
+msgid "Shortkey to toggle the systray in dock mode:"
+msgstr ""
+
+#: ../systray/data/messages:85
+msgid "Icons packing :"
+msgstr ""
+
+#: ../systray/data/messages:87
+msgid "horizontal"
+msgstr ""
+
+#: ../systray/data/messages:89
+msgid "vertical"
+msgstr ""
+
+#: ../template/data/messages:91
+msgid "This is a tooltip for this parameter."
+msgstr ""
+
+#: ../template/data/messages:93
+msgid "This is a boolean parameter. Y/N ?"
+msgstr ""
+
+#: ../template/data/messages:95
+msgid "This integer can go from 0 to 10 :"
+msgstr ""
+
+#: ../template/data/messages:97
+msgid "Enter some text here :"
+msgstr ""
+
+#: ../terminal/data/messages:93
+msgid "Foreground colour:"
+msgstr ""
+
+#: ../terminal/data/messages:95
+msgid "Background colour:"
+msgstr ""
+
+#: ../terminal/data/messages:97
+msgid "Use a custom font?"
+msgstr ""
+
+#: ../terminal/data/messages:99
+msgid "Custom font:"
+msgstr ""
+
+#: ../terminal/data/messages:103
+msgid "Automatically scroll to the bottom when new data are received"
+msgstr ""
+
+#: ../terminal/data/messages:105
+msgid "Scroll on output"
+msgstr ""
+
+#: ../terminal/data/messages:107
+msgid "Automatically scroll to the bottom when a key is pressed"
+msgstr ""
+
+#: ../terminal/data/messages:109
+msgid "Scroll on keystroke"
+msgstr ""
+
+#: ../terminal/data/messages:111
+msgid "Limited scrollback buffer"
+msgstr ""
+
+#: ../terminal/data/messages:113
+msgid "Length of the scrollback buffer"
+msgstr ""
+
+#: ../terminal/data/messages:117
+msgid ""
+"When the terminal is in a dialog. When it is in a desklet, you can just "
+"resize the desklet as usual."
+msgstr ""
+
+#: ../terminal/data/messages:119
+msgid "Size of the terminal (line x columns):"
+msgstr ""
+
+#: ../terminal/data/messages:121
+msgid "Shortkey to show the terminal:"
+msgstr ""
+
+#: ../terminal/data/messages:123
+msgid "The default terminal is defined by the COLORTERM environment variable"
+msgstr ""
+
+#: ../terminal/data/messages:125
+msgid "Open this terminal when doing a middle click on the icon:"
+msgstr ""
+
+#: ../tomboy/data/messages:19
+msgid "'Close' icon image name:"
+msgstr ""
+
+#: ../tomboy/data/messages:107
+msgid "Image file for the notes:"
+msgstr ""
+
+#: ../tomboy/data/messages:109
+msgid "Draw note's content on their icon?"
+msgstr ""
+
+#: ../tomboy/data/messages:111
+msgid "Text colour of the content :"
+msgstr ""
+
+#: ../tomboy/data/messages:113
+msgid "Display note's content with a dialog?"
+msgstr ""
+
+#: ../tomboy/data/messages:125
+msgid "Choose the note-taking application to control :"
+msgstr ""
+
+#: ../tomboy/data/messages:127
+msgid "Gnote"
+msgstr ""
+
+#: ../tomboy/data/messages:129
+msgid "Tomboy"
+msgstr ""
+
+#: ../tomboy/data/messages:133
+msgid "Ask for confirmation before deleting a note?"
+msgstr ""
+
+#: ../tomboy/data/messages:135
+msgid "Otherwise you will be asked to name it."
+msgstr ""
+
+#: ../tomboy/data/messages:137
+msgid "Automatically name a new note?"
+msgstr ""
+
+#: ../tomboy/data/messages:139
+msgid ""
+"Write the date format you usually use in your notes. The syntax is the one "
+"of 'strftime' : %d for the day, %m for the month, %y for the year (2 "
+"digits), etc. Leave it blank to use the default one (%d/%m/%y)."
+msgstr ""
+
+#: ../tomboy/data/messages:141
+msgid "Date format to search for :"
+msgstr ""
+
+#: ../tomboy/data/messages:145
+msgid ""
+"Depending on your tomboy's version, the note deletion may not be "
+"automatically notified to us. Only check this box if you notice some error "
+"message like <<No marshaller for signature of signal 'NoteDeleted'>> in the "
+"terminal."
+msgstr ""
+
+#: ../tomboy/data/messages:147
+msgid "Emulate the 'NoteDeleted' signal?"
+msgstr ""
+
+#: ../weather/data/messages:7
+msgid "Leave empty to use the name of the city."
+msgstr ""
+
+#: ../weather/data/messages:11
+msgid "City name"
+msgstr ""
+
+#: ../weather/data/messages:103
+msgid "Enter the name of your location in the text entry and press Enter."
+msgstr ""
+
+#: ../weather/data/messages:105
+msgid "Code for your location:"
+msgstr ""
+
+#: ../weather/data/messages:107
+msgid "If so, degrees will be displayed in Celsius, otherwise in Fahrenheit."
+msgstr ""
+
+#: ../weather/data/messages:109
+msgid "Use International System Units?"
+msgstr ""
+
+#: ../weather/data/messages:111
+msgid "in seconds. Set 0 to have never-ending dialogs."
+msgstr ""
+
+#: ../weather/data/messages:113
+msgid "Dialog duration:"
+msgstr ""
+
+#: ../weather/data/messages:119 ../wifi/data/messages:141
+msgid "Info"
+msgstr ""
+
+#: ../weather/data/messages:121
+msgid "Display current conditions on the icon instead of the default one?"
+msgstr ""
+
+#: ../weather/data/messages:123
+msgid "Number of days to forecast:"
+msgstr ""
+
+#: ../weather/data/messages:125
+msgid "Display nights?"
+msgstr ""
+
+#: ../weather/data/messages:127
+msgid "Display temperature as quick info?"
+msgstr ""
+
+#: ../weather/data/messages:137
+msgid "Render desklet in 3D?"
+msgstr ""
+
+#: ../weblets/data/messages:91
+msgid "URI to load in weblet"
+msgstr ""
+
+#: ../weblets/data/messages:93
+msgid "Show scrollbars?"
+msgstr ""
+
+#: ../weblets/data/messages:95
+msgid "Horizontal scroll of the browser in pixels"
+msgstr ""
+
+#: ../weblets/data/messages:97
+msgid "Position of horizontal scrollbar"
+msgstr ""
+
+#: ../weblets/data/messages:99
+msgid "Vertical scroll of the browser in pixels"
+msgstr ""
+
+#: ../weblets/data/messages:101
+msgid "Position of vertical scrollbar in pixel"
+msgstr ""
+
+#: ../weblets/data/messages:103
+msgid ""
+"This lets you right-click on the desklet to pop up the Cairo-Dock menu."
+msgstr ""
+
+#: ../weblets/data/messages:105
+msgid "Right margin width, in pixels:"
+msgstr ""
+
+#: ../weblets/data/messages:107
+msgid "Transparent background?"
+msgstr ""
+
+#: ../weblets/data/messages:109
+msgid ""
+"Time before reloading the weblet URI, in seconds. Zero means never reload."
+msgstr ""
+
+#: ../weblets/data/messages:111
+msgid "Time between two page refreshes"
+msgstr ""
+
+#: ../weblets/data/messages:113
+msgid "Any valid URI should work."
+msgstr ""
+
+#: ../weblets/data/messages:115
+msgid "Predefined bookmarks to show in applet menu:"
+msgstr ""
+
+#: ../wifi/data/messages:139
+msgid "\"No signal\" icon"
+msgstr ""
+
+#: ../wifi/data/messages:147
+msgid "Signal Strength"
+msgstr ""
+
+#: ../wifi/data/messages:149
+msgid "Signal Strength in percent"
+msgstr ""
+
+#: ../wifi/data/messages:151
+msgid "Raw Signal Informations"
+msgstr ""
+
+#: ../wifi/data/messages:157
+msgid "Delay between signal checks :"
+msgstr ""
+
+#: ../wifi/data/messages:163
+msgid ""
+"Allow you to overwrite applet's default command line and launch your "
+"wireless configuration interface."
+msgstr ""
+
+#: ../wifi/data/messages:165
+msgid "Alternative command line to launch Wireless Configuration :"
+msgstr ""
diff -pruN 3.4.1-6/po/de.po 3.4.1+git20201022.a0d3415c-1/po/de.po
--- 3.4.1-6/po/de.po	2015-02-19 16:12:48.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/po/de.po	2020-10-21 15:04:44.000000000 +0000
@@ -9,14 +9,14 @@ msgstr ""
 "Project-Id-Version: cairo-dock-plug-ins\n"
 "Report-Msgid-Bugs-To: fabounet@glx-dock.org\n"
 "POT-Creation-Date: 2014-10-19 00:22+0000\n"
-"PO-Revision-Date: 2015-02-04 16:24+0000\n"
+"PO-Revision-Date: 2015-03-20 22:54+0000\n"
 "Last-Translator: Tobias Bannert <Unknown>\n"
 "Language-Team: German <de@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2015-02-05 05:49+0000\n"
-"X-Generator: Launchpad (build 17331)\n"
+"X-Launchpad-Export-Date: 2015-03-21 05:21+0000\n"
+"X-Generator: Launchpad (build 17405)\n"
 "Language: de\n"
 
 #: ../Animated-icons/src/applet-blink.c:77 ../Animated-icons/data/messages:11
@@ -1775,7 +1775,7 @@ msgstr "Blau:"
 
 #: ../Xgamma/src/applet-xgamma.c:247 ../Xgamma/src/applet-xgamma.c:320
 msgid "Set up gamma:"
-msgstr "Einstellen des Gamma-Werts :"
+msgstr "Gamma-Werts einstellen:"
 
 #: ../Xgamma/src/applet-xgamma.c:335
 msgid "Luminosity"
@@ -1893,7 +1893,7 @@ msgstr "Alarm"
 
 #: ../clock/src/applet-config.c:36
 msgid "Time you want to be notified:"
-msgstr "Zeit, in der Sie erinnert werden möchten :"
+msgstr "Zeit, zu der Sie erinnert werden möchten:"
 
 #: ../clock/src/applet-config.c:36
 msgid "In the form xx:xx. E.g.: 20:35 for 8:35pm"
@@ -1949,7 +1949,7 @@ msgstr "Monat"
 
 #: ../clock/src/applet-config.c:36
 msgid "Repeat every:"
-msgstr "Wiederhole alle :"
+msgstr "Wiederholen alle:"
 
 #: ../clock/src/applet-config.c:36
 msgid "If every month, which day of the month?"
@@ -1957,7 +1957,7 @@ msgstr "Falls monatlich, an welchem Tag
 
 #: ../clock/src/applet-config.c:36
 msgid "Message you want to use to be notified:"
-msgstr "Meldung, die als Erinnerung angezeigt werden soll :"
+msgstr "Meldung, die als Erinnerung angezeigt werden soll:"
 
 #: ../clock/src/applet-config.c:36
 msgid "Tea Time!"
@@ -2222,7 +2222,7 @@ msgstr ""
 
 #: ../dnd2share/src/applet-backend-dropbox.c:63
 msgid "This directory seems not valid:"
-msgstr "Dieses Verzeichnis scheint nicht gültig zu sein :"
+msgstr "Dieses Verzeichnis scheint nicht gültig zu sein:"
 
 #: ../dnd2share/src/applet-backend-imgur.c:33
 msgid "Display Image"
@@ -2785,7 +2785,7 @@ msgstr ""
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Server address:"
-msgstr "Serveradresse :"
+msgstr "Serveradresse:"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "myHost"
@@ -2797,7 +2797,7 @@ msgstr "Benutzername:"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Password:"
-msgstr "Passwort :"
+msgstr "Passwort:"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "The password will be crypted."
@@ -2852,11 +2852,11 @@ msgstr "Besondere Symbolbilddatei, wenn
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Directory on server:"
-msgstr "Verzeichnis auf dem Server :"
+msgstr "Verzeichnis auf dem Server:"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Path of mbox file:"
-msgstr "Pfad der mbox-Datei :"
+msgstr "Pfad der mbox-Datei:"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Path to Mail directory:"
@@ -3240,7 +3240,7 @@ msgstr "Laptop im Akkubetrieb"
 #: ../powermanager/src/powermanager-draw.c:267
 #: ../powermanager/src/powermanager-draw.c:276
 msgid "Battery charged at:"
-msgstr "Akku geladen am :"
+msgstr "Akku geladen am:"
 
 #: ../powermanager/src/powermanager-draw.c:268
 msgid "Estimated time before empty:"
@@ -3364,44 +3364,44 @@ msgstr "Persönlicher Ordner"
 #: ../shortcuts/src/applet-disk-usage.c:183
 #: ../shortcuts/src/applet-disk-usage.c:212
 msgid "Mount point:"
-msgstr "Einhängepunkt :"
+msgstr "Einhängepunkt:"
 
 #: ../shortcuts/src/applet-disk-usage.c:184
 #: ../shortcuts/src/applet-disk-usage.c:213
 msgid "File system:"
-msgstr "Dateisystem :"
+msgstr "Dateisystem:"
 
 #: ../shortcuts/src/applet-disk-usage.c:185
 #: ../shortcuts/src/applet-disk-usage.c:214
 msgid "Device:"
-msgstr "Gerät :"
+msgstr "Gerät:"
 
 #: ../shortcuts/src/applet-disk-usage.c:186
 #: ../shortcuts/src/applet-disk-usage.c:215
 msgid "Mount options:"
-msgstr "Einhängeoptionen :"
+msgstr "Einhängeoptionen:"
 
 #: ../shortcuts/src/applet-disk-usage.c:218
 msgid "Backup frequency:"
-msgstr "Sicherungshäufigkeit :"
+msgstr "Sicherungshäufigkeit:"
 
 #: ../shortcuts/src/applet-disk-usage.c:218
 msgid "days"
-msgstr "Tage :"
+msgstr "Tage"
 
 #: ../shortcuts/src/applet-disk-usage.c:241
 #: ../shortcuts/src/applet-disk-usage.c:251
 #: ../shortcuts/src/applet-disk-usage.c:256
 msgid "Name:"
-msgstr "Name :"
+msgstr "Name:"
 
 #: ../shortcuts/src/applet-disk-usage.c:242
 msgid "Capacity:"
-msgstr "Kapazität :"
+msgstr "Größe:"
 
 #: ../shortcuts/src/applet-disk-usage.c:243
 msgid "Free space:"
-msgstr "Freier Speicherplatz :"
+msgstr "Freier Speicherplatz:"
 
 #: ../shortcuts/src/applet-disk-usage.c:251
 msgid "Not mounted"
@@ -7245,7 +7245,7 @@ msgstr "Druckmesserthema"
 
 #: ../Xgamma/data/messages:93 ../alsaMixer/data/messages:137
 msgid "Variation for 1 mouse scroll, in %:"
-msgstr "Veränderung für einen Maus-Scroll in &% :"
+msgstr "Veränderung für ein Mausrollen in %:"
 
 #: ../Xgamma/data/messages:95
 msgid "Use 0 for none."
@@ -7782,19 +7782,19 @@ msgstr "Pfeilhöhe :"
 
 #: ../dock-rendering/data/messages:83
 msgid "Scroll bar"
-msgstr "Scrollbalken"
+msgstr "Bildlaufleiste"
 
 #: ../dock-rendering/data/messages:85
 msgid "Color of the scroll bar's outline:"
-msgstr "Farbe der Umrandung des Scrollbalkens :"
+msgstr "Farbe der Umrandung der Bildlaufleiste:"
 
 #: ../dock-rendering/data/messages:87
 msgid "Color of the scroll bar's inside:"
-msgstr "Farbe der Innenseite des Scrollbalkens :"
+msgstr "Farbe der Innenseite der Bildlaufleiste:"
 
 #: ../dock-rendering/data/messages:89
 msgid "Color of the scroll grip:"
-msgstr "Fabe des Scrollgriffs :"
+msgstr "Fabe der Bildlaufleiste:"
 
 #: ../dock-rendering/data/messages:93
 msgid "The higher this value, the sooner the parabola will be curved."
@@ -8679,7 +8679,7 @@ msgstr "Benachrichtigung"
 
 #: ../powermanager/data/messages:163
 msgid "Notification when battery charged ?"
-msgstr "Benachrichtigung, wenn die Batterie geladen ist ?"
+msgstr "Benachrichtigung, wenn der Akku geladen ist?"
 
 #: ../powermanager/data/messages:165 ../powermanager/data/messages:175
 #: ../powermanager/data/messages:183
@@ -9254,23 +9254,23 @@ msgstr ""
 
 #: ../terminal/data/messages:105
 msgid "Scroll on output"
-msgstr "Bei Ausgabe nach uten scrollen"
+msgstr "Bei Ausgabe rollen"
 
 #: ../terminal/data/messages:107
 msgid "Automatically scroll to the bottom when a key is pressed"
-msgstr "Automatisch ganz nach unten scrollen wenn eine Taste gedrückt wird"
+msgstr "Automatisch ganz nach unten rollen, wenn eine Taste gedrückt wird"
 
 #: ../terminal/data/messages:109
 msgid "Scroll on keystroke"
-msgstr "Bei Tastendruck scrollen"
+msgstr "Bei Tastendruck rollen"
 
 #: ../terminal/data/messages:111
 msgid "Limited scrollback buffer"
-msgstr "Begrenzter Scrollback-Puffer"
+msgstr "Begrenzter Rückrollpuffer"
 
 #: ../terminal/data/messages:113
 msgid "Length of the scrollback buffer"
-msgstr "Länge des Scrollback-Puffers"
+msgstr "Länge des Rückrollpuffers"
 
 #: ../terminal/data/messages:117
 msgid ""
@@ -9282,11 +9282,11 @@ msgstr ""
 
 #: ../terminal/data/messages:119
 msgid "Size of the terminal (line x columns):"
-msgstr "Größe des Terminals (Zeilen x Reihen) :"
+msgstr "Größe des Terminals (Zeilen x Reihen):"
 
 #: ../terminal/data/messages:121
 msgid "Shortkey to show the terminal:"
-msgstr "Tastenkürzel, um das Terminal anzuzeigen :"
+msgstr "Tastenkürzel, um das Terminal anzuzeigen:"
 
 #: ../terminal/data/messages:123
 msgid "The default terminal is defined by the COLORTERM environment variable"
@@ -9299,7 +9299,7 @@ msgstr "Dieses Terminal bei einem Mittel
 
 #: ../tomboy/data/messages:19
 msgid "'Close' icon image name:"
-msgstr "'Schließen'-Symbolbildname :"
+msgstr "Bildname des »Schließen«-Symbols:"
 
 #: ../tomboy/data/messages:107
 msgid "Image file for the notes:"
@@ -9311,7 +9311,7 @@ msgstr "Den Inhalt der Notizen auf deren
 
 #: ../tomboy/data/messages:111
 msgid "Text colour of the content :"
-msgstr "Textfarbe des Inhalts :"
+msgstr "Textfarbe des Inhaltes:"
 
 #: ../tomboy/data/messages:113
 msgid "Display note's content with a dialog?"
@@ -9439,23 +9439,23 @@ msgstr "URL, die ins Weblet geladen werd
 
 #: ../weblets/data/messages:93
 msgid "Show scrollbars?"
-msgstr "Scrollleisten anzeigen ?"
+msgstr "Bildlaufleisten anzeigen?"
 
 #: ../weblets/data/messages:95
 msgid "Horizontal scroll of the browser in pixels"
-msgstr "Waagerechtes Scrolling des Browsers in Pixeln"
+msgstr "Waagerechten Bildlauf des Browsers in Pixeln"
 
 #: ../weblets/data/messages:97
 msgid "Position of horizontal scrollbar"
-msgstr "Position der waagerechten Scrollleiste"
+msgstr "Position der waagerechten Bildlaufleiste"
 
 #: ../weblets/data/messages:99
 msgid "Vertical scroll of the browser in pixels"
-msgstr "Senkrechtes Scrolling des Browsers in Pixeln"
+msgstr "Senkrechte Bildlauf des Browsers in Pixeln"
 
 #: ../weblets/data/messages:101
 msgid "Position of vertical scrollbar in pixel"
-msgstr "Position der senkrechten Scrollleiste"
+msgstr "Position der senkrechten Bildlaufleiste"
 
 #: ../weblets/data/messages:103
 msgid ""
diff -pruN 3.4.1-6/po/hr.po 3.4.1+git20201022.a0d3415c-1/po/hr.po
--- 3.4.1-6/po/hr.po	2015-02-19 16:12:48.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/po/hr.po	2020-10-21 15:04:44.000000000 +0000
@@ -8,14 +8,14 @@ msgstr ""
 "Project-Id-Version: cairo-dock-plug-ins\n"
 "Report-Msgid-Bugs-To: fabounet@glx-dock.org\n"
 "POT-Creation-Date: 2014-10-19 00:22+0000\n"
-"PO-Revision-Date: 2013-01-04 22:36+0000\n"
-"Last-Translator: Launchpad Translations Administrators <Unknown>\n"
+"PO-Revision-Date: 2015-12-12 20:48+0000\n"
+"Last-Translator: gogo <trebelnik2@gmail.com>\n"
 "Language-Team: Croatian <hr@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-10-19 06:35+0000\n"
-"X-Generator: Launchpad (build 17196)\n"
+"X-Launchpad-Export-Date: 2015-12-13 05:15+0000\n"
+"X-Generator: Launchpad (build 17865)\n"
 "Language: hr\n"
 
 #: ../Animated-icons/src/applet-blink.c:77 ../Animated-icons/data/messages:11
@@ -391,7 +391,7 @@ msgstr "B"
 #: ../Network-Monitor/src/applet-netspeed.c:58
 #: ../netspeed/src/applet-netspeed.c:64
 msgid "KB"
-msgstr "kB"
+msgstr "KB"
 
 #: ../Disks/src/applet-disks.c:69 ../Folders/src/applet-notifications.c:138
 #: ../Network-Monitor/src/applet-netspeed.c:66
diff -pruN 3.4.1-6/po/misc/replace_my_trad.sh 3.4.1+git20201022.a0d3415c-1/po/misc/replace_my_trad.sh
--- 3.4.1-6/po/misc/replace_my_trad.sh	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/po/misc/replace_my_trad.sh	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,110 @@
+#!/bin/sh
+
+# on cherche le fichier contenant le string
+COUNT=0
+if [ "$1" = "" ]; then exit; fi
+if [ "$2" = "" ]; then exit; fi
+if [ "$2" = "$1" ]; then exit; fi
+PH1=`echo $1 | sed 's/\\\n/\\\\\\\n/g' | sed 's/\\%/%/g'`
+PH2=`echo $2 | sed 's/\\\n/\\\\\\\n/g' | sed 's/\\%/%/g'`
+PG_check=`pwd | grep -c "plug-ins"` # 0 = core
+if test $PG_check -eq 0; then 
+	FILES_MODIF=`grep -s -r "$PH1" ../src/ -l | grep -v Makefile | grep -v config | grep -v ".bzr" | grep -v "deps" | grep -v "libs" | grep -v depcomp | grep -v "en_temp" | grep -v "sub$" | grep -v "log$" | grep -v "status" | grep -v copyright | grep -v "pc$" | grep -v ChangeLog | grep -v docum | grep -v INSTALL | grep -v "install" | grep -v intltool | grep -v missing | grep -v stamp | grep -v autom4te | grep -v "~$"`
+else
+	FILES_MODIF=`grep -s -r "$PH1" ../*/src/ -l | grep -v Makefile | grep -v config | grep -v ".bzr" | grep -v "deps" | grep -v "libs" | grep -v depcomp | grep -v "en_temp" | grep -v "sub$" | grep -v "log$" | grep -v "status" | grep -v copyright | grep -v "pc$" | grep -v ChangeLog | grep -v docum | grep -v INSTALL | grep -v "install" | grep -v intltool | grep -v missing | grep -v stamp | grep -v autom4te | grep -v "~$"`
+fi
+# double checkcheck
+if [ "$FILES_MODIF" != "" ]; then
+	COUNT=1
+	for i in $FILES_MODIF; do
+		# les .c et .h
+		if test `echo $i | grep -c "\.c$"` -ge 1 -o `echo $i | grep -c "\.h$"` -ge 1; then
+			if test `grep "$PH1" $i | grep -c "_("` -ge 1; then
+				sed -i "s/_(\"$PH1\"/_(\"$PH2\"/g" "$i"
+				if test $? -ge 1; then
+					echo "Phrase <$PH1>, donne une erreur ($i)" >> transfert_translations_log_errors_2.txt
+				fi
+			fi
+		## les autres
+		#else
+		#	sed -i "s/$PH1/$PH2/g" "$i"
+		fi
+	done
+fi
+
+# CONF : retours à la ligne avec des '\n# '
+#ph1=`echo $1 | sed 's/\\\n/\n#/g' | sed 's/\\%/%/g'`
+#ph2=`echo $2 | sed 's/\\\n/\n#/g' | sed 's/\\%/%/g'`
+ph1=`echo $1 | sed 's/\\\n/\\\\\\\n#/g' | sed 's/\\%/%/g'`
+ph2=`echo $2 | sed 's/\\\n/\\\\\\\n#/g' | sed 's/\\%/%/g'`
+if test $PG_check -eq 0; then 
+	DATA_MODIF=`find ../data/ -name "*conf*" -type f -print | grep -v "\.sh$"`
+else
+	DATA_MODIF=`ls ../*/data/*.conf.in`
+fi
+if [ "$DATA_MODIF" != "" ]; then
+	COUNT=1
+	for i in $DATA_MODIF; do
+		sed -i ':z;N;s/\n#/\\n#/;bz' "$i" # => tout sur une ligne
+		# sed -i "s/$ph1/$ph2/g" "$i"
+		sed -i "s/] $ph1/] $ph2/g" "$i"
+		sed -i "s/\[$ph1/\[$ph2/g" "$i"
+		sed -i "s/{$ph1/{$ph2/g" "$i"
+		sed -i "s/+ $ph1/+ $ph2/g" "$i"
+		sed -i "s/- $ph1/- $ph2/g" "$i"
+		sed -i "s/> $ph1/> $ph2/g" "$i"
+		sed -i "s/;$ph1;/;$ph2;/g" "$i"
+		sed -i "s/;$ph1]/;$ph2]/g" "$i"
+		sed -i "s/#b $ph1/#b $ph2/g" "$i"
+		sed -i "s/#B $ph1/#B $ph2/g" "$i"
+		sed -i "s/#c $ph1/#c $ph2/g" "$i"
+		sed -i "s/#C $ph1/#C $ph2/g" "$i"
+		sed -i "s/#k $ph1/#k $ph2/g" "$i"
+		sed -i "s/#s $ph1/#s $ph2/g" "$i"
+		sed -i "s/#s99 $ph1/#s99 $ph2/g" "$i"
+		sed -i "s/#S $ph1/#S $ph2/g" "$i"
+		sed -i "s/#d $ph1/#d $ph2/g" "$i"
+		sed -i "s/#D $ph1/#D $ph2/g" "$i"
+		sed -i "s/#D99 $ph1/#D99 $ph2/g" "$i"
+		sed -i "s/#K $ph1/#K $ph2/g" "$i"
+		sed -i "s/#_ $ph1/#_ $ph2/g" "$i"
+		sed -i "s/#u $ph1/#u $ph2/g" "$i"
+		sed -i "s/#U $ph1/#U $ph2/g" "$i"
+		sed -i "s/#a $ph1/#a $ph2/g" "$i"
+		sed -i "s/#p $ph1/#p $ph2/g" "$i"
+		if test $? -ge 1;then
+			echo "Phrase Le fichier /opt/cairo-dock_bzr/cairo-dock-core/po/testttt a été modifié sur le disque.<$ph1>, donne une erreur ($i)" >> transfert_translations_log_errors_2.txt
+		fi
+		sed -i 's/\\n#/\n#/g' "$i" # => on remet comme avant
+	done
+fi
+
+# ChangeLog.txt : retours à la ligne comme les .c/.h
+if [ `pwd | grep -c core` -ge 1 ]; then
+	if [ `grep -c "$PH1" ../data/ChangeLog.txt` -ge 1 ];then
+		COUNT=1
+		sed -i "s/ = $PH1/ = $PH2/g" "../data/ChangeLog.txt"
+		if test $? -ge 1; then
+			echo "Phrase <$PH1>, donne une erreur (CL)" >> transfert_translations_log_errors_2.txt
+		fi
+	fi
+fi
+
+if test $COUNT -eq 0; then
+	echo "Erreur pour <$PH1>" >> transfert_translations_log_error.txt
+fi
+
+# obligatoirement dans les po/pot : retours à la ligne comme les .c/.h
+#Ph1=`echo $1 | sed ':z;N;s/\n/\\n\"\n\"/;bz' | sed 's/\\%/%/g'`
+#Ph2=`echo $2 | sed ':z;N;s/\n/\\n\"\n\"/;bz' | sed 's/\\%/%/g'`
+# pas de g => seulement la 1ere occurence
+for i in `ls *.po`; do
+	sed -i "s/\"$PH1\"/\"$PH2\"/" "$i"
+	if test $? -ge 1; then
+		echo "Phrase <$PH1>, donne une erreur ($i)" >> transfert_translations_log_errors_2.txt
+	fi
+done
+sed -i "s/\"$PH1\"/\"$PH2\"/" "cairo-dock.pot"
+if [ $? -ge 1 ]; then
+	echo "Phrase <$PH1>, donne une erreur (pot)" >> transfert_translations_log_errors_2.txt
+fi
diff -pruN 3.4.1-6/po/misc/transfert_translations.sh 3.4.1+git20201022.a0d3415c-1/po/misc/transfert_translations.sh
--- 3.4.1-6/po/misc/transfert_translations.sh	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/po/misc/transfert_translations.sh	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,58 @@
+#!/bin/sh
+
+tail -n +18 en_GB.po | grep -v \# > en_temp1 # on vire les lignes et commentaires inutiles
+sed -i '/^[<space><tab>]*$/d' en_temp1 # lignes vides
+tr -d "\n" <en_temp1 >en_temp # on vire tous les \n
+sed -i 's/""//g' en_temp # on vire les ""
+sed -i 's/msgid/\n/g' en_temp # on vire ce qui est hors des "(...)"
+sed -i 's/msgstr//g' en_temp
+sed -i 's/  / /g' en_temp # les doubles espaces
+sed -i 's/^ //g' en_temp # les espaces au début
+sed -i 's/\%/\\\%/g' en_temp # les %
+sed -i 's/&/\\&/g' en_temp # les &
+sed -i 's/\//\\\//g' en_temp # les /
+sed -i 's/\\/\\\\/g' en_temp # les \
+sed -i 's/\*/\\\*/g' en_temp # les *
+# sed -i 's/\:/\\\:/g' en_temp # les :
+sed -i "s/'/\\'/g" en_temp # les '
+sed -i '/^[<space><tab>]*$/d' en_temp # lignes vides
+
+# les .po/.pot
+po_pot=`ls *.po`
+po_pot=`echo "cairo-dock.pot $po_pot"`
+for i in $po_pot; do
+	echo $i
+	sed -i ':z;N;s/ ""\n"/ "/;bz' $i # on vire tous les \n => msgid ""\n"longue ph..."
+	sed -i ':z;N;s/ "\n"/ /;bz' $i # on vire toutes les phrases coupées
+	sed -i ':z;N;s/\\n"\n"/\\n/;bz' $i # on veut une seule ligne => \\n"\n" -> \\n
+	sed -i ':z;N;s/ ""/ /;bz' $i # on vire les "" isolés
+	sed -i 's/""//g' $i # on vire les ""
+	sed -i ':z;N;s/msgid \n/msgid ""\n/;bz' $i # les msgid vides
+	sed -i ':z;N;s/msgstr \n/msgstr ""\n/;bz' $i # les msgstr vides
+done
+
+# scripte pour remplacer les phrases mauvaises ($1) par les bonnes ($2) sans modifier d'autres fichiers
+## => replace_my_trad.sh
+
+
+# le fichier est lit ligne par ligne et les arguments sont envoyés dans le script ci-dessus.
+#total_ph=`wc -l en_temp`
+while [ "`head -n 1 'en_temp'`" != "" ];do
+	head -n 1 en_temp | xargs sh replace_my_trad.sh
+	tail -n+2 en_temp > en_temp0
+	mv en_temp0 en_temp
+	wc -l en_temp
+done
+
+rm en_temp en_temp1
+#find . -name "*.*" -type f -print | grep -v bzr | xargs sed -i 's/cairo-dock.org/glx-dock.org/g'
+
+for i in `ls *.po`; do
+	msguniq $i > "temp"
+	mv "temp" $i
+done
+# 2 fois pour les erreurs
+for i in `ls *.po`; do msguniq $i > "temp"; mv "temp" $i; done
+
+##### Prob #####
+#sed -e 'N;s/{$ph1/AAAAAAAAAAAA/P;D; # => n'accepte que 2 lignes :/
diff -pruN 3.4.1-6/po/pl.po 3.4.1+git20201022.a0d3415c-1/po/pl.po
--- 3.4.1-6/po/pl.po	2015-02-19 16:12:48.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/po/pl.po	2020-10-21 15:04:44.000000000 +0000
@@ -8,14 +8,14 @@ msgstr ""
 "Project-Id-Version: cairo-dock-plug-ins\n"
 "Report-Msgid-Bugs-To: fabounet@glx-dock.org\n"
 "POT-Creation-Date: 2014-10-19 00:22+0000\n"
-"PO-Revision-Date: 2014-11-16 14:55+0000\n"
+"PO-Revision-Date: 2015-12-23 19:14+0000\n"
 "Last-Translator: Piotr Strębski <strebski@o2.pl>\n"
 "Language-Team: Polish <pl@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-11-17 05:39+0000\n"
-"X-Generator: Launchpad (build 17241)\n"
+"X-Launchpad-Export-Date: 2015-12-24 05:14+0000\n"
+"X-Generator: Launchpad (build 17865)\n"
 "Language: pl\n"
 
 #: ../Animated-icons/src/applet-blink.c:77 ../Animated-icons/data/messages:11
@@ -210,12 +210,12 @@ msgstr ""
 
 #: ../Clipper/src/applet-notifications.c:143
 msgid "No items yet."
-msgstr ""
+msgstr "Brak elementów."
 
 #: ../Composite-Manager/src/applet-composite-manager.c:430
 #: ../Composite-Manager/src/applet-composite-manager.c:445
 msgid "No compositor is available."
-msgstr ""
+msgstr "Brak kompozytora."
 
 #: ../Composite-Manager/src/applet-composite-manager.c:453
 #: ../Composite-Manager/src/applet-composite-manager.c:468
@@ -259,7 +259,7 @@ msgstr ""
 #: ../Composite-Manager/src/applet-notifications.c:120
 #: ../Composite-Manager/data/messages:125
 msgid "Edit Window-Manager settings"
-msgstr ""
+msgstr "Edycja ustawień menedżera okien"
 
 #: ../Composite-Manager/src/applet-notifications.c:120
 #: ../Composite-Manager/src/applet-notifications.c:127
diff -pruN 3.4.1-6/po/ru.po 3.4.1+git20201022.a0d3415c-1/po/ru.po
--- 3.4.1-6/po/ru.po	2015-02-19 16:12:48.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/po/ru.po	2020-10-21 15:04:44.000000000 +0000
@@ -8,14 +8,14 @@ msgstr ""
 "Project-Id-Version: PACKAGE VERSION\n"
 "Report-Msgid-Bugs-To: fabounet@glx-dock.org\n"
 "POT-Creation-Date: 2014-10-19 00:22+0000\n"
-"PO-Revision-Date: 2014-08-18 21:20+0000\n"
-"Last-Translator: Matthieu Baerts <matttbe@gmail.com>\n"
+"PO-Revision-Date: 2015-08-07 12:08+0000\n"
+"Last-Translator: Odessa Soul <duha@ukr.net>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-10-19 06:35+0000\n"
-"X-Generator: Launchpad (build 17196)\n"
+"X-Launchpad-Export-Date: 2015-08-08 05:59+0000\n"
+"X-Generator: Launchpad (build 17656)\n"
 "Language: \n"
 
 #: ../Cairo-Penguin/src/applet-init.c:33
@@ -652,7 +652,7 @@ msgstr ""
 #: ../Scooby-Do/src/applet-backend-files.c:395
 #: ../Screenshot/src/applet-screenshot.c:424
 msgid "Cancel"
-msgstr ""
+msgstr "Отменить"
 
 #: ../Folders/src/applet-notifications.c:301
 #, c-format
diff -pruN 3.4.1-6/po/sv.po 3.4.1+git20201022.a0d3415c-1/po/sv.po
--- 3.4.1-6/po/sv.po	2015-02-19 16:12:48.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/po/sv.po	2020-10-21 15:04:44.000000000 +0000
@@ -8,17 +8,15 @@ msgstr ""
 "Project-Id-Version: 1.0.0\n"
 "Report-Msgid-Bugs-To: fabounet@glx-dock.org\n"
 "POT-Creation-Date: 2014-10-19 00:22+0000\n"
-"PO-Revision-Date: 2014-08-18 21:21+0000\n"
-"Last-Translator: Matthieu Baerts <matttbe@gmail.com>\n"
+"PO-Revision-Date: 2016-01-30 22:07+0000\n"
+"Last-Translator: Påvel Nicklasson <Unknown>\n"
 "Language-Team: Cairo-Dock\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-10-19 06:36+0000\n"
-"X-Generator: Launchpad (build 17196)\n"
-"X-Poedit-Country: SWEDEN\n"
+"X-Launchpad-Export-Date: 2016-01-31 05:44+0000\n"
+"X-Generator: Launchpad (build 17908)\n"
 "Language: sv\n"
-"X-Poedit-Language: Swedish\n"
 
 #: ../Animated-icons/src/applet-blink.c:77 ../Animated-icons/data/messages:11
 #: ../Animated-icons/data/messages:31 ../Animated-icons/data/messages:55
@@ -36,7 +34,7 @@ msgstr "Studsa"
 #: ../Animated-icons/data/messages:41 ../Animated-icons/data/messages:65
 #: ../Animated-icons/data/messages:181
 msgid "Busy"
-msgstr ""
+msgstr "Upptagen"
 
 #: ../Animated-icons/src/applet-init.c:39
 msgid "Animated icons"
@@ -45,7 +43,8 @@ msgstr "Animerade ikoner"
 #: ../Animated-icons/src/applet-init.c:42
 msgid "This plug-in provides many different animations for your icons."
 msgstr ""
-"Detta plugin tillhandahåller många olika animeringar till dina ikoner."
+"Detta insticksprogram tillhandahåller många olika animeringar för dina "
+"ikoner."
 
 #: ../Animated-icons/src/applet-pulse.c:106 ../Animated-icons/data/messages:13
 #: ../Animated-icons/data/messages:33 ../Animated-icons/data/messages:57
@@ -63,7 +62,7 @@ msgstr "Rotera"
 #: ../Animated-icons/data/messages:39 ../Animated-icons/data/messages:63
 #: ../Animated-icons/data/messages:87 ../Animated-icons/data/messages:95
 msgid "Spot"
-msgstr "Spot"
+msgstr "Strålkastare"
 
 #: ../Animated-icons/src/applet-wave.c:287 ../Animated-icons/data/messages:17
 #: ../Animated-icons/data/messages:37 ../Animated-icons/data/messages:61
@@ -85,11 +84,11 @@ msgid ""
 "Tux images are taken from Pingus, some other characters are available or can "
 "be added easily."
 msgstr ""
-"Lägg till en livfull Pingvin till din docka!\n"
+"Lägg till en livlig Pingvin i din docka!\n"
 "Vänsterklicka för att ändra animering,\n"
 "Mittenklicka för att störa honom ^_^\n"
 "Bilder på tux är tagna från Pingus, några andra karaktärer\n"
-"finns tillgängliga eller kan enkelt bli tillagda."
+"finns tillgängliga eller kan enkelt läggas till."
 
 #: ../Cairo-Penguin/src/applet-init.c:39
 msgid "Cairo-Penguin"
@@ -101,7 +100,7 @@ msgstr "Hallå, här är jag!"
 
 #: ../Cairo-Penguin/src/applet-notifications.c:30
 msgid "Sorry but I'm busy right now."
-msgstr "Tyvärr, jag är upptagen nu."
+msgstr "Tyvärr, jag är upptagen just nu."
 
 #: ../Cairo-Penguin/src/applet-notifications.c:31
 msgid ""
@@ -112,19 +111,19 @@ msgstr ""
 
 #: ../Cairo-Penguin/src/applet-notifications.c:32
 msgid "Your dock is so messy! Let me clean it."
-msgstr "Din docka är en röra! Låt mig städa upp åt dig."
+msgstr "Din docka är så rörig! Låt mig städa den."
 
 #: ../Cairo-Penguin/src/applet-notifications.c:33
 msgid "Admit my superiority on you as a penguin!"
-msgstr "Erkänn att jag är överlägsen dig!"
+msgstr "Erkänn att jag är överlägsen dig som pingvin!"
 
 #: ../Cairo-Penguin/src/applet-notifications.c:34
 msgid "Wait, do you want to kill me?!"
-msgstr "Vänta lite, försöker du döda mig?!"
+msgstr "Vänta, försöker du döda mig?!"
 
 #: ../Cairo-Penguin/src/applet-notifications.c:35
 msgid "Do you know how painful it is to be clicked on??"
-msgstr "Har du en aning om hur ont det gör när du klickar på mig?"
+msgstr "Har du en aning om hur ont det gör att bli klickad på??"
 
 #: ../Cairo-Penguin/src/applet-notifications.c:36
 msgid "It's my dock now, mwahahaha!"
@@ -136,11 +135,11 @@ msgstr "Jag vill bli pirat!"
 
 #: ../Cairo-Penguin/src/applet-notifications.c:38
 msgid "You shall not pass!"
-msgstr "Du får inte passera!"
+msgstr "Du ska inte passera!"
 
 #: ../Cairo-Penguin/src/applet-notifications.c:39
 msgid "I'm your father!"
-msgstr "Jag är din fader!"
+msgstr "Jag är din pappa!"
 
 #: ../Cairo-Penguin/src/applet-notifications.c:40
 msgid ""
@@ -148,11 +147,11 @@ msgid ""
 "- The same thing we do every night, Pinky : try to take over the Dock!"
 msgstr ""
 "- Vad ska vi göra ikväll Cortex?\n"
-"- Samma om varje kväll, Minus. Försöka ta över dockan!"
+"- Samma som varje kväll, Minus. Försöka ta över dockan!"
 
 #: ../Cairo-Penguin/src/applet-notifications.c:41
 msgid "For Aiur!"
-msgstr "För Auir!"
+msgstr "För Aiur!"
 
 #: ../Cairo-Penguin/src/applet-notifications.c:139
 msgid "Wake up"
@@ -160,7 +159,7 @@ msgstr "Vakna"
 
 #: ../Cairo-Penguin/src/applet-notifications.c:143
 msgid "Keep quiet"
-msgstr "Var tyst"
+msgstr "Håll tyst"
 
 #: ../Cairo-Penguin/src/applet-notifications.c:158
 msgid "Start XPenguins"
@@ -185,7 +184,7 @@ msgid ""
 "Drop text on the icon to create persistent items, and middle-clck to recall "
 "them."
 msgstr ""
-"Detta applet håller koll på dina urklipp och markeringar,\n"
+"Denna applet håller koll på dina urklipp och markeringar,\n"
 "så att du kan återkalla dem fort. Det är en kopia av det välkända programmet "
 "Klipper.\n"
 "Det stödjer urklipp och markeringar, förinställda handlingar, och ihållande "
@@ -200,41 +199,41 @@ msgstr "Klippbordshistorik"
 
 #: ../Clipper/src/applet-init.c:87
 msgid "Pop-up the items menu"
-msgstr ""
+msgstr "Visa objektmenyn"
 
 #: ../Clipper/src/applet-notifications.c:33
 msgid "The clipboard history is empty."
-msgstr ""
+msgstr "Urklippshistoriken är tom."
 
 #: ../Clipper/src/applet-notifications.c:89
 msgid "Clear clipboard History"
-msgstr ""
+msgstr "Rensa urklippshistoriken"
 
 #: ../Clipper/src/applet-notifications.c:91
 msgid "Paste all copied items"
-msgstr ""
+msgstr "Klistra in alla kopierade objekt"
 
 #: ../Clipper/src/applet-notifications.c:99
 msgid ""
 "No persistent items.\n"
 "You can add some by drag and dropping some text on the icon."
 msgstr ""
-"Inga ihållande punkter.\n"
-"Du kan lägga till punkter genom att dra och släppa lite text på ikonen."
+"Inga ihållande saker.\n"
+"Du kan lägga till några genom att dra och släppa lite text på ikonen."
 
 #: ../Clipper/src/applet-notifications.c:143
 msgid "No items yet."
-msgstr "Inga urklipp än."
+msgstr "Inga saker än."
 
 #: ../Composite-Manager/src/applet-composite-manager.c:430
 #: ../Composite-Manager/src/applet-composite-manager.c:445
 msgid "No compositor is available."
-msgstr "Ingen sammansatt grafik tillgänglig."
+msgstr "Ingen sammansatt grafik är tillgänglig."
 
 #: ../Composite-Manager/src/applet-composite-manager.c:453
 #: ../Composite-Manager/src/applet-composite-manager.c:468
 msgid "No fallback is available."
-msgstr "Ingen återgångsläge tillgängligt."
+msgstr "Ingen reservläge är tillgängligt."
 
 #: ../Composite-Manager/src/applet-composite-manager.c:508
 #, c-format
@@ -261,21 +260,19 @@ msgid ""
 "You can define in the configuration a Window-Manager that will provide the "
 "composite, and another as a fallback."
 msgstr ""
-"Det här programmet låter dig <b>sätta på eller stänga av sammansatt "
-"grafik</b>.\n"
-"Sammansatt grafik gör det möjligt att ha genomskinlighet på skrivbordet, men "
-"det kan göra datorn långsammare,\n"
-"särskilt när du spelar spel. <b>Klicka</b> på ikonen för att växla "
-"sammansättningen PÅ eller AV. Du kan ange en\n"
-"<b>genväg</b> för den här åtgärden. Programmet låter dig också komma åt en "
-"del åtgärder i fönsterhanteraren,\n"
-"från <b>mittenklick och menyn</b>. Du kan ange i konfigurationen en "
-"fönsterhanterare som kommer tillhandahålla\n"
-"sammansatt grafik, och en annan som återgång."
+"Denna applet låter dig <b>växla den sammansatta grafiken PÅ/AV</b>.\n"
+"Den sammansatta grafiken tillåter genomskinlighet på skrivbordet, men det "
+"kan göra din dator långsammare, speciellt när du spelar spel.\n"
+"<b>Klicka</b> på ikonen för att växla sammansättningen PÅ/AV. Du kan ange "
+"ett <b>kortkommando</b> för åtgärden.\n"
+"Applet låter dig också komma åt en del åtgärder i fönsterhanteraren, från "
+"<b>mittenklick och menyn</b>.\n"
+"Du kan ange i inställningen en fönsterhanterare som tillhandahåller "
+"sammansatt grafik, och en annan som reserv."
 
 #: ../Composite-Manager/src/applet-init.c:52
 msgid "Toggle the composite ON/OFF"
-msgstr ""
+msgstr "Växla sammansättning PÅ/AV"
 
 #: ../Composite-Manager/src/applet-notifications.c:43
 msgid "Toggle composite?"
@@ -355,15 +352,15 @@ msgstr "Visa alla fönster"
 #: ../Composite-Manager/data/messages:135 ../showDesktop/data/messages:105
 #: ../showDesktop/data/messages:119
 msgid "Show the Widget Layer"
-msgstr "Visa komponentlagret"
+msgstr "Visa Widget-lagret"
 
 #: ../Dbus/src/applet-init.c:36
 msgid ""
 "This plug-in lets extern applications interact on the dock.\n"
 "The communication between both sides is based on Dbus"
 msgstr ""
-"Detta plugin låter externa program interagera på dockan.\n"
-"Kommunikationen mellan båda sidorna baseras på Dbus."
+"Detta insticksprogram låter externa program interagera på dockan.\n"
+"Kommunikationen mellan båda sidor baseras på Dbus."
 
 #: ../Dbus/src/interface-applet-signals.c:428
 #: ../Dbus/src/interface-applet-signals.c:459
@@ -379,15 +376,13 @@ msgstr "Modulen har lagts till, men kund
 #, c-format
 msgid ""
 "The applet '%s' has been succefully updated and automatically reloaded"
-msgstr ""
-"Appleten '%s' har blivit framgångsrikt uppdaterat och automatiskt omstartat."
+msgstr "Applet '%s' har uppdaterats och lästs om automatiskt."
 
 #: ../Dbus/src/interface-applet-signals.c:472
 #, c-format
 msgid ""
 "The applet '%s' has been succefully installed and automatically launched"
-msgstr ""
-"Appleten '%s' har blivit framgångsrikt installerat och automatiskt startat."
+msgstr "Applet '%s' har installerats och startats automatiskt."
 
 #: ../Disks/src/applet-disks.c:45 ../Disks/src/applet-disks.c:53
 #: ../Network-Monitor/src/applet-netspeed.c:42
@@ -470,12 +465,12 @@ msgid ""
 " - Find actions : left, middle click, drop and wheel.\n"
 " - Fill menu with actions.\n"
 msgstr ""
-"<b><i>Övervakar diskars hastighet och utrymme</i></b>.\n"
+"<b><i>Övervakar diskhastighet och utrymme</i></b>.\n"
 "\n"
-"Det här programmet visar information om dina diskar. Du kan aktivera båda "
-"alternativen samtidigt, men de gör sig bättre uppdelade på två eller flera "
-"instanser av programmet.\n"
-"Att använda båda i samma instans kan orsaka problem med att "
+"Denna applet visar information om dina diskar. Du kan aktivera båda "
+"alternativen samtidigt, men de gör sig bättre uppdelade på 2 eller flera "
+"instanser av applet.\n"
+"Att använda båda i samma applet kan orsaka problem med att "
 "hastighetsindikatorn inte skalar ner.\n"
 "\n"
 "<b>Diskutrymme</b> : Visa disköverföringshastighet. Upp till 10 partitioner\n"
@@ -523,10 +518,10 @@ msgid ""
 "  - NEED TO BE DETACHED FROM THE DOCK TO WORK !\n"
 "  - Middle-clic to reload values"
 msgstr ""
-"Detta applet låter dig skriva texter och övervaka ditt\n"
+"Denna applet låter dig skriva texter och övervaka ditt\n"
 "system med ett \"text style desklet\".\n"
 "ANVÄNDNING:\n"
-"  - BEHÖVER FRÅNSKILJAS FRÅN DOCKAN FÖR ATT FUNGERA!\n"
+"  - BEHÖVER LOSSAS FRÅN DOCKAN FÖR ATT FUNGERA!\n"
 "  - Mittenklicka för att läsa om värden"
 
 #: ../Doncky/src/applet-notifications.c:210
@@ -535,7 +530,7 @@ msgstr "Det verkar inte vara en giltig X
 
 #: ../Doncky/src/applet-xml.c:311
 msgid "Please wait..."
-msgstr ""
+msgstr "Vänta..."
 
 #: ../Folders/src/applet-init.c:29
 msgid "Folders"
@@ -551,19 +546,18 @@ msgid ""
 " - or just drop a folder into the dock\n"
 "Middle-click on the main icon opens the folder.\n"
 msgstr ""
-"Det här programmet importerar kataloger till Dockan\n"
-"Du kan ha så många instanser av det här programmet som du vill, en för varje "
-"katalog.\n"
-"För att lägga till en katalog i din docka:\n"
-" - aktivera programmet, öppna dess konfigurationspanel, och välj en katalog\n"
-" - eller släpp bara en katalog i dockan\n"
-"Mittenklick på huvudikonen öppnar katalogen.\n"
+"Denna applet importerar mappar inuti Dockan\n"
+"Du kan ha så många instanser av denna applet som du vill, var och en med en "
+"särskild mapp.\n"
+"För att lägga till en mapp i din docka:\n"
+" - aktivera applet, öppna dess inställningspanel, och välj en mapp\n"
+" - eller bara dra-och-släpp en mapp i dockan\n"
+"Mittenklick på huvudikonen öppnar mappen.\n"
 
 #: ../Folders/src/applet-init.c:87 ../Folders/src/applet-init.c:150
 #: ../Folders/src/applet-notifications.c:42
 msgid "Open the configuration of the applet to choose a folder to import."
-msgstr ""
-"Öppna programmets konfiguration för att välja en katalog att importera."
+msgstr "Öppna applets inställning för att välja en katalog att importera."
 
 #: ../Folders/src/applet-notifications.c:54
 msgid "Empty or unreadable folder."
@@ -587,7 +581,7 @@ msgstr "Senaste Förändring"
 
 #: ../Folders/src/applet-notifications.c:159
 msgid "Mime Type"
-msgstr "Mime typ"
+msgstr "Mime-typ"
 
 #: ../Folders/src/applet-notifications.c:169
 msgid "User ID"
@@ -599,7 +593,7 @@ msgstr "Grupp ID"
 
 #: ../Folders/src/applet-notifications.c:179
 msgid "Permissions"
-msgstr ""
+msgstr "Tillstånd"
 
 #: ../Folders/src/applet-notifications.c:179
 msgid "Read"
@@ -647,8 +641,8 @@ msgid ""
 "Warning: could not delete this file.\n"
 "Please check file permissions."
 msgstr ""
-"Varning: kunde inte radera filen.\n"
-"Kontrollera att du har skrivrättigheter för den."
+"Varning: kunde inte ta bort denna fil.\n"
+"Kontrollera att du har skrivrättigheter."
 
 #: ../Folders/src/applet-notifications.c:221
 #, c-format
@@ -657,7 +651,7 @@ msgid ""
 "  (%s)\n"
 "from your hard-disk. Sure ?"
 msgstr ""
-"Du är på väg att radera följande fil:\n"
+"Du håller på att radera denna fil:\n"
 "  (%s)\n"
 "från din hårddisk, Säker på det?"
 
@@ -669,30 +663,30 @@ msgid ""
 "and that the new name does not already exist."
 msgstr ""
 "Varning: kunde inte byta namn på %s.\n"
-"Kontrollera att du har skrivrättigheter för filen\n"
-"och att namnet inte redan existerar."
+"Kontrollera skrivrättigheter\n"
+"och att namnet inte redan finns."
 
 #: ../Folders/src/applet-notifications.c:249
 msgid "Rename to:"
-msgstr "Döpom till:"
+msgstr "Byt namn till:"
 
 #: ../Folders/src/applet-notifications.c:264
 #: ../Scooby-Do/src/applet-backend-files.c:390
 #: ../Screenshot/src/applet-screenshot.c:419
 msgid "Pick up a directory"
-msgstr "Snappa upp en katalog"
+msgstr "Plocka upp en katalog"
 
 #: ../Folders/src/applet-notifications.c:267
 #: ../Scooby-Do/src/applet-backend-files.c:393
 #: ../Screenshot/src/applet-screenshot.c:422
 msgid "Ok"
-msgstr ""
+msgstr "Ok"
 
 #: ../Folders/src/applet-notifications.c:269
 #: ../Scooby-Do/src/applet-backend-files.c:395
 #: ../Screenshot/src/applet-screenshot.c:424
 msgid "Cancel"
-msgstr ""
+msgstr "Avbryt"
 
 #: ../Folders/src/applet-notifications.c:301
 #, c-format
@@ -702,7 +696,7 @@ msgid ""
 "and that the new name does not already exist."
 msgstr ""
 "Varning!:kunde inte skapa: %s.\n"
-"Kontrollera fil-rättigheter \n"
+"Kontrollera filrättigheter \n"
 "och att det nya namnet inte redan finns"
 
 #: ../Folders/src/applet-notifications.c:311
@@ -715,7 +709,7 @@ msgstr "Öppna mappen"
 
 #: ../Folders/src/applet-notifications.c:397
 msgid "Rename this file"
-msgstr "Byt namn på filen"
+msgstr "Byt namn på denna fil"
 
 #: ../Folders/src/applet-notifications.c:398
 msgid "Delete this file"
@@ -735,7 +729,7 @@ msgstr "Öppna med"
 
 #: ../Folders/src/applet-notifications.c:438
 msgid "Properties"
-msgstr "Inställningar"
+msgstr "Egenskaper"
 
 #: ../Folders/src/applet-notifications.c:441
 msgid "Create a new file"
@@ -775,11 +769,11 @@ msgstr "Vill du importera katalogens inn
 
 #: ../GMenu/src/applet-apps.c:114
 msgid "Launch this new application?"
-msgstr ""
+msgstr "Starta detta nya program?"
 
 #: ../GMenu/src/applet-entry.c:456
 msgid "Launch this command"
-msgstr ""
+msgstr "Starta kommandot"
 
 #: ../GMenu/src/applet-init.c:31
 msgid ""
@@ -789,23 +783,23 @@ msgid ""
 "a shortkey for it, like ALT+F2)\n"
 "You can also set up a shortkey to pop up the menu (like ALT+F1)"
 msgstr ""
-"Visar den vanliga Program listan och de tidigare använda filerna.\n"
-"Det är kompatibelt med alla XDG kompatibla menyer (Gnome, XFCE, KDE, ...)\n"
-"Mittenklicka för att öppna en dialog för att snabbt köra ett kommando(du kan "
-"sätta upp en tangentkombination för det, t ex Alt+F2)\n"
-"Du kan också sätta upp en tangentkombination för att visa menyn(t ex Alt+F1)"
+"Visar den vanliga Programmenyn och nyligen använda filer.\n"
+"Den är kompatibelt med alla XDG kompatibla menyer (Gnome, XFCE, KDE, ...)\n"
+"Mittenklicka för att öppna en dialog för att snabbt köra kommandon (du kan "
+"ange ett kortkommando för det, t ex Alt+F2)\n"
+"Du kan också ange ett kortkommando för att visa menyn (som Alt+F1)"
 
 #: ../GMenu/src/applet-init.c:37
 msgid "Applications Menu"
-msgstr "Program-menyn"
+msgstr "Programmeny"
 
 #: ../GMenu/src/applet-init.c:63
 msgid "Show/hide the Applications menu"
-msgstr ""
+msgstr "Visa/dölj Programmenyn"
 
 #: ../GMenu/src/applet-init.c:68
 msgid "Show/hide the quick-launch dialog"
-msgstr ""
+msgstr "Visa/dölj snabbstartsdialogen"
 
 #: ../GMenu/src/applet-menu.c:148 ../GMenu/data/messages:115
 msgid "Logout"
@@ -821,31 +815,31 @@ msgstr "Snabbstart"
 
 #: ../GMenu/src/applet-notifications.c:97
 msgid "Configure menu"
-msgstr "Konfigurera menyn"
+msgstr "Inställningsmeny"
 
 #: ../GMenu/src/applet-notifications.c:102
 msgid "None of these applications seems available:"
-msgstr ""
+msgstr "Inget av dessa program verkar vara tillgängligt:"
 
 #: ../GMenu/src/applet-notifications.c:110
 msgid "Clear recent"
-msgstr "Rensa Tidigare"
+msgstr "Rensa nyligen använda"
 
 #: ../GMenu/src/applet-recent.c:53
 msgid "Recent Documents"
-msgstr "Tidigare använda dokument"
+msgstr "Nyligen använda dokument"
 
 #: ../GMenu/src/applet-recent.c:109
 msgid "Clear the list of the recently used documents?"
-msgstr "Rensa listan över senast använda dokument?"
+msgstr "Rensa listan över nyligen använda dokument?"
 
 #: ../GMenu/src/applet-run-dialog.c:360 ../Scooby-Do/data/messages:113
 msgid "Enter a command to launch:"
-msgstr "Skriv in ett kommando att köra:"
+msgstr "Ange ett kommando att köra:"
 
 #: ../Global-Menu/src/applet-init.c:30
 msgid "Global Menu"
-msgstr ""
+msgstr "Globalmeny"
 
 #: ../Global-Menu/src/applet-init.c:33
 msgid ""
@@ -855,14 +849,18 @@ msgid ""
 "by default.\n"
 "You can bind a shortkey to this action."
 msgstr ""
+"Denna applet låter dig kontrollera det för närvarande aktiva fönstret:\n"
+" stäng, minimera, maximera, och visa programmenyn. För att visa menyn, måste "
+"programmen stödja denna funktion, vilket är fallet som standard i Ubuntu.\n"
+"Du kan binda ett kortkommando till denna åtgärd."
 
 #: ../Global-Menu/src/applet-init.c:112 ../Global-Menu/src/applet-init.c:211
 msgid "Show/hide the current application menu"
-msgstr ""
+msgstr "Visa/dölj den aktiva programmenyn"
 
 #: ../Global-Menu/src/applet-notifications.c:99
 msgid "The application didn't send its menu to us."
-msgstr ""
+msgstr "Programmet skickade inte sin meny till oss."
 
 #: ../Impulse/src/applet-impulse.c:169
 msgid ""
@@ -871,7 +869,7 @@ msgid ""
 "(if any) to forum.glx-dock.org"
 msgstr ""
 "Något är fel med PulseAudio.\n"
-"Kontrollera dess status (installerad? kör? version?) och rapportera felet "
+"Kontrollera dess status (installerat? igång? version?) och rapportera felet "
 "(om så är fallet) på forum.glx-dock.org"
 
 #: ../Impulse/src/applet-init.c:32
@@ -882,13 +880,13 @@ msgid ""
 "It will analyse the signal given by PulseAudio."
 msgstr ""
 "Visste du att din docka kan dansa? :-)\n"
-"Om du klickar på den här ikonen kommer dockan göra det!\n"
+"Om du klickar på den här ikonen, kommer dockan att dansa!\n"
 "Du kommer till och med se en grafisk equalizer i dockan.\n"
-"Den kommer analysera signalen som kommer från PulseAudio."
+"Den kommer att analysera signalen från PulseAudio."
 
 #: ../Indicator-Generic/src/applet-init.c:30
 msgid "Indicator-Generic"
-msgstr ""
+msgstr "Indikator-Allmän"
 
 #: ../Indicator-Generic/src/applet-init.c:33
 msgid ""
@@ -898,6 +896,11 @@ msgid ""
 "automatically hidden.\n"
 "You can also blacklist indicators you don't want to see."
 msgstr ""
+"Detta insticksprogram kan visa alla tillgängliga indikatorer i din docka.\n"
+"Indikatorer ger information om något, och en meny att agera utifrån den:\n"
+" till exempel, en indikator för att kontrollera utskrifter. Inaktiva "
+"indikatorer döljs automatiskt.\n"
+"Du kan också svartlista indikatorer du inte vill se."
 
 #: ../Indicator-Generic/src/applet-notifications.c:34
 #, c-format
@@ -905,6 +908,8 @@ msgid ""
 "This indicator service did not reply.\n"
 "Please check that '%s' is correctly installed and its daemon is running."
 msgstr ""
+"Denna indikatortjänst svarade inte.\n"
+"Kontrollera att '%s' är korrekt installerat och att dess demon körs."
 
 #: ../MeMenu/src/applet-init.c:30
 msgid "Me Menu"
@@ -915,12 +920,12 @@ msgid ""
 "A menu that lets you access quickly to your information, your online status, "
 "your friends."
 msgstr ""
-"En meny som låter dig komma snabbt åt din information, din onlinestatus, "
+"En meny som låter dig snabbt komma åt din information, din onlinestatus, "
 "dina vänner."
 
 #: ../MeMenu/src/applet-notifications.c:31
 msgid "It seems that the Me-Menu is not installed on your system"
-msgstr "Det verkar som om Migmenyn inte är installerad på ditt system"
+msgstr "Det verkar som om Mig-menyn inte är installerad på ditt system"
 
 #: ../Messaging-Menu/src/applet-init.c:34
 msgid "Messaging Menu"
@@ -932,20 +937,26 @@ msgid ""
 "It handles Evolution, Pidgin, Empathy, etc\n"
 "It requires the Messaging service, which is available on Ubuntu by default."
 msgstr ""
+"En meny som underrättar dig om nya meddelanden från e-post eller chatt-"
+"program.\n"
+"Den hanterar Evolution, Pidgin, Empathy, etc+n\n"
+"Den kräver Meddelandetjänsten, som är tillgänglig i Ubuntu som standard."
 
 #: ../Messaging-Menu/src/applet-init.c:106
 msgid "Show/hide the Messaging menu"
-msgstr ""
+msgstr "Visa/dölj Meddelandemenyn"
 
 #: ../Messaging-Menu/src/applet-notifications.c:78
 msgid ""
 "The Messaging service did not reply.\n"
 "Please check that it is correctly installed."
 msgstr ""
+"Meddelartjänsten svarade inte.\n"
+"Kontrollera att den är korrekt installerad."
 
 #: ../Network-Monitor/src/applet-dbus-callbacks.c:69
 msgid "Network connection state changed to inactive."
-msgstr "Nätverkanslutningsstatus ändrades till inaktiv."
+msgstr "Nätverksanslutningsstatus ändrades till inaktiv."
 
 #: ../Network-Monitor/src/applet-dbus-callbacks.c:75
 msgid "Connecting..."
@@ -953,7 +964,7 @@ msgstr "Ansluter..."
 
 #: ../Network-Monitor/src/applet-dbus-callbacks.c:82
 msgid "Network connection is established."
-msgstr "Nätverksanslutning etablerad"
+msgstr "Nätverksanslutning etablerad."
 
 #: ../Network-Monitor/src/applet-dbus-callbacks.c:88
 msgid "Network connection state changed to disconnected."
@@ -965,7 +976,7 @@ msgstr "En kabel har kopplats in"
 
 #: ../Network-Monitor/src/applet-dbus-callbacks.c:150
 msgid "A cable has been unplugged"
-msgstr "En kapel har kopplats från"
+msgstr "En kabel har kopplats från"
 
 #: ../Network-Monitor/src/applet-draw.c:128 ../wifi/src/applet-draw.c:130
 msgid ""
@@ -1022,22 +1033,24 @@ msgid ""
 "Left-click to pop-up some info,Scroll on the icon to switch the display "
 "between net speed and wifi."
 msgstr ""
-"Detta applet låter dig övervaka dina närverksanslutningar.\n"
-"Det kan visa nerladdnings/uppladdnings hastigheterna och signalstyrkan på "
-"det trådlösa nätverket.\n"
-"Vänsterklicka för att visa lite information, scrolla på ikonen för att "
-"skifta mellan hastighet och wifi."
+"Denna applet låter dig övervaka dina nätverksanslutningar.\n"
+"Den kan visa nerladdnings-/uppladdningshastigheter och signalstyrkan på "
+"trådlösa nätverk.\n"
+"Om nätverkshanteraren körs, kan den också låta dig välja aktivt trådlöst "
+"nätverk.\n"
+"Vänsterklicka för att visa lite information, rulla på ikonen för att växla "
+"mellan hastighet och wifi."
 
 #: ../Network-Monitor/src/applet-init.c:41
 msgid "Network Monitor"
-msgstr ""
+msgstr "Nätverksövervakare"
 
 #: ../Network-Monitor/src/applet-netspeed.c:202
 #: ../System-Monitor/src/applet-monitor.c:97
 #: ../System-Monitor/src/applet-top.c:429
 #: ../netspeed/src/applet-netspeed.c:243
 msgid "Loading"
-msgstr "Laddar"
+msgstr "Läser in"
 
 #: ../Network-Monitor/src/applet-notifications.c:81
 #: ../wifi/src/applet-notifications.c:85
@@ -1067,7 +1080,7 @@ msgstr "Aktivera wifi"
 
 #: ../RSSreader/src/applet-init.c:31
 msgid "RSSreader"
-msgstr "RSSläsare"
+msgstr "RSS-läsare"
 
 #: ../RSSreader/src/applet-init.c:34
 msgid ""
@@ -1081,12 +1094,12 @@ msgid ""
 "    or copy it and use \"Paste a new RSS Url\" in the menu.\n"
 "    or edit the Configuration Panel."
 msgstr ""
-"Det här programmet är en RSS-/Atom-flödesläsare.\n"
-"Du kan instansiera den så många gånger du vill.\n"
+"Denna  applet är en RSS-/Atom-flödesläsare.\n"
+"Du kan starta så många instanser du vill.\n"
 "ANVÄNDNING:\n"
 " - Vänsterklick : Visa de fullständiga flödesraderna i en dialogruta.\n"
 " - Mittenklick : Uppdatera flödet.\n"
-" - Rulla med mushjulet på komponenten : Rulla flödesraderna.\n"
+" - Rulla på deskleten : Rulla flödesraderna.\n"
 " - Dra och släpp en giltig URL på ikonen för att använda den,\n"
 "    eller kopiera den och använd \"Klistra in en ny RSS-URL\" i menyn,\n"
 "    eller redigera konfigurationspanelen."
@@ -1102,7 +1115,7 @@ msgstr "Det verkar inte vara en giltig U
 
 #: ../RSSreader/src/applet-notifications.c:124
 msgid "Paste a new RSS Url (drag and drop)"
-msgstr "Klistra in en ny RSS-URL (dra och släpp)"
+msgstr "Klistra in en ny RSS-URL (dra-och-släpp)"
 
 #: ../RSSreader/src/applet-notifications.c:128
 msgid "Open with your web browser"
@@ -1115,7 +1128,7 @@ msgstr "Uppdatera"
 
 #: ../RSSreader/src/applet-rss.c:400
 msgid "Warning: couldn't retrieve data last time we tried."
-msgstr "Varning: Kunde inte hämta data vid senaste försöket."
+msgstr "Varning: Det gick inte att hämta data senast vi försökte."
 
 #: ../RSSreader/src/applet-rss.c:436
 msgid "No URL is defined."
@@ -1158,25 +1171,25 @@ msgid ""
 "Is your connection alive?"
 msgstr ""
 "Ingen data\n"
-"Skrev du in en gilltig RSS feed?\n"
-"Fungerar din internetanslutning"
+"Skrev du in en gilltig RSS-ström?\n"
+"Fungerar din Internetanslutning"
 
 #: ../Recent-Events/src/applet-dialog.c:316
 #: ../Screenshot/src/applet-screenshot.c:319
 #: ../quick-browser/src/applet-menu.c:346
 #: ../stack/src/applet-notifications.c:212
 msgid "Open parent folder"
-msgstr "Öppna toppkatalog"
+msgstr "Öppna överordnad mapp"
 
 #: ../Recent-Events/src/applet-dialog.c:318
 #: ../Screenshot/src/applet-screenshot.c:281
 #: ../quick-browser/src/applet-menu.c:348
 msgid "Copy the location"
-msgstr "Kopiera plats"
+msgstr "Kopiera platsen"
 
 #: ../Recent-Events/src/applet-dialog.c:321
 msgid "Delete this event"
-msgstr "Radera händelsen"
+msgstr "Radera denna händelse"
 
 #: ../Recent-Events/src/applet-dialog.c:405
 msgid "All"
@@ -1184,11 +1197,11 @@ msgstr "Alla"
 
 #: ../Recent-Events/src/applet-dialog.c:406
 msgid "Applications"
-msgstr ""
+msgstr "Program"
 
 #: ../Recent-Events/src/applet-dialog.c:407
 msgid "Documents"
-msgstr ""
+msgstr "Dokument"
 
 #: ../Recent-Events/src/applet-dialog.c:409 ../drop-indicator/data/messages:3
 msgid "Images"
@@ -1200,7 +1213,7 @@ msgstr "Ljud"
 
 #: ../Recent-Events/src/applet-dialog.c:411
 msgid "Videos"
-msgstr ""
+msgstr "Filmer"
 
 #: ../Recent-Events/src/applet-dialog.c:412
 msgid "Web"
@@ -1208,7 +1221,7 @@ msgstr "Webb"
 
 #: ../Recent-Events/src/applet-dialog.c:413
 msgid "Others"
-msgstr ""
+msgstr "Annat"
 
 #: ../Recent-Events/src/applet-dialog.c:414
 msgid "Top Results"
@@ -1226,6 +1239,11 @@ msgid ""
 "quoting the string \"foo is a bar\". You can truncate terms by appending a "
 "*. "
 msgstr ""
+"Standard boolean operatören är OCH. Således kommer frågan foo bar att tolkas "
+"som foo OCH bar. För att utesluta en term från resultatmängden låt den "
+"föregås av ett minustecken - till exempel foo -bar. Frasfrågor kan göras "
+"genom att dubbelcitera strängen \"foo är en bar\". Du kan korta termer genom "
+"att lägga till en *. "
 
 #: ../Recent-Events/src/applet-dialog.c:470
 #: ../Screenshot/src/applet-screenshot.c:479
@@ -1238,11 +1256,11 @@ msgstr "Senast åtkommen"
 
 #: ../Recent-Events/src/applet-dialog.c:522
 msgid "You need to install the Zeitgeist data engine."
-msgstr "Du måste installera datamotorn Zeitgeist."
+msgstr "Du behöver installera datamotorn Zeitgeist."
 
 #: ../Recent-Events/src/applet-dialog.c:570
 msgid "Browse and search in recent events"
-msgstr "Bläddra och sök bland de senaste händelserna"
+msgstr "Bläddra och sök bland senaste händelser"
 
 #: ../Recent-Events/src/applet-init.c:29
 msgid "Recent-Events"
@@ -1250,12 +1268,12 @@ msgstr "Senaste-händelser"
 
 #: ../Recent-Events/src/applet-init.c:58
 msgid "Show/hide the Recent Events"
-msgstr ""
+msgstr "Visa/dölj Senaste händelser"
 
 #: ../Recent-Events/src/applet-notifications.c:74
 #, c-format
 msgid "%d event(s) deleted"
-msgstr "%d händelse(r) raderade"
+msgstr "%d händelse(r) borttagna"
 
 #: ../Recent-Events/src/applet-notifications.c:114
 #: ../Scooby-Do/src/applet-backend-recent.c:213 ../Scooby-Do/data/messages:107
@@ -1264,11 +1282,11 @@ msgstr "Senaste filer"
 
 #: ../Recent-Events/src/applet-notifications.c:187
 msgid "Delete today's events"
-msgstr "Radera dagens händelser"
+msgstr "Ta bort dagens händelser"
 
 #: ../Recent-Events/src/applet-notifications.c:189
 msgid "Delete all events"
-msgstr "Radera alla händelser"
+msgstr "Ta bort alla händelser"
 
 #: ../Remote-Control/src/applet-init.c:32
 msgid ""
@@ -1283,14 +1301,24 @@ msgid ""
 "middle click, and Ctrl+Enter for left click\n"
 "Escape or the same shortkey will cancel."
 msgstr ""
+"Detta insticksprogram låter dig kontrollera din docka med tangentbordet\n"
+"Tryck kortkommandot (som standard Super + Enter) och sedan antingen:\n"
+" - tryck numret på den ikon som du vill aktivera - eller använd pilarna för "
+"att navigera i dockan och underdockor (Ctrl - Page upp/ner för att ändra "
+"till en annan huvuddocka)\n"
+" - eller skriv namnet på startaren och tryck Tab för att automatiskt hoppa "
+"till nästa lämpliga startare\n"
+"Tryck Enter för att klicka på ikonen, Skift+Enter för Skift+klick, Alt+Enter "
+"för mittenklick, och Ctrl+Enter för vänsterklick\n"
+"Escape eller samma genväg avbryter."
 
 #: ../Remote-Control/src/applet-init.c:42
 msgid "Control from keyboard"
-msgstr ""
+msgstr "Kontroll från tangentbord"
 
 #: ../Remote-Control/src/applet-init.c:49
 msgid "Enable/disable the keyboard control of the dock"
-msgstr ""
+msgstr "Aktivera/inaktivera tangentbordskontroll av dockan"
 
 #: ../Scooby-Do/src/applet-backend-command.c:63
 #, c-format
@@ -1378,7 +1406,7 @@ msgstr "Amazon"
 
 #: ../Scooby-Do/src/applet-init.c:73
 msgid "Enable/disable the Finder"
-msgstr ""
+msgstr "Aktivera/inaktivera Programsökaren"
 
 #: ../Scooby-Do/src/applet-listing.c:486
 msgid "(F1) Match case"
@@ -1428,7 +1456,7 @@ msgstr "Söker ..."
 
 #: ../Scooby-Do/src/applet-session.c:70
 msgid "Enter your search"
-msgstr "Skriv in din sökning"
+msgstr "Ange din sökning"
 
 #: ../Screenshot/src/applet-init.c:31
 msgid ""
@@ -1437,26 +1465,30 @@ msgid ""
 "<b>Middle-click</b> gives you more options.\n"
 "You can bind a <b>shortcut</b> to the action."
 msgstr ""
+"En enkel Applet för att snabbt ta skärmdumpar.\n"
+"<b>Klicka</b> för att ta en skärmdump.\n"
+"<b>Mittenklick</b> ger dig fler alternativ.\n"
+"Du kan binda ett <b>kortkommando</b> till åtgärden."
 
 #: ../Screenshot/src/applet-init.c:53
 msgid "Take a screenshot"
-msgstr ""
+msgstr "Ta en skärmdump"
 
 #: ../Screenshot/src/applet-notifications.c:49
 msgid "Screenshot"
-msgstr ""
+msgstr "Skärmdump"
 
 #: ../Screenshot/src/applet-notifications.c:61
 msgid "Screenshot with options"
-msgstr ""
+msgstr "Skärmdump med alternativ"
 
 #: ../Screenshot/src/applet-screenshot.c:164
 msgid "Screenshot from"
-msgstr ""
+msgstr "Skärmdump från"
 
 #: ../Screenshot/src/applet-screenshot.c:333
 msgid "Unable to take a screenshot"
-msgstr ""
+msgstr "Det gick inte att ta en skärmdump"
 
 #: ../Screenshot/src/applet-screenshot.c:450 ../Cairo-Penguin/data/messages:19
 #: ../Clipper/data/messages:137 ../Disks/data/messages:143
@@ -1472,36 +1504,39 @@ msgstr "i sekunder."
 
 #: ../Screenshot/src/applet-screenshot.c:451
 msgid "Delay"
-msgstr ""
+msgstr "Fördröjning"
 
 #: ../Screenshot/src/applet-screenshot.c:469
 msgid "Grab the current window instead of the all screen"
-msgstr ""
+msgstr "Fånga aktivt fönster istället för hela skärmen"
 
 #: ../Screenshot/src/applet-screenshot.c:470
 msgid "Grab the current window"
-msgstr ""
+msgstr "Fånga aktivt fönster"
 
 #: ../Screenshot/src/applet-screenshot.c:478
 #: ../Screenshot/src/applet-screenshot.c:487
 #: ../Status-Notifier/data/messages:11 ../mail/data/messages:107
 #: ../mail/data/messages:111 ../mail/data/messages:127
 msgid "Let empty to use the default one."
-msgstr ""
+msgstr "Lämna tomt för att använda standard."
 
 #: ../Screenshot/src/applet-screenshot.c:488
 msgid "Directory"
-msgstr ""
+msgstr "Katalog"
 
 #: ../Sound-Effects/src/applet-init.c:29
 msgid "Sound Effects"
-msgstr ""
+msgstr "Ljudeffekter"
 
 #: ../Sound-Effects/src/applet-init.c:32
 msgid ""
 "This plug-in add sound effects on various events in the dock:\n"
 " When clicking an icon, when hovering an icon, etc"
 msgstr ""
+"Detta insticksprogram lägger till ljudeffekter vid olika händelser i "
+"dockan:\n"
+" Då du klickar på en ikon, då du svävar med musen över en ikon, etc"
 
 #: ../Status-Notifier/src/applet-init.c:33
 msgid ""
@@ -1511,10 +1546,9 @@ msgid ""
 "doesn't support this feature yet. Please fill a bug report to the devs."
 msgstr ""
 "En <b>notifieringsyta</b> för din docka.\n"
-"Program kan använda den för att visa deras nuvarande tillstånd.\n"
-"Om ett program inte visas däri när det ska är antagligen för att det inte "
-"stöder den här funktionen än. Skicka en felrapport till de ansvariga "
-"utvecklarna."
+"Program kan använda den för att visa deras aktuella status.\n"
+"Om ett program inte visas inuti när det bör, är det antagligen för att det "
+"inte stödjer den här funktionen än. Skicka en felrapport till utvecklarna."
 
 #: ../Status-Notifier/src/applet-init.c:38
 msgid "Notification Area"
@@ -1549,13 +1583,12 @@ msgid ""
 "You can instanciate this applet several times to show different values each "
 "time."
 msgstr ""
-"Det här programmet visar dig CPU-belastningen, RAM-användning, "
+"Denna applet visar dig CPU-belastningen, RAM-användning, "
 "grafikkortstemperatur, osv.\n"
-"Mittenklicka på ikonen för att se lite intressant information.\n"
+"Mittenklicka på ikonen för att se intressant information.\n"
 "Vänsterklicka på ikonen för att se en lista över de mest resursintensiva "
 "programmen.\n"
-"Du kan instansiera det här programmet många gånger för att visa olika värden "
-"i varje instans."
+"Du kan starta flera instanser av applet för att visa olika värden varje gång."
 
 #: ../System-Monitor/src/applet-notifications.c:40
 #: ../System-Monitor/src/applet-notifications.c:84
@@ -1563,7 +1596,7 @@ msgid ""
 "The acquisition of one or more data has failed.\n"
 "You should remove the data that couldn't be fetched."
 msgstr ""
-"Insamlingen av en eller flera data misslyckades.\n"
+"Insamlingen av ett eller flera data misslyckades.\n"
 "Du bör ta bort datan som inte kunde hämtas."
 
 #: ../System-Monitor/src/applet-notifications.c:105
@@ -1600,7 +1633,7 @@ msgstr "Kärnans temperatur"
 #: ../System-Monitor/src/applet-nvidia.c:161
 #, c-format
 msgid "Alert! Graphic Card core temperature has reached %d°C"
-msgstr "Varning! Grafikkortets kärnas temperatur har nått %d°C"
+msgstr "Varning! Grafikkortskärnans temperatur har nått %d°C"
 
 #: ../System-Monitor/src/applet-rame.c:106
 msgid "Gb"
@@ -1655,7 +1688,7 @@ msgstr "Toons"
 
 #: ../Toons/src/applet-init.c:32
 msgid "This applet displays a toon that will look at your mouse."
-msgstr "Det här programmet visar en toon som kommer titta på din muspekare."
+msgstr "Denna  applet visar en toon som kommer titta på din muspekare."
 
 #: ../Xgamma/src/applet-init.c:44
 msgid ""
@@ -1675,15 +1708,15 @@ msgstr ""
 
 #: ../Xgamma/src/applet-init.c:52
 msgid "Screen Luminosity"
-msgstr "Skärmens ljusstyrka"
+msgstr "Skärmljusstyrka"
 
 #: ../Xgamma/src/applet-init.c:64
 msgid "Increase the brightness"
-msgstr ""
+msgstr "Öka ljusstyrkan"
 
 #: ../Xgamma/src/applet-init.c:68
 msgid "Decrease the brightness"
-msgstr ""
+msgstr "Minska ljusstyrkan"
 
 #: ../Xgamma/src/applet-notifications.c:87
 msgid "Set up gamma correction"
@@ -1691,23 +1724,23 @@ msgstr "Ställ in gammakorrigering"
 
 #: ../Xgamma/src/applet-notifications.c:91
 msgid "Apply current luminosity on startup"
-msgstr "Tillämpa aktuell ljusstyrka vid start"
+msgstr "Tillämpa nuvarande ljusstyrka vid start"
 
 #: ../Xgamma/src/applet-xgamma.c:215
 msgid "Gamma :"
-msgstr ""
+msgstr "Gamma :"
 
 #: ../Xgamma/src/applet-xgamma.c:217
 msgid "Red :"
-msgstr ""
+msgstr "Rött :"
 
 #: ../Xgamma/src/applet-xgamma.c:219
 msgid "Green :"
-msgstr ""
+msgstr "Grönt :"
 
 #: ../Xgamma/src/applet-xgamma.c:221
 msgid "Blue :"
-msgstr ""
+msgstr "Blått :"
 
 #: ../Xgamma/src/applet-xgamma.c:247 ../Xgamma/src/applet-xgamma.c:320
 msgid "Set up gamma:"
@@ -1720,28 +1753,28 @@ msgstr "Ljusstyrka"
 #: ../alsaMixer/src/applet-backend-alsamixer.c:71
 #, c-format
 msgid "I couldn't open card '%s'"
-msgstr "Kunde inte öppna kortet '%s'"
+msgstr "Jag kunde inte öppna kort '%s'"
 
 #: ../alsaMixer/src/applet-backend-alsamixer.c:77
 #, c-format
 msgid "Card '%s' opened but I couldn't get any info"
-msgstr "Kortet '%s' är öppet men kan inte hitta någon information"
+msgstr "Kort '%s' är öppnat men jag kunde inte hitta någon information"
 
 #: ../alsaMixer/src/applet-backend-alsamixer.c:86
 msgid "I couldn't open the mixer"
-msgstr "Kunde inte öppna mixern"
+msgstr "Jag kunde inte öppna mixern"
 
 #: ../alsaMixer/src/applet-backend-alsamixer.c:95
 msgid "I couldn't attach the mixer to the card"
-msgstr "Kunde inte ansluta mixern till kortet"
+msgstr "Jag kunde inte ansluta mixern till kortet"
 
 #: ../alsaMixer/src/applet-backend-alsamixer.c:103
 msgid "I couldn't register options"
-msgstr "Kunde inte registrera alternativ"
+msgstr "Jag kunde inte registrera alternativ"
 
 #: ../alsaMixer/src/applet-backend-alsamixer.c:111
 msgid "I couldn't load the mixer"
-msgstr "Kunde inte ladda mixern"
+msgstr "Jag kunde inte läsa in mixern"
 
 #: ../alsaMixer/src/applet-backend-alsamixer.c:319
 msgid "Set up volume:"
@@ -1761,6 +1794,13 @@ msgid ""
 "mixer.\n"
 "The applet can either use the Ubuntu Sound-menu or the Alsa driver."
 msgstr ""
+"Denna applet låter dig kontrollera ljudvolymen från dockan.\n"
+"Rulla upp/ned på ikonen för att öka/minska volymen.\n"
+"Klicka på ikonen för att visa/dölja volymkontrollen (du kan skapa ett "
+"kortkommando för den)\n"
+"Mittenklicka för att ställa in tyst eller icke-tyst, dubbelklicka för att "
+"höja mixerkanaler.\n"
+"Applet kan antingen använda Ubuntus Ljudmeny eller Alsa-drivrutinen."
 
 #: ../alsaMixer/src/applet-init.c:40
 msgid "Sound Control"
@@ -1768,7 +1808,7 @@ msgstr "Ljudkontroll"
 
 #: ../alsaMixer/src/applet-init.c:142
 msgid "Show/hide the Sound menu"
-msgstr ""
+msgstr "Visa/dölj Ljudmenyn"
 
 #: ../alsaMixer/src/applet-notifications.c:80
 msgid "Adjust channels"
@@ -1804,11 +1844,11 @@ msgstr "år"
 
 #: ../clock/src/applet-calendar.c:604 ../clock/src/applet-task-editor.c:155
 msgid "Add a new task"
-msgstr "Lägg till en ny aktivitet"
+msgstr "Lägg till en ny uppgift"
 
 #: ../clock/src/applet-calendar.c:607
 msgid "Edit tasks"
-msgstr ""
+msgstr "Redigera uppgifter"
 
 #: ../clock/src/applet-calendar.c:679
 msgid "Calendar and tasks"
@@ -1824,7 +1864,7 @@ msgstr "Tid då du vill bli förvarnad:"
 
 #: ../clock/src/applet-config.c:36
 msgid "In the form xx:xx. E.g.: 20:35 for 8:35pm"
-msgstr ""
+msgstr "I formen xx:xx. T. ex.: 20:35 för 8:35pm"
 
 #: ../clock/src/applet-config.c:36
 msgid "Never"
@@ -1876,31 +1916,31 @@ msgstr "Månad"
 
 #: ../clock/src/applet-config.c:36
 msgid "Repeat every:"
-msgstr ""
+msgstr "Upprepa varje:"
 
 #: ../clock/src/applet-config.c:36
 msgid "If every month, which day of the month?"
-msgstr ""
+msgstr "Om varje månad, vilken dag i månaden?"
 
 #: ../clock/src/applet-config.c:36
 msgid "Message you want to use to be notified:"
-msgstr ""
+msgstr "Meddelande du vill använda för att bli underrättad:"
 
 #: ../clock/src/applet-config.c:36
 msgid "Tea Time!"
-msgstr ""
+msgstr "Tedags!"
 
 #: ../clock/src/applet-config.c:36
 msgid "Command to launch:"
-msgstr ""
+msgstr "Kommando att köra:"
 
 #: ../clock/src/applet-config.c:36
 msgid "E.g.:"
-msgstr "T.ex.:"
+msgstr "T. ex.:"
 
 #: ../clock/src/applet-config.c:490 ../weather/src/applet-config.c:213
 msgid "Search for your location :"
-msgstr ""
+msgstr "Sök efter din plats :"
 
 #: ../clock/src/applet-init.c:35
 msgid "clock"
@@ -1918,6 +1958,16 @@ msgid ""
 "Left-click to show/hide the calendar, Middle-click to stop a notification,\n"
 "Double-click on a day to edit the tasks for this day."
 msgstr ""
+"Denna applet visar tid, datum och en kalender.\n"
+"Det finns 2 vyer : <b>numerisk</b> och <b>analog</b>.\n"
+" Analogvy är kompatibel med Cairo-Clocks teman, och du kan lossa applet för "
+"att bli en perfekt klon av Cairo-Clock.\n"
+"Den visar en <b>kalender</b> vid vänsterklick, som låter dig <b>hantera "
+"uppgifter</b>.\n"
+"Den stödjer också alarm, och låter dig ställa in tid och datum.\n"
+"Vänsterklicka för att visa/dölja kalendern, mittenklicka för att stoppa en "
+"underrättelse,\n"
+"Dubbelklicka på en dag för att redigera dagens uppgifter."
 
 #: ../clock/src/applet-notifications.c:62
 msgid ""
@@ -1926,6 +1976,10 @@ msgid ""
 "You can add tasks by clicking on the applet to open the calendar, and then "
 "double-clicking on a day."
 msgstr ""
+"Ingen uppgift är planerad idag.\n"
+"\n"
+"Du kan lägga till uppgifter genom att klicka på applet för att öppna "
+"kalendern, och sedan dubbelklicka på en dag."
 
 #: ../clock/src/applet-notifications.c:84
 msgid ""
@@ -1934,14 +1988,18 @@ msgid ""
 "You can add tasks by clicking on the applet to open the calendar, and then "
 "double-clicking on a day."
 msgstr ""
+"Ingen uppgift är planerad för de närmaste 7 dagarna.\n"
+"\n"
+"Du kan lägga till uppgifter genom att klicka på applet för att öppna "
+"kalendern, och sedan dubbelklicka på en dag."
 
 #: ../clock/src/applet-notifications.c:103
 msgid "Show today's tasks"
-msgstr ""
+msgstr "Visa dagens uppgifter"
 
 #: ../clock/src/applet-notifications.c:104
 msgid "Show this week's tasks"
-msgstr ""
+msgstr "Visa denna veckas uppgifter"
 
 #: ../clock/src/applet-notifications.c:109
 msgid "Set up time and date"
@@ -1949,7 +2007,7 @@ msgstr "Justera datum och tid"
 
 #: ../clock/src/applet-task-editor.c:176
 msgid "Delete this task"
-msgstr "Ta bort denna aktivitet"
+msgstr "Ta bort denna uppgift"
 
 #: ../clock/src/applet-task-editor.c:214
 msgid "Don't repeat"
@@ -1973,7 +2031,7 @@ msgstr "varje år"
 
 #: ../clock/src/applet-task-editor.c:408
 msgid "Right-click to add a new task."
-msgstr ""
+msgstr "Högerklicka för att lägga till en ny uppgift."
 
 #: ../clock/src/applet-task-editor.c:414 ../musicPlayer/src/applet-draw.c:168
 #: ../RSSreader/data/messages:133
@@ -1988,19 +2046,19 @@ msgstr "Text"
 
 #: ../clock/src/applet-task-editor.c:428
 msgid "Time"
-msgstr ""
+msgstr "Tid"
 
 #: ../clock/src/applet-task-editor.c:442
 msgid "Freq."
-msgstr ""
+msgstr "Frekvens"
 
 #: ../clock/src/applet-task-editor.c:449
 msgid "Tags"
-msgstr ""
+msgstr "Etiketter"
 
 #: ../clock/src/applet-timer.c:54
 msgid "1mn"
-msgstr "1min"
+msgstr "1 min"
 
 #: ../clock/src/applet-timer.c:59
 msgid "1h"
@@ -2008,36 +2066,36 @@ msgstr "1 timme"
 
 #: ../clock/src/applet-timer.c:87
 msgid "The following task was scheduled at"
-msgstr ""
+msgstr "Följande uppgift var planerad vid"
 
 #: ../clock/src/applet-timer.c:90 ../clock/src/applet-timer.c:453
 #: ../clock/src/applet-timer.c:496
 msgid "Repeat this message every:"
-msgstr ""
+msgstr "Upprepa detta meddelande varje:"
 
 #: ../clock/src/applet-timer.c:174
 msgid "The following task has felt due:"
-msgstr ""
+msgstr "Följande uppgift har misslyckats på grund av:"
 
 #: ../clock/src/applet-timer.c:450
 msgid "It's time for the following task:"
-msgstr ""
+msgstr "Det är dags för följande uppgift:"
 
 #: ../clock/src/applet-timer.c:464
 msgid "This task will begin in 15 minutes:"
-msgstr ""
+msgstr "Denna uppgift kommer att starta om 15 minuter:"
 
 #: ../clock/src/applet-timer.c:493
 msgid "Today is the following anniversary:"
-msgstr ""
+msgstr "Idag är det följande årsdag:"
 
 #: ../clock/src/applet-timer.c:493
 msgid "Tomorrow is the following anniversary:"
-msgstr ""
+msgstr "Imorgon är det följande årsdag:"
 
 #: ../desklet-rendering/src/rendering-desklet-decorations.c:46
 msgid "frame&reflects"
-msgstr ""
+msgstr "ram&och reflektioner"
 
 #: ../desklet-rendering/src/rendering-desklet-decorations.c:55
 msgid "scotch sellotape"
@@ -2049,31 +2107,31 @@ msgstr "tejpad ram"
 
 #: ../desklet-rendering/src/rendering-desklet-decorations.c:73
 msgid "CD box"
-msgstr "CD fodral"
+msgstr "CD-fodral"
 
 #: ../desklet-rendering/src/rendering-desklet-decorations.c:81
 msgid "dark"
-msgstr "dunkel"
+msgstr "mörk"
 
 #: ../desklet-rendering/src/rendering-desklet-decorations.c:89
 msgid "clear"
-msgstr ""
+msgstr "klar"
 
 #: ../desklet-rendering/src/rendering-desklet-decorations.c:97
 msgid "light"
-msgstr ""
+msgstr "ljus"
 
 #: ../desklet-rendering/src/rendering-desklet-decorations.c:105
 msgid "water drop"
-msgstr ""
+msgstr "vattendroppe"
 
 #: ../desklet-rendering/src/rendering-desklet-decorations.c:113
 msgid "water"
-msgstr ""
+msgstr "vatten"
 
 #: ../desklet-rendering/src/rendering-desklet-decorations.c:121
 msgid "futuristic"
-msgstr ""
+msgstr "futuristisk"
 
 #: ../desklet-rendering/src/rendering-desklet-decorations.c:129
 #: ../slider/data/messages:137
@@ -2082,27 +2140,27 @@ msgstr "ingen"
 
 #: ../desklet-rendering/src/rendering-desklet-decorations.c:137
 msgid "board"
-msgstr ""
+msgstr "bräda"
 
 #: ../dialog-rendering/src/applet-decorator-3Dplane.h:26
 msgid "3Dplane"
-msgstr ""
+msgstr "3D-plan"
 
 #: ../dialog-rendering/src/applet-decorator-comics.h:26
 msgid "comics"
-msgstr ""
+msgstr "serie"
 
 #: ../dialog-rendering/src/applet-decorator-curly.h:26
 msgid "curly"
-msgstr ""
+msgstr "lockig"
 
 #: ../dialog-rendering/src/applet-decorator-modern.h:26
 msgid "modern"
-msgstr ""
+msgstr "modern"
 
 #: ../dialog-rendering/src/applet-decorator-tooltip.h:26
 msgid "tooltip"
-msgstr ""
+msgstr "verktygstips"
 
 #: ../dnd2share/src/applet-backend-codepad.c:35
 #: ../dnd2share/src/applet-backend-custom.c:28
@@ -2116,7 +2174,7 @@ msgstr ""
 #: ../dnd2share/src/applet-backend-uppix.c:31
 #: ../dnd2share/src/applet-backend-videobin.c:32
 msgid "Direct Link"
-msgstr ""
+msgstr "Direktlänk"
 
 #: ../dnd2share/src/applet-backend-codepad.c:51
 #: ../dnd2share/src/applet-backend-custom.c:75
@@ -2124,60 +2182,65 @@ msgstr ""
 #: ../dnd2share/src/applet-backend-pastebin-mozilla.c:52
 #: ../dnd2share/src/applet-backend-pastebin.c:45
 msgid "Your text is empty and couldn't be uploaded to this server"
-msgstr ""
+msgstr "Din text är tom och kunde inte laddas upp till denna server"
 
 #: ../dnd2share/src/applet-backend-dropbox.c:63
 msgid "This directory seems not valid:"
-msgstr ""
+msgstr "Denna katalog verkar inte vara giltig:"
 
 #: ../dnd2share/src/applet-backend-imgur.c:33
 msgid "Display Image"
-msgstr ""
+msgstr "Visa bild"
 
 #: ../dnd2share/src/applet-backend-imgur.c:33
 msgid "Large"
-msgstr ""
+msgstr "Stor"
 
 #: ../dnd2share/src/applet-backend-imgur.c:33
 #: ../dock-rendering/data/messages:41
 msgid "Small"
-msgstr ""
+msgstr "Liten"
 
 #: ../dnd2share/src/applet-backend-uppix.c:31
 msgid "Thumbnail"
-msgstr ""
+msgstr "Miniatyrbild"
 
 #: ../dnd2share/src/applet-dnd2share.c:44
 msgid "No text"
-msgstr ""
+msgstr "Ingen text"
 
 #: ../dnd2share/src/applet-dnd2share.c:55
 msgid "Text:"
-msgstr ""
+msgstr "Text:"
 
 #: ../dnd2share/src/applet-dnd2share.c:317
 msgid ""
 "File has been uploaded.\n"
 "Just press CTRL+v to paste its URL anywhere."
 msgstr ""
+"Filen har laddats upp.\n"
+"Tryck bara CTRL+v för att klistra in dess URL någonstans."
 
 #: ../dnd2share/src/applet-dnd2share.c:370
 msgid ""
 "Please wait for the current upload to finish before starting a new one."
 msgstr ""
+"Vänta tills den aktiva uppladdningen slutförts innan du börjar en ny."
 
 #: ../dnd2share/src/applet-dnd2share.c:438
 msgid "This file is not readable."
-msgstr ""
+msgstr "Denna fil går inte att läsa."
 
 #: ../dnd2share/src/applet-dnd2share.c:664
 msgid "Tiny URL"
-msgstr ""
+msgstr "Tiny URL"
 
 #: ../dnd2share/src/applet-dnd2share.h:27
 msgid ""
 "Couldn't upload the file, check that your internet connection is active."
 msgstr ""
+"Det gick inte att ladda upp filen, kontrollera att din Internetanslutning är "
+"aktiv."
 
 #: ../dnd2share/src/applet-dnd2share.h:29
 #, c-format
@@ -2185,6 +2248,8 @@ msgid ""
 "Couldn't upload the file to %s, check that your internet connection is "
 "active."
 msgstr ""
+"Det gick inte att ladda upp filen till %s, kontrollera att din "
+"Internetanslutning är aktiv."
 
 #: ../dnd2share/src/applet-dnd2share.h:32
 #, c-format
@@ -2193,6 +2258,9 @@ msgid ""
 "Check that your internet connection is active and '%s' is correctly "
 "installed and running"
 msgstr ""
+"Det gick inte att ladda upp filen till %s.\n"
+"Kontrollera att din Internetanslutning är aktiv och att '%s' är korrekt "
+"installerat och igång"
 
 #: ../dnd2share/src/applet-init.c:44
 msgid ""
@@ -2210,36 +2278,56 @@ msgid ""
 "copy it into the mouse selection.\n"
 "You'll need to install 'curl' and 'wget' to upload the data."
 msgstr ""
+"Denna applet låter dig enkelt dela filer:\n"
+"Dra-och-släpp en fil på ikonen för att ladda upp den till en av de "
+"tillgängliga värdplatserna.\n"
+"Du kan ladda upp text, bild, film, filer, och till och med aktuella urklipp\n"
+" och du kan välja mellan många platser, som DropBox, Imageshack, pastebin, "
+"etc\n"
+"Den resulterande URL:en lagras automatiskt i urklipp för direktkopiering med "
+"CTRL+v\n"
+"Den kan behålla en historik av dina senaste uppladdningar för att hämta dem "
+"utan registrering på platserna\n"
+"Tryck vänsterklick för att kopiera den senaste URL:en till urklipp, "
+"mittenklicka för att kopiera den till musvalet.\n"
+"Du måste installera \"curl\" och \"wget\" för att ladda upp data."
 
 #: ../dnd2share/src/applet-init.c:54
 msgid "Drop to share"
-msgstr ""
+msgstr "Släpp för att dela"
 
 #: ../dnd2share/src/applet-notifications.c:43
 msgid "Clear the list of the recently uploaded files?"
-msgstr ""
+msgstr "Rensa listan över senast uppladdade filer?"
 
 #: ../dnd2share/src/applet-notifications.c:58
 msgid ""
 "The text has been pasted in the clipboard.\n"
 "You can retrieve it with CTRL+v."
 msgstr ""
+"Texten har klistrats in i urklipp.\n"
+"Du kan hämta den med CTRL+v."
 
 #: ../dnd2share/src/applet-notifications.c:80
 msgid "Sorry, couldn't find the original file nor a preview of it."
 msgstr ""
+"Det gick inte att hitta originalfilen eller en förhandsgranskning av den."
 
 #: ../dnd2share/src/applet-notifications.c:105
 msgid ""
 "The URL has been stored in the clipboard.\n"
 "Just use 'CTRL+v' to paste it anywhere."
 msgstr ""
+"URL:en har lagrats i urklipp.\n"
+"Använd bara \"CTRL+v\" för att klistra in den någonstans."
 
 #: ../dnd2share/src/applet-notifications.c:120
 msgid ""
 "No uploaded file available\n"
 ".Just drag'n drop a file on the icon to upload it"
 msgstr ""
+"Ingen uppladdad fil tillgänglig.\n"
+"Bara dra-och-släpp en fil på ikonen för att ladda upp den"
 
 #: ../dnd2share/src/applet-notifications.c:121
 msgid ""
@@ -2247,50 +2335,57 @@ msgid ""
 "Consider activating the history if you want the applet to remember previous "
 "uploads."
 msgstr ""
+"Ingen uppladdad fil tillgänglig.\n"
+"Överväg att aktivera historiken om du vill att applet ska minnas tidigare "
+"uppladdningar."
 
 #: ../dnd2share/src/applet-notifications.c:138
 msgid ""
 "The current URL has been stored in the clipboard.\n"
 "Just use 'CTRL+v' to paste it anywhere."
 msgstr ""
+"Den aktuella URL:en har lagrats i urklipp.\n"
+"Använd bara \"CTRL+v\" för att klistra in den någonstans."
 
 #: ../dnd2share/src/applet-notifications.c:139
 msgid ""
 "The current URL has been stored into the selection.\n"
 "Just middle-click to paste it anywhere."
 msgstr ""
+"Den aktuella URL:en har lagrats i valet.\n"
+"Bara mittenklicka för att klistra in den någonstans."
 
 #: ../dnd2share/src/applet-notifications.c:398
 msgid "File"
-msgstr ""
+msgstr "Fil"
 
 #: ../dnd2share/src/applet-notifications.c:401
 msgid "Click on the icon to copy the URL into the clipboard."
-msgstr ""
+msgstr "Klicka på ikonen för att kopiera URL:en till urklipp."
 
 #: ../dnd2share/src/applet-notifications.c:413
 msgid "Send the clipboard's content"
-msgstr ""
+msgstr "Skicka urklippsinnehållet"
 
 #: ../dnd2share/src/applet-notifications.c:416
 msgid "History"
-msgstr ""
+msgstr "Historik"
 
 #: ../dnd2share/src/applet-notifications.c:481
 msgid "Get text"
-msgstr ""
+msgstr "Hämta text"
 
 #: ../dnd2share/src/applet-notifications.c:483
 msgid "Remove from history"
-msgstr ""
+msgstr "Ta bort från historik"
 
 #: ../dnd2share/src/applet-notifications.c:486
 msgid "Clear History"
-msgstr ""
+msgstr "Rensa historik"
 
 #: ../dnd2share/src/applet-notifications.c:491
 msgid "Use only a files hosting site"
-msgstr ""
+msgstr "Använd endast en fillagringsplats"
 
 #: ../dock-rendering/src/rendering-init.c:34
 msgid "Caroussel"
@@ -2298,7 +2393,7 @@ msgstr "Karussel"
 
 #: ../dock-rendering/src/rendering-init.c:35
 msgid "3D plane"
-msgstr ""
+msgstr "3D-plan"
 
 #: ../dock-rendering/src/rendering-init.c:36
 #: ../dock-rendering/data/messages:91
@@ -2323,15 +2418,15 @@ msgstr "Kurva"
 #: ../dock-rendering/src/rendering-init.c:41
 #: ../dock-rendering/data/messages:17
 msgid "Panel"
-msgstr ""
+msgstr "Plan"
 
 #: ../drop-indicator/src/applet-init.c:28
 msgid "drop indicator"
-msgstr ""
+msgstr "släppindikator"
 
 #: ../dustbin/src/applet-init.c:30
 msgid "dustbin"
-msgstr ""
+msgstr "papperskorg"
 
 #: ../dustbin/src/applet-init.c:33
 msgid ""
@@ -2340,38 +2435,43 @@ msgid ""
 "icon.\n"
 "Middle-click on the icon will empty the dustbin."
 msgstr ""
+"Denna applet hanterar papperskorgen\n"
+"Du kan kasta filer och avmontera diskar genom att dra-och-släppa dem på "
+"ikonen.\n"
+"Mittenklick på ikonen tömmer papperskorgen."
 
 #: ../dustbin/src/applet-notifications.c:40
 msgid "You're about to delete all files in all dustbins. Sure ?"
-msgstr "Alla papperskorgar kommer att tömmas. Är du säker?"
+msgstr ""
+"Du håller på att ta bort alla filer i alla papperskorgar. Är du säker?"
 
 #: ../dustbin/src/applet-notifications.c:103
 msgid "The trash contains"
-msgstr ""
+msgstr "Papperskorgen innehåller"
 
 #: ../dustbin/src/applet-notifications.c:105
 msgid "files"
-msgstr ""
+msgstr "filer"
 
 #: ../dustbin/src/applet-notifications.c:105
 msgid "elements"
-msgstr ""
+msgstr "element"
 
 #: ../dustbin/src/applet-notifications.c:107
 msgid "Mo"
-msgstr ""
+msgstr "MB"
 
 #: ../dustbin/src/applet-notifications.c:107
 msgid "Ko"
-msgstr ""
+msgstr "KB"
 
 #: ../dustbin/src/applet-notifications.c:126
 msgid "Counting total size and files number..."
-msgstr ""
+msgstr "Beräknar total storlek och filantal..."
 
 #: ../dustbin/src/applet-notifications.c:148
 msgid "Show Trash (click)"
-msgstr ""
+msgstr "Visa papperskorg (klicka)"
 
 #: ../dustbin/src/applet-notifications.c:149
 msgid "Empty Trash"
@@ -2379,7 +2479,7 @@ msgstr "Töm Papperskorg"
 
 #: ../dustbin/src/applet-notifications.c:153
 msgid "Display dustbins information"
-msgstr ""
+msgstr "Visa papperskorgsinformation"
 
 #: ../dustbin/src/applet-notifications.c:163
 #, c-format
@@ -2391,12 +2491,12 @@ msgstr "%s har nu avmonterats"
 #: ../shortcuts/src/applet-notifications.c:82
 #, c-format
 msgid "Failed to unmount %s"
-msgstr ""
+msgstr "Kunde inte avmontera %s"
 
 #: ../dustbin/src/applet-notifications.c:191
 #: ../shortcuts/src/applet-notifications.c:180
 msgid "Unmouting this volume ..."
-msgstr ""
+msgstr "Avmonterar denna volym ..."
 
 #: ../dustbin/src/applet-trashes-manager.c:68
 msgid " trashe(s)"
@@ -2413,60 +2513,63 @@ msgstr "beräknar"
 
 #: ../icon-effect/src/applet-init.c:34
 msgid "icon effects"
-msgstr ""
+msgstr "ikoneffekter"
 
 #: ../icon-effect/src/applet-init.c:37
 msgid "This plugin adds many special effects to your icons."
 msgstr ""
+"Detta insticksprogram lägger till många specialeffekter för dina ikoner."
 
 #: ../icon-effect/src/applet-init.c:101 ../icon-effect/data/messages:7
 #: ../icon-effect/data/messages:23 ../icon-effect/data/messages:41
 #: ../icon-effect/data/messages:57
 msgid "Fire"
-msgstr ""
+msgstr "Eld"
 
 #: ../icon-effect/src/applet-init.c:104 ../icon-effect/data/messages:9
 #: ../icon-effect/data/messages:25 ../icon-effect/data/messages:43
 #: ../icon-effect/data/messages:85
 msgid "Stars"
-msgstr ""
+msgstr "Stjärnor"
 
 #: ../icon-effect/src/applet-init.c:107 ../icon-effect/data/messages:11
 #: ../icon-effect/data/messages:27 ../icon-effect/data/messages:45
 #: ../icon-effect/data/messages:129
 msgid "Rain"
-msgstr ""
+msgstr "Regn"
 
 #: ../icon-effect/src/applet-init.c:110 ../icon-effect/data/messages:13
 #: ../icon-effect/data/messages:29 ../icon-effect/data/messages:47
 #: ../icon-effect/data/messages:107
 msgid "Snow"
-msgstr ""
+msgstr "Snö"
 
 #: ../icon-effect/src/applet-init.c:113 ../icon-effect/data/messages:15
 #: ../icon-effect/data/messages:31 ../icon-effect/data/messages:49
 #: ../icon-effect/data/messages:151
 msgid "Storm"
-msgstr ""
+msgstr "Storm"
 
 #: ../icon-effect/src/applet-init.c:116 ../icon-effect/data/messages:17
 #: ../icon-effect/data/messages:33 ../icon-effect/data/messages:51
 #: ../icon-effect/data/messages:171
 msgid "Firework"
-msgstr ""
+msgstr "Fyrverkeri"
 
 #: ../illusion/src/applet-init.c:30
 msgid "illusion"
-msgstr ""
+msgstr "illusion"
 
 #: ../illusion/src/applet-init.c:33
 msgid ""
 "This plugin provides animations for appearance & disappearance of icons."
 msgstr ""
+"Detta insticksprogram tillhandahåller animeringar för framträdande & "
+"försvinnande av ikoner."
 
 #: ../keyboard-indicator/src/applet-init.c:32
 msgid "keyboard indicator"
-msgstr ""
+msgstr "tangentbordsindikator"
 
 #: ../keyboard-indicator/src/applet-init.c:35
 msgid ""
@@ -2476,14 +2579,19 @@ msgid ""
 "\tScroll up/down to select the previous/next layout\n"
 "\tRight-click gives you access to the list of available layouts."
 msgstr ""
+"Denna applet låter dig kontrollera tangentbordslayouten.\n"
+"\tDen kan också visa aktuellt num och caps lock.\n"
+"\tVänsterklicka för att växla till nästa layout\n"
+"\tRulla upp/ner för att välja föregående/nästa layout\n"
+"Högerklicka ger dig tillgång till listan över tillgängliga layouter."
 
 #: ../keyboard-indicator/src/applet-init.c:101
 msgid "Switch keyboard language"
-msgstr ""
+msgstr "Byt tangentbordsspråk"
 
 #: ../keyboard-indicator/src/applet-notifications.c:78
 msgid "Keyboard preferences"
-msgstr ""
+msgstr "Tangentbordsinställningar"
 
 #: ../logout/src/applet-init.c:32
 msgid ""
@@ -2494,27 +2602,34 @@ msgid ""
 "<b>Click</b> on the icon to pop the menu up.\n"
 "You can bind a <b>shortcut</b> to it, and also to lock the screen."
 msgstr ""
+"Denna applet låter dig hantera aktuell session. Du kan antingen:\n"
+"stänga av, starta om, försätta i vänteläge, viloläge, logga ut, låsa "
+"skärmen, byt till annan användare, eller programmera en automatisk "
+"avstängning\n"
+"Den kommer också att säga till dig om ditt system behöver startas om.\n"
+"<b>Klicka</b> på ikonen för att få fram menyn.\n"
+"Du kan skapa ett <b>kortkommando</b> för den, och även låsa skärmen."
 
 #: ../logout/src/applet-init.c:39 ../logout/src/applet-logout.c:309
 #: ../logout/data/messages:95
 msgid "Log out"
-msgstr ""
+msgstr "Logga ut"
 
 #: ../logout/src/applet-init.c:68
 msgid "Lock the screen"
-msgstr ""
+msgstr "Lås skärmen"
 
 #: ../logout/src/applet-init.c:72
 msgid "Show the log-out menu"
-msgstr ""
+msgstr "Visa utloggningsmenyn"
 
 #: ../logout/src/applet-logout.c:274 ../logout/data/messages:97
 msgid "Shut down"
-msgstr ""
+msgstr "Stäng av"
 
 #: ../logout/src/applet-logout.c:281
 msgid "Restart"
-msgstr ""
+msgstr "Starta om"
 
 #: ../logout/src/applet-logout.c:287
 msgid "Hibernate"
@@ -2522,17 +2637,19 @@ msgstr "Viloläge"
 
 #: ../logout/src/applet-logout.c:288
 msgid "Your computer will not consume any energy."
-msgstr ""
+msgstr "Din dator kommer inte att förbruka någon energi."
 
 #: ../logout/src/applet-logout.c:294
 msgid "Hybrid Sleep"
-msgstr ""
+msgstr "Hybridsömn"
 
 #: ../logout/src/applet-logout.c:295
 msgid ""
 "Your computer will still consume a small amount of energy but after some "
 "time, the computer will suspend to disk and not consume any energy."
 msgstr ""
+"Din dator kommer fortfarande att förbruka lite energi men efter ett tag, "
+"kommer datorn att försättas i viloläge och inte konsumera någon energi."
 
 #: ../logout/src/applet-logout.c:300
 msgid "Suspend"
@@ -2540,216 +2657,228 @@ msgstr "Vänteläge"
 
 #: ../logout/src/applet-logout.c:302
 msgid "Your computer will still consume a small amount of energy."
-msgstr ""
+msgstr "Din dator kommer fortfarande att förbruka lite energi."
 
 #: ../logout/src/applet-logout.c:311
 msgid "Close your session and allow to open a new one."
-msgstr ""
+msgstr "Stäng din session och tillåt att öppna en ny."
 
 #: ../logout/src/applet-logout.c:322
 msgid "Switch user"
-msgstr ""
+msgstr "Byt användare"
 
 #: ../logout/src/applet-logout.c:343
 msgid "Guest session"
-msgstr ""
+msgstr "Gästsession"
 
 #: ../logout/src/applet-logout.c:350 ../logout/data/messages:99
 msgid "Lock screen"
-msgstr ""
+msgstr "Lås skärm"
 
 #: ../logout/src/applet-logout.c:355
 msgid "Program an automatic shut-down"
-msgstr ""
+msgstr "Programmera en  automatisk avstängning"
 
 #: ../logout/src/applet-logout.c:426
 msgid "Logind has returned this error:"
-msgstr ""
+msgstr "Logind har returnerat detta del:"
 
 #: ../logout/src/applet-logout.c:428
 msgid ""
 "Please check that you can do this action\n"
 "(e.g. you can't power the computer off if another session is active)"
 msgstr ""
+"Kontrollera att du kan utföra denna åtgärd\n"
+"(t. ex. du kan inte stänga av datorn om en annan session är aktiv)"
 
 #: ../logout/src/applet-logout.c:493
 #, c-format
 msgid "It will automatically shut-down in %ds"
-msgstr ""
+msgstr "Den kommer att stängas av om %ds"
 
 #: ../logout/src/applet-logout.c:494
 msgid "Shut down the computer?"
-msgstr ""
+msgstr "Stäng av datorn?"
 
 #: ../logout/src/applet-logout.c:499
 msgid ""
 "It seems your system is being updated!\n"
 "Please be sure that you can shut down your computer right now."
 msgstr ""
+"Det verkar som om ditt system håller på att uppdateras!\n"
+"Förvissa dig om att du kan stänga av datorn just nu."
 
 #: ../logout/src/applet-logout.c:574
 msgid "Restart the computer?"
-msgstr ""
+msgstr "Starta om datorn?"
 
 #: ../logout/src/applet-logout.c:627
 msgid "Close the current session?"
-msgstr ""
+msgstr "Stäng nuvarande session?"
 
 #: ../logout/src/applet-notifications.c:103
 msgid "Manage users"
-msgstr ""
+msgstr "Hantera användare"
 
 #: ../logout/src/applet-reboot-required.c:62
 msgid "Please do that at the end of the update."
-msgstr ""
+msgstr "Gör det i slutet av uppdateringen."
 
 #: ../logout/src/applet-timer.c:50
 msgid "Your computer will shut-down in 1 minute."
-msgstr ""
+msgstr "Din dator kommer att stängas av om 1 minut."
 
 #: ../logout/src/applet-timer.c:97
 msgid "Choose in how many minutes your PC will stop:"
-msgstr ""
+msgstr "Välj om hur många minuter din PC kommer sluta:"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Server address:"
-msgstr ""
+msgstr "Serveradress:"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "myHost"
-msgstr ""
+msgstr "myHost"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Username:"
-msgstr ""
+msgstr "Användarnamn:"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Password:"
-msgstr ""
+msgstr "Lösenord:"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "The password will be crypted."
-msgstr ""
+msgstr "Lösenordet kommer att krypteras."
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Port:"
-msgstr ""
+msgstr "Port:"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid ""
 "Enter 0 to use the default port. Default ports are 110 for POP3 or APOP and "
 "995 for POP3S."
 msgstr ""
+"Ange 0 för att använda standardporten. Standardportar är 110 för POP3 eller "
+"APOP och 995 för POP3S."
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid ""
 "Enter 0 to use the default port. Default ports are 143 for IMAP4 and 993 for "
 "IMAP4 over SSL."
 msgstr ""
+"Ange 0 för att använda standardporten. Standardportar är 143 för IMAP4 och "
+"993 för IMAP4 över SSL."
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Use a secure connection (SSL)"
-msgstr ""
+msgstr "Använd en säker anslutning (SSL)"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39 ../RSSreader/data/messages:107
 #: ../netspeed/data/messages:151 ../powermanager/data/messages:159
 #: ../weather/data/messages:117
 msgid "Refresh time:"
-msgstr ""
+msgstr "Uppdateringsintervall:"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39 ../RSSreader/data/messages:105
 #: ../weather/data/messages:115
 msgid "In minutes."
-msgstr ""
+msgstr "I minuter"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Specific mail application"
-msgstr ""
+msgstr "Specifikt e-postprogram"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Leave empty to use the default mail application."
-msgstr ""
+msgstr "Lämna tomt för att använda standard e-postprogrammet."
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Specific icon file when using multiple accounts"
-msgstr ""
+msgstr "Specifik ikonfil då flera konton används"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Directory on server:"
-msgstr ""
+msgstr "Katalog på server:"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Path of mbox file:"
-msgstr ""
+msgstr "Sökväg för mbox-fil:"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Path to Mail directory:"
-msgstr ""
+msgstr "Sökväg till E-post katalog:"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Address of feed:"
-msgstr ""
+msgstr "Flödesadress:"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid "Remove this account"
-msgstr ""
+msgstr "Ta bort detta konto"
 
 #: ../mail/src/cd-mail-applet-accounts.c:39
 msgid ""
 "Don't forget to enable IMAP (or POP) service from settings of your mail "
 "account."
 msgstr ""
+"Göm inte att aktivera IMAP (eller POP) tjänst i ditt e-postkontos "
+"inställningar."
 
 #: ../mail/src/cd-mail-applet-config.c:224
 msgid "Please choose an account type."
-msgstr ""
+msgstr "Välj en kontotyp."
 
 #: ../mail/src/cd-mail-applet-config.c:229
 msgid "New account's name"
-msgstr ""
+msgstr "Nya kontots namn"
 
 #: ../mail/src/cd-mail-applet-config.c:232
 msgid "Please enter a name for this account."
-msgstr ""
+msgstr "Ange ett namn för detta konto"
 
 #: ../mail/src/cd-mail-applet-config.c:242
 msgid ""
 "This account already exists.\n"
 "Please choose another name for the new account."
 msgstr ""
+"Detta konto finns redan.\n"
+"Ange ett annat namn för det nya kontot."
 
 #: ../mail/src/cd-mail-applet-config.c:373
 msgid "Enter a name for this account. You can give it any name you want."
-msgstr ""
+msgstr "Ange ett namn för detta konto. Du kan kalla det vad du vill."
 
 #: ../mail/src/cd-mail-applet-config.c:428
 msgid "Remove Account"
-msgstr ""
+msgstr "Ta bort konto"
 
 #: ../mail/src/cd-mail-applet-etpan.c:237 ../wifi/src/applet-draw.c:145
 msgid "unknown"
-msgstr ""
+msgstr "okänt"
 
 #: ../mail/src/cd-mail-applet-etpan.c:237
 msgid "no subject"
-msgstr ""
+msgstr "inget ämne"
 
 #: ../mail/src/cd-mail-applet-etpan.c:408
 msgid "No unread mail in your mailboxes"
-msgstr ""
+msgstr "Ingen oläst e-post i dina brevlådor"
 
 #: ../mail/src/cd-mail-applet-etpan.c:430
 #, c-format
 msgid "You have %d new mails:"
-msgstr ""
+msgstr "Du har %d nya e-postmeddelanden:"
 
 #: ../mail/src/cd-mail-applet-etpan.c:432
 msgid "You have a new mail:"
-msgstr ""
+msgstr "Du har ett nytt e-postmeddelande:"
 
 #: ../mail/src/cd-mail-applet-init.c:33
 msgid "mail"
-msgstr ""
+msgstr "e-post"
 
 #: ../mail/src/cd-mail-applet-init.c:36
 msgid ""
@@ -2758,6 +2887,10 @@ msgid ""
 "Left-click to launch the prefered mail application,\n"
 "Middle-click to refresh all the mailboxes."
 msgstr ""
+"Denna applet är mycket användbar för att varna dig när du får ny e-post\n"
+"Den kan kontrollera i alla typer av brevlådor (yahoo, gmail, etc)\n"
+"Vänsterklicka för att starta det föredragna e-postprogrammet,\n"
+"Mittenklicka för att uppdatera alla brevlådor."
 
 #: ../mail/src/cd-mail-applet-notifications.c:62
 #, c-format
@@ -2766,54 +2899,60 @@ msgid ""
 "If '%s' is not your usual mail application,\n"
 "you can change it in the configuration panel of this module"
 msgstr ""
+"Ett problem uppstod\n"
+"Om '% s' inte är ditt vanliga e-postprogram,\n"
+"kan du ändra det i denna moduls inställningspanel"
 
 #: ../mail/src/cd-mail-applet-notifications.c:67
 msgid ""
 "No mail application is defined,\n"
 "you can define it in the configuration panel of this module"
 msgstr ""
+"Inget e-postprogram är angivet,\n"
+"du kan ange det i denna moduls inställningspanel"
 
 #: ../mail/src/cd-mail-applet-notifications.c:146
 msgid "Refresh a mail account"
-msgstr ""
+msgstr "Uppdatera ett e-postkonto"
 
 #: ../mail/src/cd-mail-applet-notifications.c:153
 msgid "Refresh all"
-msgstr ""
+msgstr "Uppdatera alla"
 
 #: ../mail/src/cd-mail-applet-notifications.c:160
 #, c-format
 msgid "Refresh %s"
-msgstr ""
+msgstr "Uppdatera %s"
 
 #: ../mail/src/cd-mail-applet-notifications.c:166
 msgid "Mark all emails as read"
-msgstr ""
+msgstr "Märk alla e-postmeddelanden som lästa"
 
 #: ../mail/src/cd-mail-applet-notifications.c:169
 #, c-format
 msgid "Launch %s"
-msgstr ""
+msgstr "Starta %s"
 
 #: ../mail/src/cd-mail-applet-notifications.c:346
 msgid "Mail"
-msgstr ""
+msgstr "E-post"
 
 #: ../motion-blur/src/applet-init.c:28
 msgid "motion blur"
-msgstr ""
+msgstr "Rörelseoskärpa"
 
 #: ../motion-blur/src/applet-init.c:31
 msgid "This plugin adds a motion blur effect to docks."
 msgstr ""
+"Detta insticksprogram lägger till en rörelseoskärpeeffekt till dockor."
 
 #: ../musicPlayer/src/applet-draw.c:59
 msgid "Unknown artist"
-msgstr ""
+msgstr "Okänd artist"
 
 #: ../musicPlayer/src/applet-draw.c:59
 msgid "Unknown title"
-msgstr ""
+msgstr "Okänd titel"
 
 #: ../musicPlayer/src/applet-draw.c:65 ../musicPlayer/src/applet-mpris.c:336
 msgid "Track"
@@ -2821,35 +2960,35 @@ msgstr "Spår"
 
 #: ../musicPlayer/src/applet-draw.c:150
 msgid "Track n°"
-msgstr ""
+msgstr "Spår n°"
 
 #: ../musicPlayer/src/applet-draw.c:155
 msgid "Song n°"
-msgstr ""
+msgstr "Låt n°"
 
 #: ../musicPlayer/src/applet-draw.c:166
 msgid "Artist"
-msgstr ""
+msgstr "Artist"
 
 #: ../musicPlayer/src/applet-draw.c:170
 msgid "Album"
-msgstr ""
+msgstr "Album"
 
 #: ../musicPlayer/src/applet-draw.c:172
 msgid "Length"
-msgstr ""
+msgstr "Längd"
 
 #: ../musicPlayer/src/applet-draw.c:192
 msgid "Current song"
-msgstr ""
+msgstr "Aktuell låt"
 
 #: ../musicPlayer/src/applet-draw.c:198
 msgid "There is no media playing."
-msgstr ""
+msgstr "Ingen media spelas."
 
 #: ../musicPlayer/src/applet-init.c:48
 msgid "musicPlayer"
-msgstr ""
+msgstr "musicPlayer"
 
 #: ../musicPlayer/src/applet-init.c:51
 msgid ""
@@ -2863,6 +3002,16 @@ msgid ""
 " and jpeg image to use as cover.\n"
 "Note: you may have to install or activate the MPRIS plug-in of the player."
 msgstr ""
+"Denna applet låter dig kontrollera valfri musikspelare.\n"
+"Välj först vilken spelare du vill kontrollera.\n"
+"<b>klicka</b> för att visa/dölja spelaren eller pausa,\n"
+"<b>mittenklicka</b> för att pausa eller gå till nästa låt,\n"
+"<b>Rulla upp/ned</b> för att byta låt eller justera volymen.\n"
+"Du kan dra-och-släppa låtar på ikonen för att lägga till dem i kön (beroende "
+"på spelare),\n"
+" och jpeg-bilder att använda som omslag.\n"
+"Observera: du kan behöva installera eller aktivera spelarens MPRIS-"
+"insticksprogram."
 
 #: ../musicPlayer/src/applet-notifications.c:101
 msgid ""
@@ -2870,18 +3019,21 @@ msgid ""
 "If it is running, it is maybe because its version is too old and does not "
 "offer such service."
 msgstr ""
+"Förlåt, jag kunde inte hitta någon spelare.\n"
+"Om den körs, beror det kanske på att versionen är för gammal och inte "
+"erbjuder sådan tjänst."
 
 #: ../musicPlayer/src/applet-notifications.c:193
 msgid "Choose a music player to control"
-msgstr ""
+msgstr "Välj en musikspelare att kontrollera"
 
 #: ../musicPlayer/src/applet-notifications.c:297
 msgid "Find opened player"
-msgstr ""
+msgstr "Hitta en öppna spelare"
 
 #: ../musicPlayer/src/applet-notifications.c:301
 msgid "Choose a player"
-msgstr ""
+msgstr "Välj en spelare"
 
 #: ../musicPlayer/src/applet-notifications.c:307
 msgid "Previous"
@@ -2889,23 +3041,23 @@ msgstr "Föregående"
 
 #: ../musicPlayer/src/applet-notifications.c:307
 msgid "scroll-up"
-msgstr ""
+msgstr "rulla upp"
 
 #: ../musicPlayer/src/applet-notifications.c:313
 msgid "Play/Pause"
-msgstr ""
+msgstr "Spela/Pausa"
 
 #: ../musicPlayer/src/applet-notifications.c:313
 msgid "left-click"
-msgstr ""
+msgstr "vänsterklicka"
 
 #: ../musicPlayer/src/applet-notifications.c:319
 msgid "Next"
-msgstr ""
+msgstr "Nästa"
 
 #: ../musicPlayer/src/applet-notifications.c:319
 msgid "scroll-down"
-msgstr ""
+msgstr "rulla ner"
 
 #: ../musicPlayer/src/applet-notifications.c:324
 msgid "Stop"
@@ -2921,27 +3073,27 @@ msgstr "Visa JumpBox"
 
 #: ../musicPlayer/src/applet-notifications.c:336
 msgid "Shuffle"
-msgstr ""
+msgstr "Blanda"
 
 #: ../musicPlayer/src/applet-notifications.c:344
 msgid "Repeat"
-msgstr ""
+msgstr "Upprepa"
 
 #: ../musicPlayer/src/applet-notifications.c:352
 msgid "Rate this song"
-msgstr ""
+msgstr "Betygssätt denna låt"
 
 #: ../musicPlayer/src/applet-notifications.c:356
 msgid "Show"
-msgstr ""
+msgstr "Visa"
 
 #: ../musicPlayer/src/applet-notifications.c:357
 msgid "Quit"
-msgstr ""
+msgstr "Avsluta"
 
 #: ../netspeed/src/applet-init.c:29
 msgid "netspeed"
-msgstr ""
+msgstr "näthastighet"
 
 #: ../netspeed/src/applet-init.c:32
 msgid ""
@@ -2950,6 +3102,10 @@ msgid ""
 "Left-click on the icon to have the total amount of data transfered\n"
 "Middle-click to (de)activate the network (needs NetworManager)"
 msgstr ""
+"Denna applet visar dig bithastigheten på din Internetanslutning och en del "
+"statistik om den.\n"
+"Vänsterklicka på ikonen för att få den totala mängden överförd data\n"
+"Mittenklicka för att (av)aktivera nätverket (kräver Nätverkshanterare)"
 
 #: ../netspeed/src/applet-notifications.c:36
 msgid "Total amount of data"
@@ -2957,11 +3113,11 @@ msgstr "Total mängd data"
 
 #: ../netspeed/src/applet-notifications.c:37
 msgid "downloaded"
-msgstr "hämtatHämtat:"
+msgstr "nedladdat"
 
 #: ../netspeed/src/applet-notifications.c:38
 msgid "uploaded"
-msgstr "skickatSkickat:"
+msgstr "uppladdat"
 
 #: ../netspeed/src/applet-notifications.c:44
 msgid ""
@@ -2969,6 +3125,9 @@ msgid ""
 "Please be sure that at least one interface is available\n"
 " and that you have the right to monitor it"
 msgstr ""
+"Inget gränssnitt hittades.\n"
+"Förvissa dig om att minst ett gränssnitt är tillgängligt\n"
+" och att du har rätt att övervaka det"
 
 #: ../netspeed/src/applet-notifications.c:48
 #, c-format
@@ -2977,10 +3136,13 @@ msgid ""
 "You may have to set up the interface you wish to monitor.\n"
 "Do you want to do it now?"
 msgstr ""
+"Gränssnitt '%s' verkar inte finnas eller går inte att läsa.\n"
+"Du kan behöva ställa in gränssnittet du vill övervaka.\n"
+"Vill du göra det nu?"
 
 #: ../netspeed/src/applet-notifications.c:105
 msgid "Enable/disable network"
-msgstr ""
+msgstr "Aktivera/inaktivera nätverk"
 
 #: ../netspeed/src/applet-notifications.c:113
 msgid "Re-check interface"
@@ -2988,23 +3150,23 @@ msgstr "Kontrollera gränssnitt igen"
 
 #: ../powermanager/src/powermanager-draw.c:190
 msgid "Battery charged"
-msgstr ""
+msgstr "Batteri laddat"
 
 #: ../powermanager/src/powermanager-draw.c:202
 msgid "h"
-msgstr ""
+msgstr "h"
 
 #: ../powermanager/src/powermanager-draw.c:204
 msgid "mn"
-msgstr ""
+msgstr "min"
 
 #: ../powermanager/src/powermanager-draw.c:213
 msgid "remaining"
-msgstr ""
+msgstr "återstår"
 
 #: ../powermanager/src/powermanager-draw.c:213
 msgid "until charged"
-msgstr ""
+msgstr "tills laddat"
 
 #: ../powermanager/src/powermanager-draw.c:231 ../wifi/src/applet-draw.c:30
 #: ../Clipper/data/messages:97 ../GMenu/data/messages:113
@@ -3015,40 +3177,40 @@ msgstr "Ingen"
 
 #: ../powermanager/src/powermanager-draw.c:266
 msgid "Laptop on Battery."
-msgstr ""
+msgstr "Laptop på batteri."
 
 #: ../powermanager/src/powermanager-draw.c:267
 #: ../powermanager/src/powermanager-draw.c:276
 msgid "Battery charged at:"
-msgstr ""
+msgstr "Batteri laddat vid:"
 
 #: ../powermanager/src/powermanager-draw.c:268
 msgid "Estimated time before empty:"
-msgstr ""
+msgstr "Uppskattad tid tills tomt:"
 
 #: ../powermanager/src/powermanager-draw.c:275
 msgid "Laptop on Charge."
-msgstr ""
+msgstr "Laptop på laddning."
 
 #: ../powermanager/src/powermanager-draw.c:277
 msgid "Estimated time before full:"
-msgstr ""
+msgstr "Uppskattad tid tills fullt:"
 
 #: ../powermanager/src/powermanager-draw.c:284
 msgid "Model:"
-msgstr ""
+msgstr "Modell:"
 
 #: ../powermanager/src/powermanager-draw.c:290
 msgid "Technology:"
-msgstr ""
+msgstr "Teknologi:"
 
 #: ../powermanager/src/powermanager-draw.c:294
 msgid "Maximum capacity:"
-msgstr ""
+msgstr "Maximal kapacitet:"
 
 #: ../powermanager/src/powermanager-draw.c:299
 msgid "No battery found."
-msgstr "Hittade inget batteri."
+msgstr "Inget batteri hittades"
 
 #: ../powermanager/src/powermanager-draw.c:321
 msgid ""
@@ -3060,11 +3222,11 @@ msgstr ""
 
 #: ../powermanager/src/powermanager-draw.c:321
 msgid "Estimated time with charge:"
-msgstr "Beräknad laddningstid:"
+msgstr "Uppskattad laddningstid:"
 
 #: ../powermanager/src/powermanager-draw.c:321
 msgid "Please put your laptop on charge."
-msgstr "Var vänlig ladda ditt batteri."
+msgstr "Ladda upp din laptop."
 
 #: ../powermanager/src/powermanager-draw.c:335
 msgid ""
@@ -3072,11 +3234,11 @@ msgid ""
 "Your battery is now charged"
 msgstr ""
 "Energihanterare.\n"
-"Batteriet är nu uppladdat"
+"Ditt batteri är nu laddat"
 
 #: ../powermanager/src/powermanager-init.c:32
 msgid "PowerManager"
-msgstr ""
+msgstr "Strömhanterare"
 
 #: ../powermanager/src/powermanager-init.c:35
 msgid ""
@@ -3085,18 +3247,23 @@ msgid ""
 "<b>Click</b> on the icon to have useful inforamtion,\n"
 "<b>Right-click</b> on the icon to hibernate or suspend the system."
 msgstr ""
+"Denna applet visar aktuellt tillstånd på ditt <b>laptop-batteri</b>; "
+"laddning, återstående tid, etc\n"
+"<b>Klicka</b> på ikonen för att se användbar information,\n"
+"<b>Högerklicka</b> på ikonen för att försätta systemet i vänte- eller "
+"viloläge."
 
 #: ../powermanager/src/powermanager-menu-functions.c:70
 msgid "Set up power management"
-msgstr "Konfigurera energialternativ"
+msgstr "Ställ in energihantering"
 
 #: ../powermanager/src/powermanager-menu-functions.c:87
 msgid "Power statistics"
-msgstr ""
+msgstr "Energistatistik"
 
 #: ../quick-browser/src/applet-init.c:29
 msgid "Quick Browser"
-msgstr ""
+msgstr "Snabbläddrare"
 
 #: ../quick-browser/src/applet-init.c:32
 msgid ""
@@ -3106,18 +3273,23 @@ msgid ""
 "This applet can be instanciated several times, if you want to browse "
 "different folders."
 msgstr ""
+"Denna applet låter dig bläddra i en mapp och dess undermappar mycket "
+"snabbt.\n"
+"Du kan ställa in ett kortkommando för att få fram menyn.\n"
+"Mittenklick öppnar huvudmappen.\n"
+"Denna applet kan köras i flera instanser, om du vill bläddra i olika mappar."
 
 #: ../quick-browser/src/applet-init.c:64
 msgid "Show/hide the folder menu"
-msgstr ""
+msgstr "Visa/dölj mappmenyn"
 
 #: ../quick-browser/src/applet-menu.c:103
 msgid "Open this folder"
-msgstr ""
+msgstr "Öppna denna mapp"
 
 #: ../quick-browser/src/applet-notifications.c:41
 msgid "Open folder"
-msgstr ""
+msgstr "Öppna mapp"
 
 #: ../shortcuts/src/applet-bookmarks.c:92
 #: ../shortcuts/src/applet-bookmarks.c:100
@@ -3127,77 +3299,77 @@ msgstr "Avmonterad"
 
 #: ../shortcuts/src/applet-bookmarks.c:422
 msgid "Home Folder"
-msgstr ""
+msgstr "Hemmapp"
 
 #: ../shortcuts/src/applet-disk-usage.c:183
 #: ../shortcuts/src/applet-disk-usage.c:212
 msgid "Mount point:"
-msgstr ""
+msgstr "Monteringspunkt:"
 
 #: ../shortcuts/src/applet-disk-usage.c:184
 #: ../shortcuts/src/applet-disk-usage.c:213
 msgid "File system:"
-msgstr ""
+msgstr "Filsystem:"
 
 #: ../shortcuts/src/applet-disk-usage.c:185
 #: ../shortcuts/src/applet-disk-usage.c:214
 msgid "Device:"
-msgstr ""
+msgstr "Enhet:"
 
 #: ../shortcuts/src/applet-disk-usage.c:186
 #: ../shortcuts/src/applet-disk-usage.c:215
 msgid "Mount options:"
-msgstr ""
+msgstr "Monteringsalternativ:"
 
 #: ../shortcuts/src/applet-disk-usage.c:218
 msgid "Backup frequency:"
-msgstr ""
+msgstr "Backupfrekvens:"
 
 #: ../shortcuts/src/applet-disk-usage.c:218
 msgid "days"
-msgstr ""
+msgstr "dagar"
 
 #: ../shortcuts/src/applet-disk-usage.c:241
 #: ../shortcuts/src/applet-disk-usage.c:251
 #: ../shortcuts/src/applet-disk-usage.c:256
 msgid "Name:"
-msgstr ""
+msgstr "Namn:"
 
 #: ../shortcuts/src/applet-disk-usage.c:242
 msgid "Capacity:"
-msgstr ""
+msgstr "Kapacitet:"
 
 #: ../shortcuts/src/applet-disk-usage.c:243
 msgid "Free space:"
-msgstr ""
+msgstr "Tomt utrymme:"
 
 #: ../shortcuts/src/applet-disk-usage.c:251
 msgid "Not mounted"
-msgstr ""
+msgstr "Inte monterad"
 
 #: ../shortcuts/src/applet-disk-usage.c:257 ../RSSreader/data/messages:97
 msgid "URL:"
-msgstr ""
+msgstr "URL:"
 
 #: ../shortcuts/src/applet-drives.c:132 ../shortcuts/src/applet-drives.c:200
 #, c-format
 msgid "%s is now mounted"
-msgstr ""
+msgstr "%s är nu monterad"
 
 #: ../shortcuts/src/applet-drives.c:132
 #: ../shortcuts/src/applet-load-icons.c:137
 #, c-format
 msgid "%s has been connected"
-msgstr ""
+msgstr "%s har anslutits"
 
 #: ../shortcuts/src/applet-drives.c:200
 #, c-format
 msgid "%s is now unmounted"
-msgstr "%s har nu avmonterats"
+msgstr "%s är nu avmonterad"
 
 #: ../shortcuts/src/applet-init.c:32
 msgid "shortcuts"
-msgstr ""
+msgstr "genvägar"
 
 #: ../shortcuts/src/applet-init.c:35
 msgid ""
@@ -3210,86 +3382,97 @@ msgid ""
 "The applet can also display valuable information about your disks, like free "
 "space, type, etc."
 msgstr ""
+"En applet som snabbt låter dig komma åt alla dina kortkommandon.\n"
+"Den kan hantera diskar, nätverkspunkter, och Nautilusbokmärken (även om du "
+"inte kör Nautilus).\n"
+"Dra-och-släpp en mapp på huvudikonen eller underdockan för att lägga till "
+"ett bokmärke.\n"
+"Mittenklicka på huvudikonen för att visa din hemmapp.\n"
+"Mittenklicka på en monteringspunktsikon för att snabbt (av)montera den.\n"
+"Applet kan också visa värdefull information om dina diskar, som ledigt "
+"utrymme, typ, etc."
 
 #: ../shortcuts/src/applet-notifications.c:44
 #: ../shortcuts/src/applet-notifications.c:82
 #, c-format
 msgid "Failed to mount %s"
-msgstr ""
+msgstr "Det gick inte att montera %s"
 
 #: ../shortcuts/src/applet-notifications.c:101
 msgid "Sorry, this applet is not yet available for KDE."
-msgstr ""
+msgstr "Förlåt, denna applet är ännu inte tillgänglig för KDE."
 
 #: ../shortcuts/src/applet-notifications.c:104
 msgid "No disks or bookmarks were found."
-msgstr ""
+msgstr "Inga diskar eller bokmärken hittades."
 
 #: ../shortcuts/src/applet-notifications.c:234
 msgid "Enter a name for this bookmark:"
-msgstr ""
+msgstr "Ange ett namn för detta bokmärke:"
 
 #: ../shortcuts/src/applet-notifications.c:321
 msgid "Open Home directory"
-msgstr ""
+msgstr "Öppna hemkatalog"
 
 #: ../shortcuts/src/applet-notifications.c:329
 msgid "Connect to Server..."
-msgstr ""
+msgstr "Anslut till server..."
 
 #: ../shortcuts/src/applet-notifications.c:333
 msgid "Browse Network"
-msgstr ""
+msgstr "Bläddra i nätverk"
 
 #: ../shortcuts/src/applet-notifications.c:336
 msgid "Browse recent files"
-msgstr ""
+msgstr "Bläddra senaste filer"
 
 #: ../shortcuts/src/applet-notifications.c:339
 msgid "Open Trash"
-msgstr ""
+msgstr "Öppna papperskorgen"
 
 #: ../shortcuts/src/applet-notifications.c:347
 msgid "Rename this bookmark"
-msgstr ""
+msgstr "Byt namn på detta bokmärke"
 
 #: ../shortcuts/src/applet-notifications.c:349
 msgid "Remove this bookmark"
-msgstr "Ta bort bokmärket"
+msgstr "Ta bort detta bokmärke"
 
 #: ../shortcuts/src/applet-notifications.c:358
 msgid "Eject"
-msgstr ""
+msgstr "Mata ut"
 
 #: ../shortcuts/src/applet-notifications.c:366
 msgid "Unmount"
-msgstr ""
+msgstr "Avmontera"
 
 #: ../shortcuts/src/applet-notifications.c:366
 msgid "Mount"
-msgstr ""
+msgstr "Montera"
 
 #: ../shortcuts/src/applet-notifications.c:371
 msgid "Get disk info"
-msgstr ""
+msgstr "Hämta skivinformation"
 
 #: ../shortcuts/src/applet-notifications.c:399
 msgid "Only folders can be bookmarked."
-msgstr ""
+msgstr "Bara mappar kan bokmärkas."
 
 #: ../show-mouse/src/applet-init.c:28
 msgid "show mouse"
-msgstr ""
+msgstr "visa mus"
 
 #: ../show-mouse/src/applet-init.c:31
 msgid ""
 "This plugin draws some animations around the cursor when it's inside a "
 "dock/desklet."
 msgstr ""
+"Detta insticksprogram ritar en del animeringar runt pekaren då den är inuti "
+"en docka/desklet."
 
 #: ../showDesktop/src/applet-init.c:28
 msgid "showDesktop"
-msgstr ""
+msgstr "visaSkrivbord"
 
 #: ../showDesktop/src/applet-init.c:31
 msgid ""
@@ -3301,14 +3484,21 @@ msgid ""
 "Middle-click to show/hide either the desktop, the desklets, the Widget "
 "Layer, or all the desktops at once."
 msgstr ""
+"Denna applet lägger till en ikon för att visa ditt skrivbord.\n"
+" och även : desklets, widget-lagret, eller alla desklets på en gång.\n"
+"Den kan också användas för att snabbt ändra skärmupplösning från "
+"högerklicksmenyn.\n"
+"Vänsterklicka för att visa/dölja skrivbordet,\n"
+"mittenklicka för att visa/dölja antingen skrivbordet, desklets, "
+"widgetlagret, eller alla skrivbord på en gång."
 
 #: ../showDesktop/src/applet-notifications.c:220
 msgid "Change screen resolution"
-msgstr ""
+msgstr "Ändra skärmupplösning"
 
 #: ../slider/src/applet-init.c:29
 msgid "slider"
-msgstr ""
+msgstr "bildspel"
 
 #: ../slider/src/applet-init.c:32
 msgid ""
@@ -3317,10 +3507,14 @@ msgid ""
 "Click to play/pause or to edit the current image.\n"
 "Middle-click to open the images folder."
 msgstr ""
+"Denna applet är ett enkelt bildspel\n"
+" Du behöver bara välja en katalog och en visningseffekt och allt är klart\n"
+"Klicka för att spela/pausa eller redigera nuvarande bild.\n"
+"Mittenklicka för att öppna bildmappen."
 
 #: ../slider/src/applet-notifications.c:68
 msgid "You need to define the images folder first."
-msgstr ""
+msgstr "Du måste bestämma bildmappen först."
 
 #: ../slider/src/applet-notifications.c:220
 msgid "Play"
@@ -3328,25 +3522,25 @@ msgstr "Spela"
 
 #: ../slider/src/applet-notifications.c:220
 msgid "Pause"
-msgstr "Pausa"
+msgstr "Paus"
 
 #: ../slider/src/applet-notifications.c:228
 #: ../slider/src/applet-notifications.c:230
 msgid "Open current image"
-msgstr "Öppna aktuell bild"
+msgstr "Öppna aktiv bild"
 
 #: ../slider/src/applet-notifications.c:270
 #: ../slider/src/applet-notifications.c:272
 msgid "Browse images folder"
-msgstr "Bläddra i bildkatalog"
+msgstr "Bläddra i bildkatalogen"
 
 #: ../slider/src/applet-notifications.c:275
 msgid "Refresh images list"
-msgstr ""
+msgstr "Uppdatera bildlistan"
 
 #: ../stack/src/applet-init.c:31
 msgid "stack"
-msgstr ""
+msgstr "stack"
 
 #: ../stack/src/applet-init.c:34
 msgid ""
@@ -3357,6 +3551,12 @@ msgid ""
 "You can drop any file, or web URL, or even some piece of text\n"
 "You can quickly copy the path/url/text to the clipboard, or open it."
 msgstr ""
+"Denna applet låter dig bygga en stack av filer, precis som Stackapplet i "
+"MacOS X.\n"
+"För att lägga till en fil i dina stackar, behöver du bara dra-och-släppa den "
+"på Stackikonen och det är färdigt.\n"
+"Du kan släppa alla filer, eller nät-URL, eller till och med en kort text\n"
+"Du kan snabbt kopiera sökvägen/URL:en/texten till urklipp, eller öppna den."
 
 #: ../stack/src/applet-notifications.c:54
 msgid ""
@@ -3364,14 +3564,17 @@ msgid ""
 "You can add files, URL, and even a piece of text by dragging them onto the "
 "icon."
 msgstr ""
+"Inga objekt i stacken.\n"
+"Du kan lägga till filer, URL, och till och med en kort text genom att dra "
+"dem till ikonen."
 
 #: ../stack/src/applet-notifications.c:92
 msgid "Clear the stack?"
-msgstr ""
+msgstr "Rensa stacken?"
 
 #: ../stack/src/applet-notifications.c:139
 msgid "Set new name for this item:"
-msgstr "Nytt namn:"
+msgstr "Ange nytt namn för detta objekt:"
 
 #: ../stack/src/applet-notifications.c:202
 msgid "Paste (drag'n'drop)"
@@ -3383,7 +3586,7 @@ msgstr "Töm stacken"
 
 #: ../stack/src/applet-notifications.c:209
 msgid "Open (click)"
-msgstr ""
+msgstr "Öppna (klick)"
 
 #: ../stack/src/applet-notifications.c:214
 #: ../terminal/src/terminal-widget.c:402
@@ -3396,25 +3599,25 @@ msgstr "Klipp ut"
 
 #: ../stack/src/applet-notifications.c:220
 msgid "Rename this item"
-msgstr "Byt namn"
+msgstr "Byt namn på detta objekt"
 
 #: ../stack/src/applet-notifications.c:221
 msgid "Remove this item"
-msgstr "Ta bort"
+msgstr "Ta bort detta objekt"
 
 #: ../stack/src/applet-notifications.c:290
 msgid "The file has been added to the stack."
-msgstr ""
+msgstr "Filen har lagts till i stacken."
 
 #: ../stack/src/applet-notifications.c:291
 msgid "The URL has been added to the stack."
-msgstr ""
+msgstr "URL-en har lagts till i stacken."
 
 #: ../switcher/src/applet-draw.c:600 ../switcher/src/applet-draw.c:607
 #: ../switcher/src/applet-load-icons.c:54
 #: ../switcher/src/applet-notifications.c:411
 msgid "Current"
-msgstr "Aktuell"
+msgstr "Aktiv"
 
 #: ../switcher/src/applet-draw.c:607 ../switcher/src/applet-draw.c:609
 #: ../switcher/src/applet-load-icons.c:60
@@ -3427,7 +3630,7 @@ msgstr "Skrivbord"
 
 #: ../switcher/src/applet-init.c:32
 msgid "switcher"
-msgstr ""
+msgstr "växlare"
 
 #: ../switcher/src/applet-init.c:35
 msgid ""
@@ -3439,37 +3642,46 @@ msgid ""
 " - list all windows on each workspace ((middle-click or in the menu)\n"
 "It has 2 modes : compact (on 1 icon) and expanded (with a sub-dock)."
 msgstr ""
+"Denna applet låter dig interagera med dina arbetsytor :\n"
+" - växla mellan dina arbetsytor (rulla upp/ner med musen),\n"
+" - namnge dem (i inställningar),\n"
+" - snabbt lägga till/ta bort en arbetsyta (i menyn),\n"
+" - visa skrivbordet (mittenklicka eller i menyn),\n"
+" - lista alla fönster på varje arbetsyta (mittenklick eller i menyn)\n"
+"Den har 2 lägen : kompakt (på 1 ikon) och utvidgad (med en underdocka."
 
 #: ../switcher/src/applet-notifications.c:248
 #: ../switcher/src/applet-notifications.c:282
 msgid "Rename this workspace"
-msgstr ""
+msgstr "Byt namn på denna arbetsyta"
 
 #: ../switcher/src/applet-notifications.c:269
 msgid "Add a workspace"
-msgstr "Lägg till skrivbord"
+msgstr "Lägg till ett skrivbord"
 
 #: ../switcher/src/applet-notifications.c:273
 msgid "Remove last workspace"
-msgstr "Ta bort sista skrivbordet"
+msgstr "Ta bort senaste skrivbord"
 
 #: ../switcher/src/applet-notifications.c:289
 msgid "Move current workspace to this workspace"
-msgstr ""
+msgstr "Flytta aktiv arbetsyta till denna arbetsyta"
 
 #: ../switcher/src/applet-notifications.c:294
 msgid ""
 "This will move all windows from the current desktop to the one you clicked "
 "on."
 msgstr ""
+"Detta kommer att flytta alla fönster från aktivt skrivbord till det du "
+"klickar på."
 
 #: ../switcher/src/applet-notifications.c:303
 msgid "Windows List"
-msgstr ""
+msgstr "Fönsterlista"
 
 #: ../switcher/src/applet-notifications.c:308
 msgid "Show the desktop"
-msgstr ""
+msgstr "Visa skrivbordet"
 
 #: ../systray/src/systray-init.c:35
 msgid ""
@@ -3479,14 +3691,19 @@ msgid ""
 "But the best way to use it is to detach it from the dock, and place it "
 "somewhere, above other windows."
 msgstr ""
+"Lägg till en systembricka till din docka.\n"
+"Vänsterklicka för att visa/dölja systembrickan i en dialog (du kan skapa ett "
+"kortkommando för den.)\n"
+"Men det bästa sättet att använda den är att lossa den från dockan, och "
+"placera den någonstans, över alla fönster."
 
 #: ../systray/src/systray-init.c:41
 msgid "Notification Area Old"
-msgstr ""
+msgstr "Gammal notifieringsyta"
 
 #: ../systray/src/systray-init.c:65
 msgid "Show/hide the systray"
-msgstr ""
+msgstr "Visa/dölj systembrickan"
 
 #: ../systray/src/systray-interface.c:74
 msgid ""
@@ -3494,16 +3711,21 @@ msgid ""
 "Since there can only be one systray at once, you should remove it to avoid "
 "any conflict."
 msgstr ""
+"En annan systembricka körs redan (förmodligen på din panel)\n"
+"Eftersom det bara kan finnas en systembricka åt gången, bör du ta bort den "
+"för att undvika konflikt."
 
 #: ../template/src/applet-init.c:29
 msgid "CD_APPLET_NAME"
-msgstr ""
+msgstr "CD_APPLET_NAME"
 
 #: ../template/src/applet-init.c:32
 msgid ""
 "Useful description\n"
 "and manual"
 msgstr ""
+"Användbar beskrivning\n"
+"och manual"
 
 #: ../terminal/src/terminal-callbacks.c:82
 #: ../terminal/src/terminal-widget.c:404
@@ -3512,7 +3734,7 @@ msgstr "Klistra in"
 
 #: ../terminal/src/terminal-init.c:31
 msgid "terminal"
-msgstr ""
+msgstr "terminal"
 
 #: ../terminal/src/terminal-init.c:34
 msgid ""
@@ -3524,10 +3746,19 @@ msgid ""
 "To open a new tab : type 'CTRL+t' or double-click next to the last tab\n"
 "To close a tab : type 'CTRL+w' or middle-click on it."
 msgstr ""
+"Lägg till en terminal till din docka !\n"
+"Vänsterklicka för att visa/dölja terminal (du kan skapa ett kortkommando för "
+"den.)\n"
+"Du kan dra-och-släppa filer eller text och välja en åtgärd.\n"
+"Du kan öppna flera flikar, byta namn på dem, ändra deras färg (högerklicka "
+"på en flik för att interagera med den)\n"
+"För att öppna en ny flik : skriv \"CTRL+t\" eller dubbelklicka bredvid den "
+"sista fliken\n"
+"För att stänga en flik : skriv \"CTRL+w\" eller mittenklicka på den."
 
 #: ../terminal/src/terminal-init.c:59
 msgid "Show/hide the terminal"
-msgstr ""
+msgstr "Visa/dölj terminalen"
 
 #: ../terminal/src/terminal-menu-functions.c:77
 #: ../terminal/src/terminal-widget.c:410
@@ -3536,11 +3767,11 @@ msgstr "Ny flik"
 
 #: ../terminal/src/terminal-menu-functions.c:78
 msgid "Rename current Tab"
-msgstr "Byt namn på flik"
+msgstr "Byt namn på aktiv flik"
 
 #: ../terminal/src/terminal-menu-functions.c:79
 msgid "Close current Tab"
-msgstr "Stäng flik"
+msgstr "Stäng aktiv flik"
 
 #: ../terminal/src/terminal-widget.c:49 ../terminal/data/messages:115
 msgid "Terminal"
@@ -3548,20 +3779,20 @@ msgstr "Terminal"
 
 #: ../terminal/src/terminal-widget.c:177
 msgid "Set title for this tab:"
-msgstr "Titel för flik:"
+msgstr "Ange titel på denna flik:"
 
 #: ../terminal/src/terminal-widget.c:226
 msgid "Select a color"
-msgstr "Välj färg"
+msgstr "Välj en färg"
 
 #: ../terminal/src/terminal-widget.c:364
 #, c-format
 msgid "You can recall the Terminal desklet by typing %s"
-msgstr ""
+msgstr "Du kan återkalla Terminal-deskleten genom att skriva %s"
 
 #: ../terminal/src/terminal-widget.c:412
 msgid "Rename this Tab"
-msgstr "Byt namn"
+msgstr "Byt namnc"
 
 #: ../terminal/src/terminal-widget.c:414
 msgid "Change this Tab's colour"
@@ -3573,19 +3804,19 @@ msgstr "Stäng denna flik"
 
 #: ../tomboy/src/applet-backend-default.c:159
 msgid "Note:"
-msgstr ""
+msgstr "Anteckning:"
 
 #: ../tomboy/src/applet-backend-default.c:207
 msgid "Title:"
-msgstr ""
+msgstr "Titel:"
 
 #: ../tomboy/src/tomboy-draw.c:188
 msgid "Open all"
-msgstr ""
+msgstr "Öppna alla"
 
 #: ../tomboy/src/tomboy-init.c:32
 msgid "Note-Taking"
-msgstr ""
+msgstr "Anteckningar"
 
 #: ../tomboy/src/tomboy-init.c:35
 msgid ""
@@ -3594,14 +3825,18 @@ msgid ""
 "Middle-click to instantly create a new note.\n"
 "You can search inside notes and display their content on the icons."
 msgstr ""
+"Kontrollera dina Gnote- eller Tomboyanteckningar direkt i dockan !\n"
+"Klicka på en anteckning för att öppna den, Escape för att stänga den.\n"
+"Mittenklicka för att skapa en ny anteckning direkt.\n"
+"Du kan söka i anteckningar och visa deras innehåll på ikonerna."
 
 #: ../tomboy/src/tomboy-notifications.c:86
 msgid "Note name : "
-msgstr "Antekningsnamn: "
+msgstr "Anteckningsnamn: "
 
 #: ../tomboy/src/tomboy-notifications.c:113
 msgid "Delete this note?"
-msgstr ""
+msgstr "Ta bort denna anteckning?"
 
 #: ../tomboy/src/tomboy-notifications.c:153
 msgid "Search for:"
@@ -3609,19 +3844,19 @@ msgstr "Sök efter:"
 
 #: ../tomboy/src/tomboy-notifications.c:178
 msgid "Search for tag:"
-msgstr "Sök efter nyckelord:"
+msgstr "Sök efter etikett:"
 
 #: ../tomboy/src/tomboy-notifications.c:217
 msgid "Add a note"
-msgstr "<b>Kompiskommentar</b>: %s"
+msgstr "Lägg till en anteckning"
 
 #: ../tomboy/src/tomboy-notifications.c:223
 msgid "Delete this note"
-msgstr "Ta bort anteckning"
+msgstr "Ta bort denna anteckning"
 
 #: ../tomboy/src/tomboy-notifications.c:226
 msgid "Reload notes"
-msgstr "Ladda om anteckningar"
+msgstr "Läs om anteckningar"
 
 #: ../tomboy/src/tomboy-notifications.c:230
 msgid "Search"
@@ -3629,56 +3864,57 @@ msgstr "Sök"
 
 #: ../tomboy/src/tomboy-notifications.c:231
 msgid "Search for tag"
-msgstr ""
+msgstr "Sök efter etikett"
 
 #: ../tomboy/src/tomboy-notifications.c:233
 msgid "Search for today's note"
-msgstr "Sök efter dagens anteckningar"
+msgstr "Sök efter dagens anteckning"
 
 #: ../tomboy/src/tomboy-notifications.c:234
 msgid "Search for this week's note"
-msgstr "Sök efter denna veckas anteckningar"
+msgstr "Sök efter denna veckas anteckning"
 
 #: ../tomboy/src/tomboy-notifications.c:235
 msgid "Search for next week's note"
-msgstr "Sök efter nästa veckas anteckningar"
+msgstr "Sök efter nästa veckas anteckning"
 
 #: ../tomboy/src/tomboy-notifications.c:245
 msgid "Reset marks"
-msgstr "Återställ markeringar"
+msgstr "Återställ märken"
 
 #: ../tomboy/src/tomboy-notifications.c:277
 msgid "No description"
-msgstr ""
+msgstr "Ingen beskrivning"
 
 #: ../weather/src/applet-config.c:120
 msgid ""
 "I couldn't get the info\n"
 " Is connexion alive ?"
 msgstr ""
-"Kunde inte hämta information\n"
-"Är du ansluten till Internet?"
+"Jag kunde inte hämta informationen\n"
+"Är anslutning aktiv?"
 
 #: ../weather/src/applet-config.c:126
 msgid "Couldn't get the location code (is connection alive?)"
-msgstr ""
+msgstr "Det gick inte att få platskoden (är anslutningen aktiv?)"
 
 #: ../weather/src/applet-config.c:134
 msgid "I couldn't find this location"
-msgstr ""
+msgstr "Jag kunde inte hitta denna plats"
 
 #: ../weather/src/applet-config.c:184
 msgid "Searching the location code..."
-msgstr ""
+msgstr "Söker efter platskoden..."
 
 #: ../weather/src/applet-config.c:217
 msgid ""
 "Enter the name of your location and press Enter to choose amongst results."
 msgstr ""
+"Ange namnet på din plats och tryck Enter för att välja bland resultat."
 
 #: ../weather/src/applet-init.c:29
 msgid "weather"
-msgstr ""
+msgstr "väder"
 
 #: ../weather/src/applet-init.c:32
 msgid ""
@@ -3689,66 +3925,72 @@ msgid ""
 "Middle-click on the main icon to have current conditions information, left-"
 "click on a sub-icon to have forcast information.\n"
 msgstr ""
+"Denna applet visar väder i din docka.\n"
+"Data tillhandahålls av www.weather.com, du kan hitta din plats i "
+"inställningspanelen.\n"
+"Den kan lossas för att bli vackert ögongodis som 3D-desklet.\n"
+"Mittenklicka på huvudikonen för att få information om aktuella förhållanden, "
+"vänsterklicka på en underikon för att få prognosinformation.\n"
 
 #: ../weather/src/applet-load-icons.c:26
 msgid "Jan"
-msgstr ""
+msgstr "Jan"
 
 #: ../weather/src/applet-load-icons.c:26
 msgid "Feb"
-msgstr ""
+msgstr "Feb"
 
 #: ../weather/src/applet-load-icons.c:26
 msgid "Mar"
-msgstr ""
+msgstr "Mar"
 
 #: ../weather/src/applet-load-icons.c:26
 msgid "Apr"
-msgstr ""
+msgstr "Apr"
 
 #: ../weather/src/applet-load-icons.c:26
 msgid "May"
-msgstr ""
+msgstr "Maj"
 
 #: ../weather/src/applet-load-icons.c:26
 msgid "Jun"
-msgstr ""
+msgstr "Jun"
 
 #: ../weather/src/applet-load-icons.c:26
 msgid "Jui"
-msgstr ""
+msgstr "Jul"
 
 #: ../weather/src/applet-load-icons.c:26
 msgid "Aug"
-msgstr ""
+msgstr "Aug"
 
 #: ../weather/src/applet-load-icons.c:26
 msgid "Sep"
-msgstr ""
+msgstr "Sep"
 
 #: ../weather/src/applet-load-icons.c:26
 msgid "Oct"
-msgstr ""
+msgstr "Okt"
 
 #: ../weather/src/applet-load-icons.c:26
 msgid "Nov"
-msgstr ""
+msgstr "Nov"
 
 #: ../weather/src/applet-load-icons.c:26
 msgid "Dec"
-msgstr ""
+msgstr "Dec"
 
 #: ../weather/src/applet-notifications.c:65
 msgid "Data are being retrieved, please wait a moment."
-msgstr ""
+msgstr "Data hämtas, vänta lite."
 
 #: ../weather/src/applet-notifications.c:104
 msgid "Show current conditions (middle-click)"
-msgstr ""
+msgstr "Visa aktuella förhållanden (mittenklick)"
 
 #: ../weather/src/applet-notifications.c:109
 msgid "Open weather.com (double-click)"
-msgstr ""
+msgstr "Öppna weather.com (dubbelklick)"
 
 #: ../weather/src/applet-notifications.c:111
 msgid "Reload now"
@@ -3759,8 +4001,8 @@ msgid ""
 "No data available\n"
 " is your connection alive?"
 msgstr ""
-"Inga data hittades\n"
-"Är du ansluten till Internet?"
+"Inga data tillgänglig\n"
+"Är anslutningen aktiv?"
 
 #: ../weather/src/applet-notifications.c:164
 #: ../weather/src/applet-notifications.c:202
@@ -3769,7 +4011,7 @@ msgstr "Temperatur"
 
 #: ../weather/src/applet-notifications.c:165
 msgid "Precipitation probability"
-msgstr "Risk för nederbörd"
+msgstr "Nederbördsrisk"
 
 #: ../weather/src/applet-notifications.c:166
 #: ../weather/src/applet-notifications.c:203
@@ -3793,17 +4035,19 @@ msgstr "Solnedgång"
 
 #: ../weather/src/applet-notifications.c:178
 msgid "Data are being fetched, please re-try in a few seconds."
-msgstr ""
+msgstr "Data hämtas, försök igen om några sekunder."
 
 #: ../weather/src/applet-notifications.c:188
 msgid ""
 "No data available\n"
 "Retrying now..."
 msgstr ""
+"Ingen data tillgänglig\n"
+"Försöker igen..."
 
 #: ../weather/src/applet-notifications.c:202
 msgid "Feels like"
-msgstr "upplevd"
+msgstr "Upplevd"
 
 #: ../weather/src/applet-notifications.c:204
 msgid "Pressure"
@@ -3811,7 +4055,7 @@ msgstr "Tryck"
 
 #: ../weblets/src/applet-init.c:28
 msgid "weblets"
-msgstr ""
+msgstr "weblets"
 
 #: ../weblets/src/applet-init.c:31
 msgid ""
@@ -3820,10 +4064,13 @@ msgid ""
 "You can select your web page, set the desired scrolling,\n"
 "and hide the scrollbars to get a real 'crop' of the page."
 msgstr ""
+"Weblets applet låter dig visa en interaktiv webbsida på ditt skrivbord.\n"
+"Du kan välja din webbsida, ställa in önskad rullning,\n"
+"och dölja rullningslisterna för att få en riktig \"beskärning av sidan\"."
 
 #: ../weblets/src/applet-widget.c:58
 msgid "Weblets"
-msgstr ""
+msgstr "Weblets"
 
 #: ../wifi/src/applet-draw.c:30
 msgid "Very Low"
@@ -3835,7 +4082,7 @@ msgstr "Låg"
 
 #: ../wifi/src/applet-draw.c:30
 msgid "Middle"
-msgstr "Sådär"
+msgstr "Mellan"
 
 #: ../wifi/src/applet-draw.c:30
 msgid "Good"
@@ -3847,7 +4094,7 @@ msgstr "Mycket bra"
 
 #: ../wifi/src/applet-draw.c:138
 msgid "WiFi disabled."
-msgstr "Wifi inaktiverat."
+msgstr "Wifi inaktiverad."
 
 #: ../wifi/src/applet-init.c:33
 msgid ""
@@ -3855,60 +4102,64 @@ msgid ""
 "connection\n"
 "Left-click to pop-up some info,Middle-click to re-check immediately."
 msgstr ""
+"Denna applet visar dig signalstyrkan av den första aktiva wifi-"
+"anslutningen.\n"
+"Vänsterklicka för att visa en del info, mittenklicka för att kontrollera "
+"igen omedelbart."
 
 #: ../wifi/src/applet-init.c:39 ../Network-Monitor/data/messages:179
 msgid "Wifi"
-msgstr ""
+msgstr "Wifi"
 
 #: ../wifi/src/applet-notifications.c:88
 msgid "Toggle wifi ON/OFF"
-msgstr ""
+msgstr "Växla wifi PÅ/AV"
 
 #: ../gvfs-integration/cairo-dock-gio-vfs.c:345
 #: ../gvfs-integration/cairo-dock-gio-vfs.c:707
 msgid "File System"
-msgstr ""
+msgstr "Filsystem"
 
 #: ../Animated-icons/data/messages:1 ../icon-effect/data/messages:1
 #: ../illusion/data/messages:1
 msgid "Global"
-msgstr ""
+msgstr "Global"
 
 #: ../Animated-icons/data/messages:3 ../icon-effect/data/messages:3
 msgid "when hovering over an icon"
-msgstr ""
+msgstr "när musen svävar över en ikon"
 
 #: ../Animated-icons/data/messages:5 ../icon-effect/data/messages:5
 msgid "Effects used:"
-msgstr ""
+msgstr "Använd effekt:"
 
 #: ../Animated-icons/data/messages:23 ../icon-effect/data/messages:19
 msgid "when clicking on an launcher"
-msgstr ""
+msgstr "när du klickar på en startare"
 
 #: ../Animated-icons/data/messages:25 ../icon-effect/data/messages:21
 msgid "Effects used on launcher:"
-msgstr ""
+msgstr "Effekter som används på startare:"
 
 #: ../Animated-icons/data/messages:43 ../Animated-icons/data/messages:67
 msgid "Number of times the animation will play:"
-msgstr ""
+msgstr "Antal gånger animeringen spelas:"
 
 #: ../Animated-icons/data/messages:45 ../icon-effect/data/messages:35
 msgid "Repeat these effects until the corresponding application opens?"
-msgstr ""
+msgstr "Upprepa dessa effekter tills tillhörande program öppnas?"
 
 #: ../Animated-icons/data/messages:47 ../icon-effect/data/messages:37
 msgid "when clicking on an application"
-msgstr ""
+msgstr "när du klickar på ett program"
 
 #: ../Animated-icons/data/messages:49 ../icon-effect/data/messages:39
 msgid "Effects used on applications:"
-msgstr ""
+msgstr "Effekter som används på program:"
 
 #: ../Animated-icons/data/messages:69
 msgid "Rotation"
-msgstr ""
+msgstr "Rotation"
 
 #: ../Animated-icons/data/messages:71 ../Animated-icons/data/messages:89
 #: ../Animated-icons/data/messages:137 ../Animated-icons/data/messages:149
@@ -3920,7 +4171,7 @@ msgstr ""
 #: ../icon-effect/data/messages:153 ../icon-effect/data/messages:173
 #: ../show-mouse/data/messages:19
 msgid "In ms."
-msgstr ""
+msgstr "I ms."
 
 #: ../Animated-icons/data/messages:73 ../Animated-icons/data/messages:91
 #: ../Animated-icons/data/messages:139 ../icon-effect/data/messages:61
@@ -3931,7 +4182,7 @@ msgstr ""
 #: ../illusion/data/messages:69 ../illusion/data/messages:75
 #: ../mail/data/messages:143
 msgid "Duration of the animation:"
-msgstr ""
+msgstr "Varaktighet för animeringen:"
 
 #: ../Animated-icons/data/messages:75 ../Animated-icons/data/messages:93
 #: ../Animated-icons/data/messages:141 ../Animated-icons/data/messages:153
@@ -3941,11 +4192,11 @@ msgstr ""
 #: ../icon-effect/data/messages:135 ../icon-effect/data/messages:157
 #: ../icon-effect/data/messages:177
 msgid "Repeat while icon is pointed to?"
-msgstr ""
+msgstr "Upprepa medan ikonen pekas på?"
 
 #: ../Animated-icons/data/messages:77
 msgid "Type of mesh:"
-msgstr ""
+msgstr "Typ av nät?"
 
 #: ../Animated-icons/data/messages:79 ../Clipper/data/messages:43
 #: ../Composite-Manager/data/messages:41 ../Disks/data/messages:27
@@ -3970,157 +4221,159 @@ msgstr ""
 #: ../weather/data/messages:53 ../weblets/data/messages:43
 #: ../wifi/data/messages:51
 msgid "Normal"
-msgstr ""
+msgstr "Normal"
 
 #: ../Animated-icons/data/messages:81
 msgid "Cube"
-msgstr ""
+msgstr "Kub"
 
 #: ../Animated-icons/data/messages:83
 msgid "Capsule"
-msgstr ""
+msgstr "Kapsel"
 
 #: ../Animated-icons/data/messages:85
 msgid "Colour of the sheen:"
-msgstr ""
+msgstr "Glansens färg"
 
 #: ../Animated-icons/data/messages:97
 msgid "Image for the spotlight:"
-msgstr ""
+msgstr "Bild för strålkastaren?"
 
 #: ../Animated-icons/data/messages:99
 msgid "Image for the front spotlight:"
-msgstr ""
+msgstr "Bild för frontstrålkastaren:"
 
 #: ../Animated-icons/data/messages:101
 msgid "Spot colour:"
-msgstr ""
+msgstr "Spotfärg:"
 
 #: ../Animated-icons/data/messages:103
 msgid "Halo colour:"
-msgstr ""
+msgstr "Gloriafärg:"
 
 #: ../Animated-icons/data/messages:105
 msgid "Rays"
-msgstr ""
+msgstr "Strålar"
 
 #: ../Animated-icons/data/messages:107 ../icon-effect/data/messages:67
 #: ../icon-effect/data/messages:95 ../icon-effect/data/messages:117
 #: ../icon-effect/data/messages:139 ../icon-effect/data/messages:161
 #: ../illusion/data/messages:37 ../show-mouse/data/messages:27
 msgid "1st color of gradation :"
-msgstr ""
+msgstr "1:a färg på gradering :"
 
 #: ../Animated-icons/data/messages:109 ../icon-effect/data/messages:69
 #: ../icon-effect/data/messages:97 ../icon-effect/data/messages:119
 #: ../icon-effect/data/messages:141 ../icon-effect/data/messages:163
 #: ../illusion/data/messages:39 ../show-mouse/data/messages:29
 msgid "2nd color of gradation :"
-msgstr ""
+msgstr "2:a färg på gradering :"
 
 #: ../Animated-icons/data/messages:111 ../icon-effect/data/messages:71
 #: ../icon-effect/data/messages:99 ../icon-effect/data/messages:183
 #: ../illusion/data/messages:41 ../show-mouse/data/messages:31
 msgid "Random colours?"
-msgstr ""
+msgstr "Slumpmässiga färger?"
 
 #: ../Animated-icons/data/messages:113
 msgid "Number of rays:"
-msgstr ""
+msgstr "Antal strålar:"
 
 #: ../Animated-icons/data/messages:115
 msgid "Ray size:"
-msgstr ""
+msgstr "Strålstorlek:"
 
 #: ../Animated-icons/data/messages:117
 msgid "Ray speed:"
-msgstr ""
+msgstr "Strålhastighet:"
 
 #: ../Animated-icons/data/messages:121
 msgid "Initial stretch:"
-msgstr ""
+msgstr "Inledande sträckning:"
 
 #: ../Animated-icons/data/messages:123
 msgid "Horizontal stretch"
-msgstr ""
+msgstr "Horisontell sträckning"
 
 #: ../Animated-icons/data/messages:125
 msgid "Vertical stretch"
-msgstr ""
+msgstr "Vertikal sträckning"
 
 #: ../Animated-icons/data/messages:127
 msgid "Corner stretch"
-msgstr ""
+msgstr "Hörnsträckning"
 
 #: ../Animated-icons/data/messages:129
 msgid "Spring constant:"
-msgstr ""
+msgstr "Fjäderkonstant:"
 
 #: ../Animated-icons/data/messages:131
 msgid "Friction:"
-msgstr ""
+msgstr "Friktion:"
 
 #: ../Animated-icons/data/messages:133
 msgid "Number of points on the grid in each direction:"
-msgstr ""
+msgstr "Antal punkter på rutnätet i varje riktning:"
 
 #: ../Animated-icons/data/messages:143
 msgid "Wave width:"
-msgstr ""
+msgstr "Vågbredd:"
 
 #: ../Animated-icons/data/messages:145
 msgid "Wave amplitude:"
-msgstr ""
+msgstr "Vågamplitud:"
 
 #: ../Animated-icons/data/messages:151
 msgid "Pulse duration:"
-msgstr ""
+msgstr "Pulslängd:"
 
 #: ../Animated-icons/data/messages:155
 msgid "Pulse max zoom:"
-msgstr ""
+msgstr "Puls maxzoom:"
 
 #: ../Animated-icons/data/messages:157
 msgid "Pulse follows icon shape?"
-msgstr ""
+msgstr "Puls följer ikonform?"
 
 #: ../Animated-icons/data/messages:163
 msgid "Bounce duration:"
-msgstr ""
+msgstr "Studslängd:"
 
 #: ../Animated-icons/data/messages:167
 msgid "When bouncing, resize the icon by:"
-msgstr ""
+msgstr "Under studs, ändra storlek på ikonen med:"
 
 #: ../Animated-icons/data/messages:169
 msgid "the lower the value, the more it will flatten."
-msgstr ""
+msgstr "ju lägre värde, desto mer kommer den att plattas ut."
 
 #: ../Animated-icons/data/messages:171
 msgid "How much the icon will flatten when hitting the ground:"
-msgstr ""
+msgstr "Hur mycket ikonen kommer att plattas ut då den träffar marken:"
 
 #: ../Animated-icons/data/messages:177
 msgid "Blink duration:"
-msgstr ""
+msgstr "Blinklängd:"
 
 #: ../Animated-icons/data/messages:185
 msgid "Busy duration:"
-msgstr ""
+msgstr "Upptagetlängd:"
 
 #: ../Animated-icons/data/messages:189
 msgid ""
 "The image must contain all the frames of the animation, side by side, from "
 "left to right."
 msgstr ""
+"Bilden måste innehålla alla animeringens bildrutor, bredvid varandra, frän "
+"vänster till höger."
 
 #: ../Animated-icons/data/messages:191
 msgid "Image :"
-msgstr ""
+msgstr "Bild :"
 
 #: ../Animated-icons/data/messages:193
 msgid "Image size"
-msgstr ""
+msgstr "Bildstorlek"
 
 #: ../Cairo-Penguin/data/messages:1 ../Cairo-Penguin/data/messages:3
 #: ../Clipper/data/messages:1 ../Clipper/data/messages:3
@@ -4190,7 +4443,7 @@ msgstr "Ikon"
 #: ../tomboy/data/messages:5 ../weather/data/messages:5
 #: ../weblets/data/messages:5 ../wifi/data/messages:5
 msgid "Name of the dock it belongs to:"
-msgstr "Docka som appleten tillhör:"
+msgstr "Namnet på dockan den tillhör:"
 
 #: ../Cairo-Penguin/data/messages:7 ../Clipper/data/messages:7
 #: ../Composite-Manager/data/messages:7 ../Disks/data/messages:7
@@ -4213,7 +4466,7 @@ msgstr "Docka som appleten tillhör:"
 #: ../tomboy/data/messages:7 ../weather/data/messages:9
 #: ../weblets/data/messages:7 ../wifi/data/messages:7
 msgid "Name of the icon as it will appear in its caption in the dock:"
-msgstr "Ikonens etikett:"
+msgstr "Ikonnamnet så som det kommer att visas i dess titel i dockan:"
 
 #: ../Cairo-Penguin/data/messages:9 ../Clipper/data/messages:9
 #: ../Composite-Manager/data/messages:9 ../Disks/data/messages:9
@@ -4236,7 +4489,7 @@ msgstr "Ikonens etikett:"
 #: ../tomboy/data/messages:9 ../tomboy/data/messages:131
 #: ../tomboy/data/messages:143 ../weblets/data/messages:9
 msgid "Default"
-msgstr ""
+msgstr "Standard"
 
 #: ../Cairo-Penguin/data/messages:11 ../Clipper/data/messages:13
 #: ../Composite-Manager/data/messages:11 ../Disks/data/messages:11
@@ -4261,7 +4514,7 @@ msgstr ""
 #: ../weather/data/messages:13 ../weblets/data/messages:13
 #: ../wifi/data/messages:11
 msgid "Set to 0 to use the default applet size"
-msgstr ""
+msgstr "Ställ in till 0 för att använda standard-applet-storlek"
 
 #: ../Cairo-Penguin/data/messages:13 ../Clipper/data/messages:15
 #: ../Composite-Manager/data/messages:13 ../Disks/data/messages:13
@@ -4286,7 +4539,7 @@ msgstr ""
 #: ../weather/data/messages:15 ../weblets/data/messages:15
 #: ../wifi/data/messages:13
 msgid "Desired icon size for this applet"
-msgstr "Önskad storlek för ikonen"
+msgstr "Önskad ikonstorlek för denna applet"
 
 #: ../Cairo-Penguin/data/messages:15 ../Clipper/data/messages:89
 #: ../Composite-Manager/data/messages:87 ../Dbus/data/messages:1
@@ -4315,7 +4568,7 @@ msgstr "Önskad storlek för ikonen"
 #: ../weather/data/messages:101 ../weblets/data/messages:89
 #: ../wifi/data/messages:97
 msgid "Configuration"
-msgstr "Konfiguration"
+msgstr "Inställning"
 
 #: ../Cairo-Penguin/data/messages:17 ../Disks/data/messages:97
 #: ../Network-Monitor/data/messages:147 ../Network-Monitor/data/messages:191
@@ -4323,19 +4576,19 @@ msgstr "Konfiguration"
 #: ../mail/data/messages:105 ../netspeed/data/messages:107
 #: ../weather/data/messages:131
 msgid "Choose one of the available themes:"
-msgstr "Välj ett tema:"
+msgstr "Välj ett av tillgängliga teman:"
 
 #: ../Cairo-Penguin/data/messages:21
 msgid "Delay between animation changes :"
-msgstr "Tid mellan animeringsändringar:"
+msgstr "Fördröjning mellan animeringsändringar :"
 
 #: ../Cairo-Penguin/data/messages:23
 msgid "Penguin transparency:"
-msgstr "Pingvinens genomskinlighet:"
+msgstr "Pingvingenomskinlighet:"
 
 #: ../Cairo-Penguin/data/messages:25
 msgid "Let the penguin wander everywhere in the dock?"
-msgstr "Tillåt pingvinen att vandra överallt?"
+msgstr "Låt pingvinen vandra överallt i dockan?"
 
 #: ../Cairo-Penguin/data/messages:27 ../dock-rendering/data/messages:13
 #: ../dock-rendering/data/messages:107 ../show-mouse/data/messages:23
@@ -4344,7 +4597,7 @@ msgstr "i pixlar."
 
 #: ../Cairo-Penguin/data/messages:29
 msgid "Ground offset:"
-msgstr ""
+msgstr "Markjustering:"
 
 #: ../Clipper/data/messages:11 ../Doncky/data/messages:11
 #: ../Folders/data/messages:23 ../GMenu/data/messages:11
@@ -4357,7 +4610,7 @@ msgstr ""
 #: ../systray/data/messages:11 ../template/data/messages:11
 #: ../terminal/data/messages:11 ../weblets/data/messages:11
 msgid "Image filename:"
-msgstr ""
+msgstr "Bildfilnamn:"
 
 #: ../Clipper/data/messages:17 ../Composite-Manager/data/messages:15
 #: ../Disks/data/messages:15 ../Doncky/data/messages:17
@@ -4406,7 +4659,7 @@ msgstr "Desklet"
 #: ../tomboy/data/messages:31 ../weather/data/messages:29
 #: ../weblets/data/messages:19 ../wifi/data/messages:27
 msgid "Position"
-msgstr ""
+msgstr "Position"
 
 #: ../Clipper/data/messages:21 ../Composite-Manager/data/messages:19
 #: ../Disks/data/messages:41 ../Doncky/data/messages:21
@@ -4433,8 +4686,8 @@ msgid ""
 "If locked, the desklet cannot be moved by simply dragging it with the left "
 "mouse button. It can still be moved with ALT + left-click."
 msgstr ""
-"En låst desklet kan inte flyttas genom att klicka och dra med du kan alltid "
-"använda ALT+vänsterklick."
+"Om låst, kan deskleten inte flyttas genom att enkelt dra den med vänster "
+"musknapp. Det kan fortfarande flyttas med ALT + vänsterklick."
 
 #: ../Clipper/data/messages:23 ../Composite-Manager/data/messages:21
 #: ../Disks/data/messages:43 ../Doncky/data/messages:23
@@ -4485,7 +4738,7 @@ msgid ""
 "Depending on your WindowManager, you may be able to resize this with ALT + "
 "middle-click or ALT + left-click."
 msgstr ""
-"Beroende på din fönsterhanterare, kan du ändra storlek med ALT+mellanklick "
+"Beroende på din fönsterhanterare, kan du ändra storlek med ALT+mittenklick "
 "eller ALT+vänsterklick"
 
 #: ../Clipper/data/messages:27 ../Composite-Manager/data/messages:25
@@ -4510,7 +4763,7 @@ msgstr ""
 #: ../weather/data/messages:37 ../weblets/data/messages:27
 #: ../wifi/data/messages:35
 msgid "Desklet dimensions (width x height):"
-msgstr "Storlek på Desklet (bredd x höjd):"
+msgstr "Deskletstorlek (bredd x höjd):"
 
 #: ../Clipper/data/messages:29 ../Disks/data/messages:45
 #: ../Doncky/data/messages:29 ../Folders/data/messages:41
@@ -4530,7 +4783,7 @@ msgid ""
 "Depending on your WindowManager, you may be able to move this with ALT + "
 "left-click."
 msgstr ""
-"Beroende på din fönsterhanterare, kan du flytta appleten med ALT+vänsterklick"
+"Beroende på din fönsterhanterare, kan du flytta denna med ALT+vänsterklick"
 
 #: ../Clipper/data/messages:31 ../Composite-Manager/data/messages:29
 #: ../Disks/data/messages:47 ../Doncky/data/messages:31
@@ -4554,7 +4807,7 @@ msgstr ""
 #: ../tomboy/data/messages:43 ../weather/data/messages:41
 #: ../weblets/data/messages:31 ../wifi/data/messages:39
 msgid "Desklet position (x, y):"
-msgstr "Deskletens position (x, y):"
+msgstr "Deskletposition (x, y):"
 
 #: ../Clipper/data/messages:33 ../Composite-Manager/data/messages:31
 #: ../Disks/data/messages:49 ../Doncky/data/messages:33
@@ -4580,6 +4833,8 @@ msgid ""
 "You can quickly rotate the desklet with the mouse, by dragging the little "
 "buttons on its left and top sides."
 msgstr ""
+"Du kan snabbt rotera deskleten med musen, genom att dra i de små knapparna "
+"till vänster på dess ovansida."
 
 #: ../Clipper/data/messages:35 ../Composite-Manager/data/messages:33
 #: ../Disks/data/messages:51 ../Doncky/data/messages:35
@@ -4602,7 +4857,7 @@ msgstr ""
 #: ../tomboy/data/messages:47 ../weather/data/messages:45
 #: ../weblets/data/messages:35 ../wifi/data/messages:43
 msgid "Rotation:"
-msgstr ""
+msgstr "Rotation:"
 
 #: ../Clipper/data/messages:37 ../Composite-Manager/data/messages:35
 #: ../Doncky/data/messages:37 ../Folders/data/messages:49
@@ -4626,7 +4881,7 @@ msgstr ""
 #: ../weather/data/messages:47 ../weblets/data/messages:37
 #: ../wifi/data/messages:45
 msgid "Visibility"
-msgstr ""
+msgstr "Synlighet"
 
 #: ../Clipper/data/messages:39 ../Composite-Manager/data/messages:37
 #: ../Disks/data/messages:19 ../Doncky/data/messages:39
@@ -4650,7 +4905,7 @@ msgstr ""
 #: ../tomboy/data/messages:51 ../weather/data/messages:49
 #: ../weblets/data/messages:39 ../wifi/data/messages:47
 msgid "Is detached from the dock"
-msgstr "Koppla loss från dockan?"
+msgstr "Lösgjord från dockan"
 
 #: ../Clipper/data/messages:41 ../Composite-Manager/data/messages:39
 #: ../Disks/data/messages:25 ../Doncky/data/messages:41
@@ -4674,7 +4929,7 @@ msgstr "Koppla loss från dockan?"
 #: ../tomboy/data/messages:53 ../weather/data/messages:51
 #: ../weblets/data/messages:41 ../wifi/data/messages:49
 msgid "Visibility:"
-msgstr ""
+msgstr "Synlighet:"
 
 #: ../Clipper/data/messages:45 ../Composite-Manager/data/messages:43
 #: ../Disks/data/messages:29 ../Doncky/data/messages:45
@@ -4698,7 +4953,7 @@ msgstr ""
 #: ../tomboy/data/messages:57 ../weather/data/messages:55
 #: ../weblets/data/messages:45 ../wifi/data/messages:53
 msgid "Keep above"
-msgstr ""
+msgstr "Behåll över"
 
 #: ../Clipper/data/messages:47 ../Composite-Manager/data/messages:45
 #: ../Disks/data/messages:31 ../Doncky/data/messages:47
@@ -4722,7 +4977,7 @@ msgstr ""
 #: ../tomboy/data/messages:59 ../weather/data/messages:57
 #: ../weblets/data/messages:47 ../wifi/data/messages:55
 msgid "Keep below"
-msgstr ""
+msgstr "Behåll under"
 
 #: ../Clipper/data/messages:49 ../Composite-Manager/data/messages:47
 #: ../Disks/data/messages:33 ../Doncky/data/messages:49
@@ -4746,7 +5001,7 @@ msgstr ""
 #: ../tomboy/data/messages:61 ../weather/data/messages:59
 #: ../weblets/data/messages:49 ../wifi/data/messages:57
 msgid "Keep on widget layer"
-msgstr ""
+msgstr "Behåll på widget-lager"
 
 #: ../Clipper/data/messages:51 ../Composite-Manager/data/messages:49
 #: ../Disks/data/messages:35 ../Doncky/data/messages:51
@@ -4770,7 +5025,7 @@ msgstr ""
 #: ../tomboy/data/messages:63 ../weather/data/messages:61
 #: ../weblets/data/messages:51 ../wifi/data/messages:59
 msgid "Reserve space"
-msgstr ""
+msgstr "Reservera utrymme"
 
 #: ../Clipper/data/messages:53 ../Composite-Manager/data/messages:51
 #: ../Disks/data/messages:37 ../Doncky/data/messages:53
@@ -4794,7 +5049,7 @@ msgstr ""
 #: ../tomboy/data/messages:65 ../weather/data/messages:63
 #: ../weblets/data/messages:53 ../wifi/data/messages:61
 msgid "Should be visible on all desktops?"
-msgstr ""
+msgstr "Ska visas på alla skrivbord?"
 
 #: ../Clipper/data/messages:55 ../Composite-Manager/data/messages:53
 #: ../Disks/data/messages:53 ../Doncky/data/messages:55
@@ -4818,7 +5073,7 @@ msgstr ""
 #: ../tomboy/data/messages:67 ../weather/data/messages:65
 #: ../weblets/data/messages:55 ../wifi/data/messages:63
 msgid "Decorations"
-msgstr ""
+msgstr "Dekorationer"
 
 #: ../Clipper/data/messages:57 ../Composite-Manager/data/messages:55
 #: ../Disks/data/messages:55 ../Doncky/data/messages:57
@@ -4843,6 +5098,8 @@ msgstr ""
 #: ../weblets/data/messages:57 ../wifi/data/messages:65
 msgid "Choose 'Custom decorations' to define your own decorations below."
 msgstr ""
+"Välj \"Anpassade dekorationer\" för att definiera dina egna dekorationer "
+"nedan."
 
 #: ../Clipper/data/messages:59 ../Composite-Manager/data/messages:57
 #: ../Disks/data/messages:57 ../Doncky/data/messages:59
@@ -4866,7 +5123,7 @@ msgstr ""
 #: ../tomboy/data/messages:71 ../weather/data/messages:69
 #: ../weblets/data/messages:59 ../wifi/data/messages:67
 msgid "Choose a decoration theme for this desklet:"
-msgstr ""
+msgstr "Välj ett dekorationstema för denna desklet:"
 
 #: ../Clipper/data/messages:61 ../Composite-Manager/data/messages:59
 #: ../Disks/data/messages:59 ../Doncky/data/messages:61
@@ -4892,6 +5149,7 @@ msgstr ""
 msgid ""
 "Image to be displayed below drawings, e.g. a frame. Leave empty for no image."
 msgstr ""
+"Bild som visas under ritningar, t. ex. en ram. Lämna tomt för ingen bild."
 
 #: ../Clipper/data/messages:63 ../Composite-Manager/data/messages:61
 #: ../Disks/data/messages:61 ../Doncky/data/messages:63
@@ -4917,7 +5175,7 @@ msgstr ""
 #: ../weather/data/messages:73 ../weblets/data/messages:63
 #: ../wifi/data/messages:71
 msgid "Background image:"
-msgstr ""
+msgstr "Bakgrundsbild:"
 
 #: ../Clipper/data/messages:65 ../Composite-Manager/data/messages:63
 #: ../Disks/data/messages:63 ../Doncky/data/messages:65
@@ -4941,7 +5199,7 @@ msgstr ""
 #: ../tomboy/data/messages:77 ../weather/data/messages:75
 #: ../weblets/data/messages:65 ../wifi/data/messages:73
 msgid "Background transparency:"
-msgstr ""
+msgstr "Bakgrundsgenomskinlighet:"
 
 #: ../Clipper/data/messages:67 ../Composite-Manager/data/messages:65
 #: ../Disks/data/messages:71 ../Doncky/data/messages:67
@@ -4965,7 +5223,7 @@ msgstr ""
 #: ../tomboy/data/messages:79 ../weather/data/messages:77
 #: ../weblets/data/messages:67 ../wifi/data/messages:75
 msgid "in pixels. Use this to adjust the left position of drawings."
-msgstr ""
+msgstr "i pixlar. Använd detta för att justera ritningarnas vänsterposition."
 
 #: ../Clipper/data/messages:69 ../Composite-Manager/data/messages:67
 #: ../Disks/data/messages:73 ../Doncky/data/messages:69
@@ -4989,7 +5247,7 @@ msgstr ""
 #: ../tomboy/data/messages:81 ../weather/data/messages:79
 #: ../weblets/data/messages:69 ../wifi/data/messages:77
 msgid "Left offset:"
-msgstr ""
+msgstr "Vänsterjustering:"
 
 #: ../Clipper/data/messages:71 ../Composite-Manager/data/messages:69
 #: ../Disks/data/messages:75 ../Doncky/data/messages:71
@@ -5013,7 +5271,7 @@ msgstr ""
 #: ../tomboy/data/messages:83 ../weather/data/messages:81
 #: ../weblets/data/messages:71 ../wifi/data/messages:79
 msgid "in pixels. Use this to adjust the top position of drawings."
-msgstr ""
+msgstr "i pixlar. Använd detta för att justera ritningarnas topposition."
 
 #: ../Clipper/data/messages:73 ../Composite-Manager/data/messages:71
 #: ../Disks/data/messages:77 ../Doncky/data/messages:73
@@ -5037,7 +5295,7 @@ msgstr ""
 #: ../tomboy/data/messages:85 ../weather/data/messages:83
 #: ../weblets/data/messages:73 ../wifi/data/messages:81
 msgid "Top offset:"
-msgstr ""
+msgstr "Toppjustering:"
 
 #: ../Clipper/data/messages:75 ../Composite-Manager/data/messages:73
 #: ../Disks/data/messages:79 ../Doncky/data/messages:75
@@ -5061,7 +5319,7 @@ msgstr ""
 #: ../tomboy/data/messages:87 ../weather/data/messages:85
 #: ../weblets/data/messages:75 ../wifi/data/messages:83
 msgid "in pixels. Use this to adjust the right position of drawings."
-msgstr ""
+msgstr "i pixlar. Använd detta för att justera ritningarnas högerposition."
 
 #: ../Clipper/data/messages:77 ../Composite-Manager/data/messages:75
 #: ../Disks/data/messages:81 ../Doncky/data/messages:77
@@ -5085,7 +5343,7 @@ msgstr ""
 #: ../tomboy/data/messages:89 ../weather/data/messages:87
 #: ../weblets/data/messages:77 ../wifi/data/messages:85
 msgid "Right offset:"
-msgstr ""
+msgstr "Högerjustering:"
 
 #: ../Clipper/data/messages:79 ../Composite-Manager/data/messages:77
 #: ../Disks/data/messages:83 ../Doncky/data/messages:79
@@ -5109,7 +5367,7 @@ msgstr ""
 #: ../tomboy/data/messages:91 ../weather/data/messages:89
 #: ../weblets/data/messages:79 ../wifi/data/messages:87
 msgid "in pixels. Use this to adjust the bottom position of drawings."
-msgstr ""
+msgstr "i pixlar. Använd detta för att justera ritningarnas bottenposition."
 
 #: ../Clipper/data/messages:81 ../Composite-Manager/data/messages:79
 #: ../Disks/data/messages:85 ../Doncky/data/messages:81
@@ -5133,7 +5391,7 @@ msgstr ""
 #: ../tomboy/data/messages:93 ../weather/data/messages:91
 #: ../weblets/data/messages:81 ../wifi/data/messages:89
 msgid "Bottom offset:"
-msgstr ""
+msgstr "Bottenjustering:"
 
 #: ../Clipper/data/messages:83 ../Composite-Manager/data/messages:81
 #: ../Disks/data/messages:65 ../Doncky/data/messages:83
@@ -5160,6 +5418,8 @@ msgid ""
 "Image to be displayed above the drawings, e.g. a reflection. Leave empty for "
 "no image."
 msgstr ""
+"Bild som kommer att visas över ritningarna, t. ex. en reflektion. Lämna tomt "
+"för ingen bild."
 
 #: ../Clipper/data/messages:85 ../Composite-Manager/data/messages:83
 #: ../Disks/data/messages:67 ../Doncky/data/messages:85
@@ -5183,7 +5443,7 @@ msgstr ""
 #: ../tomboy/data/messages:97 ../weather/data/messages:95
 #: ../weblets/data/messages:85 ../wifi/data/messages:93
 msgid "Foreground image:"
-msgstr ""
+msgstr "Förgrundsbild:"
 
 #: ../Clipper/data/messages:87 ../Composite-Manager/data/messages:85
 #: ../Disks/data/messages:69 ../Doncky/data/messages:87
@@ -5207,83 +5467,91 @@ msgstr ""
 #: ../tomboy/data/messages:99 ../weather/data/messages:97
 #: ../weblets/data/messages:87 ../wifi/data/messages:95
 msgid "Foreground tansparency:"
-msgstr ""
+msgstr "Förgrundsgenomskinlighet:"
 
 #: ../Clipper/data/messages:91
 msgid "Items"
-msgstr ""
+msgstr "Objekt"
 
 #: ../Clipper/data/messages:93
 msgid ""
 "Clipboard items are those you get with CTRL+c. Selection items are those you "
 "get by selecting some text with the mouse."
 msgstr ""
+"Urklippsobjekt är dem du får med CTRL+c. Markeringsobjekt är dem du får "
+"genom att markera någon text med musen."
 
 #: ../Clipper/data/messages:95
 msgid "Which items should be remembered?"
-msgstr ""
+msgstr "Vilka objekt ska kommas ihåg?"
 
 #: ../Clipper/data/messages:99
 msgid "Clipboard"
-msgstr ""
+msgstr "Urklipp"
 
 #: ../Clipper/data/messages:101
 msgid "Selection"
-msgstr ""
+msgstr "Markering"
 
 #: ../Clipper/data/messages:103 ../GMenu/data/messages:119
 #: ../show-mouse/data/messages:15
 msgid "Both"
-msgstr ""
+msgstr "Båda"
 
 #: ../Clipper/data/messages:105
 msgid "Number of items:"
-msgstr ""
+msgstr "Antal objekt:"
 
 #: ../Clipper/data/messages:107
 msgid "Remember items between 2 sessions ?"
-msgstr ""
+msgstr "Kom ihåg objekt mellan 2 sessioner ?"
 
 #: ../Clipper/data/messages:109
 msgid ""
 "It is especially useful if you often select text with the mouse and don't "
 "want to loose your clipboard items due to too many items in the selection."
 msgstr ""
+"Det är särskilt användbart om du ofta markerar text med musen och inte vill "
+"förlora urklippsobjekt på grund av för många objekt i urvalet."
 
 #: ../Clipper/data/messages:111
 msgid "Separate clipboard and selection?"
-msgstr ""
+msgstr "Separera urklipp och markering?"
 
 #: ../Clipper/data/messages:113
 msgid "If so, number of selection items:"
-msgstr ""
+msgstr "Om så, antal markeringsobjekt:"
 
 #: ../Clipper/data/messages:115
 msgid ""
 "When you click on an item, its content will become accessible with CTRL+v"
 msgstr ""
+"När du klickar på ett objekt, kommer dess innehåll att bli åtkomligt med "
+"CTRL+v"
 
 #: ../Clipper/data/messages:117
 msgid "Paste into Clipboard?"
-msgstr ""
+msgstr "Klistra in i urklipp?"
 
 #: ../Clipper/data/messages:119
 msgid ""
 "When you click on an item, its content will become accessible with the "
 "middle-click"
 msgstr ""
+"När du klickar på ett objekt, kommer dess innehåll att bli åtkomligt med "
+"mittenklick"
 
 #: ../Clipper/data/messages:121
 msgid "Paste into Selection?"
-msgstr ""
+msgstr "Klistra in i markering?"
 
 #: ../Clipper/data/messages:123
 msgid "Shortkey to pop-up the items menu:"
-msgstr ""
+msgstr "Kortkommando för att visa objektens meny:"
 
 #: ../Clipper/data/messages:125
 msgid "Pop-up menus at mouse position?"
-msgstr ""
+msgstr "Visa menyer vid musposition?"
 
 #: ../Clipper/data/messages:127
 msgid "Actions"
@@ -5294,30 +5562,32 @@ msgid ""
 "If some actions are associated with an item, they will be proposed when the "
 "item is created."
 msgstr ""
+"Om vissa åtgärder är förknippade med ett objekt, kommer de att föreslås då "
+"objektet skapas."
 
 #: ../Clipper/data/messages:131
 msgid "Enable actions?"
-msgstr ""
+msgstr "Aktivera åtgärder?"
 
 #: ../Clipper/data/messages:133
 msgid "Display actions when selecting an item in the history."
-msgstr ""
+msgstr "Visa åtgärder när ett objekt i historiken väljs."
 
 #: ../Clipper/data/messages:135
 msgid "Replay actions?"
-msgstr ""
+msgstr "Spela om åtgärd?"
 
 #: ../Clipper/data/messages:139
 msgid "Duration of the action menu:"
-msgstr ""
+msgstr "Varaktighet för åtgärdsmenyn:"
 
 #: ../Clipper/data/messages:141
 msgid "Persistent items"
-msgstr ""
+msgstr "Beständiga objekt"
 
 #: ../Clipper/data/messages:143
 msgid "A list of persistent items which can be accessed with middle-click:"
-msgstr ""
+msgstr "En lista på beständiga objekt som kan kommas åt med mittenklick:"
 
 #: ../Composite-Manager/data/messages:27 ../Global-Menu/data/messages:23
 #: ../Impulse/data/messages:23 ../Indicator-Generic/data/messages:29
@@ -5330,6 +5600,8 @@ msgid ""
 "Depending on your WindowManager, you may be able to move this with ALT + "
 "left-click.. Negative values are counted from the right/bottom of the screen"
 msgstr ""
+"Beroende på din fönsterhanterare, kan du kanske flytta denna med "
+"ALT+vänsterklick... Negativa värden räknas från höger/botten av skärmen"
 
 #: ../Composite-Manager/data/messages:89 ../Impulse/data/messages:117
 #: ../clock/data/messages:133 ../clock/data/messages:151
@@ -5340,11 +5612,11 @@ msgstr "Stil"
 
 #: ../Composite-Manager/data/messages:91
 msgid "Image when composite is active:"
-msgstr ""
+msgstr "Bild då sammansättning är aktivt:"
 
 #: ../Composite-Manager/data/messages:93
 msgid "Image when composite is inactive:"
-msgstr ""
+msgstr "Bild då sammansättning är inaktivt:"
 
 #: ../Composite-Manager/data/messages:95 ../Global-Menu/data/messages:87
 #: ../RSSreader/data/messages:103 ../Status-Notifier/data/messages:117
@@ -5360,48 +5632,50 @@ msgid ""
 "Let empty to use the default one. Alternatively, you can set any command you "
 "want."
 msgstr ""
+"Lämna tomt för att använda standard. Alternativt, kan du ange vilket "
+"kommando du vill."
 
 #: ../Composite-Manager/data/messages:99
 msgid "Composite window-manager:"
-msgstr ""
+msgstr "Kompositfönsterhanterare:"
 
 #: ../Composite-Manager/data/messages:101
 #: ../Composite-Manager/data/messages:113
 msgid "Compiz"
-msgstr ""
+msgstr "Compiz"
 
 #: ../Composite-Manager/data/messages:103
 #: ../Composite-Manager/data/messages:115
 msgid "KWin"
-msgstr ""
+msgstr "KWin"
 
 #: ../Composite-Manager/data/messages:105
 #: ../Composite-Manager/data/messages:117
 msgid "Xfwm"
-msgstr ""
+msgstr "Xfwm"
 
 #: ../Composite-Manager/data/messages:107
 #: ../Composite-Manager/data/messages:119
 msgid "Metacity"
-msgstr ""
+msgstr "Metacity"
 
 #: ../Composite-Manager/data/messages:111
 msgid "Fallback window-manager:"
-msgstr ""
+msgstr "Reservfönsterhanterare:"
 
 #: ../Composite-Manager/data/messages:121
 msgid "Ask before switching:"
-msgstr ""
+msgstr "Fråga innan växling:"
 
 #: ../Composite-Manager/data/messages:123 ../logout/data/messages:93
 #: ../showDesktop/data/messages:111 ../slider/data/messages:123
 #: ../switcher/data/messages:133
 msgid "Action on middle-click:"
-msgstr ""
+msgstr "Åtgärd vid mittenklick:"
 
 #: ../Composite-Manager/data/messages:137
 msgid "Shortkey to toggle the composite ON/OFF:"
-msgstr ""
+msgstr "Kortkommando för att växla sammansättning PÅ/AV:"
 
 #: ../Dbus/data/messages:3
 msgid "Let external applications pop up dialogs in the dock?"
@@ -5411,9 +5685,10 @@ msgstr "Tillåt externa program att visa
 msgid "Let external applications reboot the dock?"
 msgstr "Tillåt externa program att starta om dockan?"
 
+# läman eller avsluta?
 #: ../Dbus/data/messages:7
 msgid "Let external applications quit the dock?"
-msgstr ""
+msgstr "Tillåt externa program att avsluta dockan?"
 
 #: ../Dbus/data/messages:9
 msgid "Let external applications show/hide desklets?"
@@ -5425,48 +5700,50 @@ msgstr "Tillåt externa program att star
 
 #: ../Dbus/data/messages:13
 msgid "Let external applications show/hide docks?"
-msgstr ""
+msgstr "Tillåt externa program visa/dölja dockor?"
 
 #: ../Dbus/data/messages:15
 msgid "Let extern applications add launchers to the docks?"
-msgstr ""
+msgstr "Tillåt externa program lägga till startare i dockorna?"
 
 #: ../Dbus/data/messages:17
 msgid "Let external applications modify the labels of icons?"
-msgstr ""
+msgstr "Tillåt externa program modifiera ikonetiketter?"
 
 #: ../Dbus/data/messages:19
 msgid "Let extern applications modify the quick-infos on icons?"
-msgstr ""
+msgstr "Tillåt externa program modifiera snabbinfon på ikoner?"
 
 #: ../Dbus/data/messages:21
 msgid "Let extern applications modify the icons' image?"
-msgstr ""
+msgstr "Tillåt externa program modifiera ikonens bild?"
 
 #: ../Dbus/data/messages:23
 msgid "Let extern applications animate icons?"
-msgstr ""
+msgstr "Tillåt externa program animera ikoner?"
 
 #: ../Dbus/data/messages:25
 msgid "The dock will catch DBus signals to Launcher API and act as Unity"
 msgstr ""
+"Dockan kommer att fånga DBus-signaler till Launcher API och agera som Unity"
 
 #: ../Dbus/data/messages:27
 msgid "Launch the Launcher API daemon?"
-msgstr ""
+msgstr "Starta Launcher API-daemonen?"
 
 #: ../Disks/data/messages:5
 msgid "Name of the container it belongs to:"
-msgstr ""
+msgstr "Namnet på containern den tillhör?"
 
 #: ../Disks/data/messages:17
 msgid "Desklet mode"
-msgstr ""
+msgstr "Desklet-läge"
 
+# visning/skärm?
 #: ../Disks/data/messages:89 ../Network-Monitor/data/messages:139
 #: ../netspeed/data/messages:99
 msgid "Choose the style of the display: "
-msgstr ""
+msgstr "Välj visningsstil: "
 
 #: ../Disks/data/messages:91 ../Disks/data/messages:95
 #: ../Network-Monitor/data/messages:141 ../Network-Monitor/data/messages:145
@@ -5477,7 +5754,7 @@ msgstr ""
 #: ../powermanager/data/messages:109 ../wifi/data/messages:101
 #: ../wifi/data/messages:107
 msgid "Gauge"
-msgstr ""
+msgstr "Reglage"
 
 #: ../Disks/data/messages:93 ../Disks/data/messages:107
 #: ../Network-Monitor/data/messages:143 ../Network-Monitor/data/messages:149
@@ -5487,93 +5764,93 @@ msgstr ""
 #: ../powermanager/data/messages:105 ../powermanager/data/messages:113
 #: ../wifi/data/messages:103 ../wifi/data/messages:111
 msgid "Graph"
-msgstr ""
+msgstr "Graf"
 
 #: ../Disks/data/messages:99 ../System-Monitor/data/messages:109
 #: ../alsaMixer/data/messages:123 ../netspeed/data/messages:109
 msgid "Rotate applet theme :"
-msgstr ""
+msgstr "Rotera applet-tema :"
 
 #: ../Disks/data/messages:103 ../System-Monitor/data/messages:113
 #: ../alsaMixer/data/messages:127 ../netspeed/data/messages:113
 msgid "With dock orientation"
-msgstr ""
+msgstr "Med dockorientering"
 
 #: ../Disks/data/messages:109 ../Network-Monitor/data/messages:151
 #: ../Network-Monitor/data/messages:195 ../System-Monitor/data/messages:119
 #: ../netspeed/data/messages:119 ../powermanager/data/messages:115
 #: ../wifi/data/messages:113
 msgid "Type of graphic :"
-msgstr ""
+msgstr "Typ av grafik :"
 
 #: ../Disks/data/messages:111 ../Network-Monitor/data/messages:153
 #: ../Network-Monitor/data/messages:197 ../System-Monitor/data/messages:121
 #: ../netspeed/data/messages:121 ../powermanager/data/messages:117
 #: ../wifi/data/messages:115
 msgid "Line"
-msgstr ""
+msgstr "Linje"
 
 #: ../Disks/data/messages:113 ../Network-Monitor/data/messages:155
 #: ../Network-Monitor/data/messages:199 ../System-Monitor/data/messages:123
 #: ../netspeed/data/messages:123 ../powermanager/data/messages:119
 #: ../wifi/data/messages:117
 msgid "Plain"
-msgstr ""
+msgstr "Enkel"
 
 #: ../Disks/data/messages:115 ../Network-Monitor/data/messages:157
 #: ../Network-Monitor/data/messages:201 ../System-Monitor/data/messages:125
 #: ../netspeed/data/messages:125 ../powermanager/data/messages:121
 #: ../wifi/data/messages:119
 msgid "Bar"
-msgstr ""
+msgstr "Stapel"
 
 #: ../Disks/data/messages:117 ../Network-Monitor/data/messages:159
 #: ../Network-Monitor/data/messages:203 ../System-Monitor/data/messages:127
 #: ../netspeed/data/messages:127 ../powermanager/data/messages:123
 #: ../wifi/data/messages:121
 msgid "Circle"
-msgstr ""
+msgstr "Cirkel"
 
 #: ../Disks/data/messages:119 ../Network-Monitor/data/messages:161
 #: ../Network-Monitor/data/messages:205 ../System-Monitor/data/messages:129
 #: ../netspeed/data/messages:129 ../powermanager/data/messages:125
 #: ../wifi/data/messages:123
 msgid "Plain Circle"
-msgstr ""
+msgstr "Enkel cirkel"
 
 #: ../Disks/data/messages:121 ../netspeed/data/messages:131
 msgid "It's the colour of the graphic for high rate values."
-msgstr ""
+msgstr "Det är färgen på grafiken för höga värden."
 
 #: ../Disks/data/messages:123 ../Network-Monitor/data/messages:165
 #: ../Network-Monitor/data/messages:209 ../System-Monitor/data/messages:133
 #: ../netspeed/data/messages:133 ../powermanager/data/messages:129
 #: ../wifi/data/messages:127
 msgid "High value's colour :"
-msgstr ""
+msgstr "Färg för höga värden :"
 
 #: ../Disks/data/messages:125 ../netspeed/data/messages:135
 msgid "Graph colour for low rate vaues:"
-msgstr ""
+msgstr "Graffärg för låga värden:"
 
 #: ../Disks/data/messages:127 ../Network-Monitor/data/messages:169
 #: ../Network-Monitor/data/messages:213 ../System-Monitor/data/messages:137
 #: ../netspeed/data/messages:137 ../powermanager/data/messages:133
 #: ../wifi/data/messages:131
 msgid "Low value's colour :"
-msgstr ""
+msgstr "Färg för låga värden :"
 
 #: ../Disks/data/messages:129 ../Network-Monitor/data/messages:171
 #: ../Network-Monitor/data/messages:215 ../System-Monitor/data/messages:139
 #: ../netspeed/data/messages:139 ../powermanager/data/messages:135
 #: ../wifi/data/messages:133
 msgid "Background colour of the graphic :"
-msgstr ""
+msgstr "Grafikens bakgrundsfärg :"
 
 #: ../Disks/data/messages:131 ../System-Monitor/data/messages:141
 #: ../netspeed/data/messages:141
 msgid "Show all values on same graph?"
-msgstr ""
+msgstr "Visa alla värden på samma graf?"
 
 #: ../Disks/data/messages:133 ../Impulse/data/messages:85
 #: ../Status-Notifier/data/messages:103 ../alsaMixer/data/messages:99
@@ -5583,17 +5860,17 @@ msgstr ""
 #: ../stack/data/messages:93 ../tomboy/data/messages:103
 #: ../weather/data/messages:129
 msgid "Display"
-msgstr "Uteseende"
+msgstr "Visa"
 
 #: ../Disks/data/messages:135
 msgid "Display values"
-msgstr ""
+msgstr "Visa värden"
 
 #: ../Disks/data/messages:139 ../Network-Monitor/data/messages:119
 #: ../System-Monitor/data/messages:165 ../alsaMixer/data/messages:107
 #: ../clock/data/messages:107 ../netspeed/data/messages:161
 msgid "On icon"
-msgstr "På ikonen"
+msgstr "På ikon"
 
 #: ../Disks/data/messages:141 ../Network-Monitor/data/messages:121
 #: ../System-Monitor/data/messages:167 ../alsaMixer/data/messages:105
@@ -5603,186 +5880,191 @@ msgstr "På etikett"
 
 #: ../Disks/data/messages:145
 msgid "Refresh time"
-msgstr ""
+msgstr "Uppdateringsintervall"
 
 #: ../Disks/data/messages:147 ../netspeed/data/messages:153
 msgid ""
 "You need OpenGL for this option. Set it to 0 to disable it, 1 means the "
 "transition is continue."
 msgstr ""
+"Du behöver OpenGL för detta alternativ. Ställ in det till 0 för att "
+"avaktivera det, 1 betyder att övergången fortsätter."
 
 #: ../Disks/data/messages:149
 msgid "Fluidity of the transition between 2 values"
-msgstr ""
+msgstr "Fluididet på övergången mellan 2 värden"
 
 #: ../Disks/data/messages:151
 msgid "Partitions monitored : Size"
-msgstr ""
+msgstr "Övervakade partitioner : Storlek"
 
 #: ../Disks/data/messages:153
 msgid "E.g. sda1, sdb5..."
-msgstr ""
+msgstr "T. ex. sda1, sdb5..."
 
 #: ../Disks/data/messages:155
 msgid "Disks monitored : Speed"
-msgstr ""
+msgstr "Övervakade skivor : Hastighet"
 
 #: ../Disks/data/messages:157
 msgid "E.g. sda, sdb... Up to 5 values allowed"
-msgstr ""
+msgstr "T. ex. sda, sdb... Upp till 5 värden tillåts"
 
 #: ../Disks/data/messages:159
 msgid "Preferences"
-msgstr ""
+msgstr "Inställningar"
 
 #: ../Disks/data/messages:161 ../Network-Monitor/data/messages:133
 #: ../netspeed/data/messages:165
 msgid "Leave empty to use the default."
-msgstr ""
+msgstr "Lämna tomt för att använda standard."
 
 #: ../Disks/data/messages:163
 msgid "System monitor command"
-msgstr ""
+msgstr "Systemövervakningskommando"
 
 #: ../Doncky/data/messages:91
 msgid "Specify the xml file to be used :"
-msgstr ""
+msgstr "Ange xml-filen som ska användas :"
 
 #: ../Doncky/data/messages:93 ../RSSreader/data/messages:131
 #: ../terminal/data/messages:91
 msgid "Appearance"
-msgstr ""
+msgstr "Utseende"
 
 #: ../Doncky/data/messages:97
 msgid "Font to be used by default if none is specify in the .xml"
-msgstr ""
+msgstr "Teckensnitt som används som standard om inget är angivet i .xml-en"
 
 #: ../Doncky/data/messages:99
 msgid "Default Font:"
-msgstr ""
+msgstr "Standardteckensnitt:"
 
 #: ../Doncky/data/messages:101
 msgid "Color to be used by default if none is specify in the .xml"
-msgstr ""
+msgstr "Färg som ska användas som standard om ingen är angiven i .xml-en"
 
 #: ../Doncky/data/messages:103 ../icon-effect/data/messages:181
 msgid "Default colour:"
-msgstr ""
+msgstr "Standardfärg:"
 
 #: ../Doncky/data/messages:105
 msgid "Margin to be used on left, right and top of the desklet"
-msgstr ""
+msgstr "Marginal som ska användas till vänster, höger och över om deskleten"
 
 #: ../Doncky/data/messages:107
 msgid "Margin all around the desklet:"
-msgstr ""
+msgstr "Marginal runtom deskleten:"
 
 #: ../Doncky/data/messages:109
 msgid "Use this to increase the space between the lines"
-msgstr ""
+msgstr "Använd detta för att öka utrymmet mellan raderna"
 
 #: ../Doncky/data/messages:111
 msgid "Space between lines:"
-msgstr ""
+msgstr "Utrymme mellan rader:"
 
 #: ../Doncky/data/messages:113 ../RSSreader/data/messages:177
 msgid "Background"
-msgstr ""
+msgstr "Bakgrund"
 
 #: ../Doncky/data/messages:115 ../RSSreader/data/messages:179
 msgid ""
 "You can have more attractive backgrounds using the Desklet decorations"
 msgstr ""
+"Du kan få en snyggare bakgrund genom att använda Desklet-dekorationer"
 
 #: ../Doncky/data/messages:117 ../RSSreader/data/messages:181
 msgid "Display a simple background?"
-msgstr ""
+msgstr "Visa en enkel bakgrund?"
 
 #: ../Doncky/data/messages:119 ../RSSreader/data/messages:183
 msgid "first colour of the gradation"
-msgstr ""
+msgstr "förstafärg i graderingen"
 
 #: ../Doncky/data/messages:121 ../RSSreader/data/messages:185
 msgid "Background first colour :"
-msgstr ""
+msgstr "Förstafärg bakgrund :"
 
 #: ../Doncky/data/messages:123 ../RSSreader/data/messages:187
 msgid "second colour of the gradation"
-msgstr ""
+msgstr "andrafärg i graderingen"
 
 #: ../Doncky/data/messages:125 ../RSSreader/data/messages:189
 msgid "Background second colour:"
-msgstr ""
+msgstr "Andrafärg bakgrund:"
 
 #: ../Doncky/data/messages:127 ../RSSreader/data/messages:191
 msgid "Set the radius corner to 0 for no radius"
-msgstr ""
+msgstr "Ställ in radiehörnet till 0 för ingen radie"
 
 #: ../Doncky/data/messages:129 ../RSSreader/data/messages:193
 msgid "Background radius corner:"
-msgstr ""
+msgstr "Radiehörnsbakgrund:"
 
 #: ../Doncky/data/messages:131 ../RSSreader/data/messages:195
 msgid "Set the thickness to 0 for no border"
-msgstr ""
+msgstr "Ställ in tjocklek till 0 för ingen kant"
 
 #: ../Doncky/data/messages:133 ../RSSreader/data/messages:197
 msgid "Border thickness:"
-msgstr ""
+msgstr "Kanttjocklek:"
 
 #: ../Doncky/data/messages:135 ../RSSreader/data/messages:199
 msgid "Border colour"
-msgstr ""
+msgstr "Kantfärg"
 
 #: ../Doncky/data/messages:137 ../RSSreader/data/messages:201
 msgid "Border colour :"
-msgstr ""
+msgstr "Kantfärg :"
 
 #: ../Folders/data/messages:7
 msgid "Let empty to use the name of the folder."
-msgstr ""
+msgstr "Lämna tomt för att använda mappens namn."
 
 #: ../Folders/data/messages:11 ../quick-browser/data/messages:11
 msgid "Folder name"
-msgstr ""
+msgstr "Mappnamn"
 
 #: ../Folders/data/messages:13
 msgid "How to render the icon :"
-msgstr ""
+msgstr "Hur ikonen ska ritas :"
 
 #: ../Folders/data/messages:15
 msgid "Use an image"
-msgstr ""
+msgstr "Använd en bild"
 
 #: ../Folders/data/messages:17
 msgid "Draw sub-dock's content as emblems"
-msgstr ""
+msgstr "Rita underdockans innehåll som emblem"
 
 #: ../Folders/data/messages:19
 msgid "Draw sub-dock's content as stack"
-msgstr ""
+msgstr "Rita underdockans innehåll som stack"
 
 #: ../Folders/data/messages:21
 msgid "Draw sub-dock's content inside a box"
-msgstr ""
+msgstr "Rita underdockans innehåll inuti en ruta"
 
 #: ../Folders/data/messages:103
 msgid "Folder's path:"
-msgstr ""
+msgstr "Mappens sökväg:"
 
 #: ../Folders/data/messages:105
 msgid ""
 "Allow to show the files of the folder in a sub-dock. If disabled, the applet "
 "behaves as a mere launcher."
 msgstr ""
+"Tillåt att mappens filer visas i en underdocka. Om inaktiverat, kommer "
+"applet att bete sig enbart som en startare."
 
 #: ../Folders/data/messages:107
 msgid "Show folder's content?"
-msgstr ""
+msgstr "Visa mappens innehåll?"
 
 #: ../Folders/data/messages:109
 msgid "Sort files by :"
-msgstr ""
+msgstr "Sortera filer efter :"
 
 #: ../Folders/data/messages:111 ../stack/data/messages:127
 msgid "Name"
@@ -5794,55 +6076,57 @@ msgstr "Datum"
 
 #: ../Folders/data/messages:117
 msgid "Sort folders before files?"
-msgstr ""
+msgstr "Sortera mappar före filer?"
 
 #: ../Folders/data/messages:119 ../Scooby-Do/data/messages:103
 #: ../quick-browser/data/messages:101
 msgid "Show hidden files?"
-msgstr ""
+msgstr "Visa dolda filer?"
 
 #: ../GMenu/data/messages:91 ../Messaging-Menu/data/messages:101
 #: ../quick-browser/data/messages:109
 msgid "Shortkey to show/hide the menu:"
-msgstr ""
+msgstr "Kortkommando för att visa/dölja menyn:"
 
 #: ../GMenu/data/messages:93
 msgid "Shortkey to show/hide the quick-launch dialog:"
-msgstr ""
+msgstr "Kortkommando för att visa/dölja snabbstartsdialogen:"
 
 #: ../GMenu/data/messages:95
 msgid "Show recent documents?"
-msgstr ""
+msgstr "Visa senaste dokument?"
 
 #: ../GMenu/data/messages:97
 msgid "Number of items to display"
-msgstr ""
+msgstr "Antal objekt som visas"
 
 #: ../GMenu/data/messages:99
 msgid ""
 "The settings menu file is sometimes available in a settings.menu file but "
 "its content can also be available in the main .menu file used by the dock"
 msgstr ""
+"Inställningsmenyfilen är ibland tillgänglig i en settings.menu fil men dess "
+"innehåll kan också vara tillgängligt i main.menu filen som används av dockan."
 
 #: ../GMenu/data/messages:101
 msgid "Load settings' menu?"
-msgstr ""
+msgstr "Läs in inställningsmeny?"
 
 #: ../GMenu/data/messages:103
 msgid "Display the description in search's results?"
-msgstr ""
+msgstr "Visa beskrivningen i sökresultat?"
 
 #: ../GMenu/data/messages:105
 msgid "Display a notification to quickly launch new applications?"
-msgstr ""
+msgstr "Visa ett meddelande för att snabbt starta nya program?"
 
 #: ../GMenu/data/messages:107
 msgid "Command to use for configuring the menu:"
-msgstr ""
+msgstr "Kommando som ska användas för att ställa in menyn:"
 
 #: ../GMenu/data/messages:111
 msgid "Show Logout and/or Shutdown : "
-msgstr ""
+msgstr "Visa Logga ut och/eller Stäng av : "
 
 #: ../Global-Menu/data/messages:85
 msgid ""
@@ -5851,76 +6135,82 @@ msgid ""
 " The applet can steal the menu from the windows, in which case it will "
 "display a button to pop up the menu of the current window."
 msgstr ""
+"Applet kan stjäla maximerade fönsters överkant, i så fall kommer det att "
+"visa fönsterkontrollknapparna.\n"
+"Applet kan stjäla menyn från fönstren, i så fall kommer det att visa en "
+"knapp för att visa menyn i det aktiva fönstret."
 
 #: ../Global-Menu/data/messages:89
 msgid "Steal window menu"
-msgstr ""
+msgstr "Stjäl fönstermeny"
 
 #: ../Global-Menu/data/messages:91
 msgid "Steal window decoration"
-msgstr ""
+msgstr "Stjäl fönsterdekortation"
 
 #: ../Global-Menu/data/messages:93
 msgid "Steal window menu and border"
-msgstr ""
+msgstr "Stjäl fönstermeny och kant"
 
 #: ../Global-Menu/data/messages:95
 msgid "Shortkey to pop up the menu"
-msgstr ""
+msgstr "Kortkommando för att visa menyn"
 
 #: ../Global-Menu/data/messages:97
 msgid "Pop up the menu at mouse position"
-msgstr ""
+msgstr "Visa menyn vid muspekarens position"
 
 #: ../Global-Menu/data/messages:99
 msgid "Compact mode"
-msgstr ""
+msgstr "Kompakt läge"
 
 #: ../Global-Menu/data/messages:101
 msgid "Order of the buttons: "
-msgstr ""
+msgstr "Knappordning: "
 
 #: ../Global-Menu/data/messages:103
 msgid "Auto"
-msgstr ""
+msgstr "Auto"
 
 #: ../Global-Menu/data/messages:105
 msgid "Close button at the end"
-msgstr ""
+msgstr "Stängningsknapp i slutet"
 
 #: ../Global-Menu/data/messages:107
 msgid "Close button at first"
-msgstr ""
+msgstr "Stängningsknapp först"
 
 #: ../Global-Menu/data/messages:109
 msgid "Image for the 'minimize' button"
-msgstr ""
+msgstr "Bild för \"minimera\"-knappen"
 
 #: ../Global-Menu/data/messages:111
 msgid "Image for the 'maximize' button"
-msgstr ""
+msgstr "Bild för \"maximera\"-knappen"
 
 #: ../Global-Menu/data/messages:113
 msgid "Image for the 'restore' button"
-msgstr ""
+msgstr "Bild för \"återställ\"-knappen"
 
 #: ../Global-Menu/data/messages:115
 msgid "Image for the 'close' button"
-msgstr ""
+msgstr "Bild för \"stängnings\"-knappen"
 
 #: ../Impulse/data/messages:87
 msgid "Animation of the icons:"
-msgstr ""
+msgstr "Ikonanimering:"
 
 #: ../Impulse/data/messages:89
 msgid ""
 "Do we have to stop the animation on a icon which doesn't have to be animated "
 "each refresh?"
 msgstr ""
+"Måste vi stoppa animeringen på en ikon som inte måste animeras varje "
+"uppdatering?"
 
 #: ../Impulse/data/messages:91
 msgid "Stop animations sooner?"
-msgstr ""
+msgstr "Stoppa animeringar tidigare?"
 
 #: ../Impulse/data/messages:93 ../alsaMixer/data/messages:133
 msgid "Control"
@@ -5929,19 +6219,19 @@ msgstr "Kontroll"
 #: ../Impulse/data/messages:95
 msgid ""
 "It's the sensitivity in order to know if the animation is played or not."
-msgstr ""
+msgstr "Det är känsligheten för att veta om animeringen spelas eller inte."
 
 #: ../Impulse/data/messages:97
 msgid "Sensitivity of the animation:"
-msgstr ""
+msgstr "Animeringens känslighet:"
 
 #: ../Impulse/data/messages:99 ../Impulse/data/messages:109
 msgid "More"
-msgstr ""
+msgstr "Mer"
 
 #: ../Impulse/data/messages:101 ../Impulse/data/messages:107
 msgid "Less"
-msgstr ""
+msgstr "Mindre"
 
 #: ../Impulse/data/messages:103
 msgid "in ms."
@@ -5949,52 +6239,52 @@ msgstr "i ms."
 
 #: ../Impulse/data/messages:105
 msgid "Time between two animations:"
-msgstr ""
+msgstr "Tid mellan två animeringar:"
 
 #: ../Impulse/data/messages:111
 msgid "Action at Startup"
-msgstr ""
+msgstr "Åtgärd vid start"
 
 #: ../Impulse/data/messages:113
 msgid "Launch automatically at startup?"
-msgstr ""
+msgstr "Starta automatiskt vid start?"
 
 #: ../Impulse/data/messages:115
 msgid "Hide the icon?"
-msgstr ""
+msgstr "Dölj ikonen?"
 
 #: ../Impulse/data/messages:119
 msgid "Image when the applet is active:"
-msgstr ""
+msgstr "Bild då applet är aktivt:"
 
 #: ../Impulse/data/messages:121
 msgid "Image when the applet is inactive:"
-msgstr ""
+msgstr "Bild då applet är inaktivt:"
 
 #: ../Impulse/data/messages:123 ../musicPlayer/data/messages:205
 #: ../tomboy/data/messages:23
 msgid "'Broken' icon image name:"
-msgstr "Bild för bruten:"
+msgstr "Bildnamn för \"trasig\" ikon:"
 
 #: ../Impulse/data/messages:125
 msgid "PulseAudio"
-msgstr ""
+msgstr "PulseAudio"
 
 #: ../Impulse/data/messages:127
 msgid "0 in most cases"
-msgstr ""
+msgstr "0 i de flesta fall"
 
 #: ../Impulse/data/messages:129
 msgid "Index of the source:"
-msgstr ""
+msgstr "Källans index:"
 
 #: ../Indicator-Generic/data/messages:91
 msgid "Separated by a semi-colon ';'"
-msgstr ""
+msgstr "Åtskilda med ett semikolon \";\""
 
 #: ../Indicator-Generic/data/messages:93
 msgid "Blacklist these indicators:"
-msgstr ""
+msgstr "Svartlista dessa indikatorer:"
 
 #: ../Messaging-Menu/data/messages:15 ../Network-Monitor/data/messages:17
 #: ../Status-Notifier/data/messages:19 ../System-Monitor/data/messages:15
@@ -6005,7 +6295,7 @@ msgstr ""
 #: ../slider/data/messages:15 ../weather/data/messages:17
 #: ../wifi/data/messages:15
 msgid "Always display the icon, even when the dock is hidden?"
-msgstr ""
+msgstr "Visa alltid ikonen, även när dockan är dold?"
 
 #: ../Messaging-Menu/data/messages:19 ../Network-Monitor/data/messages:21
 #: ../Status-Notifier/data/messages:23 ../System-Monitor/data/messages:19
@@ -6016,7 +6306,7 @@ msgstr ""
 #: ../slider/data/messages:19 ../weather/data/messages:21
 #: ../wifi/data/messages:19
 msgid "With default background"
-msgstr ""
+msgstr "Med standardbakgrund"
 
 #: ../Messaging-Menu/data/messages:21 ../Network-Monitor/data/messages:23
 #: ../Status-Notifier/data/messages:25 ../System-Monitor/data/messages:21
@@ -6027,7 +6317,7 @@ msgstr ""
 #: ../slider/data/messages:21 ../weather/data/messages:23
 #: ../wifi/data/messages:21
 msgid "With custom background"
-msgstr ""
+msgstr "Med anpassad bakgrund"
 
 #: ../Messaging-Menu/data/messages:23 ../Network-Monitor/data/messages:25
 #: ../Status-Notifier/data/messages:27 ../System-Monitor/data/messages:23
@@ -6038,55 +6328,55 @@ msgstr ""
 #: ../slider/data/messages:23 ../weather/data/messages:25
 #: ../wifi/data/messages:23
 msgid "Background color to add in this case"
-msgstr ""
+msgstr "Bakgrundsfärg att lägga till i detta fall"
 
 #: ../Messaging-Menu/data/messages:99
 msgid ""
 "Animation of the icon when one of the application demands your attention :"
-msgstr ""
+msgstr "Ikonens animering när ett av programmen kräver din uppmärksamhet :"
 
 #: ../Network-Monitor/data/messages:7
 msgid "Leave empty to use the connection name."
-msgstr ""
+msgstr "Lämna tomt för att använda namnet på anslutningen."
 
 #: ../Network-Monitor/data/messages:11 ../wifi/data/messages:9
 msgid "Connection name"
-msgstr ""
+msgstr "Anslutningsnamn"
 
 #: ../Network-Monitor/data/messages:101 ../Network-Monitor/data/messages:173
 #: ../Network-Monitor/data/messages:261 ../System-Monitor/data/messages:143
 #: ../netspeed/data/messages:143 ../powermanager/data/messages:143
 #: ../tomboy/data/messages:123 ../wifi/data/messages:153
 msgid "Parameters"
-msgstr ""
+msgstr "Parametrar"
 
 #: ../Network-Monitor/data/messages:103
 msgid "You can quickly switch to the other mode by scrolling on the icon."
-msgstr ""
+msgstr "Du kan snabbt växla till det andra läget genom att rulla på ikonen."
 
 #: ../Network-Monitor/data/messages:105
 msgid "Info displayed by the icon:"
-msgstr ""
+msgstr "Information visas av ikonen:"
 
 #: ../Network-Monitor/data/messages:107
 msgid "Wifi signal"
-msgstr ""
+msgstr "Wifi-signal"
 
 #: ../Network-Monitor/data/messages:109
 msgid "Connexion speed"
-msgstr ""
+msgstr "Anslutningshastighet"
 
 #: ../Network-Monitor/data/messages:111
 msgid "By default the first active interface is used."
-msgstr ""
+msgstr "Som standard används det första aktiva gränssnittet."
 
 #: ../Network-Monitor/data/messages:113
 msgid "Connection interface to monitor:"
-msgstr ""
+msgstr "Anslutningsgränssnitt att övervaka:"
 
 #: ../Network-Monitor/data/messages:115
 msgid "Display numeric values:"
-msgstr ""
+msgstr "Visa numeriska värden:"
 
 #: ../Network-Monitor/data/messages:123 ../System-Monitor/data/messages:173
 #: ../wifi/data/messages:159
@@ -6094,60 +6384,64 @@ msgid ""
 "You need OpenGL for this option. Set it to 0 means not used, 1 means the "
 "movement is continue."
 msgstr ""
+"Du behöver OpenGL för detta alternativ. Ställ in till 0 betyder använd inte, "
+"1 betyder fortsatt rörelse."
 
 #: ../Network-Monitor/data/messages:125
 msgid "Fluidity of the transition animation between 2 values:"
-msgstr ""
+msgstr "Övergångsanimeringens fluiditet mellan 2 värden:"
 
 #: ../Network-Monitor/data/messages:127
 msgid "Animation of the icon when connecting:"
-msgstr ""
+msgstr "Ikonanimering vid anslutning:"
 
 #: ../Network-Monitor/data/messages:129
 msgid ""
 "Allow you to overwrite applet's default command line and launch your "
 "preferred wireless configuration interface."
 msgstr ""
+"Låter dig skriva över applets standardkommandorad och starta ditt föredragna "
+"trådlösa inställningsgränssnitt."
 
 #: ../Network-Monitor/data/messages:131
 msgid "User command to show Wireless Configuration:"
-msgstr ""
+msgstr "Användarkommando för att visa Trådlös inställning:"
 
 #: ../Network-Monitor/data/messages:135 ../System-Monitor/data/messages:187
 #: ../netspeed/data/messages:167
 msgid "User command to display a system monitor:"
-msgstr ""
+msgstr "Användarkommando för att visa systemövervakning:"
 
 #: ../Network-Monitor/data/messages:137
 msgid "Net Speed"
-msgstr ""
+msgstr "Näthastighet"
 
 #: ../Network-Monitor/data/messages:163 ../Network-Monitor/data/messages:207
 #: ../wifi/data/messages:125
 msgid "It's the colour of the graphic for high quality signal."
-msgstr ""
+msgstr "Det är färgen på grafiken för signal med hög kvalitet."
 
 #: ../Network-Monitor/data/messages:167 ../Network-Monitor/data/messages:211
 #: ../wifi/data/messages:129
 msgid "It's the colour of the graphic for low quality signal."
-msgstr ""
+msgstr "Det är färgen på grafiken för signal med dålig kvalitet."
 
 #: ../Network-Monitor/data/messages:177
 msgid "Delays between net speed checks:"
-msgstr ""
+msgstr "Fördröjningar mellan näthastighetskontroller:"
 
 #: ../Network-Monitor/data/messages:181
 msgid "Choose the style of the display:"
-msgstr ""
+msgstr "Välj visningsstilen:"
 
 #: ../Network-Monitor/data/messages:187 ../Network-Monitor/data/messages:217
 #: ../powermanager/data/messages:137
 msgid "Icons"
-msgstr ""
+msgstr "Ikoner"
 
 #: ../Network-Monitor/data/messages:219
 msgid "Effect to apply on the icon according to strength :"
-msgstr ""
+msgstr "Effekt att använda på ikonen utefter styrka :"
 
 #: ../Network-Monitor/data/messages:223
 msgid "Zoom"
@@ -6155,11 +6449,11 @@ msgstr "Zoom"
 
 #: ../Network-Monitor/data/messages:225
 msgid "Transparency"
-msgstr "Transparens"
+msgstr "Genomskinlighet"
 
 #: ../Network-Monitor/data/messages:227
 msgid "Draw Bar"
-msgstr "Visa stapel"
+msgstr "Rita stapel"
 
 #: ../Network-Monitor/data/messages:229 ../Network-Monitor/data/messages:233
 #: ../Network-Monitor/data/messages:237 ../Network-Monitor/data/messages:241
@@ -6171,693 +6465,707 @@ msgstr "Visa stapel"
 #: ../tomboy/data/messages:13 ../tomboy/data/messages:17
 #: ../tomboy/data/messages:21 ../tomboy/data/messages:105
 msgid "Leave empty to use the default icon."
-msgstr ""
+msgstr "Lämna tomt för att använda standardikonen."
 
 #: ../Network-Monitor/data/messages:231
 msgid "Name of the image for the 'No signal' icon :"
-msgstr ""
+msgstr "Namnet på bilden för \"Ingen signal\" ikonen :"
 
 #: ../Network-Monitor/data/messages:235
 msgid "Name of the image for the 'Very low' icon :"
-msgstr ""
+msgstr "Namnet på bilden för \"Mycket lågt\" ikonen :"
 
 #: ../Network-Monitor/data/messages:239
 msgid "Name of the image for the 'Low' icon :"
-msgstr ""
+msgstr "Namnet på bilden för \"Lågt\" ikonen :"
 
 #: ../Network-Monitor/data/messages:243
 msgid "Name of the image for the 'Middle' icon :"
-msgstr ""
+msgstr "Namnet på bilden för \"Mellan\" ikonen :"
 
 #: ../Network-Monitor/data/messages:247
 msgid "Name of an image for the 'Good' icon :"
-msgstr ""
+msgstr "Namnet på bilden for \"Bra\" ikonen :"
 
 #: ../Network-Monitor/data/messages:251
 msgid "Name of the image for the 'Excellent' icon :"
-msgstr ""
+msgstr "Namnet på bilden för \"Utmärkt\" ikonen :"
 
 #: ../Network-Monitor/data/messages:255
 msgid "Name of the image for the 'Not connected' icon :"
-msgstr ""
+msgstr "Namnet på bilden för \"Inte ansluten\" ikonen :"
 
 #: ../Network-Monitor/data/messages:259
 msgid "Name of the image for the 'Wired connection' icon :"
-msgstr ""
+msgstr "Namnet på bilden för \"Trådburen anslutning\" ikonen :"
 
 #: ../Network-Monitor/data/messages:263
 msgid "in seconds. if you don't have Network-Manager."
-msgstr ""
+msgstr "i sekunder. Om du inte har Nätverkshanterare."
 
 #: ../Network-Monitor/data/messages:265
 msgid "Delays between wifi signal checks:"
-msgstr ""
+msgstr "Fördröjning mellan wifi signalkontroller:"
 
 #: ../RSSreader/data/messages:7
 msgid "Leave empty to use the title of the RSS feed."
-msgstr ""
+msgstr "Lämna tomt för att använda RSS-flödets titel."
 
 #: ../RSSreader/data/messages:93
 msgid "RSS Feed"
-msgstr ""
+msgstr "RSS-flöde"
 
 #: ../RSSreader/data/messages:95
 msgid "Enter a valid atom/rss feed"
-msgstr ""
+msgstr "Ange ett giltigt atom/rss-flöde"
 
 #: ../RSSreader/data/messages:99
 msgid "RSS login (optional):"
-msgstr ""
+msgstr "RSS-inloggning (valfritt):"
 
 #: ../RSSreader/data/messages:101
 msgid "RSS password (optional):"
-msgstr ""
+msgstr "RSS-lösenord (valfritt):"
 
 #: ../RSSreader/data/messages:109
 msgid "Notify about feed updates:"
-msgstr ""
+msgstr "Informera om flödesuppdateringar:"
 
 #: ../RSSreader/data/messages:113 ../powermanager/data/messages:189
 msgid "Icon animation"
-msgstr ""
+msgstr "Ikonanimering"
 
 #: ../RSSreader/data/messages:115 ../powermanager/data/messages:191
 msgid "Dialog bubble"
-msgstr ""
+msgstr "Dialogbubbla"
 
 #: ../RSSreader/data/messages:117 ../powermanager/data/messages:193
 msgid "Icon animation + Dialog bubble"
-msgstr ""
+msgstr "Ikonanimering + Dialogbubbla"
 
 #: ../RSSreader/data/messages:119 ../powermanager/data/messages:195
 msgid "Let empty to use the default notification animation."
-msgstr ""
+msgstr "Lämna tomt för att använda standardunderrättelseanimering."
 
 #: ../RSSreader/data/messages:121 ../powermanager/data/messages:197
 msgid "Animation of the icon:"
-msgstr ""
+msgstr "Ikonens animering:"
 
 #: ../RSSreader/data/messages:123 ../powermanager/data/messages:199
 msgid ""
 "In seconds. Set to 0 for infinite time (need to click on dialog to close it)."
 msgstr ""
+"I sekunder. Ställ in till 0 för obegränsad tid (behöver klick på dialog för "
+"att stäng den)."
 
 #: ../RSSreader/data/messages:125 ../powermanager/data/messages:201
 msgid "Duration of the notification:"
-msgstr ""
+msgstr "Varaktighet för notifieringen:"
 
 #: ../RSSreader/data/messages:127
 msgid "Open the feed with the following program:"
-msgstr ""
+msgstr "Öppna flödet med följande program:"
 
 #: ../RSSreader/data/messages:135
 msgid "Font to be used for the title"
-msgstr ""
+msgstr "Teckensnitt som ska användas för titeln"
 
 #: ../RSSreader/data/messages:137
 msgid "Title font:"
-msgstr ""
+msgstr "Titelteckensnitt:"
 
 #: ../RSSreader/data/messages:139
 msgid "Colour to be used for the title"
-msgstr ""
+msgstr "Färg som ska användas för titeln"
 
 #: ../RSSreader/data/messages:141
 msgid "Title colour:"
-msgstr ""
+msgstr "Titelfärg:"
 
 #: ../RSSreader/data/messages:143
 msgid "Alignment of the title:"
-msgstr ""
+msgstr "Titelns justering:"
 
 #: ../RSSreader/data/messages:145
 msgid "left"
-msgstr ""
+msgstr "vänster"
 
 #: ../RSSreader/data/messages:147
 msgid "right"
-msgstr ""
+msgstr "höger"
 
 #: ../RSSreader/data/messages:151
 msgid "Font to be used for the feed lines"
-msgstr ""
+msgstr "Teckensnitt som ska användas för flödesraderna"
 
 #: ../RSSreader/data/messages:153
 msgid "Feed lines font:"
-msgstr ""
+msgstr "Flödesradsteckensnitt:"
 
 #: ../RSSreader/data/messages:155
 msgid "Colour to be used for the feed lines"
-msgstr ""
+msgstr "Färg som ska användas för flödesraderna"
 
 #: ../RSSreader/data/messages:157
 msgid "Feed lines colour:"
-msgstr ""
+msgstr "Flödesradsfärg:"
 
 #: ../RSSreader/data/messages:159
 msgid "Left margin for the feed lines:"
-msgstr ""
+msgstr "Vänstermarginal för flödesraderna:"
 
 #: ../RSSreader/data/messages:161
 msgid "Space between 2 feed lines:"
-msgstr ""
+msgstr "Avstånd mellan 2 flödesrader:"
 
 #: ../RSSreader/data/messages:163
 msgid "Logo"
-msgstr ""
+msgstr "Logotype"
 
 #: ../RSSreader/data/messages:165
 msgid "The default logo is the applet's icon"
-msgstr ""
+msgstr "Standardlogotypen är applets ikon"
 
 #: ../RSSreader/data/messages:167
 msgid "Display the logo?"
-msgstr ""
+msgstr "Visa logotypen?"
 
 #: ../RSSreader/data/messages:169
 msgid "Adjust to increase/decrease the logo's size"
-msgstr ""
+msgstr "Justera för att öka/minska logotypens storlek"
 
 #: ../RSSreader/data/messages:171
 msgid "Logo size:"
-msgstr ""
+msgstr "Logotypstorlek:"
 
 #: ../RSSreader/data/messages:173 ../dock-rendering/data/messages:47
 #: ../keyboard-indicator/data/messages:133
 msgid "normal"
-msgstr ""
+msgstr "normal"
 
 #: ../RSSreader/data/messages:175 ../dock-rendering/data/messages:49
 msgid "big"
-msgstr ""
+msgstr "stor"
 
 #: ../Recent-Events/data/messages:91
 msgid "Shortkey to show/hide the search dialog"
-msgstr ""
+msgstr "Kortkommando för att visa/dölja sökdialogen"
 
 #: ../Recent-Events/data/messages:93
 msgid "Max number of results to show"
-msgstr ""
+msgstr "Maxantal resultat som visas"
 
 #: ../Remote-Control/data/messages:1 ../Scooby-Do/data/messages:1
 msgid "Help"
-msgstr ""
+msgstr "Hjälp"
 
 #: ../Remote-Control/data/messages:5
 msgid "Shortkey to trigger the applet:"
-msgstr ""
+msgstr "Kortkommando för att utlösa applet:"
 
 #: ../Remote-Control/data/messages:7
 msgid "Dock to control initially"
-msgstr ""
+msgstr "Docka att kontrollera inldningsvis"
 
 #: ../Remote-Control/data/messages:9 ../Scooby-Do/data/messages:25
 msgid "Animation of the current icon :"
-msgstr ""
+msgstr "Animering av den aktuella ikonen :"
 
 #: ../Remote-Control/data/messages:13 ../Scooby-Do/data/messages:23
 msgid "Duration of the stop animation :"
-msgstr ""
+msgstr "Varaktighet för stoppanimeringen :"
 
 #: ../Scooby-Do/data/messages:5
 msgid "Shortkey to enable/disable the finder mode:"
-msgstr ""
+msgstr "Kortkommando för att aktivera/inaktivera sökläget:"
 
 #: ../Scooby-Do/data/messages:7
 msgid ""
 "Maximum number of mails that will be previewed. Put -1 to show the maximum "
 "possible."
 msgstr ""
+"Maximalt antal e-postmeddelanden som kommer att förhandsvisas. Ange -1 för "
+"att visa flesta möjliga."
 
 #: ../Scooby-Do/data/messages:9
 msgid "Maximum number of results :"
-msgstr ""
+msgstr "Maximalt antal resultat :"
 
 #: ../Scooby-Do/data/messages:11
 msgid ""
 "Number of lines of the listing. If there are more results, the listing will "
 "scroll when you go up or down with the arrows."
 msgstr ""
+"Antal rader i listan. Om det finns fler resultat, kommer listan att rulla "
+"när du går upp eller ner med pilarna."
 
 #: ../Scooby-Do/data/messages:13
 msgid "Number of lines to display :"
-msgstr ""
+msgstr "Antal rader som visas :"
 
 #: ../Scooby-Do/data/messages:15
 msgid "Animations"
-msgstr ""
+msgstr "Animeringar"
 
 #: ../Scooby-Do/data/messages:19
 msgid "Duration of the appearance animation :"
-msgstr ""
+msgstr "Varaktighet för visningsanimeringen :"
 
 #: ../Scooby-Do/data/messages:29
 msgid "Font used to display what you type:"
-msgstr ""
+msgstr "Teckensnitt som används för att visa vad du skriver:"
 
 #: ../Scooby-Do/data/messages:31
 msgid "Color of the text's frame  :"
-msgstr ""
+msgstr "Färg på textramen :"
 
 #: ../Scooby-Do/data/messages:33
 msgid "Font size, relative to the dock size:"
-msgstr ""
+msgstr "Teckensnittsstorlek relativt till dockans storlek:"
 
 #: ../Scooby-Do/data/messages:35
 msgid "between 1 and 9, the higher, the bigger."
-msgstr ""
+msgstr "mellan 1 och 9, ju högre, desto större."
 
 #: ../Scooby-Do/data/messages:37
 msgid "Text size:"
-msgstr ""
+msgstr "Textstorlek:"
 
 #: ../Scooby-Do/data/messages:39 ../keyboard-indicator/data/messages:123
 msgid "Outline text?"
-msgstr ""
+msgstr "Textkontur?"
 
 #: ../Scooby-Do/data/messages:41 ../clock/data/messages:157
 #: ../keyboard-indicator/data/messages:121
 msgid "Text colour"
-msgstr ""
+msgstr "Textfärg"
 
 #: ../Scooby-Do/data/messages:43
 msgid "Character background colour:"
-msgstr ""
+msgstr "Teckenbakgrundsfärg:"
 
 #: ../Scooby-Do/data/messages:45
 msgid "Write text on the top of the dock?"
-msgstr ""
+msgstr "Skriv text ovanpå dockan?"
 
 #: ../Scooby-Do/data/messages:47
 msgid "Favorite applications"
-msgstr ""
+msgstr "Favoritprogram"
 
 #: ../Scooby-Do/data/messages:49
 msgid "FAvorite applications starting with 'a' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"a\":"
 
 #: ../Scooby-Do/data/messages:51
 msgid "Favorite application starting with 'b' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"b\":"
 
 #: ../Scooby-Do/data/messages:53
 msgid "Favorite application(s) starting with 'c' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"c\":"
 
 #: ../Scooby-Do/data/messages:55
 msgid "Favorite application(s starting with 'd' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"d\":"
 
 #: ../Scooby-Do/data/messages:57
 msgid "Favorite application(s) starting with 'e' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"e\":"
 
 #: ../Scooby-Do/data/messages:59
 msgid "Favorite application(s) starting with 'f' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"f\":"
 
 #: ../Scooby-Do/data/messages:61
 msgid "Favorite application(s) starting with 'g' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"g\":"
 
 #: ../Scooby-Do/data/messages:63
 msgid "Favorite application(s) starting with 'h' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"h\":"
 
 #: ../Scooby-Do/data/messages:65
 msgid "Favorite application(s) starting with 'i' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"i\":"
 
 #: ../Scooby-Do/data/messages:67
 msgid "Favorite application(s) starting with 'j' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"j\":"
 
 #: ../Scooby-Do/data/messages:69
 msgid "Favorite application(s) starting with 'k' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"k\":"
 
 #: ../Scooby-Do/data/messages:71
 msgid "Favorite application(s) starting with 'l' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"l\":"
 
 #: ../Scooby-Do/data/messages:73
 msgid "Favorite application(s) starting with 'm' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"m\":"
 
 #: ../Scooby-Do/data/messages:75
 msgid "Favorite application(s) starting with 'n' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"n\":"
 
 #: ../Scooby-Do/data/messages:77
 msgid "Favorite application(s) starting with 'o' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"o\":"
 
 #: ../Scooby-Do/data/messages:79
 msgid "Favorite application(s) starting with 'p' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"p\":"
 
 #: ../Scooby-Do/data/messages:81
 msgid "Favorite application(s) starting with 'q' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"q\":"
 
 #: ../Scooby-Do/data/messages:83
 msgid "Favorite application(s) starting with 'r' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"r\":"
 
 #: ../Scooby-Do/data/messages:85
 msgid "Favorite application(s) starting with 's' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"s\":"
 
 #: ../Scooby-Do/data/messages:87
 msgid "Favorite application(s) starting with 't' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"t\":"
 
 #: ../Scooby-Do/data/messages:89
 msgid "Favorite application(s) starting with 'u' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"u\":"
 
 #: ../Scooby-Do/data/messages:91
 msgid "Favorite application(s) starting with 'v' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"v\":"
 
 #: ../Scooby-Do/data/messages:93
 msgid "Favorite application(s) starting with 'w' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"w\":"
 
 #: ../Scooby-Do/data/messages:95
 msgid "Favorite application(s) starting with 'x' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"x\":"
 
 #: ../Scooby-Do/data/messages:97
 msgid "Favorite application(s) starting with 'y' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"y\":"
 
 #: ../Scooby-Do/data/messages:99
 msgid "Favorite application(s) starting with 'z' :"
-msgstr ""
+msgstr "Favoritprogram som början med \"z\":"
 
 #: ../Scooby-Do/data/messages:109
 msgid "Propose some web search engines ?"
-msgstr ""
+msgstr "Föreslå några Internetsökmotorer ?"
 
 #: ../Scooby-Do/data/messages:111
 msgid "It can launch commands and even do some calculations."
-msgstr ""
+msgstr "Den kan köra kommandon och till och med utföra en del beräkningar."
 
 #: ../Screenshot/data/messages:91
 msgid "Shortkey to take a screenshot"
-msgstr ""
+msgstr "Kortkommando för att ta en skärmdump"
 
 #: ../Screenshot/data/messages:93
 msgid "Save image in"
-msgstr ""
+msgstr "Spara bild i"
 
 #: ../Sound-Effects/data/messages:3
 msgid "Play a sound on click ?"
-msgstr ""
+msgstr "Spela ett ljud vid klick ?"
 
 #: ../Sound-Effects/data/messages:5 ../Sound-Effects/data/messages:11
 #: ../Sound-Effects/data/messages:17
 msgid "A .wav file encoded in PCM."
-msgstr ""
+msgstr "En .wav-fil kodad i PCM."
 
 #: ../Sound-Effects/data/messages:7 ../Sound-Effects/data/messages:13
 #: ../Sound-Effects/data/messages:19
 msgid "Sound file"
-msgstr ""
+msgstr "Ljudfil"
 
 #: ../Sound-Effects/data/messages:9
 msgid "Play a sound on middle click ?"
-msgstr ""
+msgstr "Spela ett ljud vid mittenklick ?"
 
 #: ../Sound-Effects/data/messages:15
 msgid "Play a sound on mouse hover ?"
-msgstr ""
+msgstr "Spela ett ljud vid mussvävning ?"
 
 #: ../Sound-Effects/data/messages:21
 msgid "Volume:"
-msgstr ""
+msgstr "Volym:"
 
 #: ../Sound-Effects/data/messages:25
 msgid "High"
-msgstr ""
+msgstr "Hög"
 
 #: ../Status-Notifier/data/messages:13
 msgid "Image's filename :"
-msgstr ""
+msgstr "Bildens filnamn :"
 
 #: ../Status-Notifier/data/messages:105
 msgid "Hide inactive items"
-msgstr ""
+msgstr "Dölj inaktiva objekt"
 
 #: ../Status-Notifier/data/messages:107
 msgid "How to display items:"
-msgstr ""
+msgstr "Hur objekt visas:"
 
 #: ../Status-Notifier/data/messages:109
 msgid "Compact"
-msgstr ""
+msgstr "Kompakt"
 
 #: ../Status-Notifier/data/messages:111
 msgid "Sub-dock"
-msgstr ""
+msgstr "Underdocka"
 
 #: ../Status-Notifier/data/messages:113
 msgid "Allow the icon to automatically resize itself?"
-msgstr ""
+msgstr "Tillåt ikonen att ändra storlek på sig själv automatiskt?"
 
 #: ../Status-Notifier/data/messages:115
 msgid "Number of lines to pack items in:"
-msgstr ""
+msgstr "Antal rader att packa objekt på:"
 
 #: ../Status-Notifier/data/messages:119
 msgid "Left click pops up the items' menu"
-msgstr ""
+msgstr "Vänsterklick visar objektets meny"
 
 #: ../System-Monitor/data/messages:99 ../alsaMixer/data/messages:109
 #: ../powermanager/data/messages:101 ../wifi/data/messages:99
 msgid "Display style"
-msgstr ""
+msgstr "Visningsstil"
 
 #: ../System-Monitor/data/messages:107 ../alsaMixer/data/messages:121
 #: ../powermanager/data/messages:111 ../wifi/data/messages:109
 msgid "Gauge theme"
-msgstr ""
+msgstr "Reglagetema"
 
 #: ../System-Monitor/data/messages:131 ../powermanager/data/messages:127
 msgid "It's the colour of the graphic for high values."
-msgstr ""
+msgstr "Det är färgen på grafiken för höga värden."
 
 #: ../System-Monitor/data/messages:135 ../powermanager/data/messages:131
 msgid "It's the colour of the graphic for low values."
-msgstr ""
+msgstr "Det är färgen på grafiken för låga värden."
 
 #: ../System-Monitor/data/messages:145
 msgid "Show CPU usage?"
-msgstr ""
+msgstr "Visa CPU-användning?"
 
 #: ../System-Monitor/data/messages:147
 msgid "Show RAM usage ?"
-msgstr ""
+msgstr "Visa RAM-användning ?"
 
 #: ../System-Monitor/data/messages:149
 msgid "Show SWAP too?"
-msgstr ""
+msgstr "Visa SWAP också?"
 
 #: ../System-Monitor/data/messages:151
 msgid "You need an nVidia card and the 'nvidia-settings' tool."
-msgstr ""
+msgstr "Du behöver ett nVidia-kort och \"nvidia-inställnings\" verktyget."
 
 #: ../System-Monitor/data/messages:153
 msgid "Show graphic card's temperature?"
-msgstr ""
+msgstr "Visa grafikkortstemperaturen?"
 
 #: ../System-Monitor/data/messages:155
 msgid "Show CPU temperature?"
-msgstr ""
+msgstr "Visa CPU-temperaturen?"
 
 #: ../System-Monitor/data/messages:157
 msgid "Show fan speed?"
-msgstr ""
+msgstr "Visa fläkthastighet?"
 
 #: ../System-Monitor/data/messages:159
 msgid "Show free memory instead of used memory?"
-msgstr ""
+msgstr "Visa ledigt minne istället för använt minne?"
 
 #: ../System-Monitor/data/messages:161
 msgid "Display values :"
-msgstr ""
+msgstr "Visa värden :"
 
 #: ../System-Monitor/data/messages:171
 msgid "Delay between refreshes:"
-msgstr "Tid mellan uppdateringar:"
+msgstr "Fördröjning mellan uppdateringar:"
 
 #: ../System-Monitor/data/messages:175 ../wifi/data/messages:161
 msgid "How smooth is the movement?"
-msgstr ""
+msgstr "Hur mjuk är rörelsen?"
 
 #: ../System-Monitor/data/messages:177
 msgid "Alerts"
-msgstr ""
+msgstr "Larm"
 
 #: ../System-Monitor/data/messages:179
 msgid "Show alerts?"
-msgstr ""
+msgstr "Visa larm?"
 
 #: ../System-Monitor/data/messages:181
 msgid "Play a sound when displaying warning?"
-msgstr ""
+msgstr "Spela ett ljud då en varning visas?"
 
 #: ../System-Monitor/data/messages:183
 msgid "Path to sound file:"
-msgstr ""
+msgstr "Sökväg till ljudfil:"
 
 #: ../System-Monitor/data/messages:185
 msgid "System-Monitor"
-msgstr ""
+msgstr "Systemövervakare"
 
 #: ../System-Monitor/data/messages:191
 msgid ""
 "It will prevent the system monitor's icon to show in the taskbar. The "
 "applet's icon will then behave as a launcher, an application, and an applet."
 msgstr ""
+"Det kommer att förhindra systemövervakarens ikon att visas i "
+"aktivitetsfältet. Applets ikon kommer då att bete sig som en "
+"programstartare, ett program och en applet."
 
 #: ../System-Monitor/data/messages:193
 msgid "Steal the system monitor's icon from the taskbar?"
-msgstr ""
+msgstr "Stjäla systemövervakarens ikon från aktivitetsfältet?"
 
 #: ../System-Monitor/data/messages:195
 msgid "Class of the system monitor program:"
-msgstr ""
+msgstr "Systemövervakningsprogrammets klass:"
 
 #: ../System-Monitor/data/messages:199
 msgid "Top List"
-msgstr ""
+msgstr "Topplista"
 
 #: ../System-Monitor/data/messages:201
 msgid ""
 "When you left-click on the icon, you will get the list of the N most CPU/RAM-"
 "intensive programs."
 msgstr ""
+"När du vänsterklickar på ikonen, kommer du att få en lista över de N mest "
+"CPU/RAM-intensiva programmen."
 
 #: ../System-Monitor/data/messages:203
 msgid "Number of programs to display in the top list:"
-msgstr "Antal program att visa:"
+msgstr "Antal program som ska visas i topplistan:"
 
 #: ../System-Monitor/data/messages:205
 msgid "The first colour of the gradient used to display the top list."
-msgstr "Startfärgen för färgtoning i topplistan."
+msgstr ""
+"Den första färgen i färgtoningen som används för att visa topplistan."
 
 #: ../System-Monitor/data/messages:207
 msgid "Top list start colour:"
-msgstr "Startfärg för topplistan:"
+msgstr "Startfärg topplista:"
 
 #: ../System-Monitor/data/messages:209
 msgid "The second colour of the gradient used to display the top list."
-msgstr "Slutfärgen för färgtoning i topplistan."
+msgstr "Den andra färgen i färgtoningen som används för att visa topplistan."
 
 #: ../System-Monitor/data/messages:211
 msgid "Top list stop colour:"
-msgstr "Slutfärg för topplistan:"
+msgstr "Slutfärg topplista:"
 
 #: ../System-Monitor/data/messages:213
 msgid "Show top memory usage in %?"
-msgstr ""
+msgstr "Visa högsta minnesanvändning i %?"
 
 #: ../System-Monitor/data/messages:217
 msgid "Delay between top list refreshes:"
-msgstr ""
+msgstr "Fördröjning mellan topplistsuppdateringar:"
 
 #: ../System-Monitor/data/messages:219
 msgid "Graphic Card temperature"
-msgstr ""
+msgstr "Grafikkortstemperatur"
 
 #: ../System-Monitor/data/messages:221 ../System-Monitor/data/messages:225
 msgid ""
 "in Celsius. The temperature will be displayed between this value and the "
 "upper limit."
 msgstr ""
+"i Celsiua. Temperaturen kommer att visas mellan detta värde och den övre "
+"gränsen."
 
 #: ../System-Monitor/data/messages:223
 msgid "Lower limit of graphic card temperature:"
-msgstr ""
+msgstr "Undre gräns för grafikkortstemperatur:"
 
 #: ../System-Monitor/data/messages:227
 msgid "Upper limit of graphic card temperature:"
-msgstr ""
+msgstr "Övre gräns för grafikkortstemperatur:"
 
 #: ../System-Monitor/data/messages:229
 msgid "in celcius."
-msgstr ""
+msgstr "i Celsius"
 
 #: ../System-Monitor/data/messages:231
 msgid "Notification limit of graphic card temperature:"
-msgstr ""
+msgstr "Notifieringsgräns för grafikkortstemperatur:"
 
 #: ../Toons/data/messages:103
 msgid "Mean delay between winks:"
-msgstr ""
+msgstr "Genomsnittsfördröjning mellan blinkningar:"
 
 #: ../Toons/data/messages:107
 msgid "Wink duration:"
-msgstr ""
+msgstr "Varaktighet för blinkning:"
 
 #: ../Toons/data/messages:109
 msgid "Keep ratio?"
-msgstr ""
+msgstr "Behåll förhållande?"
 
 #: ../Toons/data/messages:111
 msgid "A high refresh frequency will use more CPU."
-msgstr ""
+msgstr "En hög uppdateringsfrekvens kommer att använda mer CPU."
 
 #: ../Toons/data/messages:113
 msgid "High refresh frequency?"
-msgstr ""
+msgstr "Hög uppdateringsfrekvens?"
 
 #: ../Xgamma/data/messages:7
 msgid "Leave empty to display the current luminosity."
-msgstr ""
+msgstr "Lämna tomt för att visa den aktuella ljusstyrkan."
 
 #: ../Xgamma/data/messages:11
 msgid "Current luminosity"
-msgstr ""
+msgstr "Aktuell ljusstyrka"
 
 #: ../Xgamma/data/messages:93 ../alsaMixer/data/messages:137
 msgid "Variation for 1 mouse scroll, in %:"
-msgstr ""
+msgstr "Variation för 1 musrullning, i %:"
 
 #: ../Xgamma/data/messages:95
 msgid "Use 0 for none."
-msgstr ""
+msgstr "Använd 0 för ingen"
 
 #: ../Xgamma/data/messages:97
 msgid "Brightness to apply automatically on startup:"
-msgstr ""
+msgstr "Ljusstyrka att använda automatiskt vid start:"
 
 #: ../Xgamma/data/messages:99
 msgid "Shortkey to increase the brightness:"
-msgstr ""
+msgstr "Kortkommando för att öka ljusstyrka:"
 
 #: ../Xgamma/data/messages:101
 msgid "Shortkey to decrease the brightness:"
-msgstr ""
+msgstr "Kortkommando för att minska ljusstyrka:"
 
 #: ../alsaMixer/data/messages:9
 msgid "Sound card name"
-msgstr ""
+msgstr "Ljudkortsnamn"
 
 #: ../alsaMixer/data/messages:101
 msgid "Display volume :"
-msgstr "Visa volym:"
+msgstr "Visa volym :"
 
 #: ../alsaMixer/data/messages:113 ../powermanager/data/messages:107
 #: ../wifi/data/messages:105
 msgid "Icon with progress bar"
-msgstr ""
+msgstr "Ikon med förloppsindikator"
 
 #: ../alsaMixer/data/messages:117 ../wifi/data/messages:137
 msgid "Default icon:"
-msgstr "Standard ikon:"
+msgstr "Standardikon:"
 
 #: ../alsaMixer/data/messages:119
 msgid "Mute icon:"
@@ -6865,15 +7173,15 @@ msgstr "Tysta ikon:"
 
 #: ../alsaMixer/data/messages:131
 msgid "Broken icon:"
-msgstr "Bruten ikon:"
+msgstr "Trasig ikon:"
 
 #: ../alsaMixer/data/messages:135
 msgid "Shortkey to show/hide the sound control dialog:"
-msgstr "Tangentkombination för att visa/dölja konfigurationsdialog"
+msgstr "Kortkommando för att visa/dölja ljudinställningsdialog:"
 
 #: ../alsaMixer/data/messages:139
 msgid "Hide the scale when mouse leaves the desklet?"
-msgstr "Dölj skalan när musen lämnar deskleten?"
+msgstr "Dölj skalan då musen lämnar deskleten?"
 
 #: ../alsaMixer/data/messages:141
 msgid "Alsa"
@@ -6881,11 +7189,11 @@ msgstr "Alsa"
 
 #: ../alsaMixer/data/messages:143
 msgid "Sound card:"
-msgstr "Ljudkort som ska kontrolleras:"
+msgstr "Ljudkort:"
 
 #: ../alsaMixer/data/messages:145
 msgid "Select channel:"
-msgstr "Välj kanal att kontrollera:"
+msgstr "Välj kanal:"
 
 #: ../alsaMixer/data/messages:147
 msgid ""
@@ -6893,18 +7201,21 @@ msgid ""
 "need to specify a second channel here, to control both sides. Most of the "
 "time, you should just leave this empty."
 msgstr ""
+"På en del kort, kontrollerar en kanal endast 1 sida (höger eller vänster). "
+"Du måste då ange en andra kanal här, för att kontrollera båda sidor. Oftast, "
+"bör du bara lämna det tomt."
 
 #: ../alsaMixer/data/messages:149
 msgid "Choose a second channel to control (optional):"
-msgstr ""
+msgstr "Välj en andra kanal att kontrollera (valfritt):"
 
 #: ../alsaMixer/data/messages:151
 msgid "Specific command to run to show an advanced sound mixer:"
-msgstr "Kommando som ska köras för att visa avancerad ljudmixer:"
+msgstr "Specifikt kommando att köra för att visa en avancerad ljudmixer:"
 
 #: ../clock/data/messages:7
 msgid "Leave empty to use the location name if available."
-msgstr ""
+msgstr "Lämna tomt för att använda platsnamnet om det finns."
 
 #: ../clock/data/messages:103
 msgid "Show the date:"
@@ -6912,16 +7223,18 @@ msgstr "Visa datum:"
 
 #: ../clock/data/messages:111
 msgid "for digital format only."
-msgstr ""
+msgstr "endast för digitalt format."
 
 #: ../clock/data/messages:113
 msgid "Display the time in a 24h format?"
-msgstr ""
+msgstr "Visa tiden i 24h format?"
 
 #: ../clock/data/messages:115
 msgid ""
 "if not, then the applet will update the time once a minute, saving CPU power."
 msgstr ""
+"om inte, kommer applet att uppdatera tiden en gång per minut, för att spara "
+"CPU-kraft."
 
 #: ../clock/data/messages:117
 msgid "Show seconds?"
@@ -6932,14 +7245,16 @@ msgid ""
 "In ms. Set 0 for non-smooth animation, set 1000 to have a continuous "
 "animation. Requires OpenGL."
 msgstr ""
+"I ms. Ställ in till 0 för icke-mjuk animering, ställ in till 1000 för att få "
+"en kontinuerlig animering. Kräver OpenGL."
 
 #: ../clock/data/messages:121
 msgid "Display seconds with smooth animation for a duration of:"
-msgstr ""
+msgstr "Visa sekunder med mjuk animering under en tid av:"
 
 #: ../clock/data/messages:123
 msgid "E.g. :Europe/Paris, :Japan, etc. Leave empty for local time."
-msgstr ""
+msgstr "T. ex. :Europa/Paris, :Japan, etc. Lämna tomt för lokal tid."
 
 #: ../clock/data/messages:125
 msgid "Timezone:"
@@ -6947,116 +7262,120 @@ msgstr "Tidszon:"
 
 #: ../clock/data/messages:127
 msgid "Use the tasks from the following task-manager:"
-msgstr ""
+msgstr "Använd uppgifter från följande uppgiftshanterare:"
 
 #: ../clock/data/messages:131
 msgid "iCal"
-msgstr ""
+msgstr "iCal"
 
 #: ../clock/data/messages:135
 msgid ""
 "The analogue view is based on CairoClock; otherwise it will be displayed in "
 "digital format."
 msgstr ""
+"Den analoga vyn baseras på CairoClock; annars kommer den att visas i "
+"digitalt format."
 
 #: ../clock/data/messages:137
 msgid "Select the view :"
-msgstr ""
+msgstr "Välj vyn :"
 
 #: ../clock/data/messages:139
 msgid "Analogue"
-msgstr ""
+msgstr "Analog"
 
 #: ../clock/data/messages:141
 msgid "Digital"
-msgstr ""
+msgstr "Digital"
 
 #: ../clock/data/messages:143
 msgid "Analogue View"
-msgstr ""
+msgstr "Analogvy"
 
 #: ../clock/data/messages:145
 msgid "List of available themes for analogue display:"
-msgstr "Teman för analogic:"
+msgstr "Lista över tillgängliga teman för analog visning:"
 
 #: ../clock/data/messages:147
 msgid "Date text colour:"
-msgstr ""
+msgstr "Datumtextfärg:"
 
 #: ../clock/data/messages:149
 msgid "Digital View"
-msgstr ""
+msgstr "Digitalvy"
 
 #: ../clock/data/messages:153 ../clock/data/messages:171
 #: ../dock-rendering/data/messages:59 ../keyboard-indicator/data/messages:117
 #: ../switcher/data/messages:101 ../switcher/data/messages:115
 #: ../switcher/data/messages:147
 msgid "Automatic"
-msgstr ""
+msgstr "Automatisk"
 
 #: ../clock/data/messages:155 ../dnd2share/data/messages:127
 #: ../dnd2share/data/messages:139 ../dnd2share/data/messages:149
 #: ../dnd2share/data/messages:155 ../dock-rendering/data/messages:61
 #: ../keyboard-indicator/data/messages:119 ../switcher/data/messages:149
 msgid "Custom"
-msgstr ""
+msgstr "Anpassad"
 
 #: ../clock/data/messages:159 ../keyboard-indicator/data/messages:125
 msgid "Use a custom font"
-msgstr ""
+msgstr "Använd anpassat teckensnitt"
 
 #: ../clock/data/messages:161 ../keyboard-indicator/data/messages:127
 msgid "Font:"
-msgstr ""
+msgstr "Teckensnitt:"
 
 #: ../clock/data/messages:163
 msgid "Set to 0 to not have it"
-msgstr ""
+msgstr "Ställ in till 0 för att inte ha det"
 
 #: ../clock/data/messages:165
 msgid "Outline thickness:"
-msgstr ""
+msgstr "Konturtjocklek:"
 
 #: ../clock/data/messages:167
 msgid "Outline colour:"
-msgstr ""
+msgstr "Konturfärg:"
 
 #: ../clock/data/messages:169
 msgid "Layout of the text:"
-msgstr ""
+msgstr "Layout för texten:"
 
 #: ../clock/data/messages:173
 msgid "On 1 line"
-msgstr ""
+msgstr "På 1 rad"
 
 #: ../clock/data/messages:175
 msgid "On 2 lines"
-msgstr ""
+msgstr "På 2 rader"
 
 #: ../clock/data/messages:177
 msgid "Ratio to apply on text :"
-msgstr ""
+msgstr "Förhållande att applicera på text :"
 
 #: ../clock/data/messages:181
 msgid "Configure time and date"
-msgstr "Justera datum och tid"
+msgstr "Ställ in tid och datum"
 
 #: ../clock/data/messages:183 ../logout/data/messages:121
 msgid "Leave empty to execute the default command."
-msgstr "Lämna tomt för att utföra standardkommandot."
+msgstr "Lämna tomt för att köra standardkommandot."
 
 #: ../clock/data/messages:185
 msgid "Specific command to run:"
-msgstr ""
+msgstr "Särskilt kommando att köra:"
 
 #: ../clock/data/messages:189
 msgid ""
 "The new alarm will be added to the end / the last alarm will be removed."
 msgstr ""
+"Det nya larmet kommer att läggas till på slutet / det sista larmet kommer "
+"att tas bort."
 
 #: ../clock/data/messages:191
 msgid "Add or remove an alarm:"
-msgstr ""
+msgstr "Lägg till eller ta bort ett larm:"
 
 #: ../dnd2share/data/messages:87
 msgid "Info-bubbles"
@@ -7064,119 +7383,119 @@ msgstr "Infobubblor"
 
 #: ../dnd2share/data/messages:89
 msgid "Enable info-bubbles?"
-msgstr ""
+msgstr "Aktivera infobubblor?"
 
 #: ../dnd2share/data/messages:93
 msgid "Duration of the info-bubbles :"
-msgstr ""
+msgstr "Varaktighet för infobubblorna :"
 
 #: ../dnd2share/data/messages:97
 msgid "Number of items to keep in the history :"
-msgstr ""
+msgstr "Antal objekt att hålla i historiken :"
 
 #: ../dnd2share/data/messages:99
 msgid "Keep a copy of each uploaded image?"
-msgstr ""
+msgstr "Behåll en kopia av varje uppladdad bild?"
 
 #: ../dnd2share/data/messages:101
 msgid "This will override the image setting."
-msgstr ""
+msgstr "Detta åsidosätter bildinställningarna."
 
 #: ../dnd2share/data/messages:103
 msgid "If so, display the last image on the icon?"
-msgstr ""
+msgstr "Om så, visa den sista bilden på ikonen?"
 
 #: ../dnd2share/data/messages:105
 msgid "Animation of the icon during upload :"
-msgstr ""
+msgstr "Ikonanimering under uppladdning :"
 
 #: ../dnd2share/data/messages:107
 msgid "Use the following service to make the URL smaller:"
-msgstr ""
+msgstr "Använd den följande tjänsten för att göra URL:en mindre:"
 
 #: ../dnd2share/data/messages:111
 msgid "Tiny-URL"
-msgstr ""
+msgstr "Tiny-URL"
 
 #: ../dnd2share/data/messages:113
 msgid "Shorter-Link"
-msgstr ""
+msgstr "Shorter-Link"
 
 #: ../dnd2share/data/messages:115
 msgid "Use the tiny URL by default?"
-msgstr ""
+msgstr "Använd den lilla URL:en som standard?"
 
 #: ../dnd2share/data/messages:117
 msgid "in KB/s - 0 means unlimited"
-msgstr ""
+msgstr "i KB/s - 0 betyder obegränsat"
 
 #: ../dnd2share/data/messages:119
 msgid "Maximum upload rate:"
-msgstr ""
+msgstr "Maximal uppladdningshastighet:"
 
 #: ../dnd2share/data/messages:121
 msgid "Sites"
-msgstr ""
+msgstr "Platser"
 
 #: ../dnd2share/data/messages:123
 msgid "Use files hosting site for any kind of files?"
-msgstr ""
+msgstr "Använd fillagringsplatser för alla sorters filer?"
 
 #: ../dnd2share/data/messages:125
 msgid "Preferred site for texts hosting :"
-msgstr ""
+msgstr "Föredragen plats för textlagring :"
 
 #: ../dnd2share/data/messages:129
 msgid "Pastebin.com"
-msgstr ""
+msgstr "Pastebin.com"
 
 #: ../dnd2share/data/messages:131
 msgid "Paste-ubuntu.com"
-msgstr ""
+msgstr "Paste-ubuntu.com"
 
 #: ../dnd2share/data/messages:133
 msgid "Pastebin.mozilla.org"
-msgstr ""
+msgstr "Pastebin.mozilla.org"
 
 #: ../dnd2share/data/messages:135
 msgid "Codepad.org"
-msgstr ""
+msgstr "Codepad.org"
 
 #: ../dnd2share/data/messages:137
 msgid "Preferred site for images hosting :"
-msgstr ""
+msgstr "Föredragen plats för bildlagring :"
 
 #: ../dnd2share/data/messages:141
 msgid "Uppix.com"
-msgstr ""
+msgstr "Uppix.com"
 
 #: ../dnd2share/data/messages:143
 msgid "Imagebin.ca"
-msgstr ""
+msgstr "Imagebin.ca"
 
 #: ../dnd2share/data/messages:145
 msgid "Imgur.com"
-msgstr ""
+msgstr "Imgur.com"
 
 #: ../dnd2share/data/messages:147
 msgid "Preferred site for videos hosting :"
-msgstr ""
+msgstr "Föredragen plats för filmlagring :"
 
 #: ../dnd2share/data/messages:151
 msgid "VideoBin.org"
-msgstr ""
+msgstr "VideoBin.org"
 
 #: ../dnd2share/data/messages:153
 msgid "Preferred site for files hosting :"
-msgstr ""
+msgstr "Föredragen plats för fillagring :"
 
 #: ../dnd2share/data/messages:157
 msgid "dl.free.fr"
-msgstr ""
+msgstr "dl.free.fr"
 
 #: ../dnd2share/data/messages:159
 msgid "DropBox"
-msgstr ""
+msgstr "DropBox"
 
 #: ../dnd2share/data/messages:161 ../dnd2share/data/messages:165
 #: ../dnd2share/data/messages:169 ../dnd2share/data/messages:173
@@ -7184,47 +7503,51 @@ msgid ""
 "The script takes the file path as a parameter, and write the resulting URL "
 "on the standard output."
 msgstr ""
+"Skriptet tar sökvägen till filen som parameter, och skriver den resulterande "
+"URL:en på standardutmatningen."
 
 #: ../dnd2share/data/messages:163
 msgid "Custom script for text upload :"
-msgstr ""
+msgstr "Anpassat skript för textuppladdning :"
 
 #: ../dnd2share/data/messages:167
 msgid "Custom script for image upload :"
-msgstr ""
+msgstr "Anpassat skript för bilduppladdning :"
 
 #: ../dnd2share/data/messages:171
 msgid "Custom script for video upload :"
-msgstr ""
+msgstr "Anpassat skript för filmuppladdning :"
 
 #: ../dnd2share/data/messages:175
 msgid "Custom script for file upload :"
-msgstr ""
+msgstr "Anpassat skript för filuppladdning :"
 
 #: ../dnd2share/data/messages:177
 msgid ""
 "Leave empty to upload files into '~/Dropbox/Public' or '~/Ubuntu One'."
 msgstr ""
+"Lämna tomt för att ladda upp filer till \"~/Dropbox/Public\" eller "
+"\"~/Ubuntu One\"."
 
 #: ../dnd2share/data/messages:179
 msgid "Path of a custom DropBox / UbuntuOne folder :"
-msgstr ""
+msgstr "Sökväg till en anpassad DropBox / UbuntuOne mapp :"
 
 #: ../dnd2share/data/messages:181
 msgid "Otherwise, your user name will be used when possible."
-msgstr ""
+msgstr "Annars, kommer ditt användarnamn att användas när det är möjligt."
 
 #: ../dnd2share/data/messages:183
 msgid "Post text as Anonymous ?"
-msgstr ""
+msgstr "Posta text anonymt ?"
 
 #: ../dock-rendering/data/messages:1
 msgid "Inclinated Plane"
-msgstr "Sluttande plan"
+msgstr "Lutande plan"
 
 #: ../dock-rendering/data/messages:3
 msgid "The lower the value, the lower the point of view on the plane."
-msgstr "Ju lägre värde, desto mer horisontellt är planet."
+msgstr "Ju lägre värde, desto lägre vinkel på planet."
 
 #: ../dock-rendering/data/messages:5
 msgid "Height of the vanishing point:"
@@ -7232,7 +7555,7 @@ msgstr "Höjd på flyktpunkten:"
 
 #: ../dock-rendering/data/messages:9
 msgid "The lower the value, the flatter the curve will appear."
-msgstr "Ju lägre värde, desto plattare kurva."
+msgstr "Ju lägre värde, desto plattare kurva visas."
 
 #: ../dock-rendering/data/messages:11
 msgid "Curvature of the curve in percent:"
@@ -7244,27 +7567,27 @@ msgstr "Kurvans amplitud."
 
 #: ../dock-rendering/data/messages:19
 msgid "Physically separate groups of icons"
-msgstr ""
+msgstr "Separera ikongrupper fysiskt"
 
 #: ../dock-rendering/data/messages:21
 msgid "At 1, the icons will have the same size as in other views."
-msgstr ""
+msgstr "Vid 1, kommer ikonerna att ha samma storlek som i andra vyer."
 
 #: ../dock-rendering/data/messages:23
 msgid "Ratio to apply on icons' size :"
-msgstr ""
+msgstr "Förhållande att applicera på ikonstorlek :"
 
 #: ../dock-rendering/data/messages:25
 msgid "smaller icons"
-msgstr ""
+msgstr "mindre ikoner"
 
 #: ../dock-rendering/data/messages:27
 msgid "normal icons"
-msgstr ""
+msgstr "normala ikoner"
 
 #: ../dock-rendering/data/messages:31
 msgid "Grid"
-msgstr ""
+msgstr "Rutnät"
 
 #: ../dock-rendering/data/messages:33
 msgid "Space between columns:"
@@ -7276,19 +7599,19 @@ msgstr "Avstånd mellan rader:"
 
 #: ../dock-rendering/data/messages:37
 msgid "Only for sub-docks."
-msgstr ""
+msgstr "Endast för underdockor"
 
 #: ../dock-rendering/data/messages:39
 msgid "Maximum size of the dock:"
-msgstr ""
+msgstr "Maximal storlek på dockan:"
 
 #: ../dock-rendering/data/messages:43
 msgid "Full screen"
-msgstr ""
+msgstr "Fullskärmsläge"
 
 #: ../dock-rendering/data/messages:45
 msgid "Zoom when mouse hovers an icon:"
-msgstr ""
+msgstr "Zooma när musen svävar över en ikon:"
 
 #: ../dock-rendering/data/messages:51
 msgid "Sinusoidal wave radius:"
@@ -7296,7 +7619,7 @@ msgstr "Sinusvågens radie:"
 
 #: ../dock-rendering/data/messages:53
 msgid "Use a linear wave rather than a sinusoidal wave?"
-msgstr "Använd linjär våg istället för sinusformad?"
+msgstr "Använd en linjär våg istället för en sinusformad?"
 
 #: ../dock-rendering/data/messages:55
 msgid "Display text for all icons?"
@@ -7304,23 +7627,23 @@ msgstr "Visa text för alla ikoner?"
 
 #: ../dock-rendering/data/messages:63 ../slider/data/messages:171
 msgid "Frame"
-msgstr ""
+msgstr "Ram"
 
 #: ../dock-rendering/data/messages:65
 msgid "First gradient colour :"
-msgstr ""
+msgstr "Första gradientfärg :"
 
 #: ../dock-rendering/data/messages:67
 msgid "Second gradient colour :"
-msgstr ""
+msgstr "Andra gradientfärg :"
 
 #: ../dock-rendering/data/messages:69
 msgid "Top to bottom gradient?"
-msgstr "Uppifrån och ner?"
+msgstr "Färgtoning uppifrån och ned?"
 
 #: ../dock-rendering/data/messages:71
 msgid "Left to right gradient?"
-msgstr "Vänster till höger?"
+msgstr "Färgtoning vänster till höger?"
 
 #: ../dock-rendering/data/messages:73
 msgid "Corner radius:"
@@ -7328,35 +7651,35 @@ msgstr "Hörnradie:"
 
 #: ../dock-rendering/data/messages:75
 msgid "Border line width :"
-msgstr "Linjebredd för ram:"
+msgstr "Ramlinjebredd :"
 
 #: ../dock-rendering/data/messages:77
 msgid "Border line colour :"
-msgstr ""
+msgstr "Kantlinjefärg :"
 
 #: ../dock-rendering/data/messages:79
 msgid "Arrow width :"
-msgstr "Pilens bredd:"
+msgstr "Pilbredd :"
 
 #: ../dock-rendering/data/messages:81
 msgid "Arrow height:"
-msgstr "Pilens höjd:"
+msgstr "Pilhöjd:"
 
 #: ../dock-rendering/data/messages:83
 msgid "Scroll bar"
-msgstr ""
+msgstr "Rullningslist"
 
 #: ../dock-rendering/data/messages:85
 msgid "Color of the scroll bar's outline:"
-msgstr ""
+msgstr "Färg på rullningslistens kontur:"
 
 #: ../dock-rendering/data/messages:87
 msgid "Color of the scroll bar's inside:"
-msgstr ""
+msgstr "Färg på rullningslistens insida:"
 
 #: ../dock-rendering/data/messages:89
 msgid "Color of the scroll grip:"
-msgstr ""
+msgstr "Färg på rullhandtaget:"
 
 #: ../dock-rendering/data/messages:93
 msgid "The higher this value, the sooner the parabola will be curved."
@@ -7364,7 +7687,7 @@ msgstr "Ju högre värde, desto tidigare
 
 #: ../dock-rendering/data/messages:95
 msgid "Curvature:"
-msgstr "Kurva:"
+msgstr "Kröning:"
 
 #: ../dock-rendering/data/messages:97
 msgid "The parabola will be restricted to a rectangle of this proportion."
@@ -7372,33 +7695,35 @@ msgstr "Parabolen begränsas av en rekta
 
 #: ../dock-rendering/data/messages:99
 msgid "Height/width ratio:"
-msgstr "Förhållande höjd/bredd:"
+msgstr "Höjd/bredd förhållande:"
 
 #: ../dock-rendering/data/messages:101
 msgid "0 represents a flat wave, 1 represents maximum wave curvature."
-msgstr "0 betyder att vågen är helt platt, 1 betyder vågens maxvärde."
+msgstr "0 representerar en plan våg, 1 representerar maximal vågkrökning."
 
 #: ../dock-rendering/data/messages:103 ../dock-rendering/data/messages:123
 msgid "Magnitude of the wave:"
-msgstr "Vågens styrka:"
+msgstr "Vågstorlek:"
 
 #: ../dock-rendering/data/messages:105
 msgid "Curve towards the outside?"
-msgstr ""
+msgstr "Kurva utåt?"
 
 #: ../dock-rendering/data/messages:109
 msgid "Space between icons and their captions:"
-msgstr "Avstånd mellan ikon och etikett:"
+msgstr "Avstånd mellan ikoner och deras etiketter:"
 
 #: ../dock-rendering/data/messages:111
 msgid ""
 "This may recquire more CPU during the unfolding animation, except if you "
 "launch Cairo-Dock with OpenGL."
 msgstr ""
+"Detta kräver mer CPU under uppvikingsanimeringen, utom ifall du startar "
+"Cairo-Dock med OpenGL."
 
 #: ../dock-rendering/data/messages:113
 msgid "Draw captions while unfolding?"
-msgstr "Visa etiketter under animering?"
+msgstr "Rita etiketter under uppveckling?"
 
 #: ../dock-rendering/data/messages:119
 msgid "Space between icons:"
@@ -7408,8 +7733,7 @@ msgstr "Avstånd mellan ikoner:"
 msgid ""
 "0 represents a flat wave, 1 means the wave is identical to other views."
 msgstr ""
-"0 betyder at vågen är helt platt. 1 betyder att vågen är identisk med andra "
-"vyer."
+"0 representerar en  plan våg. 1 betyder att vågen är identisk med andra vyer."
 
 #: ../dock-rendering/data/messages:125
 msgid "Number of icons on the first row:"
@@ -7420,24 +7744,26 @@ msgid ""
 "in degrees. The lower the value, the narrower the cone. 180° represents a "
 "wide open cone."
 msgstr ""
-"i grader. Ju lägre värde, desto smalare kon. 180° betyder att konen är "
-"vidöppen."
+"i grader. Ju lägre värde, desto smalare kon. 180° representerar en vidöppen "
+"kon."
 
 #: ../dock-rendering/data/messages:129
 msgid "Cone width:"
-msgstr "Konens bredd:"
+msgstr "Konbredd:"
 
 #: ../dock-rendering/data/messages:131
 msgid "Set transparency to 0 to not use it. This is quite slow with cairo."
 msgstr ""
+"Ställ in genomskinlighet till 0 för att inte använda det. Detta är ganska "
+"långsamt med Cairo."
 
 #: ../dock-rendering/data/messages:133
 msgid "Bow colour:"
-msgstr ""
+msgstr "Bågfärg:"
 
 #: ../dock-rendering/data/messages:135
 msgid "Line colour:"
-msgstr ""
+msgstr "Linjefärg:"
 
 #: ../dock-rendering/data/messages:138
 msgid ""
@@ -7446,12 +7772,18 @@ msgid ""
 "You can choose to display separators as a line\n"
 " or a physical hole on the plane."
 msgstr ""
+"<b>A 3D-planvy</b>\n"
+"Detta är den närmaste vyn till MacOSX:s docka.\n"
+"Du kan välja att visa avgränsare som en linje\n"
+"eller ett fysiskt hål på planet."
 
 #: ../dock-rendering/data/messages:140
 msgid ""
 "<b>A 3D caroussel view</b>\n"
 "Icons scroll with mouse position."
 msgstr ""
+"<b>En 3D-karusellvy</b>\n"
+"Ikoner rullar med musposition."
 
 #: ../dock-rendering/data/messages:142
 msgid ""
@@ -7460,12 +7792,18 @@ msgid ""
 "You can choose to display separators as a line\n"
 " or a physical hole on the plane."
 msgstr ""
+"<b>Kurvvy</b>\n"
+"Låter dig böja dina docka !\n"
+"Du kan välja att visa avgränsare som en linje\n"
+"eller ett fysiskt hål på planet."
 
 #: ../dock-rendering/data/messages:144
 msgid ""
 "<b>Slide view</b>\n"
 "A brand new view, especially designed for big subdocks."
 msgstr ""
+"<b>Glidvy</b>\n"
+"En helt ny vy, specialdesignad för stora underdockor."
 
 #: ../dock-rendering/data/messages:146
 msgid ""
@@ -7474,6 +7812,10 @@ msgid ""
 "Icons are not zoomed on mouse over.\n"
 "Separators are rendered as spaces between the different groups of icons."
 msgstr ""
+"<b>Panelvy</b>\n"
+"Denna vy kommer att visa din docka som en gnome-panel eller en KDE-panel.\n"
+"Ikoner zoomas inte då musen förs över dem.\n"
+"Avgränsare ritas som mellanrum mellan de olika ikongrupperna."
 
 #: ../dock-rendering/data/messages:148
 msgid ""
@@ -7481,6 +7823,9 @@ msgid ""
 "Perfect for medium sub-docks with 3 to 10 icons.\n"
 "Labels are also clickable."
 msgstr ""
+"<b>En parabolvy</b>\n"
+"Perfekt för medelstora underdockor med 3 till 10 ikoner.\n"
+"Etiketter är också klickbara."
 
 #: ../dock-rendering/data/messages:150
 msgid ""
@@ -7488,6 +7833,9 @@ msgid ""
 "An original view, designed for sub-docks with few icons.\n"
 "Icons' labels can be displayed horizontally or not."
 msgstr ""
+"<b>Regnbågsvy</b>\n"
+"En originell vy, utformad för underdockor med få ikoner.\n"
+"Ikonetiketter kan visas horisontellt eller inte alls."
 
 #: ../dock-rendering/data/messages:152
 msgid ""
@@ -7495,47 +7843,54 @@ msgid ""
 "This view is specially adapted to large sub-docks.\n"
 "You can choose to display all icons' labels."
 msgstr ""
+"<b>Glidvy</b>\n"
+"Denna vy är specialanpassad för stora underdockor.\n"
+"Du kan välja att visa alla ikonetiketter."
 
 #: ../drop-indicator/data/messages:1
 msgid "Drag and drop indicator"
-msgstr ""
+msgstr "Dra-och-släppindikator"
 
 #: ../drop-indicator/data/messages:5
 msgid ""
 "Typically an arrow, this will be displayed when you try to drop a new "
 "launcher into the dock. Leave this empty to use the default."
 msgstr ""
+"Typiskt en pil, detta kommer att visas när du försöker att släppa en ny "
+"startare i dockan. Lämna detta tomt för att använda standard."
 
 #: ../drop-indicator/data/messages:7
 msgid "Image for the drag & drop animation:"
-msgstr ""
+msgstr "Bild för dra-och-släppanimeringen:"
 
 #: ../drop-indicator/data/messages:9
 msgid ""
 "An emblem that will be displayed when you try to drop something on an icon. "
 "Leave empty to use the default one."
 msgstr ""
+"Ett emblem som kommer att visas när du försöker att släppa något på en ikon. "
+"Lämna tomt för standard."
 
 #: ../drop-indicator/data/messages:11
 msgid "Image when hovering an icon :"
-msgstr ""
+msgstr "Bild vid svävning över ikon :"
 
 #: ../drop-indicator/data/messages:13
 msgid "Animation"
-msgstr ""
+msgstr "Animering"
 
 #: ../drop-indicator/data/messages:15
 msgid "Speed:"
-msgstr ""
+msgstr "Hastighet:"
 
 #: ../drop-indicator/data/messages:17
 msgid "Number of round per second."
-msgstr ""
+msgstr "Antal rundor per sekund."
 
 #: ../drop-indicator/data/messages:19 ../illusion/data/messages:79
 #: ../show-mouse/data/messages:7
 msgid "Rotation speed :"
-msgstr ""
+msgstr "Rotationshastighet:"
 
 #: ../dustbin/data/messages:89
 msgid "Theme"
@@ -7543,23 +7898,23 @@ msgstr "Tema"
 
 #: ../dustbin/data/messages:93
 msgid "Name of the image to overwrite the theme's empty image :"
-msgstr "Bild för papperskorgen när den är tom:"
+msgstr "Namnet på bilden för att skriva över temats tomma bild :"
 
 #: ../dustbin/data/messages:95
 msgid "Name of the image to overwrite the theme's full image :"
-msgstr "Bild för papperskorgen när den inte är tom:"
+msgstr "Namnet på bilden för att skriva över temats fulla bild :"
 
 #: ../dustbin/data/messages:97
 msgid "Config"
-msgstr "Konfigurera"
+msgstr "Ställ in"
 
 #: ../dustbin/data/messages:99
 msgid "Display the following quick info :"
-msgstr "Visa följande snabbinformation:"
+msgstr "Visa följande snabbinfo :"
 
 #: ../dustbin/data/messages:103
 msgid "Number of files"
-msgstr ""
+msgstr "Antal filer"
 
 #: ../dustbin/data/messages:105
 msgid "Total number of files"
@@ -7567,233 +7922,238 @@ msgstr "Totalt antal filer"
 
 #: ../dustbin/data/messages:107
 msgid "Total weight"
-msgstr "Total storlek"
+msgstr "Totalvikt"
 
 #: ../dustbin/data/messages:109
 msgid "Ask confirmation before emptying Dustbin?"
-msgstr ""
+msgstr "Bekräfta innan Papperskorgen töms?"
 
 #: ../icon-effect/data/messages:53
 msgid "Draw in background?"
-msgstr ""
+msgstr "Rita i bakgrunden?"
 
 #: ../icon-effect/data/messages:55
 msgid "Rotate effects with dock?"
-msgstr ""
+msgstr "Rotera effekter med docka?"
 
 #: ../icon-effect/data/messages:59
 msgid "In ms. Set 0 to not use this effect."
-msgstr ""
+msgstr "I ms. Ställ in 0 för att inte använda denna effekt."
 
 #: ../icon-effect/data/messages:65 ../icon-effect/data/messages:93
 #: ../icon-effect/data/messages:115 ../icon-effect/data/messages:137
 #: ../icon-effect/data/messages:159 ../icon-effect/data/messages:179
 #: ../illusion/data/messages:35
 msgid "Colours"
-msgstr ""
+msgstr "Färger"
 
 #: ../icon-effect/data/messages:73
 msgid ""
 "This will slightly alter your colours, so you may have to modify them."
 msgstr ""
+"Detta kommer att ändra dina färger något, så du kan behöva modifiera dem."
 
 #: ../icon-effect/data/messages:75 ../icon-effect/data/messages:187
 msgid "Add luminance?"
-msgstr ""
+msgstr "Lägg till ljusstyrka?"
 
 #: ../icon-effect/data/messages:77 ../icon-effect/data/messages:101
 #: ../icon-effect/data/messages:121 ../icon-effect/data/messages:143
 #: ../icon-effect/data/messages:165 ../icon-effect/data/messages:189
 #: ../illusion/data/messages:43
 msgid "Particles"
-msgstr ""
+msgstr "Partiklar"
 
 #: ../icon-effect/data/messages:79 ../icon-effect/data/messages:103
 #: ../icon-effect/data/messages:123 ../icon-effect/data/messages:145
 #: ../icon-effect/data/messages:167 ../illusion/data/messages:45
 msgid "Number of particles:"
-msgstr ""
+msgstr "Antal partiklar:"
 
 #: ../icon-effect/data/messages:81 ../icon-effect/data/messages:105
 #: ../icon-effect/data/messages:125 ../icon-effect/data/messages:147
 #: ../icon-effect/data/messages:169 ../icon-effect/data/messages:199
 #: ../illusion/data/messages:47 ../show-mouse/data/messages:25
 msgid "Particle size:"
-msgstr ""
+msgstr "Partikelstorlek:"
 
 #: ../icon-effect/data/messages:83 ../icon-effect/data/messages:127
 #: ../icon-effect/data/messages:149 ../illusion/data/messages:49
 msgid "Particle speed:"
-msgstr ""
+msgstr "Partikelhastighet:"
 
 #: ../icon-effect/data/messages:185
 msgid "It particularily fits a dark wallpaper or a dark theme."
 msgstr ""
+"Det passar speciellt en mörk skrivbordsbakgrund eller ett mörkt tema."
 
 #: ../icon-effect/data/messages:191 ../show-mouse/data/messages:3
 msgid "Number of sources:"
-msgstr ""
+msgstr "Antal källor:"
 
 #: ../icon-effect/data/messages:193 ../show-mouse/data/messages:17
 msgid "Number of particles per source:"
-msgstr ""
+msgstr "Antal partiklar per källa:"
 
 #: ../icon-effect/data/messages:195
 msgid "In percentage of the icon's size."
-msgstr ""
+msgstr "I procent av ikonstorleken."
 
 #: ../icon-effect/data/messages:197
 msgid "Radius of the explosion:"
-msgstr ""
+msgstr "Explosionsradien:"
 
 #: ../icon-effect/data/messages:201
 msgid "Show the launching?"
-msgstr ""
+msgstr "Visa starten?"
 
 #: ../icon-effect/data/messages:203
 msgid "Particle friction:"
-msgstr ""
+msgstr "Partikelfriktion:"
 
 #: ../illusion/data/messages:3
 msgid "Animation on disappearance:"
-msgstr ""
+msgstr "Animera vid försvinnande:"
 
 #: ../illusion/data/messages:5 ../illusion/data/messages:19
 #: ../illusion/data/messages:31
 msgid "Evaporate"
-msgstr ""
+msgstr "Avdunsta"
 
 #: ../illusion/data/messages:7 ../illusion/data/messages:21
 #: ../illusion/data/messages:53
 msgid "Fade out"
-msgstr ""
+msgstr "Tona bort"
 
 #: ../illusion/data/messages:9 ../illusion/data/messages:23
 #: ../illusion/data/messages:57
 msgid "Explode"
-msgstr ""
+msgstr "Explodera"
 
 #: ../illusion/data/messages:11 ../illusion/data/messages:25
 #: ../illusion/data/messages:67
 msgid "Break"
-msgstr ""
+msgstr "Gå sönder"
 
 #: ../illusion/data/messages:13 ../illusion/data/messages:27
 #: ../illusion/data/messages:73
 msgid "Black Hole"
-msgstr ""
+msgstr "Svart hål"
 
 #: ../illusion/data/messages:15 ../illusion/data/messages:29
 msgid "Random"
-msgstr ""
+msgstr "Slumpmässig"
 
 #: ../illusion/data/messages:17
 msgid "Animation on appearance:"
-msgstr ""
+msgstr "Animering vid framträdande:"
 
 #: ../illusion/data/messages:51
 msgid "Evaporate upwards?"
-msgstr ""
+msgstr "Avdunsta uppåt?"
 
 #: ../illusion/data/messages:61 ../illusion/data/messages:71
 msgid "Number of pieces:"
-msgstr ""
+msgstr "Antal bitar:"
 
 #: ../illusion/data/messages:63
 msgid "Explosion radius:"
-msgstr ""
+msgstr "Explosionsradie:"
 
 #: ../illusion/data/messages:65
 msgid "Break the icon into cubes?"
-msgstr ""
+msgstr "Bryt sönder ikonen i kuber?"
 
 #: ../illusion/data/messages:77
 msgid "in round per second."
-msgstr ""
+msgstr "i varv per sekund."
 
 #: ../illusion/data/messages:81
 msgid "The greater, the faster the icon will collapse to the center."
-msgstr ""
+msgstr "Ju större, desto snabbare kommer ikonen att kollapsa mot centrum."
 
 #: ../illusion/data/messages:83
 msgid "Attraction of the Black Hole:"
-msgstr ""
+msgstr "Svarta hålets dragningskraft:"
 
 #: ../keyboard-indicator/data/messages:99
 msgid "General"
-msgstr ""
+msgstr "Allmänt"
 
 #: ../keyboard-indicator/data/messages:101
 msgid "caps lock, num lock, etc."
-msgstr ""
+msgstr "caps lock, num lock, etc."
 
 #: ../keyboard-indicator/data/messages:103
 msgid "Display keyboard locks as quick-info?"
-msgstr ""
+msgstr "Visa tangentbordslås som snabbinfo?"
 
 #: ../keyboard-indicator/data/messages:105
 msgid "Icon image name for NumLock status:"
-msgstr ""
+msgstr "Ikonbildsnamn för NumLock-läge:"
 
 #: ../keyboard-indicator/data/messages:107
 msgid "Icon image name for CapsLock status:"
-msgstr ""
+msgstr "Ikonbildsnamn för Caps-Lock-läge"
 
 #: ../keyboard-indicator/data/messages:109
 msgid ""
 "in ms. Set to 0 if you don't want an animation when the keyboard layout "
 "changes."
 msgstr ""
+"i ms. Ställ in till 0 om du inte vill ha en animering när "
+"tangentbordslayouten ändras."
 
 #: ../keyboard-indicator/data/messages:111
 msgid "Duration of the transition animation:"
-msgstr ""
+msgstr "Varaktighet för övergångsanimeringen:"
 
 #: ../keyboard-indicator/data/messages:129
 msgid "Relative size of the text :"
-msgstr ""
+msgstr "Textens relativa storlek :"
 
 #: ../keyboard-indicator/data/messages:131
 msgid "smaller"
-msgstr ""
+msgstr "mindre"
 
 #: ../keyboard-indicator/data/messages:137
 msgid "Number of letters to draw on the icon."
-msgstr ""
+msgstr "Antal bokstäver att rita på ikonen."
 
 #: ../logout/data/messages:91
 msgid "Action"
-msgstr ""
+msgstr "Åtgärd"
 
 #: ../logout/data/messages:101
 msgid "Shortkey to lock the screen"
-msgstr ""
+msgstr "Kortkommando för att låsa skärmen"
 
 #: ../logout/data/messages:103
 msgid "Shortkey to show the menu"
-msgstr ""
+msgstr "Kortkommando för att visa menyn"
 
 #: ../logout/data/messages:105
 msgid "Demand confirmation before closing"
-msgstr ""
+msgstr "Kräv bekräftelse innan stängning"
 
 #: ../logout/data/messages:107 ../musicPlayer/data/messages:185
 #: ../tomboy/data/messages:11
 msgid "Customisation"
-msgstr "Inställningar"
+msgstr "Anpassning"
 
 #: ../logout/data/messages:111
 msgid "Icon image name to use when the system has to be rebooted:"
-msgstr ""
+msgstr "Ikonbildsnamn att använda när systemet har startats om:"
 
 #: ../logout/data/messages:113
 msgid ""
 "Display this image as an emblem or replace applet's icon with this image?"
 msgstr ""
+"Visa denna bild som ett emblem eller ersätt applets ikon med denna bild?"
 
 #: ../logout/data/messages:115
 msgid "Emblem"
-msgstr ""
+msgstr "Emblem"
 
 #: ../logout/data/messages:117
 msgid "Image"
@@ -7801,12 +8161,13 @@ msgstr "Bild"
 
 #: ../logout/data/messages:119
 msgid "Commands"
-msgstr ""
+msgstr "Kommandon"
 
 #: ../logout/data/messages:123
 msgid ""
 "Fallback user-defined command to execute for logout in case of problem:"
 msgstr ""
+"Användardefinierat reservkommando för att utföra utloggning vid problem:"
 
 #: ../logout/data/messages:125
 msgid ""
@@ -7814,21 +8175,27 @@ msgid ""
 "default command, which depends on your distribution. In some cases the "
 "command to shutdown is the same as the one to log out."
 msgstr ""
+"Detta kommer att vara tillgängligt vid mittenklick. Lämna tomt för att "
+"utföra standardkommandot, som beror på din distribution. I en del fall är "
+"kommandot för att stänga av detsamma som det för att logga ut."
 
 #: ../logout/data/messages:127
 msgid ""
 "Fallback user-defined command to execute for shutdown in case of problem:"
 msgstr ""
+"Användardefinierat reservkommando för att utföra avstängning vid problem:"
 
 #: ../logout/data/messages:129
 msgid ""
 "Leave empty to execute the default command. If not empty, it will execute "
 "this command with the name of the user (or nothing for guest session)"
 msgstr ""
+"Lämna tomt för att utföra standardkommandot. Om inte tomt, kommer det att "
+"utföra detta kommando med användarens namn (eller inget vid gästsession)"
 
 #: ../logout/data/messages:131
 msgid "User-defined command to execute for changing user:"
-msgstr ""
+msgstr "Användardefinierat kommando för att byta användare:"
 
 #: ../mail/data/messages:99
 msgid ""
@@ -7836,112 +8203,119 @@ msgid ""
 "maintenance mode, then after the dock has relaunched, remove/modify the mail "
 "accounts you want."
 msgstr ""
+"Om du har några problem med applet, avbocka detta alternativ under "
+"underhållsläget, därefter då dockan har startat om, ta bort/ändra de "
+"postkonton du vill."
 
 #: ../mail/data/messages:101
 msgid "Check mail account on startup?"
-msgstr ""
+msgstr "Kontrollera e-postkonto vid start?"
 
 #: ../mail/data/messages:109
 msgid "Name of the file for the \"no mail\" image :"
-msgstr ""
+msgstr "Filnamn för \"ingen e-post\" bilden :"
 
 #: ../mail/data/messages:113
 msgid "Name of the file for the \"has mail\" image :"
-msgstr ""
+msgstr "Filnamn för \"fått e-post\" bilden :"
 
 #: ../mail/data/messages:115
 msgid ""
 "If checked, the number of mails will be shown even if there is no mail."
 msgstr ""
+"Om valt, kommer antal e-postmeddelanden att visas även om det inte finns "
+"någon e-post."
 
 #: ../mail/data/messages:117
 msgid "Show '0' if there is no mail?"
-msgstr ""
+msgstr "Visa \"0\" om det inte finns någon e-post?"
 
 #: ../mail/data/messages:119 ../shortcuts/data/messages:103
 #: ../stack/data/messages:95 ../switcher/data/messages:189
 #: ../tomboy/data/messages:119 ../weather/data/messages:133
 msgid "Leave empty to use default sub-dock view."
-msgstr "Lämna tomt för att använda standard sub-docka."
+msgstr "Lämna tomt för att använda standard underdocksvy."
 
 #: ../mail/data/messages:121 ../shortcuts/data/messages:105
 #: ../stack/data/messages:97 ../switcher/data/messages:191
 #: ../tomboy/data/messages:121 ../weather/data/messages:135
 msgid "Sub-dock view name:"
-msgstr "Namn på vy för sub-dockan:"
+msgstr "Underdocksvynamn:"
 
 #: ../mail/data/messages:123
 msgid "Action on new mail"
-msgstr ""
+msgstr "Åtgärd vid ny e-post"
 
 #: ../mail/data/messages:125
 msgid "Play sound when a new e-mail is received?"
-msgstr ""
+msgstr "Spela ett ljud då ny e-post tas emot?"
 
 #: ../mail/data/messages:129
 msgid "Name of the file for the \"new mail\" sound :"
-msgstr ""
+msgstr "Namnet på filen för \"ny e-post\" ljudet :"
 
 #: ../mail/data/messages:131
 msgid "Show new messages' content?"
-msgstr ""
+msgstr "Visa innehållet i nya meddelanden?"
 
 #: ../mail/data/messages:133
 msgid "Maximum number of mails that will be previewed."
-msgstr ""
+msgstr "Maximalt antal e-postmeddelanden som kommer att förhandsvisas."
 
 #: ../mail/data/messages:135
 msgid "Maximum of new messages shown?"
-msgstr ""
+msgstr "Maximalt antal nya meddelanden som visas?"
 
 #: ../mail/data/messages:139 ../tomboy/data/messages:117
 msgid "Duration of the dialog:"
-msgstr ""
+msgstr "Varaktighet för dialogen:"
 
 #: ../mail/data/messages:141
 msgid "Animation when new message arrives:"
-msgstr ""
+msgstr "Animering när nytt meddelande anländer:"
 
 #: ../mail/data/messages:145
 msgid "Mail application"
-msgstr ""
+msgstr "E-postprogram"
 
 #: ../mail/data/messages:147
 msgid "for instance \"thunderbird\" or \"firefox mail.google.com\""
-msgstr ""
+msgstr "till exempel \"thunderbird\" eller \"firefox mail.google.com\""
 
 #: ../mail/data/messages:149
 msgid "Preferred mail application to launch on left-click :"
-msgstr ""
+msgstr "Föredraget e-postprogram att starta med vänsterklick :"
 
 #: ../mail/data/messages:151
 msgid "Add a mail account (you've to launch the applet)"
-msgstr ""
+msgstr "Lägg till ett e-postkonto (du måste starta applet)"
 
 #: ../mail/data/messages:153
 msgid "The new account will be created with the specified type and name."
-msgstr ""
+msgstr "Det nya kontot kommer att skapas med angiven typ och namn."
 
 #: ../mail/data/messages:155
 msgid "Add an account with specified type and name:"
-msgstr ""
+msgstr "Lägg till ett konto av angiven typ och namn:"
 
 #: ../motion-blur/data/messages:3
 msgid "Also blur on mouse movement?"
-msgstr ""
+msgstr "Oskärpa även vid musrörelse?"
 
 #: ../motion-blur/data/messages:5
 msgid "Blur amount:"
-msgstr ""
+msgstr "Mängd oskärpa:"
 
 #: ../musicPlayer/data/messages:7
 msgid ""
 "Leave it empty to display the name of the player currently controlled."
 msgstr ""
+"Lämna det tomt för att visa namnet på den för närvarande kontrollerade "
+"spelaren."
 
 #: ../musicPlayer/data/messages:11
 msgid "Player name"
-msgstr ""
+msgstr "Spelarnamn"
 
 #: ../musicPlayer/data/messages:101
 msgid "Audio Player"
@@ -7949,11 +8323,11 @@ msgstr "Ljudspelare"
 
 #: ../musicPlayer/data/messages:103
 msgid "Player to control:"
-msgstr "Spelare som ska kontrolleras:"
+msgstr "Spelare att kontrollera:"
 
 #: ../musicPlayer/data/messages:105
 msgid "Amarok 2"
-msgstr ""
+msgstr "Amarok 2"
 
 #: ../musicPlayer/data/messages:107
 msgid "Audacious"
@@ -7965,7 +8339,7 @@ msgstr "Banshee"
 
 #: ../musicPlayer/data/messages:111
 msgid "Clementine"
-msgstr ""
+msgstr "Clementine"
 
 #: ../musicPlayer/data/messages:113
 msgid "Exaile"
@@ -7973,47 +8347,47 @@ msgstr "Exaile"
 
 #: ../musicPlayer/data/messages:115
 msgid "Exaile 0.3"
-msgstr ""
+msgstr "Exaile 0.3"
 
 #: ../musicPlayer/data/messages:117
 msgid "GMusicBrowser"
-msgstr ""
+msgstr "GMusicBrowser"
 
 #: ../musicPlayer/data/messages:119
 msgid "Guayadeque"
-msgstr ""
+msgstr "Guayadeque"
 
 #: ../musicPlayer/data/messages:121
 msgid "Listen"
-msgstr ""
+msgstr "Lyssna"
 
 #: ../musicPlayer/data/messages:123
 msgid "Qmmp"
-msgstr ""
+msgstr "Qmmp"
 
 #: ../musicPlayer/data/messages:125
 msgid "QuodLibet"
-msgstr ""
+msgstr "QuodLibet"
 
 #: ../musicPlayer/data/messages:127
 msgid "Rhythmbox"
-msgstr ""
+msgstr "Rhythmbox"
 
 #: ../musicPlayer/data/messages:129
 msgid "Songbird"
-msgstr ""
+msgstr "Songbird"
 
 #: ../musicPlayer/data/messages:131
 msgid "XMMS 2"
-msgstr ""
+msgstr "XMMS 2"
 
 #: ../musicPlayer/data/messages:133
 msgid ""
 "This will prevent the player icon appearing in the taskbar. The applet's "
 "icon will then behave as a launcher, an application and an applet."
 msgstr ""
-"Gör att spelarens ikon inte visas i aktivitetsfältet. Appletens ikon används "
-"istället för att styra programmet."
+"Detta kommer att förhindra att spelarikonen visas i aktivitetsfältet. Applet-"
+"ikonen kommer då att uppföra sig som en startare, ett program och en applet."
 
 #: ../musicPlayer/data/messages:135
 msgid "Steal the player's icon from the taskbar?"
@@ -8021,60 +8395,60 @@ msgstr "Stjäl spelarens ikon från akti
 
 #: ../musicPlayer/data/messages:137
 msgid "Actions on click and middle-click :"
-msgstr ""
+msgstr "Åtgärd vid klick och mittenklick :"
 
 #: ../musicPlayer/data/messages:139
 msgid "Play/Pause on click, Next on middle-click"
-msgstr ""
+msgstr "Spela/Pausa med klick, Nästa med mittenklick"
 
 #: ../musicPlayer/data/messages:141
 msgid "Show/Hide player on click, Play/Pause on middle-click"
-msgstr ""
+msgstr "Visa/dölj spelare vid klick, Spela/Pausa med mittenklick"
 
 #: ../musicPlayer/data/messages:143
 msgid "Actions on scroll up/down:"
-msgstr ""
+msgstr "Åtgärd vid rulla upp/ner:"
 
 #: ../musicPlayer/data/messages:145
 msgid "Next/previous song"
-msgstr ""
+msgstr "Nästa/föregående låt"
 
 #: ../musicPlayer/data/messages:147
 msgid "Control the volume"
-msgstr ""
+msgstr "Kontrollera volymen"
 
 #: ../musicPlayer/data/messages:149
 msgid "Action on music change"
-msgstr "Aktivitet vid musikbyte:"
+msgstr "Åtgärd vid musikbyte"
 
 #: ../musicPlayer/data/messages:151
 msgid "Show tooltips?"
-msgstr "Visa infobubbla?"
+msgstr "Visa verktygstips?"
 
 #: ../musicPlayer/data/messages:155
 msgid "Time length of tooltips:"
-msgstr "Tid som infobubblor visas:"
+msgstr "Tidslängd verktygstips:"
 
 #: ../musicPlayer/data/messages:157
 msgid "Animation when music changes:"
-msgstr "Animering när musiken ändras:"
+msgstr "Animering när musik ändras:"
 
 #: ../musicPlayer/data/messages:161 ../powermanager/data/messages:145
 #: ../wifi/data/messages:143
 msgid "Information to display on the icon :"
-msgstr "Information att visa på ikonen:"
+msgstr "Information att visa på ikonen :"
 
 #: ../musicPlayer/data/messages:163 ../powermanager/data/messages:147
 msgid "Nothing"
-msgstr "inget"
+msgstr "Inget"
 
 #: ../musicPlayer/data/messages:165
 msgid "Time Elapsed"
-msgstr "Använd tid"
+msgstr "Tid som gått"
 
 #: ../musicPlayer/data/messages:167
 msgid "Time Remaining"
-msgstr "Tid kvar"
+msgstr "Återstående tid"
 
 #: ../musicPlayer/data/messages:169
 msgid "Track number"
@@ -8082,47 +8456,47 @@ msgstr "Spårnummer"
 
 #: ../musicPlayer/data/messages:171
 msgid "Display album's cover?"
-msgstr ""
+msgstr "Visa albumomslag?"
 
 #: ../musicPlayer/data/messages:173
 msgid "You need to be connected to the Internet."
-msgstr ""
+msgstr "Du måste vara ansluten till Internet."
 
 #: ../musicPlayer/data/messages:175
 msgid "Allow Cairo-Dock to download missing covers?"
-msgstr ""
+msgstr "Tillåt Cairo-Dock att ladda ner saknade omslag?"
 
 #: ../musicPlayer/data/messages:177 ../musicPlayer/data/messages:181
 msgid "requires OpenGL."
-msgstr ""
+msgstr "kräver OpenGL."
 
 #: ../musicPlayer/data/messages:179
 msgid "Use 3D themes?"
-msgstr ""
+msgstr "Använd 3D-teman?"
 
 #: ../musicPlayer/data/messages:183
 msgid "List of available 3D themes for covers :"
-msgstr ""
+msgstr "Lista på tillgängliga 3D-teman för omslag :"
 
 #: ../musicPlayer/data/messages:189 ../tomboy/data/messages:15
 msgid "'Default' icon image name:"
-msgstr "Bild för standard:"
+msgstr "\"Standard\" ikonbildsnamn:"
 
 #: ../musicPlayer/data/messages:193
 msgid "Name of the image for the 'play' icon :"
-msgstr "Bild för spela upp:"
+msgstr "Namnet på bild för \"spela\" ikonen :"
 
 #: ../musicPlayer/data/messages:197
 msgid "Name of the image for the 'stop' icon :"
-msgstr "Bild för stop:"
+msgstr "Namnet på bild för \"stoppa\" ikonen :"
 
 #: ../musicPlayer/data/messages:201
 msgid "Name of the image for the 'pause' icon :"
-msgstr "Bild för pausa:"
+msgstr "Namnet på bild för \"pausa\" ikonen :"
 
 #: ../netspeed/data/messages:145
 msgid "By default all interfaces will be monitored."
-msgstr ""
+msgstr "Som standard kommer alla gränssnitt att övervakas."
 
 #: ../netspeed/data/messages:147
 msgid "interface:"
@@ -8130,27 +8504,27 @@ msgstr "gränssnitt:"
 
 #: ../netspeed/data/messages:155
 msgid "Fluidity of the transition between 2 values :"
-msgstr ""
+msgstr "Övergångens fluiditet mellan 2 värden :"
 
 #: ../netspeed/data/messages:157
 msgid "Display rate values :"
-msgstr ""
+msgstr "Visa hastighetsvärden :"
 
 #: ../powermanager/data/messages:7
 msgid "Leave empty to display the current status information."
-msgstr ""
+msgstr "Lämna tomt för att visa aktuell statusinformation."
 
 #: ../powermanager/data/messages:11
 msgid "Current status"
-msgstr ""
+msgstr "Nuvarande status"
 
 #: ../powermanager/data/messages:139
 msgid "'On-battery' icon filename:"
-msgstr "Ikon när datorn körs på batteri:"
+msgstr "\"På batteri\" ikonfilnamn:"
 
 #: ../powermanager/data/messages:141
 msgid "Icon's filename when on charge :"
-msgstr "Ikon när batteriet laddasi"
+msgstr "Ikonfilnamn under laddning :"
 
 #: ../powermanager/data/messages:149
 msgid "charge"
@@ -8158,37 +8532,37 @@ msgstr "ladda"
 
 #: ../powermanager/data/messages:151
 msgid "Timelength"
-msgstr ""
+msgstr "Tidslängd"
 
 #: ../powermanager/data/messages:153
 msgid "Emblem icon's filename when on charge:"
-msgstr ""
+msgstr "Emblemikonens filnamn vid laddning:"
 
 #: ../powermanager/data/messages:155
 msgid "Hide the icon when not on battery?"
-msgstr ""
+msgstr "Dölj ikonen när inte på batteri?"
 
 #: ../powermanager/data/messages:161
 msgid "Notification"
-msgstr "Meddelande"
+msgstr "Underrättelse"
 
 #: ../powermanager/data/messages:163
 msgid "Notification when battery charged ?"
-msgstr ""
+msgstr "Meddelande när batteri laddas ?"
 
 #: ../powermanager/data/messages:165 ../powermanager/data/messages:175
 #: ../powermanager/data/messages:183
 msgid "Leave it empty for no sound"
-msgstr "Lämna tomt om du inte vill spela upp ett ljud"
+msgstr "Lämna tomt för inget ljud"
 
 #: ../powermanager/data/messages:167 ../powermanager/data/messages:177
 #: ../powermanager/data/messages:185
 msgid "Play a sound:"
-msgstr "Använd ljud:"
+msgstr "Spela ett ljud:"
 
 #: ../powermanager/data/messages:169
 msgid "Notification when low battery ?"
-msgstr ""
+msgstr "Meddelande vid svagt batteri ?"
 
 #: ../powermanager/data/messages:171
 msgid "in percent."
@@ -8200,168 +8574,174 @@ msgstr "Batterinivå:"
 
 #: ../powermanager/data/messages:179
 msgid "When battery level is under 4%"
-msgstr "När laddningsnivån är under 4%"
+msgstr "När batterinivån är under 4%"
 
 #: ../powermanager/data/messages:181
 msgid "Notification when battery charge is critical ?"
-msgstr ""
+msgstr "Meddelande när batteriladdningen är kritisk?"
 
 #: ../powermanager/data/messages:187
 msgid "Notification type:"
-msgstr ""
+msgstr "Meddelandetyp:"
 
 #: ../quick-browser/data/messages:7
 msgid "Leave empty to use the folder's name."
-msgstr ""
+msgstr "Lämna tomt för att använda mappens namn."
 
 #: ../quick-browser/data/messages:93 ../slider/data/messages:99
 msgid "Folder"
-msgstr ""
+msgstr "Mapp"
 
 #: ../quick-browser/data/messages:95
 msgid "Folder to browse :"
-msgstr ""
+msgstr "Mapp att bläddra i :"
 
 #: ../quick-browser/data/messages:97
 msgid "List folders first?"
-msgstr ""
+msgstr "Lista mappar först?"
 
 #: ../quick-browser/data/messages:99
 msgid "Ignore case?"
-msgstr ""
+msgstr "Ignorera skiftläge?"
 
 #: ../quick-browser/data/messages:103
 msgid "Menu"
-msgstr ""
+msgstr "Meny"
 
 #: ../quick-browser/data/messages:105
 msgid "It can be CPU intense to load a lot of icons."
-msgstr ""
+msgstr "Det kan vara CPU-krävande att läsa in många ikoner."
 
 #: ../quick-browser/data/messages:107
 msgid "Display icons in the menu?"
-msgstr ""
+msgstr "Visa ikoner i menyn?"
 
 #: ../quick-browser/data/messages:111
 msgid ""
 "Number of items loaded at once. Setting a high value speeds up loading a "
 "little but will hang the application for longer."
 msgstr ""
+"Antal objekt som läses in samtidigt. Att ställa in ett högre värde snabbar "
+"upp inläsning lite men kommer att hänga programmet längre."
 
 #: ../quick-browser/data/messages:113
 msgid "Build menu gradually:"
-msgstr ""
+msgstr "Bygg meny stegvis:"
 
 #: ../shortcuts/data/messages:93
 msgid "List drives and volumes?"
-msgstr "Visa diskar och volymer?"
+msgstr "Lista diskar och volymer?"
 
 #: ../shortcuts/data/messages:95
 msgid "List networks?"
-msgstr "Visa nätverk?"
+msgstr "Lista nätverk?"
 
 #: ../shortcuts/data/messages:97
 msgid "GTK bookmarks, that are used by Nautilus for exemple."
-msgstr "GTK bokmärken. Används av t ex Nautilus."
+msgstr "GTK-bokmärken, som används av till exempel Nautilus."
 
 #: ../shortcuts/data/messages:99
 msgid "List bookmarks?"
-msgstr "Visa bokmärken?"
+msgstr "Lista bokmärken?"
 
 #: ../shortcuts/data/messages:107 ../stack/data/messages:99
 msgid "Type of view for the desklet mode :"
-msgstr ""
+msgstr "Typ av vy för desklet-läget :"
 
 #: ../shortcuts/data/messages:111 ../stack/data/messages:103
 msgid "Tree"
-msgstr ""
+msgstr "Träd"
 
 #: ../shortcuts/data/messages:113
 msgid "Disk usage"
-msgstr ""
+msgstr "Diskanvändning"
 
 #: ../shortcuts/data/messages:115
 msgid "Show disk usage :"
-msgstr ""
+msgstr "Visa diskanvändning :"
 
 #: ../shortcuts/data/messages:119
 msgid "Free space"
-msgstr ""
+msgstr "Ledigt utrymme"
 
 #: ../shortcuts/data/messages:121
 msgid "Used space"
-msgstr ""
+msgstr "Använt utrymme"
 
 #: ../shortcuts/data/messages:123
 msgid "Free space (in percent)"
-msgstr ""
+msgstr "Ledigt utrymme (i procent)"
 
 #: ../shortcuts/data/messages:125
 msgid "Used space (in percent)"
-msgstr ""
+msgstr "Använt utrymme (i procent)"
 
 #: ../shortcuts/data/messages:129
 msgid "Delay between disk usage refresh :"
-msgstr ""
+msgstr "Fördröjning mellan diskanvändningsuppdateringar :"
 
 #: ../shortcuts/data/messages:131
 msgid "Display disk usage with a bar?"
-msgstr ""
+msgstr "Visa diskanvändning med en stapel?"
 
 #: ../show-mouse/data/messages:5
 msgid "In rotations per second."
-msgstr ""
+msgstr "I rotationer per sekund."
 
 #: ../show-mouse/data/messages:9
 msgid "Show mouse on:"
-msgstr ""
+msgstr "Visa mus på:"
 
 #: ../show-mouse/data/messages:11
 msgid "Dock"
-msgstr ""
+msgstr "Docka"
 
 #: ../show-mouse/data/messages:21
 msgid "Particle life time:"
-msgstr ""
+msgstr "Livstid för partiklar:"
 
 #: ../show-mouse/data/messages:33
 msgid ""
 "The higher the value, the more particles will scatter from their source."
 msgstr ""
+"Ju högre värde, desto mer kommer partiklar att spridas från sin källa."
 
 #: ../show-mouse/data/messages:35
 msgid "Scattering:"
-msgstr ""
+msgstr "Spridning:"
 
 #: ../showDesktop/data/messages:13
 msgid "Image when the applet is active :"
-msgstr ""
+msgstr "Bild när applet är aktivt :"
 
 #: ../showDesktop/data/messages:95 ../showDesktop/data/messages:109
 msgid ""
 "You need to activate the Dbus plug-in in Compiz for the last 2 actions. "
 "Showing desktop and desklets can fail on some Window Manager (like Metacity)."
 msgstr ""
+"Du måste aktivera Dbus-insticksprogrammet i Compiz för de sista 2 "
+"åtgärderna. Att visa skrivbordet och desklets kan misslyckas på en del "
+"fönsterhanterare (som Metacity)."
 
 #: ../showDesktop/data/messages:97 ../slider/data/messages:117
 msgid "Action on left-click:"
-msgstr ""
+msgstr "Åtgärd vid vänsterklick:"
 
 #: ../showDesktop/data/messages:101 ../showDesktop/data/messages:115
 msgid "Show the desklets"
-msgstr ""
+msgstr "Visa desklets"
 
 #: ../showDesktop/data/messages:103 ../showDesktop/data/messages:117
 msgid "Show desktop and desklets"
-msgstr ""
+msgstr "Visa skrivbord och desklets"
 
 #: ../showDesktop/data/messages:123
 msgid "Shortkey for the middle-click action:"
-msgstr ""
+msgstr "Kortkommando för mittenklicksåtgärden:"
 
 #: ../slider/data/messages:101
 msgid "Folder for the images:"
-msgstr ""
+msgstr "Mapp för bilderna:"
 
 #: ../slider/data/messages:103
 msgid "Scan sub direcotries?"
@@ -8369,25 +8749,27 @@ msgstr "Sök i underkataloger?"
 
 #: ../slider/data/messages:105
 msgid "Randomly browse files?"
-msgstr "Sök efter filer slumpmässigt?"
+msgstr "Bläddra slumpmässigt bland filer?"
 
 #: ../slider/data/messages:107
 msgid "Display image name as quickinfo?"
-msgstr ""
+msgstr "Visa bildnamn som snabbinfo?"
 
 #: ../slider/data/messages:109
 msgid ""
 "This will prevent the dock from freezing during image loading, but works "
 "only with OpenGL."
 msgstr ""
+"Detta kommer att förhindra dockan att frysa under bildinläsning, men "
+"fungerar bara med OpenGL."
 
 #: ../slider/data/messages:111
 msgid "Use another thread to load images?"
-msgstr ""
+msgstr "Använd en annan tråd för att läsa in bilder?"
 
 #: ../slider/data/messages:113
 msgid "Read all images properties on startup?"
-msgstr ""
+msgstr "Läs alla bildegenskaper vid start?"
 
 #: ../slider/data/messages:119 ../slider/data/messages:125
 msgid "play/pause"
@@ -8399,35 +8781,35 @@ msgstr "öppna bild"
 
 #: ../slider/data/messages:129
 msgid "open parent folder"
-msgstr ""
+msgstr "öppna överordnad mapp"
 
 #: ../slider/data/messages:133
 msgid "Sliding delay:"
-msgstr "Paus mellan bilder:"
+msgstr "Bildfördröjning:"
 
 #: ../slider/data/messages:135
 msgid "Effect while changing image:"
-msgstr "Effekt när bilden byts:"
+msgstr "Effekt när bild byts:"
 
 #: ../slider/data/messages:139
 msgid "fade"
-msgstr "tona"
+msgstr "tona bort"
 
 #: ../slider/data/messages:141
 msgid "blank fade"
-msgstr "tona till blank"
+msgstr "tona bort till tom"
 
 #: ../slider/data/messages:143
 msgid "fade in/out"
-msgstr "tona in ut"
+msgstr "tona in/ut"
 
 #: ../slider/data/messages:145
 msgid "side kick"
-msgstr "sidokick"
+msgstr "sidspark"
 
 #: ../slider/data/messages:147
 msgid "slideshow"
-msgstr "slideshow"
+msgstr "bildspel"
 
 #: ../slider/data/messages:149
 msgid "grow up"
@@ -8435,11 +8817,11 @@ msgstr "väx uppåt"
 
 #: ../slider/data/messages:151
 msgid "shrink"
-msgstr "krymp neråt"
+msgstr "krymp"
 
 #: ../slider/data/messages:153
 msgid "cube"
-msgstr ""
+msgstr "kub"
 
 #: ../slider/data/messages:155
 msgid "random"
@@ -8447,69 +8829,71 @@ msgstr "slumpmässig"
 
 #: ../slider/data/messages:157
 msgid "Number of steps for transitions:"
-msgstr ""
+msgstr "Antal steg för övergångar:"
 
 #: ../slider/data/messages:159
 msgid "fast"
-msgstr ""
+msgstr "snabbt"
 
 #: ../slider/data/messages:161
 msgid "slow"
-msgstr ""
+msgstr "långsamt"
 
 #: ../slider/data/messages:165
 msgid "Add a background to the image?"
-msgstr ""
+msgstr "Lägg till en bakgrund till bilden?"
 
 #: ../slider/data/messages:173
 msgid ""
 "Set the transparency channel to 0 if you just don't want to have a "
 "background."
-msgstr "Sätt alfakanalen till 0 om du inte vill visa någon bakgrund."
+msgstr ""
+"Ställ in genomskinlighetskanalen till 0 om du absolut inte vill ha en "
+"bakgrund."
 
 #: ../slider/data/messages:175
 msgid "Choose a background colour :"
-msgstr "Välj bakgrundsfärg:"
+msgstr "Välj en bakgrundsfärg :"
 
 #: ../slider/data/messages:177
 msgid "Frame width:"
-msgstr ""
+msgstr "Rambredd:"
 
 #: ../slider/data/messages:179
 msgid "Gives better image rendering."
-msgstr "Ger bättre bildrendering."
+msgstr "Ger bättre bildvisning."
 
 #: ../slider/data/messages:181
 msgid "Keep width/height ratio?"
-msgstr "Behåll ursprungligt bildförhållande?"
+msgstr "Behåll bredd/höjd förhållande?"
 
 #: ../slider/data/messages:183
 msgid "If the image is too small, it will be stretched."
-msgstr "Om bilden är för liten, förstoras den automatiskt."
+msgstr "Om bilden är för liten, kommer den att sträckas ut."
 
 #: ../slider/data/messages:185
 msgid "Force the image to fill the icon/desklet?"
-msgstr "Repetera bilden för att fylla hela dockan?"
+msgstr "Tvinga bilden att fylla ikonen/deskleten?"
 
 #: ../stack/data/messages:7
 msgid "Leave empty to use a default name"
-msgstr "Lämna tomt för att använda standardnamnet"
+msgstr "Lämna tomt för att använda ett standardnamn"
 
 #: ../stack/data/messages:105
 msgid "They are items created by dropping a text into the Stack."
-msgstr "Objekt som skapas när text släpps i stacken."
+msgstr "De är objekt som har skapats genom att släppa en text i Stacken."
 
 #: ../stack/data/messages:107
 msgid "Image for 'text' items:"
-msgstr "Bild för textobjekt:"
+msgstr "Bild för \"text\" objekt:"
 
 #: ../stack/data/messages:109
 msgid "These are items created by dropping a URL into the Stack."
-msgstr "Objekt som skapas när URL:er släpps i stacken."
+msgstr "Dessa är objekt som skapats genom att släppa en URL i Stacken."
 
 #: ../stack/data/messages:111
 msgid "Image for 'URL' items:"
-msgstr "Bild för URL-objekt:"
+msgstr "Bild för \"URL\"-objekt:"
 
 #: ../stack/data/messages:113
 msgid "Options"
@@ -8517,31 +8901,31 @@ msgstr "Alternativ"
 
 #: ../stack/data/messages:115
 msgid "Separate the items by type (file/web page/text)"
-msgstr ""
+msgstr "Separera objekten genom typ (fil/webbsida/text)"
 
 #: ../stack/data/messages:117
 msgid ""
 "These options allow you to prevent some files from displaying in stacks "
 "based on their type (video, image, etc.)"
 msgstr ""
-"Gör att du kan utesluta vissa filtyper från att visas i stacken (video, "
-"bilder, etc...)"
+"Dessa alternativ gör att du kan förhindra vissa filer från att visas i "
+"stackar baserat på deras typ (film, bild, etc.)"
 
 #: ../stack/data/messages:119
 msgid "Filter files on MIME type?"
-msgstr "Filtrera filer efter MIME typ?"
+msgstr "Filtrera filer utifrån MIME-typ?"
 
 #: ../stack/data/messages:121
 msgid "E.g. image, text, video, audio, application..."
-msgstr "T ex bilder, video, ljud, program..."
+msgstr "T. ex. bilder, text, film, ljud, program..."
 
 #: ../stack/data/messages:123
 msgid "Here you can specify a list of MIME types to ignore:"
-msgstr "MIME typer som skall undvikas:"
+msgstr "Här kan du ange en lista över MIME-typer att ignorera:"
 
 #: ../stack/data/messages:125
 msgid "Sort items by:"
-msgstr "Sortera efter:"
+msgstr "Sortera objekt efter:"
 
 #: ../stack/data/messages:131
 msgid "Type"
@@ -8549,47 +8933,47 @@ msgstr "Typ"
 
 #: ../stack/data/messages:133
 msgid "Manual order"
-msgstr "Manuell sortering"
+msgstr "Manuell ordning"
 
 #: ../switcher/data/messages:93
 msgid "How to display all desktops?"
-msgstr ""
+msgstr "Hur ska alla skrivbord visas?"
 
 #: ../switcher/data/messages:95
 msgid "A sub-dock with all desktops"
-msgstr ""
+msgstr "En underdocka med alla skrivbord"
 
 #: ../switcher/data/messages:97
 msgid "All desktops drawn on the main icon"
-msgstr ""
+msgstr "Alla skrivbord ritade på huvudikonen"
 
 #: ../switcher/data/messages:99
 msgid "Desktops layout"
-msgstr ""
+msgstr "Skribordslayout"
 
 #: ../switcher/data/messages:103
 msgid "On a single line"
-msgstr ""
+msgstr "På en enda rad"
 
 #: ../switcher/data/messages:105
 msgid "Preserve the ratio of the screen?"
-msgstr ""
+msgstr "Behåll skärmförhållandet?"
 
 #: ../switcher/data/messages:107
 msgid "Background for each desktop"
-msgstr ""
+msgstr "Bakgrund för varje skrivbord"
 
 #: ../switcher/data/messages:109
 msgid "Wallpaper"
-msgstr ""
+msgstr "Skrivbordsbakgrund"
 
 #: ../switcher/data/messages:111 ../switcher/data/messages:117
 msgid "Custom image"
-msgstr ""
+msgstr "Anpassad bild"
 
 #: ../switcher/data/messages:113 ../switcher/data/messages:121
 msgid "Custom colour"
-msgstr ""
+msgstr "Anpassad färg"
 
 #: ../switcher/data/messages:119 ../switcher/data/messages:153
 #: ../switcher/data/messages:159 ../switcher/data/messages:163
@@ -8599,23 +8983,23 @@ msgstr "r, g, b, a"
 
 #: ../switcher/data/messages:125
 msgid "Show desktop number on icons?"
-msgstr ""
+msgstr "Visa skrivbordsnummer på ikoner?"
 
 #: ../switcher/data/messages:127
 msgid "Draw windows on icons?"
-msgstr "Visa fönsterinnehåll på ikonen?"
+msgstr "Rita fönster på ikoner?"
 
 #: ../switcher/data/messages:129
 msgid "Draw hidden windows?"
-msgstr ""
+msgstr "Rita dolda fönster?"
 
 #: ../switcher/data/messages:131
 msgid "Draw icons of windows?"
-msgstr ""
+msgstr "Rita fönsters ikoner?"
 
 #: ../switcher/data/messages:135
 msgid "Show windows' list"
-msgstr ""
+msgstr "Visa fönsterlista"
 
 #: ../switcher/data/messages:143
 msgid "Display options"
@@ -8623,7 +9007,7 @@ msgstr "Visningsalternativ"
 
 #: ../switcher/data/messages:151
 msgid "Size of the inside lines :"
-msgstr "Storlek på inre linjer:"
+msgstr "Storlek på inre linjer :"
 
 #: ../switcher/data/messages:155
 msgid "Internal line colour:"
@@ -8631,7 +9015,7 @@ msgstr "Färg på inre linjer:"
 
 #: ../switcher/data/messages:157
 msgid "External line size:"
-msgstr "Storlek på yttre linje:"
+msgstr "Storlek på yttre linjer:"
 
 #: ../switcher/data/messages:161
 msgid "External line colour:"
@@ -8639,15 +9023,15 @@ msgstr "Färg på yttre linje:"
 
 #: ../switcher/data/messages:165
 msgid "Active window colour:"
-msgstr ""
+msgstr "Aktiv fönsterfärg:"
 
 #: ../switcher/data/messages:169
 msgid "Current desktop colour:"
-msgstr "Färg för aktivt skrivbord:"
+msgstr "Aktivt skrivbords färg:"
 
 #: ../switcher/data/messages:171
 msgid "How to draw the current desktop:"
-msgstr "Hur ska aktivt skrivbord visas:"
+msgstr "Hur aktivt skrivbord ska ritas:"
 
 #: ../switcher/data/messages:173
 msgid "draw a frame"
@@ -8663,159 +9047,159 @@ msgstr "fyll övriga"
 
 #: ../switcher/data/messages:179
 msgid "All windows can be filled with one colour"
-msgstr ""
+msgstr "Alla fönster kan fyllas med en färg"
 
 #: ../switcher/data/messages:181
 msgid "Fill all windows?"
-msgstr ""
+msgstr "Fyll alla fönster?"
 
 #: ../switcher/data/messages:185
 msgid "Colour of these windows:"
-msgstr ""
+msgstr "Färg på dessa fönster?"
 
 #: ../switcher/data/messages:187
 msgid "Sub-Dock"
-msgstr ""
+msgstr "Underdocka"
 
 #: ../systray/data/messages:83
 msgid "Shortkey to toggle the systray in dock mode:"
-msgstr ""
+msgstr "Kortkommando för att växla systembrickan i dockläge:"
 
 #: ../systray/data/messages:85
 msgid "Icons packing :"
-msgstr ""
+msgstr "Ikonpackning :"
 
 #: ../systray/data/messages:87
 msgid "horizontal"
-msgstr ""
+msgstr "horisontell"
 
 #: ../systray/data/messages:89
 msgid "vertical"
-msgstr ""
+msgstr "vertikal"
 
 #: ../template/data/messages:91
 msgid "This is a tooltip for this parameter."
-msgstr ""
+msgstr "Detta är ett verktygstips för denna parameter."
 
 #: ../template/data/messages:93
 msgid "This is a boolean parameter. Y/N ?"
-msgstr ""
+msgstr "Detta är en booleansk parameter. J/N ?"
 
 #: ../template/data/messages:95
 msgid "This integer can go from 0 to 10 :"
-msgstr ""
+msgstr "Detta heltal kan gå från 0 till 10 :"
 
 #: ../template/data/messages:97
 msgid "Enter some text here :"
-msgstr ""
+msgstr "Skriv in någon text här :"
 
 #: ../terminal/data/messages:93
 msgid "Foreground colour:"
-msgstr ""
+msgstr "Förgrundsfärg:"
 
 #: ../terminal/data/messages:95
 msgid "Background colour:"
-msgstr ""
+msgstr "Bakgrundsfärg:"
 
 #: ../terminal/data/messages:97
 msgid "Use a custom font?"
-msgstr ""
+msgstr "Använd ett anpassat teckensnitt?"
 
 #: ../terminal/data/messages:99
 msgid "Custom font:"
-msgstr ""
+msgstr "Anpassat teckensnitt:"
 
 #: ../terminal/data/messages:103
 msgid "Automatically scroll to the bottom when new data are received"
-msgstr ""
+msgstr "Bläddra automatiskt till botten när ny data mottas"
 
 #: ../terminal/data/messages:105
 msgid "Scroll on output"
-msgstr ""
+msgstr "Bläddra vid utdata"
 
 #: ../terminal/data/messages:107
 msgid "Automatically scroll to the bottom when a key is pressed"
-msgstr ""
+msgstr "Bläddra automatiskt till botten när en tangent trycks ner"
 
 #: ../terminal/data/messages:109
 msgid "Scroll on keystroke"
-msgstr ""
+msgstr "Bläddra vid tangenttryckning"
 
 #: ../terminal/data/messages:111
 msgid "Limited scrollback buffer"
-msgstr ""
+msgstr "Begränsad tillbakabläddringsbuffert"
 
 #: ../terminal/data/messages:113
 msgid "Length of the scrollback buffer"
-msgstr ""
+msgstr "Längd på tillbakabläddringsbuffert"
 
 #: ../terminal/data/messages:117
 msgid ""
 "When the terminal is in a dialog. When it is in a desklet, you can just "
 "resize the desklet as usual."
 msgstr ""
-"När terminalen visas i ett fönster. När den är i en desklet, kan du ändra "
-"storlek som vanligt."
+"När terminalen är i en dialogruta. När den är i en desklet, kan du ändra "
+"storlek på deskleten som vanligt."
 
 #: ../terminal/data/messages:119
 msgid "Size of the terminal (line x columns):"
-msgstr "Storlek på terminal (rader x kolumner):"
+msgstr "Storlek på terminalen (rader x kolumner):"
 
 #: ../terminal/data/messages:121
 msgid "Shortkey to show the terminal:"
-msgstr ""
+msgstr "Kortkommando för att visa terminalen:"
 
 #: ../terminal/data/messages:123
 msgid "The default terminal is defined by the COLORTERM environment variable"
-msgstr ""
+msgstr "Standardterminalen definieras av miljövariabeln COLORTERM"
 
 #: ../terminal/data/messages:125
 msgid "Open this terminal when doing a middle click on the icon:"
-msgstr ""
+msgstr "Öppna denna terminal vid mittenklick på ikonen:"
 
 #: ../tomboy/data/messages:19
 msgid "'Close' icon image name:"
-msgstr ""
+msgstr "Ikonbildnamn för \"Stäng\":"
 
 #: ../tomboy/data/messages:107
 msgid "Image file for the notes:"
-msgstr ""
+msgstr "Bildfil för anteckningarna:"
 
 #: ../tomboy/data/messages:109
 msgid "Draw note's content on their icon?"
-msgstr "Visa noteringens innehåll på ikonen?"
+msgstr "Rita anteckningens innehåll på deras ikon?"
 
 #: ../tomboy/data/messages:111
 msgid "Text colour of the content :"
-msgstr ""
+msgstr "Innehållets textfärg :"
 
 #: ../tomboy/data/messages:113
 msgid "Display note's content with a dialog?"
-msgstr ""
+msgstr "Visa anteckningsinnehåll med en dialog?"
 
 #: ../tomboy/data/messages:125
 msgid "Choose the note-taking application to control :"
-msgstr ""
+msgstr "Välj ett anteckningsprogram att kontrollera :"
 
 #: ../tomboy/data/messages:127
 msgid "Gnote"
-msgstr ""
+msgstr "Gnote"
 
 #: ../tomboy/data/messages:129
 msgid "Tomboy"
-msgstr ""
+msgstr "Tomboy"
 
 #: ../tomboy/data/messages:133
 msgid "Ask for confirmation before deleting a note?"
-msgstr ""
+msgstr "Bekräfta innan en anteckning tas bort?"
 
 #: ../tomboy/data/messages:135
 msgid "Otherwise you will be asked to name it."
-msgstr ""
+msgstr "Annars kommer du att tillfrågas om att byta namn på den."
 
 #: ../tomboy/data/messages:137
 msgid "Automatically name a new note?"
-msgstr ""
+msgstr "Namnge automatiskt en ny anteckning?"
 
 #: ../tomboy/data/messages:139
 msgid ""
@@ -8823,13 +9207,13 @@ msgid ""
 "of 'strftime' : %d for the day, %m for the month, %y for the year (2 "
 "digits), etc. Leave it blank to use the default one (%d/%m/%y)."
 msgstr ""
-"Ange datumformat som du oftast använder. Syntax är samma som för 'strftime': "
-"%d för dag, %m för månad, %y för år (2 siffror) etc. Lämna tomt för att "
-"använda standardformatet (%d/%m/%y)."
+"Skriv datumformat du brukar använda i dina anteckningar. Syntaxen är en av "
+"\"strftime\" : %d för dagen, %m för månaden, %y för året (2 siffror), etc. "
+"Lämna tomt för att använda standardvärdet (%d/%m/%y)."
 
 #: ../tomboy/data/messages:141
 msgid "Date format to search for :"
-msgstr "Datumformat att söka efter:"
+msgstr "Datumformat att söka efter :"
 
 #: ../tomboy/data/messages:145
 msgid ""
@@ -8838,26 +9222,26 @@ msgid ""
 "message like <<No marshaller for signature of signal 'NoteDeleted'>> in the "
 "terminal."
 msgstr ""
-"beroende på vilken version av Tomboy du har, kanske inte borttagning av "
-"anteckningar alltid upptäcks. Markera bara rutan om du ser meddelanden som "
-"<<No marshaller for signature of signal 'NoteDeleted'>> i ett "
-"terminalfönster."
+"Beroende på din tomboy-version, kan inte anteckningsradering automatiskt "
+"meddelas till oss. Bara markera den här rutan om du märker något "
+"felmeddelande som <<No marshaller for signature of signal 'NoteDeleted'>> i "
+"terminalen."
 
 #: ../tomboy/data/messages:147
 msgid "Emulate the 'NoteDeleted' signal?"
-msgstr "Emulera 'NoteDeleted' meddelanden?"
+msgstr "Emulera 'NoteDeleted' signal?"
 
 #: ../weather/data/messages:7
 msgid "Leave empty to use the name of the city."
-msgstr "Lämna tomt för att använda namnet på staden."
+msgstr "Lämna tomt för att använda stadens namn."
 
 #: ../weather/data/messages:11
 msgid "City name"
-msgstr ""
+msgstr "Stadsnamn"
 
 #: ../weather/data/messages:103
 msgid "Enter the name of your location in the text entry and press Enter."
-msgstr ""
+msgstr "Ange namnet på din plats i textrutan och tryck Enter."
 
 #: ../weather/data/messages:105
 msgid "Code for your location:"
@@ -8865,101 +9249,103 @@ msgstr "Kod för din geografiska plats:"
 
 #: ../weather/data/messages:107
 msgid "If so, degrees will be displayed in Celsius, otherwise in Fahrenheit."
-msgstr ""
+msgstr "Om så, kommer grader att visas i Celsius, i annars i Fahrenheit."
 
 #: ../weather/data/messages:109
 msgid "Use International System Units?"
-msgstr "Använd internationella enheter?"
+msgstr "Använd internationella systemenheter?"
 
 #: ../weather/data/messages:111
 msgid "in seconds. Set 0 to have never-ending dialogs."
-msgstr "i sekunder. Ange 0 om du vill stänga dialoger manuellt."
+msgstr "i sekunder. Ange 0 för att ha eviga dialoger."
 
 #: ../weather/data/messages:113
 msgid "Dialog duration:"
-msgstr "Visningstid för fönster:"
+msgstr "Varaktighet för dialog:"
 
 #: ../weather/data/messages:119 ../wifi/data/messages:141
 msgid "Info"
-msgstr "Info"
+msgstr "Information"
 
 #: ../weather/data/messages:121
 msgid "Display current conditions on the icon instead of the default one?"
-msgstr "Visa aktuellt väder på ikonen istället för standardbilden?"
+msgstr "Visa aktuella förhållanden på ikonen istället för standardvärdet?"
 
 #: ../weather/data/messages:123
 msgid "Number of days to forecast:"
-msgstr "Antal dagar med väderprognoser:"
+msgstr "Antal dagar att förutse:"
 
 #: ../weather/data/messages:125
 msgid "Display nights?"
-msgstr "Visa även nattväder?"
+msgstr "Visa nätter?"
 
 #: ../weather/data/messages:127
 msgid "Display temperature as quick info?"
-msgstr "Visa temperaturen som snabbinformation?"
+msgstr "Visa temperatur som snabbinfo?"
 
 #: ../weather/data/messages:137
 msgid "Render desklet in 3D?"
-msgstr "Använd 3D för Desklet?"
+msgstr "Rendera desklet i 3D?"
 
 #: ../weblets/data/messages:91
 msgid "URI to load in weblet"
-msgstr ""
+msgstr "URI att ladda i weblet"
 
 #: ../weblets/data/messages:93
 msgid "Show scrollbars?"
-msgstr ""
+msgstr "Visa rullningslister?"
 
 #: ../weblets/data/messages:95
 msgid "Horizontal scroll of the browser in pixels"
-msgstr ""
+msgstr "Webbläsarens horisontella rullning i pixlar"
 
 #: ../weblets/data/messages:97
 msgid "Position of horizontal scrollbar"
-msgstr ""
+msgstr "Position för horisontell rullningslist"
 
 #: ../weblets/data/messages:99
 msgid "Vertical scroll of the browser in pixels"
-msgstr ""
+msgstr "Webbläsarens vertikala rullning i pixlar"
 
 #: ../weblets/data/messages:101
 msgid "Position of vertical scrollbar in pixel"
-msgstr ""
+msgstr "Position för vertikal rullningslist"
 
 #: ../weblets/data/messages:103
 msgid ""
 "This lets you right-click on the desklet to pop up the Cairo-Dock menu."
 msgstr ""
+"Detta låter dig högerklicka på deskleten för att visa Cairo-Dock-menyn."
 
 #: ../weblets/data/messages:105
 msgid "Right margin width, in pixels:"
-msgstr ""
+msgstr "Högermarginalbredd, i pixlar:"
 
 #: ../weblets/data/messages:107
 msgid "Transparent background?"
-msgstr ""
+msgstr "Genomskinlig bakgrund?"
 
 #: ../weblets/data/messages:109
 msgid ""
 "Time before reloading the weblet URI, in seconds. Zero means never reload."
 msgstr ""
+"Tid innan weblet-URI:n laddas om, i sekunder. Noll betyder ladda aldrig om."
 
 #: ../weblets/data/messages:111
 msgid "Time between two page refreshes"
-msgstr ""
+msgstr "Tids mellan två siduppdateringar"
 
 #: ../weblets/data/messages:113
 msgid "Any valid URI should work."
-msgstr ""
+msgstr "Alla giltiga URI bör fungera."
 
 #: ../weblets/data/messages:115
 msgid "Predefined bookmarks to show in applet menu:"
-msgstr ""
+msgstr "Fördefinierade bokmärken som ska visas i applet-menyn:"
 
 #: ../wifi/data/messages:139
 msgid "\"No signal\" icon"
-msgstr ""
+msgstr "\"Ingen signal\" ikon"
 
 #: ../wifi/data/messages:147
 msgid "Signal Strength"
@@ -8971,18 +9357,20 @@ msgstr "Signalstyrka i procent"
 
 #: ../wifi/data/messages:151
 msgid "Raw Signal Informations"
-msgstr ""
+msgstr "Raw Signal Information"
 
 #: ../wifi/data/messages:157
 msgid "Delay between signal checks :"
-msgstr "Tid mellan uppdateringar:"
+msgstr "Fördröjning mellan signalkontroller :"
 
 #: ../wifi/data/messages:163
 msgid ""
 "Allow you to overwrite applet's default command line and launch your "
 "wireless configuration interface."
 msgstr ""
+"Låter dig skriva över applets standardkommandorad och starta ditt trådlösa "
+"inställningsgränssnitt."
 
 #: ../wifi/data/messages:165
 msgid "Alternative command line to launch Wireless Configuration :"
-msgstr ""
+msgstr "Alternativ kommandorad för att starta trådlös inställning :"
diff -pruN 3.4.1-6/README.md 3.4.1+git20201022.a0d3415c-1/README.md
--- 3.4.1-6/README.md	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/README.md	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,61 @@
+Cairo-Dock
+==========
+
+Cairo-Dock is a pretty, light and convenient interface to your desktop, able to replace advantageously your system panel! It features multi-docks, taskbar, launchers and a lot of useful applets. Applets can be detached from the dock to act as desktop widgets. Numerous ready-to-use themes are available in 1 click, and can be easily customized at your convenience. It can use hardware acceleration to be very fast and low on CPU.
+
+[![Preview](http://download.tuxfamily.org/glxdock/communication/images/3.3/cd-panel-mix-600.jpg)](http://download.tuxfamily.org/glxdock/communication/images/3.3/cd-panel-mix.png)
+Other screenshots are available at [Glx-Dock.org](http://www.glx-dock.org/mc_album.php?a=3).
+
+This project is split in 3 parts:
+
+  - Cairo-Dock-Core (the minimal - https://github.com/Cairo-Dock/cairo-dock-core)
+  - Cairo-Dock-Plug-ins (a collection of views, applets, animations, effects, etc. - https://github.com/Cairo-Dock/cairo-dock-plug-ins)
+  - Cairo-Dock-Plug-ins-Extras (a collection of third-party applets written in any language - https://github.com/Cairo-Dock/cairo-dock-plug-ins-extras)
+
+The Cairo-Dock-Session project aims to provide an easy way to install a session that is desktop agnostic and uses Cairo-Dock as a Shell (the main interface).
+
+
+Installation
+------------
+
+Please see our [Wiki at Glx-Dock.org](http://www.glx-dock.org/ww_page.php?p=By%20distributions&lang=en) for an excellent installation guide.
+
+Tarballs of the sources are available at: https://launchpad.net/cairo-dock-core and https://launchpad.net/cairo-dock-plug-ins
+
+A stable **PPA** is available here : https://launchpad.net/~cairo-dock-team/+archive/ppa
+
+
+Need some help?
+---------------
+
+See our wiki! http://www.glx-dock.org/ww_page.php
+
+You can find: how to launch the dock at startup, how to customise it, how to resolve some recurrent problems (black background, messages at startup, etc.), how to help us, who we are, etc.
+A useful tutorial is also available to help you customize your dock: http://www.glx-dock.org/ww_page.php?p=Tutorial-Customisation&lang=en
+
+If you have other questions not solved on our wiki you can post them on our forum (in English or French): http://www.glx-dock.org/bg_forumlist.php
+
+
+Join the project
+----------------
+
+* Want to **HACK** into the dock or write an **APPLET**? see the complete C API here: http://doc.glx-dock.org
+* You don't like C and still want to write an **APPLET** for the dock or **CONTROL** it from a script or the terminal? see its powerful DBus API here: http://www.glx-dock.org/ww_page.php?p=Control_your_dock_with_DBus&lang=en
+* You have some **IDEAS / PROPOSITIONS**? You need some help to develop an applet? Feel free post a topic on our forum! We'll be happy to answer you!
+* You want to **TRANSLATE** Cairo-Dock in your language? Use the 'Translations' tab in Launchpad, it's very simple to use it and helpful for us!
+
+
+Bug reports
+-----------
+
+You can report bugs in **Launchpad** under the '[Bugs](https://bugs.launchpad.net/cairo-dock)' section. If possible:
+
+* Read our wiki specially the '[Recurring Problems](http://www.glx-dock.org/ww_page.php?p=Recurrents%20problems&lang=en)' section which can help you to resolve some bugs like a black background, messages at startup, etc.
+* Please include also some information like your distribution, your achitecture (32/64bits), your Desktop Manager (Gnome, KDE, XFCE,...) your Window Manager (Compiz, Metacity, Kwin, etc.), if you use Cairo-Dock with or without OpenGL, with which theme, etc.
+* Include the method to reproduce the bug (which actions, which options activated)
+* Run the dock with the command
+          cairo-dock -l debug > debug.txt
+reproduce the bug and join the content of debug.txt.
+* If it's a crash, please give us a backtrace of it with GDB. It's easy thanks to this [wiki page](http://wiki.glx-dock.org/?p=ddd).
+
+Thank you for your help!
diff -pruN 3.4.1-6/Recent-Events/src/applet-dialog.c 3.4.1+git20201022.a0d3415c-1/Recent-Events/src/applet-dialog.c
--- 3.4.1-6/Recent-Events/src/applet-dialog.c	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Recent-Events/src/applet-dialog.c	2020-10-21 15:04:44.000000000 +0000
@@ -19,7 +19,6 @@
 
 #include <stdlib.h>
 #include <string.h>
-#define __USE_POSIX
 #include <time.h>
 
 #include "applet-struct.h"
diff -pruN 3.4.1-6/Screenshot/src/applet-screenshot.c 3.4.1+git20201022.a0d3415c-1/Screenshot/src/applet-screenshot.c
--- 3.4.1-6/Screenshot/src/applet-screenshot.c	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Screenshot/src/applet-screenshot.c	2020-10-21 15:04:44.000000000 +0000
@@ -18,7 +18,6 @@
 */
 
 #include <stdlib.h>
-#define __USE_POSIX
 #include <time.h>
 
 #include <cairo-xlib.h>
diff -pruN 3.4.1-6/shared-files/scripts/lock-screen.sh 3.4.1+git20201022.a0d3415c-1/shared-files/scripts/lock-screen.sh
--- 3.4.1-6/shared-files/scripts/lock-screen.sh	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/shared-files/scripts/lock-screen.sh	2020-10-21 15:04:44.000000000 +0000
@@ -30,6 +30,8 @@ elif test -n "`echo $PS_OUTPUT | grep li
 	light-locker-command --lock
 elif hash xlock 2> /dev/null; then
 	xlock
+elif hash xdg-screensaver 2> /dev/null; then
+	xdg-screensaver lock
 else # check is another "*-screensaver" daemon is running
 	# we need to relaunch ps, easier to parse compare to PS_OUTPUT which contains only one big line
 	SCREENSAVER=`ps -u $USER -wwo pid,cmd | grep "\-[s]creensaver" | awk '{print $2}'`
diff -pruN 3.4.1-6/shortcuts/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/shortcuts/data/misc/icon.svg
--- 3.4.1-6/shortcuts/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/shortcuts/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,686 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   version="1.0"
+   width="48"
+   height="48"
+   id="svg3823"
+   inkscape:version="0.47 r22583"
+   sodipodi:docname="icon.svg">
+  <metadata
+     id="metadata69">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <dc:title />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <sodipodi:namedview
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1"
+     objecttolerance="10"
+     gridtolerance="10"
+     guidetolerance="10"
+     inkscape:pageopacity="0"
+     inkscape:pageshadow="2"
+     inkscape:window-width="1246"
+     inkscape:window-height="767"
+     id="namedview67"
+     showgrid="false"
+     inkscape:zoom="4.5998527"
+     inkscape:cx="47.035163"
+     inkscape:cy="31.385412"
+     inkscape:window-x="308"
+     inkscape:window-y="141"
+     inkscape:window-maximized="0"
+     inkscape:current-layer="layer2" />
+  <defs
+     id="defs3825">
+    <linearGradient
+       x1="62.988873"
+       y1="18"
+       x2="62.988873"
+       y2="21.007532"
+       id="linearGradient2831-6"
+       xlink:href="#linearGradient6404-4"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-50.940898,0)" />
+    <linearGradient
+       id="linearGradient6404-4">
+      <stop
+         id="stop6406-6"
+         style="stop-color:#f9f9f9;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6408-2"
+         style="stop-color:#c9c9c9;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="3"
+       cy="5.01718"
+       r="21"
+       fx="3"
+       fy="5.01718"
+       id="radialGradient2833-8"
+       xlink:href="#linearGradient3484-9"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.274898e-8,1.7142916,-2.159331,-1.4599595e-8,12.809361,2.8570011)" />
+    <linearGradient
+       id="linearGradient3484-9">
+      <stop
+         id="stop3486-6"
+         style="stop-color:#bdbdbd;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3488-0"
+         style="stop-color:#d0d0d0;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="302.85715"
+       y1="366.64789"
+       x2="302.85715"
+       y2="609.50507"
+       id="linearGradient7596-975-7"
+       xlink:href="#linearGradient5048-585-0"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.08284024,0,0,0.03705882,-5.9408285,25.412461)" />
+    <linearGradient
+       id="linearGradient5048-585-0">
+      <stop
+         id="stop2667-1"
+         style="stop-color:black;stop-opacity:0"
+         offset="0" />
+      <stop
+         id="stop2669-0"
+         style="stop-color:black;stop-opacity:1"
+         offset="0.5" />
+      <stop
+         id="stop2671-1"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient7598-526-3"
+       xlink:href="#linearGradient5060-179-7"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.03212956,0,0,0.03705882,24.636785,25.412461)" />
+    <linearGradient
+       id="linearGradient5060-179-7">
+      <stop
+         id="stop2675-7"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2677-2"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient7600-312-6"
+       xlink:href="#linearGradient5060-820-4"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.03212956,0,0,0.03705882,23.363215,25.412461)" />
+    <linearGradient
+       id="linearGradient5060-820-4">
+      <stop
+         id="stop2681-5"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2683-2"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="7.2646537"
+       cy="8.3021259"
+       r="20.979567"
+       fx="7.2646537"
+       fy="8.3021259"
+       id="radialGradient2603-4"
+       xlink:href="#linearGradient6087-437-184-795-110-6"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,0.9862682,-1.6271642,0,-25.127044,13.600721)" />
+    <linearGradient
+       id="linearGradient6087-437-184-795-110-6">
+      <stop
+         id="stop4655-7"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4657-6"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6129-963-697-142-998-0-5">
+      <stop
+         id="stop4661-3-3"
+         style="stop-color:black;stop-opacity:0.498"
+         offset="0" />
+      <stop
+         id="stop4663-7-9"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       y2="36.657963"
+       x2="22.809399"
+       y1="49.629246"
+       x1="22.934725"
+       gradientTransform="matrix(1.1446925,0,0,0.8146303,-3.1333107,5.61619)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient7519"
+       xlink:href="#linearGradient6129-963-697-142-998-0-5"
+       inkscape:collect="always" />
+    <linearGradient
+       id="linearGradient7012-661-145-733-759-865-745-661-970-94-2-5">
+      <stop
+         id="stop3618-9-2"
+         style="stop-color:#8babcb;stop-opacity:1;"
+         offset="0" />
+      <stop
+         id="stop3620-0-4"
+         style="stop-color:#426296;stop-opacity:1;"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3390-178-986-453-9-3">
+      <stop
+         id="stop3624-4-8"
+         style="stop-color:#3a5073;stop-opacity:1;"
+         offset="0" />
+      <stop
+         id="stop3626-5-6"
+         style="stop-color:#426296;stop-opacity:1;"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="13.079692"
+       y1="20.730078"
+       x2="16.36186"
+       y2="32.979298"
+       id="linearGradient2601-8-0"
+       xlink:href="#linearGradient8265-821-176-38-919-8-8"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.1446925,0,0,0.8040948,-3.5175612,5.0983703)" />
+    <linearGradient
+       id="linearGradient8265-821-176-38-919-8-8">
+      <stop
+         id="stop4667-6-9"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4669-0-2"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       r="24.097353"
+       fy="19.54422"
+       fx="13.857143"
+       cy="19.54422"
+       cx="13.857143"
+       gradientTransform="matrix(1.4880117,0,0,0.7912602,-6.6847124,7.1177263)"
+       gradientUnits="userSpaceOnUse"
+       id="radialGradient7567"
+       xlink:href="#linearGradient7012-661-145-733-759-865-745-661-970-94-2-5"
+       inkscape:collect="always" />
+    <linearGradient
+       y2="20.980713"
+       x2="25.474075"
+       y1="45.114197"
+       x1="34.954498"
+       gradientTransform="translate(0.07773563,-3.7034247)"
+       gradientUnits="userSpaceOnUse"
+       id="linearGradient7569"
+       xlink:href="#linearGradient3390-178-986-453-9-3"
+       inkscape:collect="always" />
+    <radialGradient
+       gradientTransform="matrix(1,0,0,0.341176,0,3.047059)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient8838-487-8"
+       id="radialGradient2499-518-3"
+       fy="4.625"
+       fx="62.625"
+       r="10.625"
+       cy="4.625"
+       cx="62.625" />
+    <linearGradient
+       id="linearGradient8838-487-8">
+      <stop
+         offset="0"
+         style="stop-color:black;stop-opacity:1"
+         id="stop2432-3" />
+      <stop
+         offset="1"
+         style="stop-color:black;stop-opacity:0"
+         id="stop2434-2" />
+    </linearGradient>
+    <linearGradient
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient2250-714-5"
+       id="linearGradient2465-608-9"
+       y2="33.409534"
+       x2="21.483376"
+       y1="21.671062"
+       x1="21.483376" />
+    <linearGradient
+       id="linearGradient2250-714-5">
+      <stop
+         offset="0"
+         style="stop-color:#c7c7c7;stop-opacity:1"
+         id="stop2438-4" />
+      <stop
+         offset="1"
+         style="stop-color:#a5a5a5;stop-opacity:1"
+         id="stop2440-3" />
+    </linearGradient>
+    <linearGradient
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3215-22-4"
+       id="linearGradient2467-856-9"
+       y2="9.5799999"
+       x2="21.483376"
+       y1="36.345936"
+       x1="21.483376" />
+    <linearGradient
+       id="linearGradient3215-22-4">
+      <stop
+         offset="0"
+         style="stop-color:#6d6d6d;stop-opacity:1"
+         id="stop2444-9" />
+      <stop
+         offset="1"
+         style="stop-color:#999;stop-opacity:1"
+         id="stop2446-5" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="matrix(1.5575239,0,0,1.5420736,-9.4936458,-12.492178)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient5178-177-7"
+       id="linearGradient5541-370-5"
+       y2="26.294357"
+       x2="21.483376"
+       y1="9.463129"
+       x1="21.483376" />
+    <linearGradient
+       id="linearGradient5178-177-7">
+      <stop
+         offset="0"
+         style="stop-color:white;stop-opacity:1"
+         id="stop2450-3" />
+      <stop
+         offset="0.8918919"
+         style="stop-color:#e1e1e1;stop-opacity:1"
+         id="stop2452-9" />
+      <stop
+         offset="1"
+         style="stop-color:#c3c3c3;stop-opacity:0"
+         id="stop2454-0" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="matrix(1.3469077,0,0,1.3469077,-8.3257881,-6.6326722)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3230-405-2"
+       id="linearGradient2476-945-7"
+       y2="22.839001"
+       x2="23.673159"
+       y1="9.5958176"
+       x1="24.097157" />
+    <linearGradient
+       id="linearGradient3230-405-2">
+      <stop
+         offset="0"
+         style="stop-color:#ececec;stop-opacity:1"
+         id="stop2458-7" />
+      <stop
+         offset="1"
+         style="stop-color:#c9c9c9;stop-opacity:1"
+         id="stop2460-2" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient6404-4"
+       id="linearGradient2940"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-50.940898,0)"
+       x1="62.988873"
+       y1="18"
+       x2="62.988873"
+       y2="21.007532" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3484-9"
+       id="radialGradient2942"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.274898e-8,1.7142916,-2.159331,-1.4599595e-8,12.809361,2.8570011)"
+       cx="3"
+       cy="5.01718"
+       fx="3"
+       fy="5.01718"
+       r="21" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient5048-585-0"
+       id="linearGradient2944"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.08284024,0,0,0.03705882,-5.9408285,25.412461)"
+       x1="302.85715"
+       y1="366.64789"
+       x2="302.85715"
+       y2="609.50507" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient5060-179-7"
+       id="radialGradient2946"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.03212956,0,0,0.03705882,24.636785,25.412461)"
+       cx="605.71429"
+       cy="486.64789"
+       fx="605.71429"
+       fy="486.64789"
+       r="117.14286" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient5060-820-4"
+       id="radialGradient2948"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.03212956,0,0,0.03705882,23.363215,25.412461)"
+       cx="605.71429"
+       cy="486.64789"
+       fx="605.71429"
+       fy="486.64789"
+       r="117.14286" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient6087-437-184-795-110-6"
+       id="radialGradient2950"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,0.9862682,-1.6271642,0,-25.127044,13.600721)"
+       cx="7.2646537"
+       cy="8.3021259"
+       fx="7.2646537"
+       fy="8.3021259"
+       r="20.979567" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient6404-4"
+       id="linearGradient2960"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-50.737508,-3.0932209)"
+       x1="62.988873"
+       y1="18"
+       x2="62.988873"
+       y2="21.007532" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3484-9"
+       id="radialGradient2962"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.274898e-8,1.7142916,-2.159331,-1.4599595e-8,13.012751,-0.2362198)"
+       cx="3"
+       cy="5.01718"
+       fx="3"
+       fy="5.01718"
+       r="21" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient6404-4"
+       id="linearGradient2968"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-50.737508,-3.0932209)"
+       x1="62.988873"
+       y1="18"
+       x2="62.988873"
+       y2="21.007532" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3484-9"
+       id="radialGradient2970"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.274898e-8,1.7142916,-2.159331,-1.4599595e-8,13.012751,-0.2362198)"
+       cx="3"
+       cy="5.01718"
+       fx="3"
+       fy="5.01718"
+       r="21" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient6404-4"
+       id="linearGradient2978"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-50.737508,-3.0932209)"
+       x1="62.988873"
+       y1="18"
+       x2="62.988873"
+       y2="21.007532" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3484-9"
+       id="radialGradient2980"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.274898e-8,1.7142916,-2.159331,-1.4599595e-8,13.012751,-0.2362198)"
+       cx="3"
+       cy="5.01718"
+       fx="3"
+       fy="5.01718"
+       r="21" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient6404-4"
+       id="linearGradient2988"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-50.737508,-3.0932209)"
+       x1="62.988873"
+       y1="18"
+       x2="62.988873"
+       y2="21.007532" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3484-9"
+       id="radialGradient2990"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.274898e-8,1.7142916,-2.159331,-1.4599595e-8,13.012751,-0.2362198)"
+       cx="3"
+       cy="5.01718"
+       fx="3"
+       fy="5.01718"
+       r="21" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient6404-4"
+       id="linearGradient2994"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.90914387,0,0,0.93586213,-44.00553,-2.6568538)"
+       x1="62.988873"
+       y1="18"
+       x2="62.988873"
+       y2="21.007532" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3484-9"
+       id="radialGradient2996"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.1590657e-8,1.6043406,-1.9631425,-1.3663208e-8,13.952627,0.01690536)"
+       cx="3"
+       cy="5.01718"
+       fx="3"
+       fy="5.01718"
+       r="21" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient6404-4"
+       id="linearGradient3000"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.80434225,0,0,0.94502496,-36.074741,-6.9623534)"
+       x1="62.988873"
+       y1="18"
+       x2="62.988873"
+       y2="21.007532" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3484-9"
+       id="radialGradient3002"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.0254543e-8,1.6200484,-1.7368412,-1.3796982e-8,15.202286,-4.262416)"
+       cx="3"
+       cy="5.01718"
+       fx="3"
+       fy="5.01718"
+       r="21" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient6404-4"
+       id="linearGradient3006"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-50.737508,0.9067791)"
+       x1="62.988873"
+       y1="18"
+       x2="62.988873"
+       y2="21.007532" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3484-9"
+       id="radialGradient3008"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.274898e-8,1.7142916,-2.159331,-1.4599595e-8,13.012751,3.7637802)"
+       cx="3"
+       cy="5.01718"
+       fx="3"
+       fy="5.01718"
+       r="21" />
+  </defs>
+  <g
+     inkscape:groupmode="layer"
+     id="layer2"
+     inkscape:label="sfondo"
+     style="display:inline">
+    <path
+       style="fill:url(#linearGradient3000);fill-opacity:1;stroke:url(#radialGradient3002);stroke-width:0.87185073;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;display:inline"
+       id="path2984"
+       d="m 7.7194005,1.0703583 c -0.5552141,0.00725 -0.8046976,0.3233366 -0.8046976,0.945025 0,5.211297 0.021136,9.2041427 -0.00467,13.9395247 1.1546113,0 34.1845471,0.323295 34.1845471,-1.181687 l 0.402169,-9.9164808 c 0,-0.6216875 -0.445769,-0.9522742 -1.000987,-0.9450249 l -16.292369,0 c -1.646878,0 -2.814306,-2.841357 -4.021712,-2.841357 l -12.4622773,0 z" />
+    <rect
+       style="fill:#8babcb;fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:block;overflow:visible;enable-background:accumulate"
+       id="rect2986"
+       y="2.4878964"
+       x="9.3051968"
+       ry="0.49704102"
+       rx="0.64079297"
+       height="0.99408203"
+       width="8.3303089" />
+    <path
+       d="M 5.4947607,5.2979739 C 4.867205,5.3051519 4.5852151,5.6181754 4.5852151,6.233836 c 0,5.160769 0.023891,9.114901 -0.00528,13.804369 1.3050512,0 38.6386159,0.320161 38.6386159,-1.17023 l 0.45457,-9.8203315 c 0,-0.6156597 -0.503851,-0.9430411 -1.13141,-0.9358621 l -18.415181,0 c -1.861457,0 -3.180995,-2.8138075 -4.545719,-2.8138075 l -14.0860482,0 z"
+       id="path2974"
+       style="fill:url(#linearGradient2994);fill-opacity:1;stroke:url(#radialGradient2996);stroke-width:0.92240638;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;display:inline" />
+    <rect
+       width="9.8775148"
+       height="1.2568291"
+       rx="0.75980878"
+       ry="0.62841457"
+       x="7.7367063"
+       y="6.5864749"
+       id="rect2976"
+       style="fill:#8babcb;fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:block;overflow:visible;enable-background:accumulate" />
+    <g
+       style="opacity:0.4"
+       id="g7591"
+       transform="matrix(0.9583333,0,0,0.6666667,1.2033909,11.906779)">
+      <rect
+         style="fill:url(#linearGradient2944);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible"
+         id="rect4173"
+         y="39"
+         x="4"
+         height="9"
+         width="40" />
+      <path
+         style="fill:url(#radialGradient2946);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible"
+         id="path5058"
+         d="m 44,39.00031 c 0,0 0,8.999504 0,8.999504 1.654593,0.01694 4.000001,-2.016333 4,-4.500331 0,-2.483999 -1.846402,-4.499173 -4,-4.499173 z" />
+      <path
+         style="fill:url(#radialGradient2948);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible"
+         id="path5018"
+         d="m 4,39.00031 c 0,0 0,8.999504 0,8.999504 C 2.3454068,48.016755 0,45.983481 0,43.499483 0,41.015484 1.8464008,39.00031 4,39.00031 z" />
+    </g>
+    <path
+       style="fill:url(#linearGradient3006);fill-opacity:1;stroke:url(#radialGradient3008);stroke-width:1.00000012;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;display:inline"
+       id="path3468"
+       d="m 3.7096399,9.4067786 c -0.690271,0.00767 -1.0004418,0.3421461 -1.0004418,1.0000004 0,5.514454 0.026278,9.739576 -0.00581,14.75043 1.4354727,0 42.5000019,0.342102 42.5000019,-1.25043 l 0.499998,-10.493353 c 0,-0.657853 -0.554204,-1.007671 -1.244479,-1 l -20.255519,0 c -2.047483,0 -3.498891,-3.0066474 -5,-3.0066474 l -15.4937501,0 z" />
+    <rect
+       style="fill:#8babcb;fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:block;overflow:visible;enable-background:accumulate"
+       id="rect3562"
+       y="10.906779"
+       x="5.2033901"
+       ry="0.90392262"
+       rx="1"
+       height="1.8078452"
+       width="13" />
+    <g
+       id="g2629"
+       transform="translate(51.705535,-1.8705681)">
+      <path
+         style="opacity:0.4;fill:none;stroke:url(#radialGradient2950);stroke-width:0.99999982;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none"
+         id="path2544"
+         d="m -4.998792,21.163151 c -13.53125,0 -31.46875,0 -45,0 0.220184,0.893165 1.92721,19.690463 2.23001,21.161942" />
+    </g>
+  </g>
+  <g
+     inkscape:groupmode="layer"
+     id="layer6"
+     inkscape:label="Livello#3" />
+  <g
+     inkscape:groupmode="layer"
+     id="layer5"
+     inkscape:label="Livello#2"
+     style="display:inline">
+    <path
+       d="m 1.1430884,17.79658 c -1.07270677,0.100992 -0.49947287,1.279221 -0.58499987,1.866173 0.300461,1.216969 1.97642187,19.433868 2.17924987,20.746557 0.341836,0.788453 1.594434,0.384685 2.388117,0.484775 13.1935446,0 26.3870896,0 39.5806336,0 1.089379,-0.08708 0.636457,-1.149321 0.789703,-1.757245 0.06207,-0.884547 1.706566,-14.739761 2.179297,-20.746557 -0.251172,-0.779143 -1.487747,-0.593703 -2.263,-0.593703 -14.089378,0 -30.179622,0 -44.2690006,0 z"
+       id="path7314"
+       style="fill:url(#radialGradient7567);fill-opacity:1;stroke:url(#linearGradient7569);stroke-width:1.00000024;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dashoffset:0;display:inline" />
+    <path
+       d="m 1.0065796,16.85488 45.8969994,0 c 0.63416,0 1.045,0.663907 1.045,1.109377 l -0.46,6.002915 L 0.6455797,29.79571 -0.0384202,17.963886 c 0,-0.445468 0.4108399,-1.109006 1.0449998,-1.109006 z"
+       id="path8263"
+       style="opacity:0.2;fill:url(#linearGradient2601-8-0);fill-opacity:1;stroke:none;display:inline" />
+  </g>
+  <g
+     inkscape:groupmode="layer"
+     id="layer4"
+     inkscape:label="Livello#1"
+     style="display:inline">
+    <path
+       d="m 1.3908307,17.835642 45.8969933,3.3e-4 c 0.63416,0 1.045,0.363009 1.045,0.814314 l -2.244363,21.995005 c 0,0.451305 -0.510532,0.81463 -1.14469,0.81463 l -41.2089287,0 c -0.63416,0 -1.144693,-0.363325 -1.144693,-0.81463 L 0.3458308,18.650273 c 0,-0.451306 0.41084,-0.814631 1.0449999,-0.814631 z"
+       id="path2541"
+       style="opacity:0.4;fill:url(#linearGradient7519);fill-opacity:1;stroke:none"
+       sodipodi:nodetypes="ccccccccc" />
+  </g>
+  <g
+     inkscape:groupmode="layer"
+     id="layer3"
+     inkscape:label="Livello" />
+</svg>
diff -pruN 3.4.1-6/showDesktop/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/showDesktop/data/misc/icon.svg
--- 3.4.1-6/showDesktop/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/showDesktop/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,329 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   version="1.0"
+   width="48"
+   height="48"
+   id="svg2453"
+   inkscape:version="0.47 r22583"
+   sodipodi:docname="icon-desktop.svg">
+  <metadata
+     id="metadata58">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <sodipodi:namedview
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1"
+     objecttolerance="10"
+     gridtolerance="10"
+     guidetolerance="10"
+     inkscape:pageopacity="0"
+     inkscape:pageshadow="2"
+     inkscape:window-width="1277"
+     inkscape:window-height="780"
+     id="namedview56"
+     showgrid="false"
+     inkscape:zoom="9.8333333"
+     inkscape:cx="34.662396"
+     inkscape:cy="17.525394"
+     inkscape:window-x="0"
+     inkscape:window-y="24"
+     inkscape:window-maximized="0"
+     inkscape:current-layer="svg2453" />
+  <defs
+     id="defs2455">
+    <linearGradient
+       id="linearGradient6568">
+      <stop
+         id="stop6570"
+         style="stop-color:#1a232d;stop-opacity:1;"
+         offset="0" />
+      <stop
+         id="stop6572"
+         style="stop-color:#455462;stop-opacity:1;"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6560">
+      <stop
+         id="stop6562"
+         style="stop-color:#48637e;stop-opacity:1;"
+         offset="0" />
+      <stop
+         id="stop6564"
+         style="stop-color:#313f4d;stop-opacity:1;"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6592">
+      <stop
+         id="stop6594"
+         style="stop-color:white;stop-opacity:0.27450982"
+         offset="0" />
+      <stop
+         id="stop6596"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6602">
+      <stop
+         id="stop6604"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6606"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5060">
+      <stop
+         id="stop5062"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop5064"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5048">
+      <stop
+         id="stop5050"
+         style="stop-color:black;stop-opacity:0"
+         offset="0" />
+      <stop
+         id="stop5056"
+         style="stop-color:black;stop-opacity:1"
+         offset="0.5" />
+      <stop
+         id="stop5052"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient259-942">
+      <stop
+         id="stop3802"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3804"
+         style="stop-color:#e0e0e0;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="302.85715"
+       y1="366.64789"
+       x2="302.85715"
+       y2="609.50507"
+       id="linearGradient5516"
+       xlink:href="#linearGradient5048"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.08449704,0,0,0.01235294,-6.5396456,38.470822)" />
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient5518"
+       xlink:href="#linearGradient5060"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.0289166,0,0,0.01235294,21.026894,38.470848)" />
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient5520"
+       xlink:href="#linearGradient5060"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.02891661,0,0,0.01235294,26.973101,38.470848)" />
+    <linearGradient
+       id="linearGradient8589">
+      <stop
+         id="stop8591"
+         style="stop-color:#fefefe;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop8593"
+         style="stop-color:#cbcbcb;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3600">
+      <stop
+         id="stop3602"
+         style="stop-color:#f4f4f4;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3604"
+         style="stop-color:#dbdbdb;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="12.9375"
+       y1="8.4375"
+       x2="15.25"
+       y2="19.8125"
+       id="linearGradient5529"
+       xlink:href="#linearGradient6592"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.952381,0,0,1.1999998,1.1428569,7.4000011)" />
+    <linearGradient
+       x1="32.892288"
+       y1="8.0590115"
+       x2="36.358372"
+       y2="5.4565363"
+       id="linearGradient5532"
+       xlink:href="#linearGradient8589"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.2651735,0,0,0.2436435,6.6646887,27.973458)" />
+    <linearGradient
+       x1="25.132275"
+       y1="6.7287393"
+       x2="25.132275"
+       y2="47.013336"
+       id="linearGradient5535"
+       xlink:href="#linearGradient3600"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.2657853,0,0,0.2289442,6.6211523,28.005341)" />
+    <linearGradient
+       x1="32.892288"
+       y1="8.0590115"
+       x2="36.358372"
+       y2="5.4565363"
+       id="linearGradient5538"
+       xlink:href="#linearGradient8589"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.2651735,0,0,0.2436435,6.6646887,13.973458)" />
+    <linearGradient
+       x1="25.132275"
+       y1="6.7287393"
+       x2="25.132275"
+       y2="47.013336"
+       id="linearGradient5541"
+       xlink:href="#linearGradient3600"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.2657853,0,0,0.2289442,6.6211523,14.00534)" />
+    <radialGradient
+       cx="5.9687753"
+       cy="-0.64647216"
+       r="19.999998"
+       fx="5.9687753"
+       fy="-0.64647216"
+       id="radialGradient5544"
+       xlink:href="#linearGradient6602"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.5021509,-0.00983156,0.00260397,0.6551098,-2.0708508,14.823029)" />
+    <radialGradient
+       cx="12.244348"
+       cy="4.8630676"
+       r="20.999998"
+       fx="12.244348"
+       fy="4.8630676"
+       id="radialGradient5547"
+       xlink:href="#linearGradient6560"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.315565,0.02141904,-0.01224891,1.1973217,-3.2308678,12.141925)" />
+    <linearGradient
+       x1="24.875"
+       y1="29"
+       x2="24.999996"
+       y2="3.0000005"
+       id="linearGradient5549"
+       xlink:href="#linearGradient6568"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9512191,0,0,1.1999998,1.1707379,7.2999983)" />
+    <linearGradient
+       x1="108.26451"
+       y1="110.28094"
+       x2="25.817675"
+       y2="14.029031"
+       id="linearGradient5552"
+       xlink:href="#linearGradient259-942"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.5066363,0,0,0.3512482,-58.338079,-49.08598)" />
+  </defs>
+  <g
+     id="g3257"
+     style="opacity:0.4">
+    <rect
+       width="40.799999"
+       height="2.9999998"
+       x="3.5999999"
+       y="43"
+       id="rect2879"
+       style="fill:url(#linearGradient5516);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+    <path
+       d="m 3.6,43.00013 c 0,0 0,2.999835 0,2.999835 C 2.1108662,46.005612 0,45.327854 0,44.499854 0,43.671856 1.6617608,43.000131 3.6,43.00013 z"
+       id="path2881"
+       style="fill:url(#radialGradient5518);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+    <path
+       d="m 44.4,43.00013 c 0,0 0,2.999835 0,2.999835 1.489133,0.0056 3.6,-0.672111 3.6,-1.500111 0,-0.827998 -1.661761,-1.499723 -3.6,-1.499724 z"
+       id="path2883"
+       style="fill:url(#radialGradient5520);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+  </g>
+  <rect
+     width="44.965565"
+     height="35.922085"
+     x="-46.457321"
+     y="-44.502605"
+     transform="matrix(-0.9999985,0.00173317,-9.6052611e-4,-0.9999995,0,0)"
+     id="rect3580"
+     style="fill:url(#linearGradient5552);fill-opacity:1;stroke:#c1c1c1;stroke-width:0.99999994;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:0.96862745;stroke-dasharray:none" />
+  <rect
+     width="38.999973"
+     height="29.999975"
+     x="4.5000124"
+     y="11.500012"
+     id="rect2716"
+     style="fill:url(#radialGradient5547);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient5549);stroke-width:1.00002503;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;display:inline;enable-background:new" />
+  <rect
+     width="36.999931"
+     height="27.999933"
+     x="5.5000334"
+     y="12.500033"
+     id="rect6600"
+     style="opacity:0.3;fill:none;stroke:url(#radialGradient5544);stroke-width:1.000067;stroke-linecap:square;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+  <path
+     d="m 8.3487466,14.348746 c 2.1316754,0 3.5319754,0 5.6636514,0 0.373944,0.111126 3.114265,1.794557 3.638855,2.671143 0,2.682927 0,4.948434 0,7.631364 -3.100834,0 -6.201672,0 -9.3025064,0 0,-3.434169 0,-6.868338 0,-10.302507 z"
+     id="rect2594"
+     style="fill:url(#linearGradient5541);fill-opacity:1;stroke:#6e6e6e;stroke-width:0.69749314;stroke-linecap:butt;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;display:inline" />
+  <path
+     d="m 14.072974,14.348947 c 0,1.059696 0,2.747894 0,2.747894 0,0 2.918922,0 3.578069,0 0,-1.305816 -2.150053,-2.747894 -3.578069,-2.747894 z"
+     id="path12038"
+     style="fill:url(#linearGradient5538);fill-opacity:1;fill-rule:evenodd;stroke:#6e6e6e;stroke-width:0.69749314;stroke-linecap:butt;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;display:inline" />
+  <path
+     d="m 8.3487466,28.348746 c 2.1316754,0 3.5319754,0 5.6636514,0 0.373944,0.111126 3.114265,1.794557 3.638855,2.671143 0,2.682927 0,4.948434 0,7.631364 -3.100834,0 -6.201672,0 -9.3025064,0 0,-3.434169 0,-6.868338 0,-10.302507 z"
+     id="path7643"
+     style="fill:url(#linearGradient5535);fill-opacity:1;stroke:#787878;stroke-width:0.69749314;stroke-linecap:butt;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;display:inline" />
+  <path
+     d="m 14.072974,28.348947 c 0,1.059696 0,2.747894 0,2.747894 0,0 2.918922,0 3.578069,0 0,-1.305816 -2.150053,-2.747894 -3.578069,-2.747894 z"
+     id="path7645"
+     style="fill:url(#linearGradient5532);fill-opacity:1;fill-rule:evenodd;stroke:#787878;stroke-width:0.69749314;stroke-linecap:butt;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;display:inline" />
+  <path
+     d="m 4,11 40,0 0,9.600001 L 4,29 4,11 z"
+     id="rect6588"
+     style="fill:url(#linearGradient5529);fill-opacity:1;stroke:none" />
+</svg>
diff -pruN 3.4.1-6/show-mouse/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/show-mouse/data/misc/icon.svg
--- 3.4.1-6/show-mouse/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/show-mouse/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,165 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   version="1.1"
+   width="48"
+   height="48"
+   id="svg15137"
+   inkscape:version="0.47 r22583"
+   sodipodi:docname="icon.svg">
+  <metadata
+     id="metadata39">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <dc:title></dc:title>
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <sodipodi:namedview
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1"
+     objecttolerance="10"
+     gridtolerance="10"
+     guidetolerance="10"
+     inkscape:pageopacity="0"
+     inkscape:pageshadow="2"
+     inkscape:window-width="1176"
+     inkscape:window-height="837"
+     id="namedview37"
+     showgrid="false"
+     inkscape:zoom="4.8981876"
+     inkscape:cx="8.3699641"
+     inkscape:cy="20.987578"
+     inkscape:window-x="0"
+     inkscape:window-y="24"
+     inkscape:window-maximized="0"
+     inkscape:current-layer="svg15137" />
+  <defs
+     id="defs15139">
+    <linearGradient
+       id="linearGradient3635">
+      <stop
+         style="stop-color:#426296;stop-opacity:1;"
+         offset="0"
+         id="stop3637" />
+      <stop
+         style="stop-color:#8babcb;stop-opacity:1;"
+         offset="1"
+         id="stop3639" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4845">
+      <stop
+         id="stop4847"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4849"
+         style="stop-color:#b6b6b6;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4845"
+       id="radialGradient2857"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-2.643979,0,2.93653e-8,2.534421,78.72514,-37.986139)"
+       cx="17.81411"
+       cy="24.149399"
+       fx="17.81411"
+       fy="24.149399"
+       r="9.125" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3635"
+       id="radialGradient3643"
+       cx="23.898306"
+       cy="18.813559"
+       fx="23.898306"
+       fy="18.813559"
+       r="9.6183472"
+       gradientTransform="matrix(1,0,0,0.85197784,0,2.7848235)"
+       gradientUnits="userSpaceOnUse" />
+    <filter
+       inkscape:collect="always"
+       id="filter3673"
+       x="-0.17357825"
+       width="1.3471565"
+       y="-0.20597952"
+       height="1.411959">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="1.3091918"
+         id="feGaussianBlur3675" />
+    </filter>
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3635"
+       id="radialGradient3695"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1,0,0,0.85197784,0,2.7848235)"
+       cx="23.898306"
+       cy="18.813559"
+       fx="23.898306"
+       fy="18.813559"
+       r="9.6183472" />
+    <filter
+       inkscape:collect="always"
+       id="filter3713"
+       x="-0.48316141"
+       width="1.9663228"
+       y="-0.57335152"
+       height="2.146703">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="3.6441834"
+         id="feGaussianBlur3715" />
+    </filter>
+  </defs>
+  <path
+     transform="matrix(1.274406,0,0,1.2647049,-6.0512824,-6.1996135)"
+     d="m 32.949153,18.813559 a 9.0508471,7.6271186 0 1 1 -18.101694,0 9.0508471,7.6271186 0 1 1 18.101694,0 z"
+     sodipodi:ry="7.6271186"
+     sodipodi:rx="9.0508471"
+     sodipodi:cy="18.813559"
+     sodipodi:cx="23.898306"
+     id="path3677"
+     style="fill:url(#radialGradient3695);fill-opacity:1;stroke:none;filter:url(#filter3713)"
+     sodipodi:type="arc" />
+  <path
+     sodipodi:type="arc"
+     style="fill:url(#radialGradient3643);fill-opacity:1;stroke:none;filter:url(#filter3673)"
+     id="path2861"
+     sodipodi:cx="23.898306"
+     sodipodi:cy="18.813559"
+     sodipodi:rx="9.0508471"
+     sodipodi:ry="7.6271186"
+     d="m 32.949153,18.813559 a 9.0508471,7.6271186 0 1 1 -18.101694,0 9.0508471,7.6271186 0 1 1 18.101694,0 z"
+     transform="translate(1.0169492,-1.4237288)" />
+  <g
+     id="g2414"
+     transform="matrix(0.9999061,-0.01370139,0.01370139,0.9999061,-5.1700557,-2.108214)">
+    <path
+       style="fill:url(#radialGradient2857);fill-opacity:1;fill-rule:evenodd;stroke:#666666;stroke-width:1;stroke-linecap:butt;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible"
+       id="path3970"
+       d="m 30.5,20.93716 17,16.500001 -7.75,0.25 c 0,0 3.25,6.75 3.25,6.75 1,3 -3.5,4.125 -4.25,1.875 0,0 -3,-6.75 -3,-6.75 l -5.5,5.875 0.25,-24.500001 z" />
+    <path
+       style="opacity:0.4;fill:none;stroke:#ffffff;stroke-width:1;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible"
+       id="path4853"
+       d="m 31.657235,23.378571 13.475546,13.185793 -6.921861,0.277459 c 0,0 3.872136,7.756567 3.872136,7.756567 0.402731,1.650134 -2.028275,2.412565 -2.5071,1.152867 0,0 -3.683065,-7.844955 -3.683065,-7.844955 l -4.424727,4.708334 0.189071,-19.236065 z" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/show-mouse/data/misc/mouse_pointer_wolfram_es_03.svg 3.4.1+git20201022.a0d3415c-1/show-mouse/data/misc/mouse_pointer_wolfram_es_03.svg
--- 3.4.1-6/show-mouse/data/misc/mouse_pointer_wolfram_es_03.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/show-mouse/data/misc/mouse_pointer_wolfram_es_03.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,55 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) --><svg height="297mm" id="svg2" inkscape:version="0.40+cvs" sodipodi:docbase="D:\" sodipodi:docname="mousepointer3.svg" sodipodi:version="0.32" width="210mm" xmlns="http://www.w3.org/2000/svg" xmlns:cc="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:sodipodi="http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd" xmlns:svg="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
+  <metadata>
+    <rdf:RDF xmlns:cc="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
+      <cc:Work rdf:about="">
+        <dc:title></dc:title>
+        <dc:description></dc:description>
+        <dc:subject>
+          <rdf:Bag>
+            <rdf:li></rdf:li>
+            <rdf:li>11</rdf:li>
+            <rdf:li>computer</rdf:li>
+          </rdf:Bag>
+        </dc:subject>
+        <dc:publisher>
+          <cc:Agent rdf:about="http://www.openclipart.org">
+            <dc:title></dc:title>
+          </cc:Agent>
+        </dc:publisher>
+        <dc:creator>
+          <cc:Agent>
+            <dc:title></dc:title>
+          </cc:Agent>
+        </dc:creator>
+        <dc:rights>
+          <cc:Agent>
+            <dc:title></dc:title>
+          </cc:Agent>
+        </dc:rights>
+        <dc:date></dc:date>
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
+        <cc:license rdf:resource=""/>
+        <dc:language>en</dc:language>
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <defs id="defs3">
+    <linearGradient id="linearGradient7601" inkscape:collect="always">
+      <stop id="stop7603" offset="0" style="stop-color:#000000;stop-opacity:1;"/>
+      <stop id="stop7605" offset="1" style="stop-color:#000000;stop-opacity:0;"/>
+    </linearGradient>
+    <linearGradient gradientTransform="matrix(0.755921,0.000000,0.000000,1.322890,-36.00000,0.000000)" gradientUnits="userSpaceOnUse" id="linearGradient7607" inkscape:collect="always" spreadMethod="reflect" x1="-526.86133" x2="1370.5586" xlink:href="#linearGradient7601" y1="45.132561" y2="471.38400"/>
+    <linearGradient gradientTransform="matrix(0.323979,0.000000,0.000000,0.566975,399.6324,14.15086)" gradientUnits="userSpaceOnUse" id="linearGradient10869" inkscape:collect="always" spreadMethod="reflect" x1="-526.86133" x2="1370.5586" xlink:href="#linearGradient7601" y1="45.132561" y2="471.38400"/>
+    <linearGradient gradientTransform="matrix(8.892150e-2,0.000000,0.000000,0.155616,635.7169,9.380527)" gradientUnits="userSpaceOnUse" id="linearGradient10877" inkscape:collect="always" spreadMethod="reflect" x1="-526.86133" x2="1370.5586" xlink:href="#linearGradient7601" y1="45.132561" y2="471.38400"/>
+    <linearGradient gradientTransform="matrix(0.755921,0.000000,0.000000,1.322890,-36.00000,0.000000)" gradientUnits="userSpaceOnUse" id="linearGradient1323" inkscape:collect="always" spreadMethod="reflect" x1="-526.86133" x2="1370.5586" xlink:href="#linearGradient7601" y1="45.132561" y2="471.38400"/>
+  </defs>
+  <sodipodi:namedview bordercolor="#666666" borderopacity="1.0" gridoriginx="0.00000000mm" gridoriginy="0.00000000mm" gridspacingx="10.000000mm" gridspacingy="10.000000mm" gridtolerance="5.0000000mm" id="base" inkscape:current-layer="layer1" inkscape:cx="372.04724" inkscape:cy="550.69603" inkscape:document-units="px" inkscape:grid-bbox="true" inkscape:grid-points="true" inkscape:guide-bbox="true" inkscape:guide-points="true" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:window-height="841" inkscape:window-width="992" inkscape:window-x="22" inkscape:window-y="29" inkscape:zoom="0.62906099" pagecolor="#ffffff" showgrid="true" showguides="true"/>
+  <g id="layer1" inkscape:groupmode="layer" inkscape:label="Layer 1" style="display:inline">
+    <g id="g1325">
+      <path d="M 35.437500,24.812500 L 35.437500,627.15625 L 70.875000,627.15625 L 70.875000,591.71875 L 106.31250,591.71875 L 106.31250,556.31250 L 70.875000,556.31250 L 70.875000,95.656250 L 106.31250,95.656250 L 106.31250,60.250000 L 70.875000,60.250000 L 70.875000,24.812500 L 35.437500,24.812500 z M 106.31250,95.656250 L 106.31250,131.09375 L 141.71875,131.09375 L 141.71875,95.656250 L 106.31250,95.656250 z M 141.71875,131.09375 L 141.71875,166.53125 L 177.15625,166.53125 L 177.15625,131.09375 L 141.71875,131.09375 z M 177.15625,166.53125 L 177.15625,201.96875 L 212.59375,201.96875 L 212.59375,166.53125 L 177.15625,166.53125 z M 212.59375,201.96875 L 212.59375,237.40625 L 248.03125,237.40625 L 248.03125,201.96875 L 212.59375,201.96875 z M 248.03125,237.40625 L 248.03125,272.84375 L 283.46875,272.84375 L 283.46875,237.40625 L 248.03125,237.40625 z M 283.46875,272.84375 L 283.46875,308.28125 L 318.90625,308.28125 L 318.90625,272.84375 L 283.46875,272.84375 z M 318.90625,308.28125 L 318.90625,343.68750 L 354.34375,343.68750 L 354.34375,308.28125 L 318.90625,308.28125 z M 354.34375,343.68750 L 354.34375,379.12500 L 389.75000,379.12500 L 389.75000,343.68750 L 354.34375,343.68750 z M 389.75000,379.12500 L 389.75000,414.56250 L 283.46875,414.56250 L 283.46875,450.00000 L 283.46875,520.87500 L 318.90625,520.87500 L 318.90625,450.00000 L 460.62500,450.00000 L 460.62500,414.56250 L 425.18750,414.56250 L 425.18750,379.12500 L 389.75000,379.12500 z M 318.90625,520.87500 L 318.90625,591.71875 L 354.34375,591.71875 L 354.34375,520.87500 L 318.90625,520.87500 z M 354.34375,591.71875 L 354.34375,662.59375 L 389.75000,662.59375 L 389.75000,591.71875 L 354.34375,591.71875 z M 389.75000,662.59375 L 389.75000,733.46875 L 425.18750,733.46875 L 425.18750,662.59375 L 389.75000,662.59375 z M 389.75000,733.46875 L 318.90625,733.46875 L 318.90625,768.90625 L 389.75000,768.90625 L 389.75000,733.46875 z M 318.90625,733.46875 L 318.90625,662.59375 L 283.46875,662.59375 L 283.46875,733.46875 L 318.90625,733.46875 z M 283.46875,662.59375 L 283.46875,591.71875 L 248.03125,591.71875 L 248.03125,662.59375 L 283.46875,662.59375 z M 248.03125,591.71875 L 248.03125,520.87500 L 212.59375,520.87500 L 212.59375,591.71875 L 248.03125,591.71875 z M 212.59375,520.87500 L 212.59375,450.00000 L 177.15625,450.00000 L 177.15625,485.43750 L 141.71875,485.43750 L 141.71875,520.87500 L 177.15625,520.87500 L 212.59375,520.87500 z M 141.71875,520.87500 L 106.31250,520.87500 L 106.31250,556.31250 L 141.71875,556.31250 L 141.71875,520.87500 z " id="rect1430" style="fill:#000000;fill-opacity:1.0000000;fill-rule:evenodd;stroke:none;stroke-width:1.0000000px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1.0000000"/>
+      <path d="M 70.875000,95.656250 L 70.875000,556.31250 L 106.31250,556.31250 L 106.31250,520.87500 L 141.71875,520.87500 L 141.71875,485.43750 L 177.15625,485.43750 L 177.15625,450.00000 L 212.59375,450.00000 L 212.59375,520.87500 L 248.03125,520.87500 L 248.03125,591.71875 L 283.46875,591.71875 L 283.46875,662.59375 L 318.90625,662.59375 L 318.90625,733.46875 L 354.34375,733.46875 L 389.75000,733.46875 L 389.75000,662.59375 L 354.34375,662.59375 L 354.34375,591.71875 L 318.90625,591.71875 L 318.90625,520.87500 L 283.46875,520.87500 L 283.46875,414.56250 L 318.90625,414.56250 L 354.34375,414.56250 L 389.75000,414.56250 L 389.75000,379.12500 L 354.34375,379.12500 L 354.34375,343.68750 L 318.90625,343.68750 L 318.90625,308.28125 L 283.46875,308.28125 L 283.46875,272.84375 L 248.03125,272.84375 L 248.03125,237.40625 L 212.59375,237.40625 L 212.59375,201.96875 L 177.15625,201.96875 L 177.15625,166.53125 L 141.71875,166.53125 L 141.71875,131.09375 L 106.31250,131.09375 L 106.31250,95.656250 L 70.875000,95.656250 z " id="rect3779" style="fill:#ffffff;fill-opacity:1.0000000;stroke:none"/>
+    </g>
+  </g>
+</svg>
diff -pruN 3.4.1-6/show-mouse/data/misc/plugin-showmouse.svg 3.4.1+git20201022.a0d3415c-1/show-mouse/data/misc/plugin-showmouse.svg
--- 3.4.1-6/show-mouse/data/misc/plugin-showmouse.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/show-mouse/data/misc/plugin-showmouse.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,413 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   inkscape:export-ydpi="90.000000"
+   inkscape:export-xdpi="90.000000"
+   inkscape:export-filename="/home/jimmac/Desktop/wi-fi.png"
+   width="32"
+   height="32"
+   id="svg11300"
+   sodipodi:version="0.32"
+   inkscape:version="0.45+devel"
+   sodipodi:docbase="/home/patrick/Projects/Fusion/config/ccsm-new-icons/images"
+   sodipodi:docname="plugin-showmouse.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape"
+   sodipodi:modified="true"
+   version="1.0">
+  <defs
+     id="defs3">
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient8676">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop8678" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop8680" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient8668">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop8670" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop8672" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient8660">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop8662" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop8664" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient8681">
+      <stop
+         style="stop-color:#edd400;stop-opacity:1;"
+         offset="0"
+         id="stop8683" />
+      <stop
+         style="stop-color:#edd400;stop-opacity:0;"
+         offset="1"
+         id="stop8685" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient8673">
+      <stop
+         style="stop-color:#edd400;stop-opacity:1;"
+         offset="0"
+         id="stop8675" />
+      <stop
+         style="stop-color:#edd400;stop-opacity:0;"
+         offset="1"
+         id="stop8677" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient8665">
+      <stop
+         style="stop-color:#edd400;stop-opacity:1;"
+         offset="0"
+         id="stop8667" />
+      <stop
+         style="stop-color:#edd400;stop-opacity:0;"
+         offset="1"
+         id="stop8669" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient8716">
+      <stop
+         style="stop-color:#edd400;stop-opacity:1;"
+         offset="0"
+         id="stop8718" />
+      <stop
+         style="stop-color:#edd400;stop-opacity:0;"
+         offset="1"
+         id="stop8720" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient124">
+      <stop
+         id="stop125"
+         offset="0.0000000"
+         style="stop-color:#ffffff;stop-opacity:1.0000000;" />
+      <stop
+         id="stop126"
+         offset="1"
+         style="stop-color:silver;stop-opacity:1;" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient10554"
+       inkscape:collect="always">
+      <stop
+         id="stop10556"
+         offset="0"
+         style="stop-color:white;stop-opacity:1;" />
+      <stop
+         id="stop10558"
+         offset="1"
+         style="stop-color:white;stop-opacity:0;" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient124"
+       id="linearGradient4372"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.4019046,3.2381864,-0.8095466,0.3504761,-482.91339,-745.38115)"
+       x1="253.75711"
+       y1="-129.52815"
+       x2="252.00447"
+       y2="-135.47408" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient124"
+       id="radialGradient4374"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.279254,0,0,1.7073246,-321.71546,-587.15241)"
+       cx="307.7507"
+       cy="361.47824"
+       fx="307.7507"
+       fy="361.47824"
+       r="12.509617" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient8716"
+       id="radialGradient8722"
+       cx="17.5625"
+       cy="2.5505798"
+       fx="17.5625"
+       fy="2.5505798"
+       r="12.84375"
+       gradientTransform="matrix(1.3768197,0.5593068,-0.2962439,0.7265725,-13.689484,-7.3025078)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient8716"
+       id="radialGradient8726"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.4760355,-1.3506095,0.7125958,-0.2519174,15.01014,53.528997)"
+       cx="17.5625"
+       cy="2.5505798"
+       fx="17.5625"
+       fy="2.5505798"
+       r="12.84375" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient8716"
+       id="radialGradient8730"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.2116544,0.9112847,-0.4819166,-0.6396052,51.900092,3.7391751)"
+       cx="17.5625"
+       cy="2.5505798"
+       fx="17.5625"
+       fy="2.5505798"
+       r="12.84375" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient10554"
+       id="linearGradient8734"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.5347684,0,0,1.4230823,-296.72742,-584.34298)"
+       x1="240.9062"
+       y1="425.18195"
+       x2="248.28683"
+       y2="437.96558" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient8665"
+       id="linearGradient8671"
+       x1="20.585707"
+       y1="5.8888607"
+       x2="37.848656"
+       y2="14.418337"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.6889464,0,0,0.6886399,-0.8217231,-0.5379257)" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient8673"
+       id="linearGradient8679"
+       x1="8.4011497"
+       y1="37.36874"
+       x2="5.5226607"
+       y2="18.895575"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.6889464,0,0,0.6886399,-0.8217231,-0.5379257)" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient8681"
+       id="linearGradient8687"
+       x1="41.054279"
+       y1="34.407265"
+       x2="22.929279"
+       y2="40.157265"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.6889464,0,0,0.6886399,-0.8217231,-0.5379257)" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient8660"
+       id="linearGradient8666"
+       x1="41.65625"
+       y1="32.163155"
+       x2="24.516338"
+       y2="42.413155"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient8668"
+       id="linearGradient8674"
+       x1="9.6503668"
+       y1="39.639404"
+       x2="5.1133409"
+       y2="20.635908"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient8676"
+       id="linearGradient8682"
+       x1="22.121695"
+       y1="6.4904122"
+       x2="37.09375"
+       y2="13.296315"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient10554"
+       id="linearGradient8675"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.5347684,0,0,1.4230823,-296.72742,-584.34298)"
+       x1="240.9062"
+       y1="425.18195"
+       x2="248.28683"
+       y2="437.96558" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient10554"
+       id="linearGradient8678"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.5347684,0,0,1.4230823,-296.72742,-584.34298)"
+       x1="240.9062"
+       y1="425.18195"
+       x2="248.28683"
+       y2="437.96558" />
+  </defs>
+  <sodipodi:namedview
+     stroke="#ef2929"
+     fill="#eeeeec"
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="0.25490196"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="0.99999996"
+     inkscape:cx="15.613714"
+     inkscape:cy="14.297831"
+     inkscape:current-layer="layer1"
+     showgrid="false"
+     inkscape:grid-bbox="true"
+     inkscape:document-units="px"
+     inkscape:showpageshadow="false"
+     inkscape:window-width="1280"
+     inkscape:window-height="710"
+     inkscape:window-x="0"
+     inkscape:window-y="49"
+     showguides="true"
+     inkscape:guide-bbox="true">
+    <inkscape:grid
+       type="xygrid"
+       id="grid7912"
+       visible="true"
+       enabled="true" />
+  </sodipodi:namedview>
+  <metadata
+     id="metadata4">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <dc:creator>
+          <cc:Agent>
+            <dc:title>Patrick Niklaus</dc:title>
+          </cc:Agent>
+        </dc:creator>
+        <dc:source />
+        <cc:license
+           rdf:resource="http://creativecommons.org/licenses/GPL/2.0/" />
+        <dc:title>State</dc:title>
+        <dc:subject>
+          <rdf:Bag />
+        </dc:subject>
+      </cc:Work>
+      <cc:License
+         rdf:about="http://creativecommons.org/licenses/GPL/2.0/">
+        <cc:permits
+           rdf:resource="http://web.resource.org/cc/Reproduction" />
+        <cc:permits
+           rdf:resource="http://web.resource.org/cc/Distribution" />
+        <cc:requires
+           rdf:resource="http://web.resource.org/cc/Notice" />
+        <cc:permits
+           rdf:resource="http://web.resource.org/cc/DerivativeWorks" />
+        <cc:requires
+           rdf:resource="http://web.resource.org/cc/ShareAlike" />
+        <cc:requires
+           rdf:resource="http://web.resource.org/cc/SourceCode" />
+      </cc:License>
+    </rdf:RDF>
+  </metadata>
+  <g
+     id="layer1"
+     inkscape:label="Layer 1"
+     inkscape:groupmode="layer">
+    <g
+       id="g4366"
+       transform="matrix(0.6514264,0,0,0.6392958,-36.997774,-2.4062985)">
+      <path
+         sodipodi:nodetypes="cccccccc"
+         style="fill:none;fill-opacity:1;fill-rule:evenodd;stroke:#888a85;stroke-width:1.54958844;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1"
+         d="M 71.401064,17.737975 L 71.401064,39.715361 L 78.379472,35.446114 L 82.648046,44.607206 L 86.149237,43.184125 L 81.976586,34.245388 L 88.258546,33.62279 L 71.401064,17.737975 z"
+         id="rect16" />
+      <path
+         transform="matrix(0.8698963,0,0,0.8065934,98.369116,14.067108)"
+         d="M -22.34375,19.125 L -24.75,20.125 C -24.912579,20.188558 -25.005181,20.360533 -24.96875,20.53125 L -24.1875,25.90625 C -24.152501,26.068677 -24.009891,26.185357 -23.84375,26.1875 L -22.5625,26.125 L -17.9375,36.84375 C -17.929156,36.865557 -17.918689,36.886491 -17.90625,36.90625 C -17.813226,37.032959 -17.648165,37.083747 -17.5,37.03125 L -15.0625,36 C -14.967095,35.963538 -14.891921,35.887892 -14.856059,35.792259 C -14.820197,35.696627 -14.827094,35.590203 -14.875,35.5 L -19.34375,25.1875 L -18.625,24.21875 C -18.52494,24.09008 -18.52494,23.90992 -18.625,23.78125 L -21.9375,19.25 C -21.94726,19.238947 -21.957697,19.22851 -21.96875,19.21875 C -22.064469,19.116528 -22.211188,19.079848 -22.34375,19.125 L -22.34375,19.125 z"
+         id="path2887"
+         style="fill:url(#linearGradient4372);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.24999988;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dashoffset:0;stroke-opacity:1"
+         inkscape:original="M -22.21875 19.46875 L -24.625 20.46875 L -23.84375 25.84375 L -22.34375 25.78125 L -17.625 36.6875 L -15.1875 35.65625 L -19.75 25.125 L -18.90625 24 L -22.21875 19.46875 z "
+         inkscape:radius="0.35630482"
+         sodipodi:type="inkscape:offset" />
+      <path
+         sodipodi:nodetypes="ccccc"
+         id="path2891"
+         d="M 72.159588,19.530082 C 72.177963,19.556626 72.272895,31.883058 72.145946,38.383094 L 79.79228,33.640724 C 82.066969,33.343364 87.30507,33.322546 87.336388,33.314445 L 72.159588,19.530082 z"
+         style="fill:url(#radialGradient4374);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.25;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dashoffset:0;stroke-opacity:1" />
+      <path
+         style="fill:none;fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient8678);stroke-width:1.54958844;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dashoffset:0;stroke-opacity:1"
+         d="M 72.958869,21.309665 C 72.966431,26.377251 72.95712,30.338728 72.926802,35.406225 C 72.926413,35.942848 72.928051,36.47947 72.927618,37.016093 C 75.156785,35.630676 77.267228,34.243915 79.496395,32.858498 C 82.497243,32.556758 83.40427,32.645597 85.372329,32.573153 C 81.140499,28.585704 77.206309,25.280488 72.958869,21.309665 z"
+         id="path8732"
+         sodipodi:nodetypes="cscccc" />
+    </g>
+    <path
+       style="opacity:1;fill:url(#radialGradient8722);fill-opacity:1;stroke:url(#linearGradient8671);stroke-width:0.99999994;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1"
+       d="M 10.188877,2.0838985 C 10.023648,2.1319691 9.8652873,2.192152 9.7033566,2.2456063 L 9.7088517,2.2644627 C 9.6307355,2.2803489 9.5547219,2.2888495 9.4767332,2.3115388 C 8.0172843,2.7361393 7.1589026,4.1996897 7.5636655,5.5885564 C 7.9684291,6.9774228 9.4845045,7.7706224 10.943954,7.3460208 C 11.021942,7.3233322 11.090641,7.2897307 11.165082,7.2612334 L 11.176073,7.2989447 C 11.539487,7.1597189 11.916843,7.042522 12.298195,6.9315746 C 17.563049,5.3998587 22.9091,7.1058907 25.822921,10.810404 C 25.755122,10.351119 25.65466,9.8815702 25.521693,9.4253194 C 23.769022,3.4113704 16.901865,0.13087443 10.188877,2.0838985 z"
+       id="path8705"
+       inkscape:transform-center-y="1.0532948"
+       inkscape:transform-center-x="-0.24914834" />
+    <path
+       id="path8724"
+       d="M 6.5281707,30.30617 C 6.66829,30.394464 6.8127497,30.470048 6.9546437,30.552515 L 6.9647188,30.536476 C 7.0260357,30.5826 7.0806899,30.631941 7.146824,30.673616 C 8.3844797,31.453504 9.9869208,31.134643 10.729134,29.953227 C 11.471347,28.771812 11.074917,27.171008 9.8372616,26.39112 C 9.7711269,26.349446 9.7030597,26.321457 9.6350028,26.286059 L 9.6551566,26.25398 C 9.3228371,26.08124 8.9974883,25.88434 8.6740907,25.680557 C 4.2093438,22.867172 2.0254286,17.921212 2.8341315,13.448055 C 2.5465204,13.791131 2.2723653,14.164325 2.0285443,14.552426 C -1.1853221,19.668089 0.83536421,26.718945 6.5281707,30.30617 z"
+       style="opacity:0.98000004;fill:url(#radialGradient8726);fill-opacity:1;stroke:url(#linearGradient8679);stroke-width:0.99999994;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1" />
+    <path
+       style="opacity:1;fill:url(#radialGradient8730);fill-opacity:1;stroke:url(#linearGradient8687);stroke-width:0.99999994;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1"
+       d="M 31.161303,19.707994 C 31.205704,19.538307 31.235887,19.368286 31.273839,19.198662 L 31.254427,19.193594 C 31.281416,19.116954 31.313781,19.046017 31.334739,18.965927 C 31.726933,17.467102 30.89326,15.949887 29.463397,15.576554 C 28.033533,15.203221 26.543843,16.113812 26.151649,17.612637 C 26.130692,17.692728 26.124169,17.77041 26.110162,17.850443 L 26.071336,17.840305 C 26.003049,18.231066 25.908143,18.622484 25.805664,19.014126 C 24.390852,24.421023 20.094473,28.203334 15.319795,28.811771 C 15.758036,28.992999 16.222389,29.151035 16.692107,29.273677 C 22.883576,30.890251 29.357338,26.602096 31.161303,19.707994 z"
+       id="path8728" />
+    <path
+       sodipodi:type="inkscape:offset"
+       inkscape:radius="-1.3593043"
+       inkscape:original="M 23.21875 3.0625 C 20.874307 2.8782667 18.404712 3.1034849 15.96875 3.8125 C 15.728921 3.882305 15.516291 3.9536262 15.28125 4.03125 L 15.28125 4.0625 C 15.167865 4.0855697 15.0507 4.0920521 14.9375 4.125 C 12.819122 4.741579 11.56874 6.8894242 12.15625 8.90625 C 12.743761 10.923075 14.944121 12.05408 17.0625 11.4375 C 17.175698 11.404553 17.298199 11.353882 17.40625 11.3125 L 17.40625 11.375 C 17.933743 11.172825 18.477721 11.004861 19.03125 10.84375 C 26.673144 8.619488 34.458112 11.089286 38.6875 16.46875 C 38.58909 15.801805 38.443 15.131289 38.25 14.46875 C 36.342009 7.918938 30.252078 3.6151999 23.21875 3.0625 z "
+       style="opacity:1;fill:none;fill-opacity:1;stroke:url(#linearGradient8682);stroke-width:1.45181465;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.54983921"
+       id="path8756"
+       d="M 23.125,4.40625 C 20.941135,4.2346354 18.617178,4.4632922 16.34375,5.125 C 16.230056,5.1580919 16.114814,5.1815407 16,5.21875 C 15.989753,5.2293353 15.979335,5.2397534 15.96875,5.25 C 15.842604,5.3235647 15.70543,5.3763241 15.5625,5.40625 C 15.318587,5.4558774 15.229986,5.4615165 15.3125,5.4375 C 13.869613,5.8574694 13.098556,7.260433 13.46875,8.53125 C 13.839543,9.8041204 15.239893,10.546344 16.6875,10.125 C 16.694289,10.123024 16.772553,10.082454 16.90625,10.03125 C 17.027706,9.9929549 17.15394,9.9719159 17.28125,9.96875 C 17.290669,9.9654206 17.303084,9.9720592 17.3125,9.96875 C 17.759763,9.8115631 18.219973,9.6582335 18.65625,9.53125 C 24.685007,7.7765104 30.813132,8.778444 35.46875,11.78125 C 32.975089,7.5960687 28.438957,4.8238366 23.125,4.40625 z"
+       transform="matrix(0.6889464,0,0,0.6886399,-0.8217231,-0.5379261)" />
+    <path
+       sodipodi:type="inkscape:offset"
+       inkscape:radius="-1.493752"
+       inkscape:original="M 5.3125 20.3125 C 4.8950349 20.810695 4.4789042 21.342673 4.125 21.90625 C -0.5399003 29.334897 2.3931885 39.572104 10.65625 44.78125 C 10.859632 44.909463 11.075292 45.036496 11.28125 45.15625 L 11.3125 45.125 C 11.401501 45.191978 11.466507 45.251982 11.5625 45.3125 C 13.358947 46.445003 15.703934 45.996829 16.78125 44.28125 C 17.858567 42.565672 17.265197 40.226255 15.46875 39.09375 C 15.372756 39.033235 15.286284 38.988903 15.1875 38.9375 L 15.21875 38.90625 C 14.736391 38.655409 14.250659 38.358421 13.78125 38.0625 C 7.3007065 33.977077 4.1386745 26.808141 5.3125 20.3125 z "
+       style="opacity:1;fill:none;fill-opacity:1;stroke:url(#linearGradient8674);stroke-width:1.45181465;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.52411577"
+       id="path8764"
+       d="M 3.9375,26.125 C 2.2277088,32.278437 5.0225399,39.487172 11.4375,43.53125 C 11.495502,43.567815 11.562615,43.61843 11.625,43.65625 C 11.678216,43.674131 11.730382,43.694997 11.78125,43.71875 C 11.938111,43.767135 12.085926,43.841042 12.21875,43.9375 C 12.371013,44.052086 12.367207,44.077288 12.34375,44.0625 C 13.493728,44.787461 14.910784,44.488065 15.53125,43.5 C 16.151964,42.511542 15.824437,41.060491 14.6875,40.34375 C 14.655438,40.323538 14.603459,40.303836 14.5,40.25 C 14.363077,40.18611 14.236638,40.101818 14.125,40 C 14.11443,39.989738 14.104012,39.97932 14.09375,39.96875 C 13.714293,39.754145 13.344983,39.529981 13,39.3125 C 7.9953671,36.157511 4.8620713,31.279175 3.9375,26.125 z"
+       transform="matrix(0.6889464,0,0,0.6886399,-0.8217231,-0.5379261)" />
+    <path
+       sodipodi:type="inkscape:offset"
+       inkscape:radius="-1.4340611"
+       inkscape:original="M 42.40625 23.3125 C 40.895852 23.55771 39.583199 24.711374 39.15625 26.34375 C 39.12583 26.460052 39.114082 26.571281 39.09375 26.6875 L 39.03125 26.6875 C 38.932132 27.254939 38.804997 27.837532 38.65625 28.40625 C 36.602661 36.257809 30.367905 41.741465 23.4375 42.625 C 24.073604 42.888167 24.724458 43.103156 25.40625 43.28125 C 34.393117 45.628738 43.81906 39.417436 46.4375 29.40625 C 46.50195 29.159842 46.538664 28.902567 46.59375 28.65625 L 46.5625 28.65625 C 46.601675 28.544958 46.657079 28.428802 46.6875 28.3125 C 47.256766 26.136 46.044185 23.948382 43.96875 23.40625 C 43.449891 23.270717 42.909716 23.230763 42.40625 23.3125 z "
+       style="opacity:1;fill:none;fill-opacity:1;stroke:url(#linearGradient8666);stroke-width:1.45181465;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.51125399"
+       id="path8768"
+       d="M 42.625,24.71875 C 41.687164,24.871006 40.817976,25.622495 40.53125,26.71875 C 40.5346,26.705943 40.530939,26.760653 40.5,26.9375 C 40.469352,27.114435 40.40575,27.284041 40.3125,27.4375 C 40.312613,27.447916 40.312613,27.458334 40.3125,27.46875 C 40.22537,27.904406 40.144148,28.349598 40.03125,28.78125 C 38.408589,34.985227 34.325884,39.81379 29.25,42.3125 C 36.259478,42.319194 42.966647,37.04441 45.0625,29.03125 C 45.077476,28.973991 45.107625,28.840124 45.125,28.75 C 45.123183,28.708353 45.123183,28.666647 45.125,28.625 C 45.13317,28.47516 45.164804,28.327531 45.21875,28.1875 C 45.294766,27.971546 45.330795,27.867557 45.3125,27.9375 C 45.696094,26.470888 44.888612,25.119486 43.59375,24.78125 C 43.243695,24.689811 42.895345,24.67486 42.625,24.71875 z"
+       transform="matrix(0.6889464,0,0,0.6886399,-0.8217231,-0.5379261)" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/slider/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/slider/data/misc/icon.svg
--- 3.4.1-6/slider/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/slider/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,527 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   version="1.0"
+   width="48"
+   height="48"
+   id="svg3380"
+   inkscape:version="0.47 r22583"
+   sodipodi:docname="folder-pictures.svg">
+  <metadata
+     id="metadata88">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <sodipodi:namedview
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1"
+     objecttolerance="10"
+     gridtolerance="10"
+     guidetolerance="10"
+     inkscape:pageopacity="0"
+     inkscape:pageshadow="2"
+     inkscape:window-width="843"
+     inkscape:window-height="491"
+     id="namedview86"
+     showgrid="false"
+     inkscape:zoom="4.9166667"
+     inkscape:cx="24.000748"
+     inkscape:cy="23.594144"
+     inkscape:window-x="0"
+     inkscape:window-y="24"
+     inkscape:window-maximized="0"
+     inkscape:current-layer="svg3380" />
+  <defs
+     id="defs3382">
+    <radialGradient
+       cx="34.828457"
+       cy="65.617027"
+       r="42.271381"
+       fx="34.828457"
+       fy="65.617027"
+       id="radialGradient2759"
+       xlink:href="#linearGradient4342"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.1481826,0.01025688,-0.00894678,0.1326541,2.7080247,-1.8757458)" />
+    <linearGradient
+       x1="20.252666"
+       y1="40.522579"
+       x2="5.5249739"
+       y2="11.734877"
+       id="linearGradient2757"
+       xlink:href="#linearGradient4157-401"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.3333929,0,0,0.3359124,2.9801845,-1.4923359)" />
+    <linearGradient
+       x1="0.63340867"
+       y1="3.0903029"
+       x2="79.104187"
+       y2="170.28906"
+       id="linearGradient2755"
+       xlink:href="#linearGradient3997"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.235535,0,5.2452621e-8,0.2044822,-28.669682,14.794629)" />
+    <linearGradient
+       id="linearGradient4342">
+      <stop
+         id="stop4344"
+         style="stop-color:#8babcb;stop-opacity:1;"
+         offset="0" />
+      <stop
+         id="stop4350"
+         style="stop-color:#8babcb;stop-opacity:0.49803922;"
+         offset="0.5" />
+      <stop
+         id="stop4352"
+         style="stop-color:#8bb4cb;stop-opacity:0.24705882;"
+         offset="0.75" />
+      <stop
+         id="stop4354"
+         style="stop-color:#95bfd8;stop-opacity:0.12156863;"
+         offset="0.875" />
+      <stop
+         id="stop4346"
+         style="stop-color:#ff480f;stop-opacity:0.13265306"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="34.828457"
+       cy="65.617027"
+       r="42.271381"
+       fx="34.828457"
+       fy="65.617027"
+       id="radialGradient2753"
+       xlink:href="#linearGradient4342"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.1481826,0.01025688,-0.00894678,0.1326541,2.7080247,-1.8757458)" />
+    <linearGradient
+       id="linearGradient4157-401">
+      <stop
+         id="stop3688"
+         style="stop-color:#426296;stop-opacity:1;"
+         offset="0" />
+      <stop
+         id="stop3690"
+         style="stop-color:#8babcb;stop-opacity:1;"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="20.252666"
+       y1="40.522579"
+       x2="5.5249739"
+       y2="11.734877"
+       id="linearGradient2751"
+       xlink:href="#linearGradient4157-401"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.3333929,0,0,0.3359124,2.9801845,-1.4923359)" />
+    <linearGradient
+       id="linearGradient3997">
+      <stop
+         id="stop3999"
+         style="stop-color:#d1dde8;stop-opacity:1;"
+         offset="0" />
+      <stop
+         id="stop4001"
+         style="stop-color:#fdfeff;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="0.63340867"
+       y1="3.0903029"
+       x2="79.104187"
+       y2="170.28906"
+       id="linearGradient2749"
+       xlink:href="#linearGradient3997"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.235535,0,5.2452621e-8,0.2044822,25.094409,19.932949)" />
+    <linearGradient
+       id="linearGradient3484">
+      <stop
+         id="stop3486"
+         style="stop-color:#bdbdbd;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3488"
+         style="stop-color:#d0d0d0;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6404">
+      <stop
+         id="stop6406"
+         style="stop-color:#f9f9f9;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6408"
+         style="stop-color:#c9c9c9;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5060-820">
+      <stop
+         id="stop2681"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2683"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient7600-312"
+       xlink:href="#linearGradient5060-820"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.03212956,0,0,0.03705882,23.363215,25.412461)" />
+    <linearGradient
+       id="linearGradient5060-179">
+      <stop
+         id="stop2675"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2677"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient7598-526"
+       xlink:href="#linearGradient5060-179"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.03212956,0,0,0.03705882,24.636785,25.412461)" />
+    <linearGradient
+       id="linearGradient5048-585">
+      <stop
+         id="stop2667"
+         style="stop-color:black;stop-opacity:0"
+         offset="0" />
+      <stop
+         id="stop2669"
+         style="stop-color:black;stop-opacity:1"
+         offset="0.5" />
+      <stop
+         id="stop2671"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="302.85715"
+       y1="366.64789"
+       x2="302.85715"
+       y2="609.50507"
+       id="linearGradient7596-975"
+       xlink:href="#linearGradient5048-585"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.08284024,0,0,0.03705882,-5.9408285,25.412461)" />
+    <linearGradient
+       id="linearGradient3390-178-986-453">
+      <stop
+         id="stop3624"
+         style="stop-color:#bb5e12;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3626"
+         style="stop-color:#cd8033;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient7012-661-145-733-759-865-745-661-970-94">
+      <stop
+         id="stop3618"
+         style="stop-color:#edd563;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3620"
+         style="stop-color:#e08223;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6129-963-697-142-998-580-273">
+      <stop
+         id="stop2661"
+         style="stop-color:#0a0a0a;stop-opacity:0.498"
+         offset="0" />
+      <stop
+         id="stop2663"
+         style="stop-color:#0a0a0a;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6087-437-184-795-110-662-495">
+      <stop
+         id="stop2693"
+         style="stop-color:white;stop-opacity:0.40000001"
+         offset="0" />
+      <stop
+         id="stop2695"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient8265-821-176-38-919-66-249">
+      <stop
+         id="stop2687"
+         style="stop-color:white;stop-opacity:0.27450982"
+         offset="0" />
+      <stop
+         id="stop2689"
+         style="stop-color:white;stop-opacity:0.07843138"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="11.566265"
+       y1="22.292103"
+       x2="15.214532"
+       y2="33.95525"
+       id="linearGradient2768"
+       xlink:href="#linearGradient8265-821-176-38-919-66-249"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       cx="7.2646537"
+       cy="8.3021259"
+       r="20.979567"
+       fx="7.2646537"
+       fy="8.3021259"
+       id="radialGradient2771"
+       xlink:href="#linearGradient6087-437-184-795-110-662-495"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,1.2079744,-1.6271642,0,26.371748,8.2664685)" />
+    <linearGradient
+       x1="22.934725"
+       y1="49.629246"
+       x2="22.809399"
+       y2="36.657963"
+       id="linearGradient2774"
+       xlink:href="#linearGradient6129-963-697-142-998-580-273"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.1446925,0,0,0.9977536,-3.4661413,1.0988425)" />
+    <radialGradient
+       cx="63.969177"
+       cy="14.113381"
+       r="23.097054"
+       fx="63.969177"
+       fy="14.113381"
+       id="radialGradient2777"
+       xlink:href="#linearGradient7012-661-145-733-759-865-745-661-970-94"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.5646925,-9.5143002e-8,6.1772287e-8,1.015888,-86.212573,8.1461173)" />
+    <linearGradient
+       x1="82.453476"
+       y1="45.114193"
+       x2="65.340263"
+       y2="15.943953"
+       id="linearGradient2779"
+       xlink:href="#linearGradient3390-178-986-453"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-53.765393,-0.1141929)" />
+    <linearGradient
+       x1="62.988873"
+       y1="13.182598"
+       x2="62.988873"
+       y2="16.19013"
+       id="linearGradient2786"
+       xlink:href="#linearGradient6404"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-50.940898,0)" />
+    <radialGradient
+       cx="3"
+       cy="5.01718"
+       r="21"
+       fx="3"
+       fy="5.01718"
+       id="radialGradient2788"
+       xlink:href="#linearGradient3484"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.274898e-8,1.7142916,-2.159331,-1.4599595e-8,12.809361,2.8570011)" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3997"
+       id="linearGradient2900"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.36824114,0,8.2005702e-8,0.3224136,16.470609,4.6554963)"
+       x1="0.63340867"
+       y1="3.0903029"
+       x2="79.104187"
+       y2="170.28906" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4157-401"
+       id="linearGradient2907"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.3333929,0,0,0.3359124,2.9801845,-1.4923359)"
+       x1="20.252666"
+       y1="40.522579"
+       x2="5.5249739"
+       y2="11.734877" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4342"
+       id="radialGradient2909"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.1481826,0.01025688,-0.00894678,0.1326541,2.7080247,-1.8757458)"
+       cx="34.828457"
+       cy="65.617027"
+       fx="34.828457"
+       fy="65.617027"
+       r="42.271381" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4342"
+       id="radialGradient2912"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.3613197,0.02512438,-0.0218153,0.32493818,17.577388,5.8399222)"
+       cx="34.828457"
+       cy="65.617027"
+       fx="34.828457"
+       fy="65.617027"
+       r="42.271381" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4157-401"
+       id="linearGradient2915"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.81292556,0,0,0.82282239,18.241006,6.7790904)"
+       x1="20.252666"
+       y1="40.522579"
+       x2="5.5249739"
+       y2="11.734877" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3997"
+       id="linearGradient2917"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.235535,0,5.2452621e-8,0.2044822,25.094409,19.932949)"
+       x1="0.63340867"
+       y1="3.0903029"
+       x2="79.104187"
+       y2="170.28906" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4157-401"
+       id="linearGradient2919"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.3333929,0,0,0.3359124,2.9801845,-1.4923359)"
+       x1="20.252666"
+       y1="40.522579"
+       x2="5.5249739"
+       y2="11.734877" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4342"
+       id="radialGradient2921"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.1481826,0.01025688,-0.00894678,0.1326541,2.7080247,-1.8757458)"
+       cx="34.828457"
+       cy="65.617027"
+       fx="34.828457"
+       fy="65.617027"
+       r="42.271381" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3997"
+       id="linearGradient2927"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.36903195,0,8.2181811e-8,0.32174043,-5.2948383,7.3473605)"
+       x1="0.63340867"
+       y1="3.0903029"
+       x2="79.104187"
+       y2="170.28906" />
+  </defs>
+  <path
+     d="m -116.73151,-19.38319 c -3.83,0 -6.946,3.109 -6.946,6.931 l 0,73.038 c 0,3.822 3.116,6.931 6.946,6.931 l 93.108,0 c 3.83,0 6.945,-3.109 6.945,-6.931 l 0,-63.972 c 0,-3.822 -3.115,-6.931 -6.945,-6.931 l -37.325,0 c -2.793,0 -6.33,-1.492 -8.801,-3.713 0,0 -1.035,-0.928 -1.035,-0.928 -2.114,-1.899 -5.372,-4.425 -9.246,-4.425 l -36.701,0 0,0 z"
+     id="path2626"
+     style="opacity:0.75;fill:url(#XMLID_17_)" />
+  <path
+     d="m -17.67751,60.58581 c 0,3.263 -2.676,5.931 -5.945,5.931 l -93.109,0 c -3.27,0 -5.946,-2.668 -5.946,-5.931 l 0,-73.038 c 0,-3.262 2.676,-5.931 5.946,-5.931 l 36.701,0 c 3.271,0 6.149,1.987 8.578,4.169 l 1.034,0.928 c 2.429,2.182 6.2,3.969 9.47,3.969 l 37.326,0 c 3.27,0 5.945,2.668 5.945,5.931 l 0,63.972 z"
+     id="path2637"
+     style="fill:url(#XMLID_18_)" />
+  <path
+     d="m -23.62251,-9.31619 -37.326,0 c -3.27,0 -7.041,-1.787 -9.47,-3.969 l -1.034,-0.928 c -2.428,-2.182 -5.307,-4.169 -8.578,-4.169 l -36.701,0 c -3.27,-10e-4 -5.946,2.668 -5.946,5.93 l 0,1 c 0,-3.262 2.676,-5.931 5.946,-5.931 l 36.701,0 c 3.271,0 6.149,1.987 8.578,4.169 l 1.034,0.928 c 2.429,2.182 6.2,3.969 9.47,3.969 l 37.326,0 c 3.27,0 5.945,2.668 5.945,5.931 l 0,-1 c 0,-3.262 -2.676,-5.93 -5.945,-5.93 z"
+     id="path2639"
+     style="fill:white" />
+  <rect
+     width="32.752773"
+     height="32.904312"
+     x="-7.5736613"
+     y="16.303844"
+     transform="matrix(0.86330235,-0.50468708,0.49500087,0.86889248,0,0)"
+     id="rect2629"
+     style="fill:url(#linearGradient2927);fill-opacity:1;stroke:#909090;stroke-width:1.58123946;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:0.96862745;stroke-dasharray:none" />
+  <g
+     transform="matrix(2.1116652,-1.2295479,1.2144204,2.1213421,-2.8343451,16.846379)"
+     id="g2631">
+    <rect
+       width="10.866501"
+       height="9.6223269"
+       rx="0"
+       ry="0"
+       x="2.5776777"
+       y="2.5667326"
+       transform="matrix(0.9999984,-0.00178851,-0.00204705,0.9999979,0,0)"
+       id="rect2633"
+       style="fill:url(#linearGradient2919);fill-opacity:1;stroke:#333333;stroke-width:0.65613586;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:0.96862745;stroke-dasharray:none" />
+    <rect
+       width="10.8665"
+       height="9.6223269"
+       rx="0"
+       ry="0"
+       x="2.5776775"
+       y="2.5667326"
+       transform="matrix(0.9999984,-0.00178851,-0.00204705,0.9999979,0,0)"
+       id="rect2635"
+       style="opacity:0.35;fill:url(#radialGradient2921);fill-opacity:1;stroke:none" />
+  </g>
+  <rect
+     style="fill:url(#linearGradient2900);fill-opacity:1;stroke:#909090;stroke-width:1.58119583;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:0.96862745;stroke-dasharray:none"
+     id="rect2722"
+     transform="matrix(0.99999847,-0.00175024,-0.0020918,0.99999781,0,0)"
+     y="13.630718"
+     x="14.196669"
+     height="32.973156"
+     width="32.682587" />
+  <rect
+     width="26.496233"
+     height="23.570032"
+     rx="0"
+     ry="0"
+     x="17.259558"
+     y="16.721838"
+     transform="matrix(0.99999839,-0.00179671,-0.00203771,0.99999792,0,0)"
+     id="rect2726"
+     style="fill:url(#linearGradient2915);fill-opacity:1;stroke:#333333;stroke-width:1.60354447;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:0.96862745;stroke-dasharray:none" />
+  <rect
+     width="26.496231"
+     height="23.570032"
+     rx="0"
+     ry="0"
+     x="17.259558"
+     y="16.721838"
+     transform="matrix(0.99999839,-0.00179671,-0.00203771,0.99999792,0,0)"
+     id="rect2728"
+     style="opacity:0.35;fill:url(#radialGradient2912);fill-opacity:1;stroke:none" />
+</svg>
diff -pruN 3.4.1-6/Sound-Effects/src/applet-struct.h 3.4.1+git20201022.a0d3415c-1/Sound-Effects/src/applet-struct.h
--- 3.4.1-6/Sound-Effects/src/applet-struct.h	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Sound-Effects/src/applet-struct.h	2020-10-21 15:04:44.000000000 +0000
@@ -23,7 +23,6 @@
 
 #include <sys/types.h>
 #include <alsa/asoundlib.h>
-#define _STRUCT_TIMEVAL
 #include <cairo-dock.h>
 
 //\___________ structure containing the applet's configuration parameters.
Binary files 3.4.1-6/stack/data/misc/default-icon.png and 3.4.1+git20201022.a0d3415c-1/stack/data/misc/default-icon.png differ
diff -pruN 3.4.1-6/stack/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/stack/data/misc/icon.svg
--- 3.4.1-6/stack/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/stack/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,506 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   version="1.0"
+   width="48"
+   height="48"
+   id="svg2605"
+   inkscape:version="0.47 r22583"
+   sodipodi:docname="icon.svg">
+  <metadata
+     id="metadata59">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <dc:title />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <sodipodi:namedview
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1"
+     objecttolerance="10"
+     gridtolerance="10"
+     guidetolerance="10"
+     inkscape:pageopacity="0"
+     inkscape:pageshadow="2"
+     inkscape:window-width="1051"
+     inkscape:window-height="770"
+     id="namedview57"
+     showgrid="false"
+     inkscape:zoom="4.625"
+     inkscape:cx="6.4628366"
+     inkscape:cy="24.498783"
+     inkscape:window-x="560"
+     inkscape:window-y="62"
+     inkscape:window-maximized="0"
+     inkscape:current-layer="layer1" />
+  <defs
+     id="defs2607">
+    <linearGradient
+       id="linearGradient3484">
+      <stop
+         id="stop3486"
+         style="stop-color:#bdbdbd;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3488"
+         style="stop-color:#d0d0d0;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6404">
+      <stop
+         id="stop6406"
+         style="stop-color:#f9f9f9;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6408"
+         style="stop-color:#c9c9c9;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5060-820">
+      <stop
+         id="stop2681"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2683"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient7600-312"
+       xlink:href="#linearGradient5060-820"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.03212956,0,0,0.03705882,23.363215,25.412461)" />
+    <linearGradient
+       id="linearGradient5060-179">
+      <stop
+         id="stop2675"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2677"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient7598-526"
+       xlink:href="#linearGradient5060-179"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.03212956,0,0,0.03705882,24.636785,25.412461)" />
+    <linearGradient
+       id="linearGradient5048-585">
+      <stop
+         id="stop2667"
+         style="stop-color:black;stop-opacity:0"
+         offset="0" />
+      <stop
+         id="stop2669"
+         style="stop-color:black;stop-opacity:1"
+         offset="0.5" />
+      <stop
+         id="stop2671"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="302.85715"
+       y1="366.64789"
+       x2="302.85715"
+       y2="609.50507"
+       id="linearGradient7596-975"
+       xlink:href="#linearGradient5048-585"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.08284024,0,0,0.03705882,-5.9408285,25.412461)" />
+    <linearGradient
+       id="linearGradient6087-437-184-795-110">
+      <stop
+         id="stop4655"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4657"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient8265-821-176-38-919">
+      <stop
+         id="stop4667"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4669"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6129-963-697-142-998">
+      <stop
+         id="stop4661"
+         style="stop-color:black;stop-opacity:0.498"
+         offset="0" />
+      <stop
+         id="stop4663"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3390-178-986-453">
+      <stop
+         id="stop3624"
+         style="stop-color:#426296;stop-opacity:1;"
+         offset="0" />
+      <stop
+         id="stop3626"
+         style="stop-color:#7b838b;stop-opacity:1;"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient7012-661-145-733-759-865-745-661-970-94">
+      <stop
+         id="stop3618"
+         style="stop-color:#8babcb;stop-opacity:1;"
+         offset="0" />
+      <stop
+         id="stop3620"
+         style="stop-color:#426296;stop-opacity:1;"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient2264">
+      <stop
+         offset="0"
+         style="stop-color:#d7e866;stop-opacity:1"
+         id="stop2266" />
+      <stop
+         offset="1"
+         style="stop-color:#8cab2a;stop-opacity:1"
+         id="stop2268" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4222">
+      <stop
+         offset="0"
+         style="stop-color:#ffffff;stop-opacity:1"
+         id="stop4224" />
+      <stop
+         offset="1"
+         style="stop-color:#ffffff;stop-opacity:0"
+         id="stop4226" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4222"
+       id="linearGradient3870"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,0.798445,-0.7913078,0,90.60617,2.4233435)"
+       x1="8.5273199"
+       y1="33.332287"
+       x2="57.411129"
+       y2="33.332287" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient2264"
+       id="linearGradient3873"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,0.54784761,-0.32313997,0,32.250062,1.2298105)"
+       x1="28.670898"
+       y1="23.890965"
+       x2="1.3099612"
+       y2="23.890965" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient6087-437-184-795-110"
+       id="radialGradient3929"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,0.9862682,-1.6271642,0,26.375101,14.823374)"
+       cx="7.2646537"
+       cy="8.3021259"
+       fx="7.2646537"
+       fy="8.3021259"
+       r="20.979567" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient8265-821-176-38-919"
+       id="linearGradient3932"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.1446925,0,0,0.8040948,-3.462788,9.1292944)"
+       x1="13.079692"
+       y1="20.730078"
+       x2="16.36186"
+       y2="32.979298" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient6129-963-697-142-998"
+       id="linearGradient3935"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.1446925,0,0,0.8146303,-3.462788,8.9712613)"
+       x1="22.934725"
+       y1="49.629246"
+       x2="22.809399"
+       y2="36.657963" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient7012-661-145-733-759-865-745-661-970-94"
+       id="radialGradient3938"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.4880117,0,0,0.7912602,-6.762448,10.706955)"
+       cx="13.857143"
+       cy="19.54422"
+       fx="13.857143"
+       fy="19.54422"
+       r="24.097353" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3390-178-986-453"
+       id="linearGradient3940"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(0,-0.1141965)"
+       x1="34.954498"
+       y1="45.114197"
+       x2="25.474075"
+       y2="20.980713" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient6404"
+       id="linearGradient3948"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-50.940898,0)"
+       x1="62.988873"
+       y1="18"
+       x2="62.988873"
+       y2="21.007532" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3484"
+       id="radialGradient3950"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.274898e-8,1.7142916,-2.159331,-1.4599595e-8,12.809361,2.8570011)"
+       cx="3"
+       cy="5.01718"
+       fx="3"
+       fy="5.01718"
+       r="21" />
+    <linearGradient
+       id="linearGradient6493">
+      <stop
+         offset="0"
+         style="stop-color:#3b4a62;stop-opacity:1;"
+         id="stop6495" />
+      <stop
+         offset="1"
+         style="stop-color:#1b2636;stop-opacity:1;"
+         id="stop6497" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3156">
+      <stop
+         offset="0"
+         style="stop-color:white;stop-opacity:1"
+         id="stop3158" />
+      <stop
+         offset="1"
+         style="stop-color:white;stop-opacity:0"
+         id="stop3160" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6326">
+      <stop
+         offset="0"
+         style="stop-color:#6d7985;stop-opacity:1;"
+         id="stop6328" />
+      <stop
+         offset="1"
+         style="stop-color:#394353;stop-opacity:1;"
+         id="stop6330" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient6493"
+       id="linearGradient4241"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9,0,0,0.9,62.296187,-16.430431)"
+       x1="29.01346"
+       y1="29"
+       x2="29.75"
+       y2="50" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient6326"
+       id="radialGradient4243"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(2.0299112,0,-1.9671666e-8,1.8508017,37.418497,-26.637536)"
+       cx="26"
+       cy="15.240479"
+       fx="26"
+       fy="15.240479"
+       r="15.074549" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3156"
+       id="radialGradient4245"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.90899325,-0.10079658,0.05101877,0.46009197,61.54238,-9.4163064)"
+       cx="22.125"
+       cy="10.874998"
+       fx="22.125"
+       fy="10.874998"
+       r="20" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3156"
+       id="radialGradient4247"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.221394,0.00919655,-0.0056821,0.75464055,57.008963,-9.8552154)"
+       cx="22.944935"
+       cy="11.222695"
+       fx="22.944935"
+       fy="4.7612267"
+       r="14" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3156"
+       id="linearGradient4249"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9685737,-0.26215758,0.17574552,0.64288485,56.731721,2.4511019)"
+       x1="24.335312"
+       y1="61.852856"
+       x2="28.290144"
+       y2="20.663898" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3156"
+       id="linearGradient4251"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.0122546,-0.00611168,0.00101081,0.66862944,59.697542,-8.6205125)"
+       x1="27.888655"
+       y1="-0.81503254"
+       x2="28.290144"
+       y2="20.663898" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3156"
+       id="linearGradient4253"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.08946085,-1.0077941,0.62514945,-0.03598888,74.153646,39.797085)"
+       x1="28.220636"
+       y1="-2.3103411"
+       x2="28.290144"
+       y2="20.663898" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3156"
+       id="linearGradient4255"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.14406993,-0.99292248,0.43707501,0.01522884,82.038107,37.649936)"
+       x1="30.501778"
+       y1="55.647495"
+       x2="29.724815"
+       y2="24.653727" />
+    <filter
+       inkscape:collect="always"
+       id="filter3837"
+       x="-0.23837766"
+       width="1.4767553"
+       y="-0.17767644"
+       height="1.3553529">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="1.6507452"
+         id="feGaussianBlur3839" />
+    </filter>
+  </defs>
+  <g
+     id="layer1">
+    <path
+       d="m 3.5062498,8.4999995 c -0.690271,0.00767 -1.0004418,0.3421461 -1.0004418,1 0,5.5144545 0.026278,9.7395765 -0.00581,14.7504305 C 3.9354707,24.25043 45,24.592532 45,23 l 0.499998,-10.493353 c 0,-0.657853 -0.554204,-1.007671 -1.244479,-1 l -20.255519,0 c -2.047483,0 -3.498891,-3.0066475 -5,-3.0066475 l -15.4937502,0 z"
+       id="path3468"
+       style="fill:url(#linearGradient3948);fill-opacity:1;stroke:url(#radialGradient3950);stroke-width:1.00000012;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;display:inline" />
+    <path
+       sodipodi:nodetypes="cccccccc"
+       style="fill:url(#linearGradient3873);fill-opacity:1;fill-rule:nonzero;stroke:#000000;stroke-width:0.60053599000000002;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible;filter:url(#filter3837);opacity:0.52467532"
+       id="path3827"
+       d="m 32.839832,14.177789 -8.3259,-11.94468 -8.293898,11.94468 4.774146,0 0,10.353091 7.071506,0 0,-10.353091 4.774146,0 z" />
+    <g
+       transform="matrix(0.9583333,0,0,0.6666667,1.0000008,15)"
+       id="g7591"
+       style="opacity:0.4">
+      <rect
+         width="40"
+         height="9"
+         x="4"
+         y="39"
+         id="rect4173"
+         style="fill:url(#linearGradient7596-975);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+      <path
+         d="m 44,39.00031 c 0,0 0,8.999504 0,8.999504 1.654593,0.01694 4.000001,-2.016333 4,-4.500331 0,-2.483999 -1.846402,-4.499173 -4,-4.499173 z"
+         id="path5058"
+         style="fill:url(#radialGradient7598-526);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+      <path
+         d="m 4,39.00031 c 0,0 0,8.999504 0,8.999504 C 2.3454068,48.016755 0,45.983481 0,43.499483 0,41.015484 1.8464008,39.00031 4,39.00031 z"
+         id="path5018"
+         style="fill:url(#radialGradient7600-312);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+    </g>
+    <rect
+       width="13"
+       height="2"
+       rx="1"
+       ry="1"
+       x="5"
+       y="10"
+       id="rect3562"
+       style="fill:#8babcb;fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:block;overflow:visible;enable-background:accumulate" />
+    <path
+       d="m 32.839832,14.177789 -8.3259,-11.94468 -8.293898,11.94468 4.774146,0 0,10.353091 7.071506,0 0,-10.353091 4.774146,0 z"
+       id="path4348"
+       style="fill:url(#linearGradient3873);fill-opacity:1;fill-rule:nonzero;stroke:#548820;stroke-width:0.60053599;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible"
+       sodipodi:nodetypes="cccccccc" />
+    <path
+       style="fill:url(#radialGradient3938);fill-opacity:1;stroke:url(#linearGradient3940);stroke-width:1.00000024;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dashoffset:0"
+       id="path7314"
+       d="m 1.065353,21.385804 c -1.072707,0.100992 -0.499473,1.279221 -0.585,1.866173 0.300461,1.216969 1.976422,19.433868 2.17925,20.746557 0.341836,0.788453 1.594434,0.384685 2.388117,0.484775 13.193544,0 26.387089,0 39.580633,0 1.089379,-0.08708 0.636457,-1.149321 0.789703,-1.757245 0.06207,-0.884547 1.706566,-14.739761 2.179297,-20.746557 -0.251172,-0.779143 -1.487747,-0.593703 -2.263,-0.593703 -14.089378,0 -30.179622,0 -44.269,0 z" />
+    <path
+       style="opacity:0.4;fill:url(#linearGradient3935);fill-opacity:1;stroke:none"
+       id="path2541"
+       d="m 1.061353,21.190716 45.897,3.3e-4 c 0.63416,0 1.045,0.363009 1.045,0.814314 L 45.75899,44.000365 c 0,0.451305 -0.510532,0.81463 -1.14469,0.81463 l -41.208935,0 c -0.63416,0 -1.144693,-0.363325 -1.144693,-0.81463 L 0.016353,22.005347 c 0,-0.451306 0.41084,-0.814631 1.045,-0.814631 z" />
+    <path
+       style="opacity:0.2;fill:url(#linearGradient3932);fill-opacity:1;stroke:none"
+       id="path8263"
+       d="m 1.061353,20.885804 45.897,0 c 0.63416,0 1.045,0.663907 1.045,1.109377 l -0.46,6.002915 -46.843,5.828538 -0.684,-11.831824 c 0,-0.445468 0.41084,-1.109006 1.045,-1.109006 z" />
+    <path
+       style="opacity:0.4;fill:none;stroke:url(#radialGradient3929);stroke-width:0.99999982;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none"
+       id="path2544"
+       d="m 46.503353,22.385804 c -13.53125,0 -31.46875,0 -45,0 0.220184,0.893165 1.92721,19.690463 2.23001,21.161942" />
+    <path
+       d="m 80.921716,22.534537 -11.205341,12.5 -11.367074,-12.5 4.867074,0 0,-13.0000004 13,0 0,13.0000004 4.705341,0 z"
+       id="path4360"
+       style="opacity:0.35400008;fill:none;stroke:url(#linearGradient3870);stroke-width:0.98045683;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/Status-Notifier/watcher/status-notifier-watcher.py 3.4.1+git20201022.a0d3415c-1/Status-Notifier/watcher/status-notifier-watcher.py
--- 3.4.1-6/Status-Notifier/watcher/status-notifier-watcher.py	2014-10-15 14:22:15.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Status-Notifier/watcher/status-notifier-watcher.py	2020-10-21 15:04:44.000000000 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 #
 # This is a part of the Cairo-Dock plug-ins.
 # Copyright : (C) 2011 by Fabrice Rey
@@ -18,17 +18,11 @@
 # Developped as a part of Cairo-Dock, but usable as a stand-alone systray daemon.
 # The code follows the same logic as the KDE watcher, to ensure a complete compatibility.
 
-from __future__ import print_function
 import sys
 
-try:
-	import glib
-	import gobject
-	g_bMainLoopInGObject = True
-except:
-	from gi.repository import GLib as glib
-	from gi.repository import GObject as gobject
-	g_bMainLoopInGObject = False
+from gi.repository import GLib as glib
+from gi.repository import GObject as gobject
+g_bMainLoopInGObject = False
 
 import dbus, dbus.service
 from dbus.mainloop.glib import DBusGMainLoop
diff -pruN 3.4.1-6/switcher/src/applet-draw.c 3.4.1+git20201022.a0d3415c-1/switcher/src/applet-draw.c
--- 3.4.1-6/switcher/src/applet-draw.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/switcher/src/applet-draw.c	2020-10-21 15:04:44.000000000 +0000
@@ -45,6 +45,9 @@ static void _cd_switcher_draw_windows_on
 	int iNumDesktop = data->iNumDesktop;
 	int iNumViewportX = data->iNumViewportX;
 	int iNumViewportY = data->iNumViewportY;
+	// skip if not on this desktop/viewport
+	if (!gldi_window_is_on_desktop (actor, iNumDesktop, iNumViewportX, iNumViewportY))
+		return;
 	int iOneViewportWidth = data->iOneViewportWidth;
 	int iOneViewportHeight = data->iOneViewportHeight;
 	cairo_t *pCairoContext = data->pCairoContext;
@@ -60,15 +63,6 @@ static void _cd_switcher_draw_windows_on
 		y += g_desktopGeometry.iNbViewportY * g_desktopGeometry.Xscreen.height;
 	int w = actor->windowGeometry.width, h = actor->windowGeometry.height;
 	
-	// test d'intersection avec le viewport donne.
-	//g_print (" %s : (%d;%d) %dx%d\n", pIcon->cName, x, y, w, h);
-	if ((actor->iNumDesktop != -1 && actor->iNumDesktop != iNumDesktop) ||
-		x + w <= iNumViewportX * g_desktopGeometry.Xscreen.width ||
-		x >= (iNumViewportX + 1) * g_desktopGeometry.Xscreen.width ||
-		y + h <= iNumViewportY * g_desktopGeometry.Xscreen.height ||
-		y >= (iNumViewportY + 1) * g_desktopGeometry.Xscreen.height)
-		return ;
-	
 	// on dessine ses traits.
 	cairo_save (pCairoContext);
 
diff -pruN 3.4.1-6/terminal/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/terminal/data/misc/icon.svg
--- 3.4.1-6/terminal/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/terminal/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,280 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   version="1.1"
+   width="48"
+   height="48"
+   id="svg4306">
+  <defs
+     id="defs4308">
+    <linearGradient
+       x1="12.578789"
+       y1="-7.8073711"
+       x2="12.578789"
+       y2="41.827358"
+       id="linearGradient2867"
+       xlink:href="#linearGradient2238-2-3"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9546411,0,0,0.8965269,1.087452,5.3852458)" />
+    <linearGradient
+       id="linearGradient2238-2-3">
+      <stop
+         id="stop2240-1-6"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2242-7-3"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="16.626165"
+       y1="15.298182"
+       x2="20.054544"
+       y2="24.627615"
+       id="linearGradient2870"
+       xlink:href="#linearGradient8265-821-176-38-919-66-249-7-7"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9578231,0,0,1.0182827,1.012241,1.9221282)" />
+    <linearGradient
+       id="linearGradient8265-821-176-38-919-66-249-7-7">
+      <stop
+         id="stop2687-1-9"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2689-5-4"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="19.362526"
+       y1="20.069984"
+       x2="19.362526"
+       y2="34.400269"
+       id="linearGradient2899"
+       xlink:href="#linearGradient4182"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.62705683,0,0,0.69110195,-0.03290423,4.574844)" />
+    <linearGradient
+       id="linearGradient4182">
+      <stop
+         id="stop4184"
+         style="stop-color:#e4e5e8;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4186"
+         style="stop-color:#b3bbc7;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="23.070969"
+       y1="36.046932"
+       x2="23.070969"
+       y2="33.296398"
+       id="linearGradient2876"
+       xlink:href="#linearGradient2223-4"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9910545,0,0,1.0114758,0.22049646,5.8120997)" />
+    <linearGradient
+       id="linearGradient2223-4">
+      <stop
+         id="stop2225-6"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2229-2"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="16.352173"
+       cy="12.225069"
+       r="19.170427"
+       fx="16.352173"
+       fy="12.225069"
+       id="radialGradient2879"
+       xlink:href="#linearGradient4128"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0,0.96364192,-2.2356343,0,48.282191,6.3238734)" />
+    <linearGradient
+       id="linearGradient4128">
+      <stop
+         id="stop4130"
+         style="stop-color:#3d434a;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4132"
+         style="stop-color:black;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="23.999996"
+       y1="7.9600015"
+       x2="23.999996"
+       y2="43.865456"
+       id="linearGradient2882"
+       xlink:href="#linearGradient3994-617"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient3994-617">
+      <stop
+         id="stop4324"
+         style="stop-color:#d8d8d8;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2860"
+         style="stop-color:#afafaf;stop-opacity:1"
+         offset="0.08552461" />
+      <stop
+         id="stop2862"
+         style="stop-color:#aaa;stop-opacity:1"
+         offset="0.92166406" />
+      <stop
+         id="stop4326"
+         style="stop-color:#8f8f8f;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="10.014208"
+       y1="44.960102"
+       x2="10.014208"
+       y2="2.8764627"
+       id="linearGradient2884"
+       xlink:href="#linearGradient4008-764"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.9574517,0,0,0.9034707,1.021174,4.3056311)" />
+    <linearGradient
+       id="linearGradient4008-764">
+      <stop
+         id="stop4334"
+         style="stop-color:#595959;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4336"
+         style="stop-color:#b3b3b3;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient2887"
+       xlink:href="#linearGradient5060-6"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-0.06553443,0,0,0.02470588,47.673126,31.941639)" />
+    <linearGradient
+       id="linearGradient5060-6">
+      <stop
+         id="stop5062-3"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop5064-1"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="605.71429"
+       cy="486.64789"
+       r="117.14286"
+       fx="605.71429"
+       fy="486.64789"
+       id="radialGradient2890"
+       xlink:href="#linearGradient5060-6"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.06553443,0,0,0.02470588,0.32688366,31.941639)" />
+    <linearGradient
+       id="linearGradient5048-7">
+      <stop
+         id="stop5050-5"
+         style="stop-color:black;stop-opacity:0"
+         offset="0" />
+      <stop
+         id="stop5056-9"
+         style="stop-color:black;stop-opacity:1"
+         offset="0.5" />
+      <stop
+         id="stop5052-6"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="302.85715"
+       y1="366.64789"
+       x2="302.85715"
+       y2="609.50507"
+       id="linearGradient4304"
+       xlink:href="#linearGradient5048-7"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.06553443,0,0,0.02470588,0.31398648,31.941639)" />
+  </defs>
+  <g
+     id="layer1">
+    <rect
+       width="31.643764"
+       height="6.0000005"
+       x="8.1781178"
+       y="41"
+       id="rect2512"
+       style="opacity:0.40206185;fill:url(#linearGradient4304);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+    <path
+       d="m 39.821883,41.000206 c 0,0 0,5.999669 0,5.999669 3.374861,0.01129 8.158771,-1.344221 8.158769,-3.000221 0,-1.655999 -3.76609,-2.999448 -8.158769,-2.999448 z"
+       id="path2514"
+       style="opacity:0.40206185;fill:url(#radialGradient2890);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+    <path
+       d="m 8.178118,41.000206 c 0,0 0,5.999669 0,5.999669 -3.3748615,0.01129 -8.15877068,-1.344221 -8.15877068,-3.000221 0,-1.655999 3.76609018,-2.999448 8.15877068,-2.999448 z"
+       id="path2516"
+       style="opacity:0.40206185;fill:url(#radialGradient2887);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;marker:none;visibility:visible;display:inline;overflow:visible" />
+    <rect
+       width="44.997868"
+       height="36.997868"
+       rx="1.4989328"
+       ry="1.4989328"
+       x="1.5010625"
+       y="7.5010676"
+       id="rect2551"
+       style="fill:url(#linearGradient2882);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient2884);stroke-width:1.00213289;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+    <rect
+       width="36.997868"
+       height="28.997868"
+       rx="0"
+       ry="0"
+       x="5.5010662"
+       y="11.501067"
+       id="rect1314"
+       style="fill:url(#radialGradient2879);fill-opacity:1;fill-rule:evenodd;stroke:#1e1f1f;stroke-width:1.00213289;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+    <rect
+       width="38.997868"
+       height="30.997868"
+       rx="0"
+       ry="0"
+       x="4.5010662"
+       y="10.501066"
+       id="rect2221"
+       style="opacity:0.4;fill:none;stroke:url(#linearGradient2876);stroke-width:1.00213289;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+    <path
+       d="M 20.03291,23.58898 C 16.688607,25.169728 13.344303,26.750475 10,28.331223 c 0,-0.687777 0,-1.375555 0,-2.063332 2.647861,-1.21216 5.295722,-2.424319 7.943583,-3.636479 C 15.295722,21.430652 12.647861,20.229891 10,19.029131 c 0,-0.676377 0,-1.352755 0,-2.029132 3.344303,1.557948 6.688607,3.115897 10.03291,4.673845 0,0.638379 0,1.276757 0,1.915136 z m 11.967091,9.411019 c 0,0.666667 0,1.333334 0,2.000001 -3.668391,0 -7.336781,0 -11.005172,0 0,-0.666667 0,-1.333334 0,-2.000001 3.668391,0 7.336781,0 11.005172,0 z"
+       id="text4138"
+       style="font-size:22.23835945px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:url(#linearGradient2899);fill-opacity:1;stroke:none;font-family:OpenSymbol;-inkscape-font-specification:OpenSymbol" />
+    <path
+       d="m 4.095234,8.0000031 c -1.157316,0 -2.095238,0.9971259 -2.095238,2.2274919 l 0,16.292523 c 0.0027,0.137064 0.05919,0.26668 0.155886,0.357384 0.09669,0.0907 0.224704,0.134203 0.352957,0.119936 l 43.10204,-7.255264 c 0.221716,-0.03717 0.386016,-0.238719 0.389116,-0.47732 l 0,-9.037259 c 0,-1.230366 -0.937923,-2.2274919 -2.095238,-2.2274919 l -39.809523,0 z"
+       id="path3333"
+       style="opacity:0.2;fill:url(#linearGradient2870);fill-opacity:1;fill-rule:evenodd;stroke:none" />
+    <rect
+       width="42.996269"
+       height="34.996269"
+       rx="0.49813175"
+       ry="0.49813175"
+       x="2.5018635"
+       y="8.5018692"
+       id="rect2556"
+       style="opacity:0.4;fill:none;stroke:url(#linearGradient2867);stroke-width:1.00373149;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/tomboy/src/tomboy-notifications.c 3.4.1+git20201022.a0d3415c-1/tomboy/src/tomboy-notifications.c
--- 3.4.1-6/tomboy/src/tomboy-notifications.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/tomboy/src/tomboy-notifications.c	2020-10-21 15:04:44.000000000 +0000
@@ -18,7 +18,6 @@
 */
 
 #include <stdlib.h>
-#define __USE_POSIX
 #include <time.h>
 #include <signal.h>
 
diff -pruN 3.4.1-6/Toons/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/Toons/data/misc/icon.svg
--- 3.4.1-6/Toons/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/Toons/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,137 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="128"
+   height="128"
+   id="svg2"
+   sodipodi:version="0.32"
+   inkscape:version="0.46"
+   version="1.0"
+   sodipodi:docname="icon.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <defs
+     id="defs4">
+    <linearGradient
+       id="linearGradient4655">
+      <stop
+         style="stop-color:#000000;stop-opacity:0;"
+         offset="0"
+         id="stop4657" />
+      <stop
+         style="stop-color:#000000;stop-opacity:1;"
+         offset="1"
+         id="stop4659" />
+    </linearGradient>
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4655"
+       id="radialGradient4714"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1,0,0,4.1379313,0,-420.03453)"
+       cx="41.785713"
+       cy="130.57739"
+       fx="37.492565"
+       fy="128.9906"
+       r="10.357142" />
+    <inkscape:perspective
+       sodipodi:type="inkscape:persp3d"
+       inkscape:vp_x="0 : 526.18109 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_z="744.09448 : 526.18109 : 1"
+       inkscape:persp3d-origin="372.04724 : 350.78739 : 1"
+       id="perspective10" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4655"
+       id="radialGradient4981"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1,0,0,4.1379313,0,-420.03453)"
+       cx="41.785713"
+       cy="130.57739"
+       fx="37.492565"
+       fy="128.9906"
+       r="10.357142" />
+  </defs>
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="1.4"
+     inkscape:cx="172.36544"
+     inkscape:cy="129.69891"
+     inkscape:document-units="px"
+     inkscape:current-layer="layer1"
+     showgrid="false"
+     inkscape:window-width="642"
+     inkscape:window-height="722"
+     inkscape:window-x="420"
+     inkscape:window-y="101" />
+  <metadata
+     id="metadata7">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:label="Calque 1"
+     inkscape:groupmode="layer"
+     id="layer1"
+     transform="translate(-1.2856186,-1.9284713)">
+    <path
+       sodipodi:type="arc"
+       style="opacity:1;fill:none;fill-opacity:1;fill-rule:nonzero;stroke:#000000;stroke-width:6.0001545;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+       id="path2393"
+       sodipodi:cx="82.85714"
+       sodipodi:cy="69.214287"
+       sodipodi:rx="47.142857"
+       sodipodi:ry="86.071434"
+       d="M 130,69.214287 A 47.142857,86.071434 0 1 1 35.714283,69.214287 A 47.142857,86.071434 0 1 1 130,69.214287 z"
+       transform="matrix(0.44824,0,0,0.717364,-6.5931718,16.616794)" />
+    <path
+       sodipodi:type="arc"
+       style="opacity:1;fill:none;fill-opacity:1;fill-rule:nonzero;stroke:#000000;stroke-width:6.0001545;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+       id="path4611"
+       sodipodi:cx="82.85714"
+       sodipodi:cy="69.214287"
+       sodipodi:rx="47.142857"
+       sodipodi:ry="86.071434"
+       d="M 130,69.214287 A 47.142857,86.071434 0 1 1 35.714283,69.214287 A 47.142857,86.071434 0 1 1 130,69.214287 z"
+       transform="matrix(0.4701096,0,0,0.7168942,60.144208,16.469193)" />
+    <path
+       sodipodi:type="arc"
+       style="opacity:1;fill:url(#radialGradient4714);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+       id="path4712"
+       sodipodi:cx="41.785713"
+       sodipodi:cy="133.85715"
+       sodipodi:rx="10.357142"
+       sodipodi:ry="42.857143"
+       d="M 52.142856,133.85715 A 10.357142,42.857143 0 1 1 31.428571,133.85715 A 10.357142,42.857143 0 1 1 52.142856,133.85715 z"
+       transform="matrix(0.563124,0,0,0.5034027,13.172552,-22.150461)" />
+    <path
+       sodipodi:type="arc"
+       style="opacity:1;fill:url(#radialGradient4981);fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:1;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+       id="path4979"
+       sodipodi:cx="41.785713"
+       sodipodi:cy="133.85715"
+       sodipodi:rx="10.357142"
+       sodipodi:ry="42.857143"
+       d="M 52.142856,133.85715 A 10.357142,42.857143 0 1 1 31.428571,133.85715 A 10.357142,42.857143 0 1 1 52.142856,133.85715 z"
+       transform="matrix(0.5905987,0,0,0.503073,81.214123,-24.608367)" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/weather/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/weather/data/misc/icon.svg
--- 3.4.1-6/weather/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/weather/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,551 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   version="1.1"
+   width="48"
+   height="48"
+   id="svg2869"
+   inkscape:version="0.47 r22583"
+   sodipodi:docname="weather-few-clouds.svg"
+   inkscape:export-filename="/opt/cairo-dock_bzr/cairo-dock-plug-ins/weather/data/icon.png"
+   inkscape:export-xdpi="120"
+   inkscape:export-ydpi="120">
+  <metadata
+     id="metadata79">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <dc:title></dc:title>
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <sodipodi:namedview
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1"
+     objecttolerance="10"
+     gridtolerance="10"
+     guidetolerance="10"
+     inkscape:pageopacity="0"
+     inkscape:pageshadow="2"
+     inkscape:window-width="640"
+     inkscape:window-height="491"
+     id="namedview77"
+     showgrid="false"
+     inkscape:zoom="2.4583333"
+     inkscape:cx="-4.4229218"
+     inkscape:cy="22.404696"
+     inkscape:window-x="0"
+     inkscape:window-y="24"
+     inkscape:window-maximized="0"
+     inkscape:current-layer="svg2869" />
+  <defs
+     id="defs2871">
+    <inkscape:perspective
+       sodipodi:type="inkscape:persp3d"
+       inkscape:vp_x="0 : 24 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_z="48 : 24 : 1"
+       inkscape:persp3d-origin="24 : 16 : 1"
+       id="perspective81" />
+    <linearGradient
+       id="linearGradient4031">
+      <stop
+         id="stop4033"
+         style="stop-color:#ffffff;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4035"
+         style="stop-color:#ffffff;stop-opacity:0.07843138"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3673">
+      <stop
+         id="stop3675"
+         style="stop-color:#ffffff;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3677"
+         style="stop-color:#ffffff;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3663">
+      <stop
+         id="stop3665"
+         style="stop-color:#edd563;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3667"
+         style="stop-color:#e08223;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3655">
+      <stop
+         id="stop3657"
+         style="stop-color:#bb5e12;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3659"
+         style="stop-color:#cd8033;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="28.402781"
+       y1="45.487808"
+       x2="21.573414"
+       y2="4.5121903"
+       id="linearGradient3661"
+       xlink:href="#linearGradient3655"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       cx="19.622166"
+       cy="9.3902397"
+       r="20.487812"
+       fx="19.622166"
+       fy="9.3902397"
+       id="radialGradient3669"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.19047887,1.0952379,-1.3678103,0.23787664,28.728624,-14.334419)" />
+    <linearGradient
+       x1="15.817192"
+       y1="1.9041535"
+       x2="32.378464"
+       y2="50.279037"
+       id="linearGradient3679"
+       xlink:href="#linearGradient3673"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="7"
+       y1="23"
+       x2="9"
+       y2="21"
+       id="linearGradient3761"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(1.3241161,1.297204)" />
+    <linearGradient
+       x1="25"
+       y1="31"
+       x2="25"
+       y2="29"
+       id="linearGradient3763"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="41"
+       y1="25"
+       x2="39"
+       y2="22"
+       id="linearGradient3765"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="47"
+       y1="8"
+       x2="44"
+       y2="7"
+       id="linearGradient3767"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="40"
+       y1="-9"
+       x2="38"
+       y2="-7"
+       id="linearGradient3769"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="25"
+       y1="-15"
+       x2="25"
+       y2="-13"
+       id="linearGradient3771"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="8"
+       y1="-9"
+       x2="10"
+       y2="-7"
+       id="linearGradient3773"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="0.5"
+       y1="23"
+       x2="4.5"
+       y2="23"
+       id="linearGradient3775"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="25"
+       y1="-15"
+       x2="25"
+       y2="-13"
+       id="linearGradient3905"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.93920018,0.34337011,-0.34337011,0.93920018,4.2273901,-7.7779686)" />
+    <linearGradient
+       x1="25"
+       y1="31"
+       x2="25"
+       y2="29"
+       id="linearGradient3907"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.93920018,0.34337011,-0.34337011,0.93920018,3.1644691,-8.6994576)" />
+    <linearGradient
+       x1="0.5"
+       y1="23"
+       x2="4.5"
+       y2="23"
+       id="linearGradient3909"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.93920018,0.34337011,-0.34337011,0.93920018,9.7213118,-22.805172)" />
+    <linearGradient
+       x1="47"
+       y1="8"
+       x2="44"
+       y2="7"
+       id="linearGradient3911"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.93920018,0.34337011,-0.34337011,0.93920018,4.2273901,-7.7779686)" />
+    <linearGradient
+       x1="7"
+       y1="23"
+       x2="9"
+       y2="21"
+       id="linearGradient3913"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.93920018,0.34337011,-0.34337011,0.93920018,4.2273901,-7.7779686)" />
+    <linearGradient
+       x1="40"
+       y1="-9"
+       x2="38"
+       y2="-7"
+       id="linearGradient3915"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.93920018,0.34337011,-0.34337011,0.93920018,4.2273901,-7.7779686)" />
+    <linearGradient
+       x1="41"
+       y1="25"
+       x2="39"
+       y2="22"
+       id="linearGradient3917"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.93920018,0.34337011,-0.34337011,0.93920018,4.2273901,-7.7779686)" />
+    <linearGradient
+       x1="8"
+       y1="-9"
+       x2="10"
+       y2="-7"
+       id="linearGradient3919"
+       xlink:href="#linearGradient3663"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(0.93920018,0.34337011,-0.34337011,0.93920018,4.2273901,-7.7779686)" />
+    <linearGradient
+       x1="18.646542"
+       y1="9.3902397"
+       x2="25.47591"
+       y2="23.048779"
+       id="linearGradient4029"
+       xlink:href="#linearGradient4031"
+       gradientUnits="userSpaceOnUse" />
+    <filter
+       x="-0.10434783"
+       y="-0.14117648"
+       width="1.2086957"
+       height="1.2823529"
+       color-interpolation-filters="sRGB"
+       id="filter3198">
+      <feGaussianBlur
+         stdDeviation="1"
+         id="feGaussianBlur3200" />
+    </filter>
+    <radialGradient
+       cx="33.249481"
+       cy="41.297321"
+       r="2.6740477"
+       fx="33.626125"
+       fy="41.297321"
+       id="radialGradient2875"
+       xlink:href="#linearGradient3837"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(3.6594127,-3.0215534e-7,3.0215534e-7,3.6594127,-92.67359,-147.12393)" />
+    <linearGradient
+       id="linearGradient3837">
+      <stop
+         id="stop3839"
+         style="stop-color:#e3e3e2;stop-opacity:0"
+         offset="0" />
+      <stop
+         id="stop3845"
+         style="stop-color:#d4d4d3;stop-opacity:1"
+         offset="0.61194032" />
+      <stop
+         id="stop3841"
+         style="stop-color:#ffffff;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="33.249481"
+       cy="41.297321"
+       r="2.6740477"
+       fx="33.626125"
+       fy="41.297321"
+       id="radialGradient2877"
+       xlink:href="#linearGradient3837"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(3.6594127,-3.0215534e-7,3.0215534e-7,3.6594127,-97.67359,-143.55178)" />
+    <radialGradient
+       cx="33.249481"
+       cy="41.297321"
+       r="2.6740477"
+       fx="33.626125"
+       fy="41.297321"
+       id="radialGradient2879"
+       xlink:href="#linearGradient3837"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(3.6594127,-3.0215534e-7,3.0215534e-7,3.6594127,-99.49194,-139.16634)" />
+    <radialGradient
+       cx="33.249481"
+       cy="41.297321"
+       r="2.6740477"
+       fx="33.626125"
+       fy="41.297321"
+       id="radialGradient2881"
+       xlink:href="#linearGradient3837"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(3.6594127,-3.0215534e-7,3.0215534e-7,3.6594127,-87.726131,-144.08659)" />
+    <radialGradient
+       cx="33.249481"
+       cy="41.297321"
+       r="2.6740477"
+       fx="33.626125"
+       fy="41.297321"
+       id="radialGradient2883"
+       xlink:href="#linearGradient3837"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(4.3443938,-3.5871378e-7,3.5871378e-7,4.3443938,-114.67291,-167.56118)" />
+    <radialGradient
+       cx="33.249481"
+       cy="41.297321"
+       r="2.6740477"
+       fx="33.626125"
+       fy="41.297321"
+       id="radialGradient3010"
+       xlink:href="#linearGradient3837"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(3.6594127,-3.0215534e-7,3.0215534e-7,3.6594127,-85.800816,-139.16634)" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3837"
+       id="radialGradient2887"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(3.6594127,-3.0215534e-7,3.0215534e-7,3.6594127,-92.67359,-147.12393)"
+       cx="33.249481"
+       cy="41.297321"
+       fx="33.626125"
+       fy="41.297321"
+       r="2.6740477" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3837"
+       id="radialGradient2889"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(3.6594127,-3.0215534e-7,3.0215534e-7,3.6594127,-97.67359,-143.55178)"
+       cx="33.249481"
+       cy="41.297321"
+       fx="33.626125"
+       fy="41.297321"
+       r="2.6740477" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3837"
+       id="radialGradient2891"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(3.6594127,-3.0215534e-7,3.0215534e-7,3.6594127,-99.49194,-139.16634)"
+       cx="33.249481"
+       cy="41.297321"
+       fx="33.626125"
+       fy="41.297321"
+       r="2.6740477" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3837"
+       id="radialGradient2893"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(3.6594127,-3.0215534e-7,3.0215534e-7,3.6594127,-87.726131,-144.08659)"
+       cx="33.249481"
+       cy="41.297321"
+       fx="33.626125"
+       fy="41.297321"
+       r="2.6740477" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3837"
+       id="radialGradient2895"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(4.3443938,-3.5871378e-7,3.5871378e-7,4.3443938,-114.67291,-167.56118)"
+       cx="33.249481"
+       cy="41.297321"
+       fx="33.626125"
+       fy="41.297321"
+       r="2.6740477" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient3837"
+       id="radialGradient2897"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(3.6594127,-3.0215534e-7,3.0215534e-7,3.6594127,-85.800816,-139.16634)"
+       cx="33.249481"
+       cy="41.297321"
+       fx="33.626125"
+       fy="41.297321"
+       r="2.6740477" />
+  </defs>
+  <g
+     transform="translate(0,16)"
+     id="layer1">
+    <path
+       d="m 32.857947,-13.281718 c 0.595829,1.28257 -1.625941,1.53503 -1.030111,2.8176"
+       id="path3889"
+       style="fill:none;stroke:url(#linearGradient3905);stroke-width:1px;stroke-linecap:round;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M 17.03011,26.1824 C 17.62594,27.46497 15.404169,27.71743 16,29"
+       id="path3891"
+       style="fill:none;stroke:url(#linearGradient3907);stroke-width:1px;stroke-linecap:round;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M 2.7629994,-0.86019722 C 4.0455698,-1.4560273 4.2980297,0.76574314 5.5806,0.16991314"
+       id="path3893"
+       style="fill:none;stroke:url(#linearGradient3909);stroke-width:1px;stroke-linecap:round;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 43.148607,13.904718 c 1.28257,-0.59583 1.53503,1.62594 2.8176,1.030109"
+       id="path3895"
+       style="fill:none;stroke:url(#linearGradient3911);stroke-width:1px;stroke-linecap:round;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 2.3585497,16.776001 c 0.4855988,-1.328231 2.2351438,0.06428 2.7207426,-1.263947"
+       id="path3897"
+       style="fill:none;stroke:url(#linearGradient3913);stroke-width:1px;stroke-linecap:round;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 42.320587,-1.3043056 c 0.4856,-1.3282297 2.235145,0.064283 2.720744,-1.2639462"
+       id="path3899"
+       style="fill:none;stroke:url(#linearGradient3915);stroke-width:1px;stroke-linecap:round;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 33.229769,26.120267 c 1.328229,0.485599 -0.06428,2.235145 1.263946,2.720743"
+       id="path3901"
+       style="fill:none;stroke:url(#linearGradient3917);stroke-width:1px;stroke-linecap:round;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 14.831322,-13.483809 c 1.328231,0.485598 -0.06428,2.235143 1.263947,2.720742"
+       id="path3903"
+       style="fill:none;stroke:url(#linearGradient3919);stroke-width:1px;stroke-linecap:round;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 25,-15 c 1,1 -1,2 0,3"
+       id="path3691"
+       style="fill:none;stroke:url(#linearGradient3771);stroke-width:1px;stroke-linecap:round;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 25,28 c 1,1 -1,2 0,3"
+       id="path3689"
+       style="fill:none;stroke:url(#linearGradient3763);stroke-width:1px;stroke-linecap:round;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 1,23 c 1,-1 2,1 3,0"
+       transform="translate(0,-16)"
+       id="path3681"
+       style="fill:none;stroke:url(#linearGradient3775);stroke-width:1px;stroke-linecap:round;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 44,7 c 1,-1 2,1 3,0"
+       id="path3683"
+       style="fill:none;stroke:url(#linearGradient3767);stroke-width:1px;stroke-linecap:round;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 8,25 c 0,-1.414214 2.12132,-0.707107 2.12132,-2.121321"
+       id="path3731"
+       style="fill:none;stroke:url(#linearGradient3761);stroke-width:1px;stroke-linecap:round;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 38,-7 c 0,-1.4142136 2.121321,-0.7071068 2.121321,-2.1213203"
+       id="path3733"
+       style="fill:none;stroke:url(#linearGradient3769);stroke-width:1px;stroke-linecap:round;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M 38.87868,21.878679 C 40.292894,21.878679 39.585787,24 41,24"
+       id="path3735"
+       style="fill:none;stroke:url(#linearGradient3765);stroke-width:1px;stroke-linecap:round;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="m 8,-9 c 1.4142138,0 0.7071068,2.1213204 2.121321,2.1213204"
+       id="path3737"
+       style="fill:none;stroke:url(#linearGradient3773);stroke-width:1px;stroke-linecap:round;stroke-linejoin:miter;stroke-opacity:1" />
+    <path
+       d="M 43.465843,25 A 18.965843,18.965843 0 1 1 5.5341568,25 18.965843,18.965843 0 1 1 43.465843,25 z"
+       transform="matrix(1.0281622,0,0,1.0281622,-1.189973,-17.704056)"
+       id="path2881"
+       style="fill:url(#radialGradient3669);fill-opacity:1;stroke:url(#linearGradient3661);stroke-width:0.97268277;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:10;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+    <path
+       d="M 42.462036,25 A 17.962036,17.962036 0 1 1 6.5379639,25 17.962036,17.962036 0 1 1 42.462036,25 z"
+       transform="matrix(1.0249852,0,0,1.0249998,-1.11243,-17.624994)"
+       id="path3671"
+       style="opacity:0.3;fill:none;stroke:url(#linearGradient3679);stroke-width:0.97562361;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:10;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+    <path
+       d="M 6.9817666,26.224026 A 17.560944,17.560944 0 0 1 39.584567,16.00875"
+       transform="matrix(1.0249852,0,0,1.0249998,-1.11243,-17.624994)"
+       id="path4021"
+       style="opacity:0.23999999;fill:url(#linearGradient4029);fill-opacity:1;stroke:none" />
+  </g>
+  <g
+     transform="translate(9.2220339,32.245797)"
+     id="g2857">
+    <path
+       d="m 25,-3.5 c -2.205281,0 -4.021902,1.59276 -4.40625,3.6875 C 20.397412,0.1613 20.203469,0.125 20,0.125 c -2.484,0 -4.5,2.016 -4.5,4.5 0,0.22466 0.03066,0.4404 0.0625,0.65625 C 14.322611,6.07248 13.5,7.44523 13.5,9.03125 13.5,11.50382 15.496176,13.5 17.96875,13.5 l 14.0625,0 C 34.503823,13.5 36.5,11.50382 36.5,9.03125 36.5,7.39462 35.619257,5.99553 34.3125,5.21875 34.423086,4.8284 34.5,4.42562 34.5,4 c 0,-2.484 -2.016,-4.5 -4.5,-4.5 -0.256436,0 -0.505242,0.02123 -0.75,0.0625 C 28.647216,-2.21269 26.978116,-3.5 25,-3.5 z"
+       id="path2859"
+       style="opacity:0.3;fill:none;stroke:#000000;stroke-opacity:1;filter:url(#filter3198)" />
+    <path
+       d="m 25,-4.5 c -2.205281,0 -4.021902,1.592762 -4.40625,3.6875 C 20.397412,-0.8387 20.203469,-0.875 20,-0.875 c -2.484,0 -4.5,2.016 -4.5,4.5 0,0.224656 0.03066,0.440395 0.0625,0.65625 C 14.322611,5.072478 13.5,6.445234 13.5,8.03125 13.5,10.503823 15.496176,12.5 17.96875,12.5 l 14.0625,0 C 34.503823,12.5 36.5,10.503822 36.5,8.03125 36.5,6.394622 35.619257,4.995526 34.3125,4.21875 34.423086,3.828401 34.5,3.425616 34.5,3 c 0,-2.484 -2.016,-4.500001 -4.5,-4.5 -0.256436,0 -0.505242,0.02123 -0.75,0.0625 C 28.647216,-3.212686 26.978116,-4.500001 25,-4.5 z"
+       id="path2861"
+       style="fill:#e3e3e2;fill-opacity:1;stroke:#b4b5b3;stroke-width:0.99999988;stroke-linecap:square;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none" />
+    <path
+       d="m 29,3e-6 c 0,2.209139 -1.790861,4 -4,4 -2.20914,0 -4.000001,-1.790861 -4.000001,-4 0,-2.20914 1.790861,-4.000001 4.000001,-4.000001 2.209139,0 4,1.790861 4,4.000001 z"
+       id="path2863"
+       style="fill:url(#radialGradient2887);fill-opacity:1;stroke:none" />
+    <path
+       d="m 24,3.572153 c 0,2.209139 -1.790861,4 -4,4 -2.20914,0 -4.000001,-1.790861 -4.000001,-4 0,-2.20914 1.790861,-4.000001 4.000001,-4.000001 2.209139,0 4,1.790861 4,4.000001 z"
+       id="path2865"
+       style="fill:url(#radialGradient2889);fill-opacity:1;stroke:none" />
+    <path
+       d="m 22.181648,7.957593 c 0,2.209139 -1.790861,4 -4,4 -2.20914,0 -4.000001,-1.790861 -4.000001,-4 0,-2.20914 1.790861,-4.000001 4.000001,-4.000001 2.209139,0 4,1.790861 4,4.000001 z"
+       id="path2867"
+       style="fill:url(#radialGradient2891);fill-opacity:1;stroke:none" />
+    <path
+       d="m 33.947457,3.037343 c 0,2.209139 -1.790861,4 -4,4 -2.20914,0 -4.000001,-1.790861 -4.000001,-4 0,-2.20914 1.790861,-4.000001 4.000001,-4.000001 2.209139,0 4,1.790861 4,4.000001 z"
+       id="path2869"
+       style="fill:url(#radialGradient2893);fill-opacity:1;stroke:none" />
+    <path
+       d="m 29.775943,7.1019 c 0,2.622654 -2.12608,4.748734 -4.748734,4.748734 -2.622653,0 -4.748734,-2.12608 -4.748734,-4.748734 0,-2.622653 2.126081,-4.748734 4.748734,-4.748734 2.622654,0 4.748734,2.126081 4.748734,4.748734 z"
+       id="path2871"
+       style="fill:url(#radialGradient2895);fill-opacity:1;stroke:none" />
+    <path
+       d="m 35.872772,7.957593 c 0,2.209139 -1.790861,4 -4,4 -2.20914,0 -4.000001,-1.790861 -4.000001,-4 0,-2.20914 1.790861,-4.000001 4.000001,-4.000001 2.209139,0 4,1.790861 4,4.000001 z"
+       id="path2873"
+       style="fill:url(#radialGradient2897);fill-opacity:1;stroke:none" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/weather/data/weather.conf.in 3.4.1+git20201022.a0d3415c-1/weather/data/weather.conf.in
--- 3.4.1-6/weather/data/weather.conf.in	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/weather/data/weather.conf.in	2020-10-21 15:04:44.000000000 +0000
@@ -118,21 +118,14 @@ IS units = true
 #{in seconds. Set 0 to have never-ending dialogs.}
 dialog duration = 7
 
-#i[5;60] Refresh time:
-#{In minutes.}
-check interval = 15
-
 #F[Info;dialog-information]
 frame_info =
 
 #b+ Display current conditions on the icon instead of the default one?
 display cc = true
 
-#i[0;5] Number of days to forecast:
-nb days = 5
-
-#b Display nights?
-display nights = false
+#i[0;8] Number of days to forecast:
+nb days = 6
 
 #b Display temperature as quick info?
 display temperature = true
diff -pruN 3.4.1-6/weather/src/applet-config.c 3.4.1+git20201022.a0d3415c-1/weather/src/applet-config.c
--- 3.4.1-6/weather/src/applet-config.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/weather/src/applet-config.c	2020-10-21 15:04:44.000000000 +0000
@@ -31,11 +31,9 @@ CD_APPLET_GET_CONFIG_BEGIN
 	myConfig.cLocationCode = CD_CONFIG_GET_STRING_WITH_DEFAULT ("Configuration", "location code", "FRXX0076");
 	myConfig.bISUnits = CD_CONFIG_GET_BOOLEAN_WITH_DEFAULT ("Configuration", "IS units", TRUE);
 	myConfig.bCurrentConditions = CD_CONFIG_GET_BOOLEAN_WITH_DEFAULT ("Configuration", "display cc", TRUE);
-	myConfig.bDisplayNights = CD_CONFIG_GET_BOOLEAN_WITH_DEFAULT ("Configuration", "display nights", FALSE);
 	myConfig.iNbDays = MIN (CD_CONFIG_GET_INTEGER_WITH_DEFAULT ("Configuration", "nb days", WEATHER_NB_DAYS_MAX), WEATHER_NB_DAYS_MAX);
 	myConfig.bDisplayTemperature = CD_CONFIG_GET_BOOLEAN_WITH_DEFAULT ("Configuration", "display temperature", TRUE);
 	myConfig.cDialogDuration = 1000 * CD_CONFIG_GET_INTEGER_WITH_DEFAULT ("Configuration", "dialog duration", 7);
-	myConfig.iCheckInterval = 60 * MAX (CD_CONFIG_GET_INTEGER_WITH_DEFAULT ("Configuration", "check interval", 15), 1);
 	
 	myConfig.cThemePath = CD_CONFIG_GET_THEME_PATH ("Configuration", "theme", "themes", "Classic");
 	
@@ -78,6 +76,7 @@ CD_APPLET_RESET_DATA_END
   /////////////////////
  /// CUSTOM WIDGET ///
 /////////////////////
+#ifdef CD_WEATHER_HAS_CODE_LOCATION
 void cd_weather_free_location_list (void)
 {
 	if (s_pLocationsList == NULL)
@@ -162,19 +161,17 @@ static void _on_got_location_data (const
 		
 		gtk_widget_show_all (pMenu);
 
-		gtk_menu_popup (GTK_MENU (pMenu),
-			NULL,
-			NULL,
-			NULL,
-			NULL,
-			1,
-			gtk_get_current_event_time ());
+		gtk_menu_popup_at_widget (GTK_MENU (pMenu),
+			pCodeEntry,
+			GDK_GRAVITY_SOUTH,
+			GDK_GRAVITY_NORTH,
+			NULL);
 	}
 	
 	gldi_task_discard (myData.pGetLocationTask);
 	myData.pGetLocationTask = NULL;
 }
-#define CD_WEATHER_BASE_URL "http://xml.weather.com"
+
 static void _cd_weather_search_for_location (GtkEntry *pEntry, GldiModuleInstance *myApplet)
 {
 	const gchar *cLocationName = gtk_entry_get_text (pEntry);
@@ -215,8 +212,9 @@ void cd_weather_load_custom_widget (Gldi
 	
 	GtkWidget *pLocationEntry = gtk_entry_new ();
 	gtk_widget_set_tooltip_text (pLocationEntry, D_("Enter the name of your location and press Enter to choose amongst results."));
-	if (myData.wdata.cLocation != NULL)
-		gtk_entry_set_text (GTK_ENTRY (pLocationEntry), (gchar *)myData.wdata.cLocation);
+	if (myData.wdata.cCity != NULL && myData.wdata.cCountry != NULL)
+		gtk_entry_set_text (GTK_ENTRY (pLocationEntry), g_strdup_printf("%s, %s", myData.wdata.cCity, myData.wdata.cCountry));
 	gtk_box_pack_start (GTK_BOX (pWidgetBox), pLocationEntry, FALSE, FALSE, 0);
 	g_signal_connect (pLocationEntry, "activate", G_CALLBACK (_cd_weather_search_for_location), myApplet);
 }
+#endif
diff -pruN 3.4.1-6/weather/src/applet-init.c 3.4.1+git20201022.a0d3415c-1/weather/src/applet-init.c
--- 3.4.1-6/weather/src/applet-init.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/weather/src/applet-init.c	2020-10-21 15:04:44.000000000 +0000
@@ -30,13 +30,15 @@ CD_APPLET_DEFINE_BEGIN (N_("weather"),
 	2, 0, 0,
 	CAIRO_DOCK_CATEGORY_APPLET_ACCESSORY,
 	N_("This applet displays weather into your dock.\n"
-	"Data are provided by www.weather.com, you can find your location in the config panel.\n"
+	"Data are provided by yahoo.com, you can find your location in the config panel.\n"
 	"It can detach itself to be a totally eye-candy 3D deskelt.\n"
 	"Middle-click on the main icon to have current conditions information, left-click on a sub-icon to have forcast information.\n"),
 	"Fabounet (Fabrice Rey)")
 	CD_APPLET_DEFINE_COMMON_APPLET_INTERFACE
 	CD_APPLET_ALLOW_EMPTY_TITLE
+	#ifdef CD_WEATHER_HAS_CODE_LOCATION
 	pInterface->load_custom_widget = cd_weather_load_custom_widget;
+	#endif
 CD_APPLET_DEFINE_END
 
 
@@ -49,6 +51,7 @@ CD_APPLET_INIT_BEGIN
 	CD_APPLET_REGISTER_FOR_DOUBLE_CLICK_EVENT;
 	CD_APPLET_REGISTER_FOR_MIDDLE_CLICK_EVENT;
 	CD_APPLET_REGISTER_FOR_BUILD_MENU_EVENT;
+
 CD_APPLET_INIT_END
 
 
diff -pruN 3.4.1-6/weather/src/applet-load-icons.c 3.4.1+git20201022.a0d3415c-1/weather/src/applet-load-icons.c
--- 3.4.1-6/weather/src/applet-load-icons.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/weather/src/applet-load-icons.c	2020-10-21 15:04:44.000000000 +0000
@@ -29,14 +29,14 @@ const char *cMonthsWeeks[19] = { N_("Mon
 	if (myData.wdata.days[i].cName != NULL)\
 	{\
 		pIcon = cairo_dock_create_dummy_launcher (g_strdup ((gchar *)myData.wdata.days[i].cName),\
-			g_strdup_printf ("%s/%s.png", myConfig.cThemePath, myData.wdata.days[i].part[j].cIconNumber),\
+			g_strdup_printf ("%s/%s.png", myConfig.cThemePath, myData.wdata.days[i].cIconNumber),\
 			NULL,\
 			(myConfig.bDisplayTemperature ? g_strdup_printf ("%s/%s", _display (myData.wdata.days[i].cTempMin), _display (myData.wdata.days[i].cTempMax)) : NULL),\
 			2*i+j);\
 		if (! g_file_test (pIcon->cFileName, G_FILE_TEST_EXISTS))\
 		{\
 			g_free (pIcon->cFileName);\
-			pIcon->cFileName = g_strdup_printf ("%s/%s.svg", myConfig.cThemePath, myData.wdata.days[i].part[j].cIconNumber);\
+			pIcon->cFileName = g_strdup_printf ("%s/%s.svg", myConfig.cThemePath, myData.wdata.days[i].cIconNumber);\
 		}\
 		cairo_dock_listen_for_double_click (pIcon);\
 		pIconList = g_list_append (pIconList, pIcon);\
@@ -51,11 +51,6 @@ static GList * _list_icons (GldiModuleIn
 	for (i = 0; i < myConfig.iNbDays; i ++)
 	{
 		_add_icon (i, 0);
-		
-		if (myConfig.bDisplayNights)
-		{
-			_add_icon (i, 1);
-		}
 	}
 	
 	return pIconList;
@@ -67,9 +62,9 @@ static void _weather_draw_current_condit
 	if (myConfig.bCurrentConditions || myData.bErrorRetrievingData)
 	{
 		cd_message ("  chargement de l'icone meteo (%x)", myApplet);
-		if (myConfig.bDisplayTemperature && myData.wdata.currentConditions.cTemp != NULL)
+		if (myConfig.bDisplayTemperature && myData.wdata.currentConditions.now.cTempMax != NULL)
 		{
-			CD_APPLET_SET_QUICK_INFO_ON_MY_ICON_PRINTF ("%s%s", myData.wdata.currentConditions.cTemp, myData.wdata.units.cTemp);
+			CD_APPLET_SET_QUICK_INFO_ON_MY_ICON_PRINTF ("%s%s", myData.wdata.currentConditions.now.cTempMax, myData.wdata.units.cTemp);
 		}
 		else
 		{
@@ -93,11 +88,11 @@ static void _weather_draw_current_condit
 		}
 		else
 		{
-			myIcon->cFileName = g_strdup_printf ("%s/%s.png", myConfig.cThemePath, myData.wdata.currentConditions.cIconNumber);
+			myIcon->cFileName = g_strdup_printf ("%s/%s.png", myConfig.cThemePath, myData.wdata.currentConditions.now.cIconNumber);
 			if (! g_file_test (myIcon->cFileName, G_FILE_TEST_EXISTS))
 			{
 				g_free (myIcon->cFileName);
-				myIcon->cFileName = g_strdup_printf ("%s/%s.svg", myConfig.cThemePath, myData.wdata.currentConditions.cIconNumber);
+				myIcon->cFileName = g_strdup_printf ("%s/%s.svg", myConfig.cThemePath, myData.wdata.currentConditions.now.cIconNumber);
 			}
 		}
 		CD_APPLET_SET_IMAGE_ON_MY_ICON (myIcon->cFileName);
@@ -159,8 +154,10 @@ gboolean cd_weather_update_from_data (CD
 	//\_______________________ On etablit le nom de l'icone.
 	if ((myIcon->cName == NULL || myData.bSetName) && myDock)
 	{
-		myData.bSetName = (myData.wdata.cLocation == NULL);  // cas ou l'applet demarre avant l'etablissesment de la connexion.
-		CD_APPLET_SET_NAME_FOR_MY_ICON (myData.wdata.cLocation != NULL ? (const gchar*)myData.wdata.cLocation : WEATHER_DEFAULT_NAME);
+		myData.bSetName = (myData.wdata.cCity == NULL);  // cas ou l'applet demarre avant l'etablissesment de la connexion.
+		gchar *cLocation = g_strdup_printf("%s, %s", myData.wdata.cCity, myData.wdata.cCountry);
+		CD_APPLET_SET_NAME_FOR_MY_ICON (myData.wdata.cCity != NULL ? cLocation : WEATHER_DEFAULT_NAME);
+		g_free (cLocation);
 	}
 	
 	//\_______________________ On cree la liste des icones de prevision.
@@ -175,7 +172,7 @@ gboolean cd_weather_update_from_data (CD
 		///gpointer pConfig[2] = {GINT_TO_POINTER (myConfig.bDesklet3D), GINT_TO_POINTER (FALSE)};
 		///CD_APPLET_LOAD_MY_ICONS_LIST (pIconList, myConfig.cRenderer, "Caroussel", pConfig);
 		gdouble white[4] = {1., 1., 1., .4};
-		gpointer pConfig[3] = {GINT_TO_POINTER (myConfig.bDisplayNights ? 2 : 1), GINT_TO_POINTER (FALSE), white};
+		gpointer pConfig[3] = {GINT_TO_POINTER (1), GINT_TO_POINTER (FALSE), white};
 		CD_APPLET_LOAD_MY_ICONS_LIST (pIconList, myConfig.cRenderer, "Panel", pConfig);
 	}
 	else if (myDock)  // sinon on ne veut pas du sous-dock vide.
@@ -190,11 +187,10 @@ gboolean cd_weather_update_from_data (CD
 	_weather_draw_current_conditions (myApplet);  // ne lance pas le redraw.
 	CD_APPLET_REDRAW_MY_ICON;
 	
-	if (myData.pTask->iPeriod != myConfig.iCheckInterval)
-	{
-		cd_message ("revert to normal frequency");
-		gldi_task_change_frequency (myData.pTask, myConfig.iCheckInterval);
-	}
+	if (myData.wdata.currentConditions.ttl <= 0)
+		myData.wdata.currentConditions.ttl = 60;  // 1h by default
+	cd_message ("next fetching in %dmn", myData.wdata.currentConditions.ttl);
+	gldi_task_change_frequency (myData.pTask, myData.wdata.currentConditions.ttl * 60);
 	
 	CD_APPLET_LEAVE (TRUE);
 }
diff -pruN 3.4.1-6/weather/src/applet-notifications.c 3.4.1+git20201022.a0d3415c-1/weather/src/applet-notifications.c
--- 3.4.1-6/weather/src/applet-notifications.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/weather/src/applet-notifications.c	2020-10-21 15:04:44.000000000 +0000
@@ -45,17 +45,20 @@ static int _get_num_day_from_icon (GldiM
 }
 static inline void _go_to_site (GldiModuleInstance *myApplet, int iNumDay)
 {
-	gchar *cURI;
-	if (iNumDay == -1)
-		cURI = g_strdup_printf ("http://www.weather.com/weather/hourbyhour/graph/%s", myConfig.cLocationCode);
-	else if (iNumDay == 0)
-		cURI = g_strdup_printf ("http://www.weather.com/weather/today/%s", myConfig.cLocationCode);
-	else if (iNumDay == 1)
-		cURI = g_strdup_printf ("http://www.weather.com/weather/tomorrow/%s", myConfig.cLocationCode);
-	else
-		cURI = g_strdup_printf ("http://www.weather.com/weather/wxdetail%d/%s", iNumDay, myConfig.cLocationCode);  // ?dayNum=%d
-	cairo_dock_fm_launch_uri (cURI);
-	g_free (cURI);
+	//~ gchar *cURI;
+	//~ if (iNumDay == -1)
+		//~ cURI = g_strdup_printf ("http://www.weather.com/weather/hourbyhour/graph/%s", myConfig.cLocationCode);
+	//~ else if (iNumDay == 0)
+		//~ cURI = g_strdup_printf ("http://www.weather.com/weather/today/%s", myConfig.cLocationCode);
+	//~ else if (iNumDay == 1)
+		//~ cURI = g_strdup_printf ("http://www.weather.com/weather/tomorrow/%s", myConfig.cLocationCode);
+	//~ else
+		//~ cURI = g_strdup_printf ("http://www.weather.com/weather/wxdetail%d/%s", iNumDay, myConfig.cLocationCode);  // ?dayNum=%d
+	//~ cairo_dock_fm_launch_uri (cURI);
+	//~ g_free (cURI);
+	g_print("url: %s\n", myData.wdata.cLink);
+	if (myData.wdata.cLink != NULL)
+		cairo_dock_fm_launch_uri ((const gchar *)myData.wdata.cLink);
 }
 
 static inline void _reload (GldiModuleInstance *myApplet)
@@ -139,7 +142,7 @@ void cd_weather_show_forecast_dialog (Gl
 		gldi_dialogs_remove_on_icon (myIcon);
 	
 	// if we never got any result, show an error message. If we lost the connection, but could get some data beforehand, we'll just present the old data, since they are not likely to change very often.
-	if (myData.wdata.cLocation == NULL)
+	if (myData.wdata.cCity == NULL)
 	{
 		gldi_dialog_show_temporary_with_icon (D_("No data available\n is your connection alive?"), 
 			(myDock ? pIcon : myIcon),
@@ -150,22 +153,17 @@ void cd_weather_show_forecast_dialog (Gl
 	}
 	
 	// present the day's forecast.
-	int iNumDay = ((int) pIcon->fOrder) / 2, iPart = ((int) pIcon->fOrder) - 2 * iNumDay;
-	g_return_if_fail (iNumDay < myConfig.iNbDays && iPart < 2);
+	int iNumDay = ((int) pIcon->fOrder) / 2;
+	g_return_if_fail (iNumDay < myConfig.iNbDays);
 	
 	Day *day = &myData.wdata.days[iNumDay];
-	DayPart *part = &day->part[iPart];
-	gldi_dialog_show_temporary_with_icon_printf ("%s (%s) : %s\n %s : %s%s -> %s%s\n %s : %s%%\n %s : %s%s (%s)\n %s : %s%%\n %s : %s  %s %s",
+	gldi_dialog_show_temporary_with_icon_printf ("%s (%s) : %s\n %s : %s%s -> %s%s",
 		(myDock ? pIcon : myIcon),
 		(myDock ? CAIRO_CONTAINER (myIcon->pSubDock) : myContainer),
 		myConfig.cDialogDuration,
 		"same icon",
-		day->cName, day->cDate, part->cWeatherDescription,
-		D_("Temperature"), _display (day->cTempMin), myData.wdata.units.cTemp, _display (day->cTempMax), myData.wdata.units.cTemp,
-		D_("Precipitation probability"), _display (part->cPrecipitationProba),
-		D_("Wind"), _display (part->cWindSpeed), myData.wdata.units.cSpeed, _display (part->cWindDirection),
-		D_("Humidity"), _display (part->cHumidity),
-		D_("Sunrise"), _display (day->cSunRise), D_("Sunset"), _display (day->cSunSet));
+		day->cName, day->cDate, day->cWeatherDescription,
+		D_("Temperature"), _display (day->cTempMin), myData.wdata.units.cTemp, _display (day->cTempMax), myData.wdata.units.cTemp);
 }
 
 void cd_weather_show_current_conditions_dialog (GldiModuleInstance *myApplet)
@@ -196,11 +194,11 @@ void cd_weather_show_current_conditions_
 	
 	// show a dialog with the current conditions.
 	CurrentContitions *cc = &myData.wdata.currentConditions;
-	gldi_dialog_show_temporary_with_icon_printf ("%s (%s, %s)\n %s : %s%s (%s : %s%s)\n %s : %s%s (%s)\n %s : %s - %s : %s%s\n %s : %s  %s %s",
+	gldi_dialog_show_temporary_with_icon_printf ("%s:\n %s : %s%s\n %s : %s%s\n %s : %s - %s : %s%s\n %s : %s  %s %s",
 		myIcon, myContainer, myConfig.cDialogDuration, myIcon->cFileName,
-		cc->cWeatherDescription, cc->cDataAcquisitionDate, cc->cObservatory,
-		D_("Temperature"), _display (cc->cTemp), myData.wdata.units.cTemp, D_("Feels like"), _display (cc->cFeltTemp), myData.wdata.units.cTemp,
-		D_("Wind"), _display (cc->cWindSpeed), myData.wdata.units.cSpeed, _display (cc->cWindDirection),
-		D_("Humidity"), _display (cc->cHumidity), D_("Pressure"), _display (cc->cPressure), myData.wdata.units.cPressure,  // unite ?...
+		cc->cDataAcquisitionDate,
+		D_("Temperature"), _display (cc->now.cTempMax), myData.wdata.units.cTemp,
+		D_("Wind"), _display (cc->cWindSpeed), myData.wdata.units.cSpeed,
+		D_("Humidity"), _display (cc->cHumidity), D_("Pressure"), _display (cc->cPressure), myData.wdata.units.cPressure,
 		D_("Sunrise"), _display (cc->cSunRise), D_("Sunset"), _display (cc->cSunSet));
 }
diff -pruN 3.4.1-6/weather/src/applet-read-data.c 3.4.1+git20201022.a0d3415c-1/weather/src/applet-read-data.c
--- 3.4.1-6/weather/src/applet-read-data.c	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/weather/src/applet-read-data.c	2020-10-21 15:04:44.000000000 +0000
@@ -17,10 +17,10 @@
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#define _BSD_SOURCE
 #include <string.h>
 #include <stdio.h>
 #include <unistd.h>
+#include <stdlib.h>  // rand
 
 #include <libxml/tree.h>
 #include <libxml/parser.h>
@@ -30,8 +30,13 @@
 #include "applet-load-icons.h"
 #include "applet-read-data.h"
 
-#define CD_WEATHER_BASE_URL "http://xml.weather.com"
+// Credentials used by Cairo-Dock for Yahoo weather
+// please do not use them for any other purpose than this applet
+#define APP_ID "kv8SljKW"
+#define CLIENT_ID "dj0yJmk9N3d2dVZVUHIxWVVpJnM9Y29uc3VtZXJzZWNyZXQmc3Y9MCZ4PWM0"
+#define CLIENT_SECRET "'2c776c9ee22643fec:59g53568d92142f97ec12e'"
 
+static gchar *_get_oauth_header (const gchar *cLocationName, gboolean bISUnits);
 
 static xmlDocPtr _cd_weather_open_xml_buffer (const gchar *cData, xmlNodePtr *root_node, const gchar *cRootNodeName, GError **erreur)
 {
@@ -62,7 +67,7 @@ static xmlDocPtr _cd_weather_open_xml_bu
 	xmlNodePtr noeud = xmlDocGetRootElement (doc);
 	if (noeud == NULL || xmlStrcmp (noeud->name, BAD_CAST cRootNodeName) != 0)
 	{
-		g_set_error (erreur, 1, 2, "xml data is not well formed (weather.com may have changed its data format)");
+		g_set_error (erreur, 1, 2, "xml data is not well formed (yahoo.com may have changed its data format)");
 		return doc;
 	}
 	*root_node = noeud;
@@ -120,7 +125,7 @@ static void _cd_weather_parse_data (CDSh
 {
 	GError *tmp_erreur = NULL;
 	xmlNodePtr noeud = NULL;
-	xmlDocPtr doc = _cd_weather_open_xml_buffer (cData, &noeud, "weather", &tmp_erreur);
+	xmlDocPtr doc = _cd_weather_open_xml_buffer (cData, &noeud, "rss", &tmp_erreur);
 	if (tmp_erreur != NULL)
 	{
 		g_propagate_error (erreur, tmp_erreur);
@@ -128,242 +133,146 @@ static void _cd_weather_parse_data (CDSh
 		return ;
 	}
 	
-	xmlNodePtr param, fils, petitfils, arrpetitfils, arrarrpetitfils;
-	int i, j;
-	gchar *index_str, *cDayName, *cDate, *str;
-	for (param = noeud->xmlChildrenNode; param != NULL; param = param->next)
+	xmlNodePtr rss_child, channel_child, item_child;
+	int i=0;  // day counter
+	for (rss_child = noeud->xmlChildrenNode; rss_child != NULL; rss_child = rss_child->next)
 	{
-		if (bParseHeader && xmlStrcmp (param->name, BAD_CAST "head") == 0)
+		if (xmlStrcmp (rss_child->name, BAD_CAST "channel") == 0)
 		{
-			for (fils = param->children; fils != NULL; fils = fils->next)
+			for (channel_child = rss_child->children; channel_child != NULL; channel_child = channel_child->next)
 			{
-				if (xmlStrcmp (fils->name, BAD_CAST "ut") == 0)
+				if (xmlStrcmp (channel_child->name, BAD_CAST "units") == 0)
 				{
-					xmlChar *degree = xmlNodeGetContent (fils);
-					if (degree == NULL || strncmp ((gchar *)degree, "°", strlen ("°")) != 0)  // prepend  if not present.
-					{
-						pSharedMemory->wdata.units.cTemp = BAD_CAST g_strconcat ("°", (gchar *)degree, NULL);
-						g_free (degree);
-					}
-					else
-						pSharedMemory->wdata.units.cTemp = degree;
+					pSharedMemory->wdata.units.cTemp = xmlGetProp (channel_child, BAD_CAST "temperature");
+					pSharedMemory->wdata.units.cSpeed = xmlGetProp (channel_child, BAD_CAST "speed");
+					pSharedMemory->wdata.units.cPressure = xmlGetProp (channel_child, BAD_CAST "pressure");
 				}
-				else if (xmlStrcmp (fils->name, BAD_CAST "ud") == 0)
-					pSharedMemory->wdata.units.cDistance = xmlNodeGetContent (fils);
-				else if (xmlStrcmp (fils->name, BAD_CAST "us") == 0)
-					pSharedMemory->wdata.units.cSpeed = xmlNodeGetContent (fils);
-				else if (xmlStrcmp (fils->name, BAD_CAST "up") == 0)
-					pSharedMemory->wdata.units.cPressure = xmlNodeGetContent (fils);
-				//else if (xmlStrcmp (fils->name, BAD_CAST "ur") == 0)  // ?
-				//	pSharedMemory->wdata.units.cR = xmlNodeGetContent (fils);
-			}
-		}
-		else if (bParseHeader && xmlStrcmp (param->name, BAD_CAST "loc") == 0)
-		{
-			for (fils = param->children; fils != NULL; fils = fils->next)
-			{
-				if (xmlStrcmp (fils->name, BAD_CAST "dnam") == 0)
-					pSharedMemory->wdata.cLocation = xmlNodeGetContent (fils);
-				/**else if (xmlStrcmp (fils->name, BAD_CAST "lat") == 0)
-					pSharedMemory->cLat = xmlNodeGetContent (fils);
-				else if (xmlStrcmp (fils->name, BAD_CAST "lon") == 0)
-					pSharedMemory->cLon = xmlNodeGetContent (fils);*/
-				else if (xmlStrcmp (fils->name, BAD_CAST "sunr") == 0)
-					pSharedMemory->wdata.currentConditions.cSunRise = xmlNodeGetContent (fils);
-				else if (xmlStrcmp (fils->name, BAD_CAST "suns") == 0)
-					pSharedMemory->wdata.currentConditions.cSunSet = xmlNodeGetContent (fils);
-			}
-		}
-		else if (xmlStrcmp (param->name, BAD_CAST "cc") == 0)
-		{
-			for (fils = param->children; fils != NULL; fils = fils->next)
-			{
-				if (xmlStrcmp (fils->name, BAD_CAST "lsup") == 0)
-					pSharedMemory->wdata.currentConditions.cDataAcquisitionDate = xmlNodeGetContent (fils);
-				else if (xmlStrcmp (fils->name, BAD_CAST "obst") == 0)
-					pSharedMemory->wdata.currentConditions.cObservatory = xmlNodeGetContent (fils);
-				else if (xmlStrcmp (fils->name, BAD_CAST "tmp") == 0)
-					pSharedMemory->wdata.currentConditions.cTemp = xmlNodeGetContent (fils);
-				else if (xmlStrcmp (fils->name, BAD_CAST "flik") == 0)
-					pSharedMemory->wdata.currentConditions.cFeltTemp = xmlNodeGetContent (fils);
-				else if (xmlStrcmp (fils->name, BAD_CAST "t") == 0)
-					pSharedMemory->wdata.currentConditions.cWeatherDescription = xmlNodeGetContent (fils);
-				else if (xmlStrcmp (fils->name, BAD_CAST "icon") == 0)
-					pSharedMemory->wdata.currentConditions.cIconNumber = xmlNodeGetContent (fils);
-				else if (xmlStrcmp (fils->name, BAD_CAST "wind") == 0)
+				else if (xmlStrcmp (channel_child->name, BAD_CAST "link") == 0)
 				{
-					for (petitfils = fils->children; petitfils != NULL; petitfils = petitfils->next)
-					{
-						if (xmlStrcmp (petitfils->name, BAD_CAST "s") == 0)
-							pSharedMemory->wdata.currentConditions.cWindSpeed = xmlNodeGetContent (petitfils);
-						else if (xmlStrcmp (petitfils->name, BAD_CAST "t") == 0)
-							pSharedMemory->wdata.currentConditions.cWindDirection = xmlNodeGetContent (petitfils);
-					}
+					pSharedMemory->wdata.cLink = xmlNodeGetContent (channel_child);
 				}
-				else if (xmlStrcmp (fils->name, BAD_CAST "bar") == 0)
+				else if (xmlStrcmp (channel_child->name, BAD_CAST "location") == 0)
 				{
-					for (petitfils = fils->children; petitfils != NULL; petitfils = petitfils->next)
-					{
-						if (xmlStrcmp (petitfils->name, BAD_CAST "r") == 0)
-							pSharedMemory->wdata.currentConditions.cPressure = xmlNodeGetContent (petitfils);
-					}
+					pSharedMemory->wdata.cCity = xmlGetProp (channel_child, BAD_CAST "city");
+					pSharedMemory->wdata.cCountry = xmlGetProp (channel_child, BAD_CAST "country");
 				}
-				else if (xmlStrcmp (fils->name, BAD_CAST "hmid") == 0)
-					pSharedMemory->wdata.currentConditions.cHumidity = xmlNodeGetContent (fils);
-				else if (xmlStrcmp (fils->name, BAD_CAST "moon") == 0)
+				else if (xmlStrcmp (channel_child->name, BAD_CAST "wind") == 0)
 				{
-					for (petitfils = fils->children; petitfils != NULL; petitfils = petitfils->next)
-					{
-						if (xmlStrcmp (petitfils->name, BAD_CAST "icon") == 0)
-							pSharedMemory->wdata.currentConditions.cMoonIconNumber = xmlNodeGetContent (petitfils);
-					}
+					pSharedMemory->wdata.currentConditions.cWindDirection = xmlGetProp (channel_child, BAD_CAST "direction");
+					pSharedMemory->wdata.currentConditions.cWindSpeed = xmlGetProp (channel_child, BAD_CAST "speed");
 				}
-			}
-		}
-		else if (xmlStrcmp (param->name, BAD_CAST "dayf") == 0)
-		{
-			for (fils = param->children; fils != NULL; fils = fils->next)
-			{
-				if (xmlStrcmp (fils->name, BAD_CAST "lsup") == 0)
-					pSharedMemory->wdata.currentConditions.cDataAcquisitionDate = xmlNodeGetContent (fils);
-				else if (xmlStrcmp (fils->name, BAD_CAST "day") == 0)
+				else if (xmlStrcmp (channel_child->name, BAD_CAST "atmosphere") == 0)
 				{
-					index_str = (gchar *) xmlGetProp (fils, BAD_CAST "d");
-					if (index_str == NULL)
-						continue;
-					i = atoi (index_str);
-					g_free (index_str);
-					cDayName = (gchar *) xmlGetProp (fils, BAD_CAST "t");
-					pSharedMemory->wdata.days[i].cName = BAD_CAST g_strdup (D_(cDayName));
-					g_free (cDayName);
-					cDate = (gchar *) xmlGetProp (fils, BAD_CAST "dt");
-					str = strchr (cDate, ' ');
-					if (str != NULL)
-					{
-						*str = '\0';
-						pSharedMemory->wdata.days[i].cDate = BAD_CAST g_strconcat (D_(cDate), " ", str+1, NULL);
-						g_free (cDate);
-					}
-					else
-						pSharedMemory->wdata.days[i].cDate = BAD_CAST cDate;
-					for (petitfils = fils->children; petitfils != NULL; petitfils = petitfils->next)
+					pSharedMemory->wdata.currentConditions.cHumidity = xmlGetProp (channel_child, BAD_CAST "humidity");
+					pSharedMemory->wdata.currentConditions.cPressure = xmlGetProp (channel_child, BAD_CAST "pressure");
+				}
+				else if (xmlStrcmp (channel_child->name, BAD_CAST "astronomy") == 0)
+				{
+					pSharedMemory->wdata.currentConditions.cSunRise = xmlGetProp (channel_child, BAD_CAST "sunrise");
+					pSharedMemory->wdata.currentConditions.cSunSet = xmlGetProp (channel_child, BAD_CAST "sunset");
+				}
+				else if (xmlStrcmp (channel_child->name, BAD_CAST "ttl") == 0)
+				{
+					xmlChar *ttl = xmlNodeGetContent (channel_child);
+					pSharedMemory->wdata.currentConditions.ttl = ttl ? atoi((gchar*)ttl) : 0;
+					xmlFree (ttl);
+				}
+				else if (xmlStrcmp (channel_child->name, BAD_CAST "lastBuildDate") == 0)
+				{
+					pSharedMemory->wdata.currentConditions.cDataAcquisitionDate = xmlNodeGetContent (channel_child);
+				}
+				else if (xmlStrcmp (channel_child->name, BAD_CAST "item") == 0)
+				{
+					for (item_child = channel_child->children; item_child != NULL; item_child = item_child->next)
 					{
-						if (xmlStrcmp (petitfils->name, BAD_CAST "hi") == 0)
-							pSharedMemory->wdata.days[i].cTempMax = xmlNodeGetContent (petitfils);
-						else if (xmlStrcmp (petitfils->name, BAD_CAST "low") == 0)
-							pSharedMemory->wdata.days[i].cTempMin = xmlNodeGetContent (petitfils);
-						else if (xmlStrcmp (petitfils->name, BAD_CAST "sunr") == 0)
-							pSharedMemory->wdata.days[i].cSunRise = xmlNodeGetContent (petitfils);
-						else if (xmlStrcmp (petitfils->name, BAD_CAST "suns") == 0)
-							pSharedMemory->wdata.days[i].cSunSet = xmlNodeGetContent (petitfils);
-						else if (xmlStrcmp (petitfils->name, BAD_CAST "part") == 0)
+						if (xmlStrcmp (item_child->name, BAD_CAST "condition") == 0)
 						{
-							index_str = (gchar *) xmlGetProp (petitfils, BAD_CAST "p");
-							if (index_str == NULL)
-								continue;
-							j = (*index_str == 'd' ? 0 : 1);  // jour : 0 / nuit : 1.
-							for (arrpetitfils = petitfils->children; arrpetitfils != NULL; arrpetitfils = arrpetitfils->next)
-							{
-								if (xmlStrcmp (arrpetitfils->name, BAD_CAST "icon") == 0)
-									pSharedMemory->wdata.days[i].part[j].cIconNumber = xmlNodeGetContent (arrpetitfils);
-								else if (xmlStrcmp (arrpetitfils->name, BAD_CAST "t") == 0)
-									pSharedMemory->wdata.days[i].part[j].cWeatherDescription = xmlNodeGetContent (arrpetitfils);
-								else if (xmlStrcmp (arrpetitfils->name, BAD_CAST "wind") == 0)
-								{
-									for (arrarrpetitfils = arrpetitfils->children; arrarrpetitfils != NULL; arrarrpetitfils = arrarrpetitfils->next)
-									{
-										if (xmlStrcmp (arrarrpetitfils->name, BAD_CAST "s") == 0)
-											pSharedMemory->wdata.days[i].part[j].cWindSpeed = xmlNodeGetContent (arrarrpetitfils);
-										else if (xmlStrcmp (arrarrpetitfils->name, BAD_CAST "t") == 0)
-											pSharedMemory->wdata.days[i].part[j].cWindDirection = xmlNodeGetContent (arrarrpetitfils);
-									}
-								}
-								else if (xmlStrcmp (arrpetitfils->name, BAD_CAST "hmid") == 0)
-									pSharedMemory->wdata.days[i].part[j].cHumidity = xmlNodeGetContent (arrpetitfils);
-								else if (xmlStrcmp (arrpetitfils->name, BAD_CAST "ppcp") == 0)
-									pSharedMemory->wdata.days[i].part[j].cPrecipitationProba = xmlNodeGetContent (arrpetitfils);
-							}
+							pSharedMemory->wdata.currentConditions.now.cIconNumber = xmlGetProp (item_child, BAD_CAST "code");
+							pSharedMemory->wdata.currentConditions.now.cDate = xmlGetProp (item_child, BAD_CAST "date");
+							pSharedMemory->wdata.currentConditions.now.cTempMax = xmlGetProp (item_child, BAD_CAST "temp");
+							pSharedMemory->wdata.currentConditions.now.cWeatherDescription = xmlGetProp (item_child, BAD_CAST "text");
+						}
+						else if (xmlStrcmp (item_child->name, BAD_CAST "forecast") == 0 && i<WEATHER_NB_DAYS_MAX)
+						{
+							pSharedMemory->wdata.days[i].cIconNumber = xmlGetProp (item_child, BAD_CAST "code");
+							pSharedMemory->wdata.days[i].cDate = xmlGetProp (item_child, BAD_CAST "date");
+							pSharedMemory->wdata.days[i].cName = xmlGetProp (item_child, BAD_CAST "day");
+							pSharedMemory->wdata.days[i].cTempMax = xmlGetProp (item_child, BAD_CAST "high");
+							pSharedMemory->wdata.days[i].cTempMin = xmlGetProp (item_child, BAD_CAST "low");
+							pSharedMemory->wdata.days[i].cWeatherDescription = xmlGetProp (item_child, BAD_CAST "text");
+							i++;
 						}
 					}
-				}  // fin du jour n.
+				}
 			}
 		}
 	}
 	_cd_weather_close_xml_file (doc);
 }
 
-
+const gchar *cBaseUrl = "https://weather-ydn-yql.media.yahoo.com/forecastrss";
+const gchar *cBaseUrlEsc = "https%3A%2F%2Fweather-ydn-yql.media.yahoo.com%2Fforecastrss";
+	
 static void cd_weather_get_distant_data (CDSharedMemory *pSharedMemory)
 {
-	//\____________________ On recupere les conditions courantes sur le serveur.
 	pSharedMemory->bErrorInThread = FALSE;
-	GError *erreur = NULL;
-	gchar *cCCData = NULL;
-	if (pSharedMemory->bCurrentConditions)
+	
+	//\____________________ remove spaces, and add a comma if necessary
+	gchar *r = strchr(pSharedMemory->cLocationCode, ' '), *w = r;
+	if (r)
 	{
-		gchar *cURL = g_strdup_printf (CD_WEATHER_BASE_URL"/weather/local/%s?cc=*%s", pSharedMemory->cLocationCode, (pSharedMemory->bISUnits ? "&unit=m" : ""));
-		cCCData = cairo_dock_get_url_data (cURL, &erreur);
-		if (erreur != NULL)
-		{
-			cd_warning ("while downloading current conditions data:\n%s -> %s", cURL, erreur->message);
-			g_error_free (erreur);
-			erreur = NULL;
-		}
-		g_free (cURL);
-		if (cCCData == NULL)
+		const gchar *r0 = pSharedMemory->cLocationCode;  // just for the sake of readability
+		while (*r)
 		{
-			pSharedMemory->bErrorInThread = TRUE;
-			return;  // a la 1ere erreur on quitte.
+			if (*r == ' ')
+			{
+				if (w != r0 && *(w-1) != ',')
+					*w++ = ',';
+			}
+			else
+			{
+				if (*r != ',' || (w != r0 && *(w-1) != ','))
+					*w++ = *r;
+			}
+			r++;
 		}
+		*w = '\0';
 	}
+	cd_debug("location code: %s", pSharedMemory->cLocationCode);
 	
-	//\____________________ On recupere les previsions a N jours sur le serveur.
-	gchar *cForecastData = NULL;
-	if (pSharedMemory->iNbDays > 0)
-	{
-		gchar *cURL = g_strdup_printf (CD_WEATHER_BASE_URL"/weather/local/%s?dayf=%d%s", pSharedMemory->cLocationCode, pSharedMemory->iNbDays, (pSharedMemory->bISUnits ? "&unit=m" : ""));
-		cForecastData = cairo_dock_get_url_data (cURL, &erreur);
-		if (erreur != NULL)
-		{
-			cd_warning ("while downloading forecast data:\n%s ->  %s", cURL, erreur->message);
-			g_error_free (erreur);
-			erreur = NULL;
-			pSharedMemory->bErrorInThread = TRUE;
-		}
-		g_free (cURL);
-		if (cForecastData == NULL)
-		{
-			pSharedMemory->bErrorInThread = TRUE;
-		}
+	//\____________________ get the rss feed
+	GError *erreur = NULL;
+	gchar *cURL = g_strdup_printf("%s?location=%s&format=xml&u=%c", cBaseUrl, pSharedMemory->cLocationCode, pSharedMemory->bISUnits ? 'c' : 'f');
+	gchar *oauth_header = _get_oauth_header (pSharedMemory->cLocationCode, pSharedMemory->bISUnits);
+	gchar *cCCData = cairo_dock_get_url_data_with_headers (cURL, FALSE, &erreur,
+		"Authorization", oauth_header,
+		"X-Yahoo-App-Id", APP_ID,
+		NULL);
+	if (erreur != NULL)
+	{
+		cd_warning ("while downloading current conditions data:\n%s -> %s", cURL, erreur->message);
+		g_error_free (erreur);
+		erreur = NULL;
 	}
+	g_free (oauth_header);
+	g_free (cURL);
 	
-	//\____________________ On extrait les donnees des conditions courantes.
-	if (cCCData != NULL)
+	if (cCCData == NULL)
 	{
-		_cd_weather_parse_data (pSharedMemory, cCCData, TRUE, &erreur);
-		if (erreur != NULL)
-		{
-			cd_warning ("weather : %s", erreur->message);
-			g_error_free (erreur);
-			erreur = NULL;
-			pSharedMemory->bErrorInThread = TRUE;
-		}
-		g_free (cCCData);
+		pSharedMemory->bErrorInThread = TRUE;
+		return;
 	}
 	
-	//\____________________ On extrait les donnees des previsions a N jours.
-	if (cForecastData != NULL)
+	//\____________________ On extrait les donnees des conditions courantes.
+	_cd_weather_parse_data (pSharedMemory, cCCData, TRUE, &erreur);
+	if (erreur != NULL)
 	{
-		_cd_weather_parse_data (pSharedMemory, cForecastData, FALSE, &erreur);
-		if (erreur != NULL)
-		{
-			cd_warning ("weather : %s", erreur->message);
-			g_error_free (erreur);
-			erreur = NULL;
-			pSharedMemory->bErrorInThread = TRUE;
-		}
-		g_free (cForecastData);
+		cd_warning ("weather : %s", erreur->message);
+		g_error_free (erreur);
+		erreur = NULL;
+		pSharedMemory->bErrorInThread = TRUE;
 	}
+	g_free (cCCData);
 }
 
 
@@ -371,7 +280,6 @@ static void cd_weather_get_distant_data
 static void _reset_units (Unit *pUnits)
 {
 	xmlFree (pUnits->cTemp);
-	xmlFree (pUnits->cDistance);
 	xmlFree (pUnits->cSpeed);
 	xmlFree (pUnits->cPressure);
 }
@@ -381,49 +289,31 @@ static void _reset_current_conditions (C
 	xmlFree (pCurrentContitions->cSunRise);
 	xmlFree (pCurrentContitions->cSunSet);
 	xmlFree (pCurrentContitions->cDataAcquisitionDate);
-	xmlFree (pCurrentContitions->cObservatory);
-	xmlFree (pCurrentContitions->cTemp);
-	xmlFree (pCurrentContitions->cFeltTemp);
-	xmlFree (pCurrentContitions->cWeatherDescription);
-	xmlFree (pCurrentContitions->cIconNumber);
 	xmlFree (pCurrentContitions->cWindSpeed);
 	xmlFree (pCurrentContitions->cWindDirection);
 	xmlFree (pCurrentContitions->cPressure);
 	xmlFree (pCurrentContitions->cHumidity);
-	xmlFree (pCurrentContitions->cMoonIconNumber);
 }
 
-static void _reset_current_one_day (Day *pDay)
+static void _reset_one_day (Day *pDay)
 {
 	xmlFree (pDay->cName);
 	xmlFree (pDay->cDate);
 	xmlFree (pDay->cTempMax);
 	xmlFree (pDay->cTempMin);
-	xmlFree (pDay->cSunRise);
-	xmlFree (pDay->cSunSet);
-	int j;
-	for (j = 0; j < 2; j ++)
-	{
-		xmlFree (pDay->part[j].cIconNumber);
-		xmlFree (pDay->part[j].cWeatherDescription);
-		xmlFree (pDay->part[j].cWindSpeed);
-		xmlFree (pDay->part[j].cWindDirection);
-		xmlFree (pDay->part[j].cHumidity);
-		xmlFree (pDay->part[j].cPrecipitationProba);
-	}
+	xmlFree (pDay->cIconNumber);
 }
 
 void cd_weather_reset_weather_data (CDWeatherData *pData)
 {
-	/**xmlFree (pData->cLon);
-	xmlFree (pData->cLat);*/
-	xmlFree (pData->cLocation);
+	xmlFree (pData->cCity);
+	xmlFree (pData->cCountry);
 	_reset_units (&pData->units);
 	_reset_current_conditions (&pData->currentConditions);
 	int i;
 	for (i = 0; i < WEATHER_NB_DAYS_MAX; i ++)
 	{
-		_reset_current_one_day (&pData->days[i]);
+		_reset_one_day (&pData->days[i]);
 	}
 }
 
@@ -449,13 +339,77 @@ void cd_weather_launch_periodic_task (Gl
 	pSharedMemory->cLocationCode = g_strdup (myConfig.cLocationCode);
 	pSharedMemory->bISUnits = myConfig.bISUnits;
 	pSharedMemory->bCurrentConditions = myConfig.bCurrentConditions;
-	pSharedMemory->iNbDays = myConfig.iNbDays;
 	pSharedMemory->pApplet = myApplet;
 	
-	myData.pTask = gldi_task_new_full (myConfig.iCheckInterval,
+	myData.pTask = gldi_task_new_full (3600,  // start with 1h period, it will be adjusted according to the TTL
 		(GldiGetDataAsyncFunc) cd_weather_get_distant_data,
 		(GldiUpdateSyncFunc) cd_weather_update_from_data,
 		(GFreeFunc) _free_shared_memory,
 		pSharedMemory);
 	gldi_task_launch (myData.pTask);
 }
+
+#include <openssl/sha.h>
+#include <openssl/hmac.h>
+#include <openssl/evp.h>
+#include <sys/time.h>
+
+static guchar *_hmac_sha1_base64(const gchar *key, const gchar *data)
+{
+	size_t key_len = strlen(++key);
+	size_t data_len = strlen(data);
+	uint8_t md[64];  // SHA1_Message_Block_Size = 64 bytes
+	uint md_len=64;
+	if (!HMAC(EVP_sha1(), key, key_len, (guchar*)data, data_len, md, &md_len))  // data is URL-encoded, so is actually a guchar*
+	{
+		//#include <openssl/err.h>
+		//ERR_clear_error();
+	}
+	guchar *b64_output = malloc((md_len+1)*4/3+1);  // taking into account the padding, and the final '\0' inserted by the function
+	EVP_EncodeBlock(b64_output, md, md_len);
+	return b64_output;
+}
+
+static gchar *_get_oauth_header (const gchar *cLocationName, gboolean bISUnits)
+{
+	// Oauth authentication: the idea is to join to the headers a hash of the GET request's signature
+	// the signature is made of: the method (GET), the url, some query parameters (like location, units and format), and the various oauth parameters (except of course the hash)
+	// they must be ordered, so that both end agree on how to form the string and calculate the hash
+	
+	// first build the parameters string
+	gchar *cLocationNameEsc = g_uri_escape_string(cLocationName, NULL, FALSE);
+	struct timeval tv;
+	gettimeofday(&tv, NULL);
+	const gchar *nonce = g_strdup_printf("%032d", rand());  // 32 bytes; it's not like we really need to be secretive...
+	gchar *params_sorted = g_strdup_printf ("format=xml&location=%s&oauth_consumer_key=%s&oauth_nonce=%s&oauth_signature_method=%s&oauth_timestamp=%ld&oauth_version=%s&u=%c",
+		cLocationNameEsc,
+		CLIENT_ID,
+		nonce,
+		"HMAC-SHA1",
+		tv.tv_sec,
+		"1.0",
+		bISUnits ? 'c' : 'f');  // all parameters are sorted by their key, and their value is URL-encoded.
+	gchar *params_sorted_esc = g_uri_escape_string(params_sorted, NULL, FALSE);
+	// then build the request's signature string
+	gchar *signature_base_str = g_strdup_printf ("GET&%s&%s",
+		cBaseUrlEsc,
+		params_sorted_esc);
+	// now calculate the hash of the signature
+	gchar *key = g_strdup (CLIENT_SECRET), *k=key;
+	while (*k) (*k++)--;
+	guchar *oauth_signature = _hmac_sha1_base64(key, signature_base_str);
+	g_free (key);
+	
+	// finally build the oauth header, containing all the oauth parameters
+	gchar *auth_header = g_strdup_printf("OAuth oauth_consumer_key=\"%s\", oauth_nonce=\"%s\", oauth_signature_method=\"%s\", oauth_timestamp=\"%ld\", oauth_version=\"%s\", oauth_signature=\"%s\"",
+		CLIENT_ID,
+		nonce,
+		"HMAC-SHA1",
+		tv.tv_sec,
+		"1.0",
+		oauth_signature);
+	free(signature_base_str);
+	free(cLocationNameEsc);
+	free(oauth_signature);
+	return auth_header;
+}
diff -pruN 3.4.1-6/weather/src/applet-read-data.h 3.4.1+git20201022.a0d3415c-1/weather/src/applet-read-data.h
--- 3.4.1-6/weather/src/applet-read-data.h	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/weather/src/applet-read-data.h	2020-10-21 15:04:44.000000000 +0000
@@ -33,5 +33,6 @@ void cd_weather_reset_data (GldiModuleIn
 
 void cd_weather_launch_periodic_task (GldiModuleInstance *myApplet);
 
+gchar *cd_weather_get_location_url (const gchar *cLocationName);
 
 #endif
diff -pruN 3.4.1-6/weather/src/applet-struct.h 3.4.1+git20201022.a0d3415c-1/weather/src/applet-struct.h
--- 3.4.1-6/weather/src/applet-struct.h	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/weather/src/applet-struct.h	2020-10-21 15:04:44.000000000 +0000
@@ -23,24 +23,27 @@
 
 #include <cairo-dock.h>
 
-#define WEATHER_NB_DAYS_MAX 5
+#define WEATHER_NB_DAYS_MAX 8
 
 #define WEATHER_RATIO_ICON_DESKLET .5
 
 #define WEATHER_DEFAULT_NAME "weather"
 
+// yahoo weather has no code location API
+// it's possible to get a code (woeid) in the 'link' of the response, but that means that you already got a valid location
+// so it's pretty useless
+#undef CD_WEATHER_HAS_CODE_LOCATION
+
 #define _display(cValue) ((cValue) == NULL || *((gchar*)cValue) == 'N' ? "?" : (const gchar*)(cValue))
 
 struct _AppletConfig {
 	gchar *cLocationCode;
 	gboolean bISUnits;
 	gboolean bCurrentConditions;
-	gboolean bDisplayNights;
 	gboolean bDisplayTemperature;
 	gint iNbDays;
 	gchar *cRenderer;
 	gint cDialogDuration;
-	guint iCheckInterval;
 	gchar *cThemePath;
 	gboolean bDesklet3D;
 	gboolean bSetName;
@@ -48,60 +51,44 @@ struct _AppletConfig {
 
 typedef struct {
 	xmlChar *cTemp;
-	xmlChar *cDistance;
 	xmlChar *cSpeed;
 	xmlChar *cPressure;
 	} Unit;
 
 typedef struct {
-	xmlChar *cSunRise;
-	xmlChar *cSunSet;
-	xmlChar *cDataAcquisitionDate;
-	xmlChar *cObservatory;
-	xmlChar *cTemp;
-	xmlChar *cFeltTemp;
-	xmlChar *cWeatherDescription;
 	xmlChar *cIconNumber;
-	xmlChar *cWindSpeed;
-	xmlChar *cWindDirection;
-	xmlChar *cPressure;
-	xmlChar *cHumidity;
-	xmlChar *cMoonIconNumber;
-	} CurrentContitions;
+	xmlChar *cDate;
+	xmlChar *cName;
+	xmlChar *cTempMax;
+	xmlChar *cTempMin;
+	xmlChar *cWeatherDescription;
+	} Day;
 
 typedef struct {
-	xmlChar *cIconNumber;
-	xmlChar *cWeatherDescription;
 	xmlChar *cWindSpeed;
 	xmlChar *cWindDirection;
+	xmlChar *cPressure;
 	xmlChar *cHumidity;
-	xmlChar *cPrecipitationProba;
-	} DayPart;
-
-typedef struct {
-	xmlChar *cName;
-	xmlChar *cDate;
-	xmlChar *cTempMax;
-	xmlChar *cTempMin;
 	xmlChar *cSunRise;
 	xmlChar *cSunSet;
-	DayPart part[2];
-	} Day;
+	int ttl;  // in mn;
+	xmlChar *cDataAcquisitionDate;
+	Day now;
+	} CurrentContitions;
 
 typedef struct {
-	xmlChar *cLocation;
-	/**xmlChar *cLon;
-	xmlChar *cLat;*/
 	Unit units;
 	CurrentContitions currentConditions;
 	Day days[WEATHER_NB_DAYS_MAX];
+	xmlChar *cCountry;
+	xmlChar *cCity;
+	xmlChar *cLink;
 	} CDWeatherData;
 
 typedef struct {
 	gchar *cLocationCode;
 	gboolean bISUnits;
 	gboolean bCurrentConditions;
-	gint iNbDays;
 	CDWeatherData wdata;
 	gboolean bErrorInThread;
 	GldiModuleInstance *pApplet;
diff -pruN 3.4.1-6/weather/src/CMakeLists.txt 3.4.1+git20201022.a0d3415c-1/weather/src/CMakeLists.txt
--- 3.4.1-6/weather/src/CMakeLists.txt	2014-10-15 14:22:16.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/weather/src/CMakeLists.txt	2020-10-21 15:04:44.000000000 +0000
@@ -29,62 +29,17 @@ add_definitions (-DMY_APPLET_ICON_FILE="
 add_definitions (-DCD_APPLET_MULTI_INSTANCE="1")
 
 include_directories (
-	${PACKAGE_INCLUDE_DIRS})
+	${PACKAGE_INCLUDE_DIRS}
+	${WEATHER_INCLUDE_DIRS})
 
 link_directories (
-	${PACKAGE_LIBRARY_DIRS})
+	${PACKAGE_LIBRARY_DIRS}
+	${WEATHER_LIBRARY_DIRS})
 
 target_link_libraries (${PACKAGE_WEATHER}
-	${PACKAGE_LIBRARIES})
+	${PACKAGE_LIBRARIES}
+	${WEATHER_LIBRARIES})
 
 ########### install files ###############
 
 install(TARGETS ${PACKAGE_WEATHER} DESTINATION ${pluginsdir})
-
-
-#original Makefile.am contents follow:
-
-# #dnl Process this file with automake to produce Makefile.in
-#
-#lib_LTLIBRARIES = 
-#	libcd-weather.la
-#
-#
-#libcd_weather_la_SOURCES = 
-#	applet-init.c
-#	applet-init.h
-#	applet-config.c
-#	applet-config.h
-#	applet-notifications.c
-#	applet-notifications.h
-#	applet-struct.h
-#	applet-read-data.c
-#	applet-read-data.h
-#	applet-load-icons.c
-#	applet-load-icons.h
-#
-#dock_version = `pkg-config --modversion cairo-dock`
-#
-#libcd_weather_la_CFLAGS = 
-#	-I$(top_srcdir)/src
-#	$(PACKAGE_CFLAGS)
-#	-DMY_APPLET_SHARE_DATA_DIR=""${weatherdatadir)""
-#	-DMY_APPLET_PREVIEW_FILE=""preview.jpg""
-#	-DMY_APPLET_CONF_FILE=""weather.conf""
-#	-DMY_APPLET_USER_DATA_DIR=""${weatheruserdirname)""
-#	-DMY_APPLET_VERSION=""${VERSION_WEATHER)""
-#	-DMY_APPLET_GETTEXT_DOMAIN=""${GETTEXT_WEATHER)""
-#	-DMY_APPLET_DOCK_VERSION=""${dock_version)""
-#	-DMY_APPLET_ICON_FILE=""icon.png""
-#	-DCD_APPLET_MULTI_INSTANCE="1"
-#	-std=c99
-#	-Werror-implicit-function-declaration
-##	-g -ggdb -W -Wall
-#
-#
-#libcd_weather_la_LIBADD = 
-#	$(PACKAGE_LIBS) -lm
-#
-#
-#libcd_weather_la_LDFLAGS =
-#	-avoid-version -module
diff -pruN 3.4.1-6/weblets/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/weblets/data/misc/icon.svg
--- 3.4.1-6/weblets/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/weblets/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,483 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   version="1.1"
+   width="48"
+   height="48"
+   id="svg15137"
+   inkscape:version="0.47 r22583"
+   sodipodi:docname="icon.svg"
+   inkscape:export-filename="/opt/cairo-dock_bzr/cairo-dock-plug-ins/weblets/data/icon.png"
+   inkscape:export-xdpi="120"
+   inkscape:export-ydpi="120">
+  <metadata
+     id="metadata39">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <dc:title></dc:title>
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <sodipodi:namedview
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1"
+     objecttolerance="10"
+     gridtolerance="10"
+     guidetolerance="10"
+     inkscape:pageopacity="0"
+     inkscape:pageshadow="2"
+     inkscape:window-width="801"
+     inkscape:window-height="619"
+     id="namedview37"
+     showgrid="false"
+     inkscape:zoom="4.9166667"
+     inkscape:cx="24"
+     inkscape:cy="36.263277"
+     inkscape:window-x="0"
+     inkscape:window-y="24"
+     inkscape:window-maximized="0"
+     inkscape:current-layer="svg15137" />
+  <defs
+     id="defs15139">
+    <linearGradient
+       id="linearGradient8838">
+      <stop
+         id="stop8840"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop8842"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="62.625"
+       cy="4.625"
+       r="10.625"
+       fx="62.625"
+       fy="4.625"
+       id="radialGradient2612"
+       xlink:href="#linearGradient8838"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1,0,0,0.341176,0,3.047059)" />
+    <linearGradient
+       id="linearGradient4873">
+      <stop
+         id="stop4875"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4877"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       x1="62.200409"
+       y1="-12.489107"
+       x2="62.200409"
+       y2="0.24325986"
+       id="linearGradient15133"
+       xlink:href="#linearGradient4873"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(2.149872,0,0,2.149872,-110.11554,31.935342)" />
+    <linearGradient
+       id="linearGradient8740-304-201-142-419-164">
+      <stop
+         id="stop14118"
+         style="stop-color:#9e9e9e;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop14120"
+         style="stop-color:#9e9e9e;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient12067-267-678-820-366-564">
+      <stop
+         id="stop14112"
+         style="stop-color:#557695;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop14114"
+         style="stop-color:#15395c;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient8647">
+      <stop
+         id="stop8649"
+         style="stop-color:#8fb1dc;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop8651"
+         style="stop-color:#3465a4;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="62.200352"
+       cy="-8.7256308"
+       r="9.7552834"
+       fx="62.200352"
+       fy="-8.7256308"
+       id="radialGradient15127"
+       xlink:href="#linearGradient8647"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(2.4129174,0,0,2.4129712,-126.47708,34.230797)" />
+    <linearGradient
+       id="linearGradient4845">
+      <stop
+         id="stop4847"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4849"
+         style="stop-color:#b6b6b6;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="17.81411"
+       cy="24.149399"
+       r="9.125"
+       fx="17.81411"
+       fy="24.149399"
+       id="radialGradient2418"
+       xlink:href="#linearGradient4845"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-2.643979,0,2.93653e-8,2.534421,78.72514,-37.986139)" />
+    <radialGradient
+       cx="23.859564"
+       cy="13.066691"
+       r="18.09778"
+       fx="23.859564"
+       fy="13.066691"
+       id="radialGradient5145"
+       xlink:href="#linearGradient12067-267-678-820-366-564"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.5425322,0,0,-0.8455253,60.718461,23.829235)" />
+    <radialGradient
+       cx="62.225391"
+       cy="-3.4420195"
+       r="10.081216"
+       fx="62.225391"
+       fy="-3.4420195"
+       id="radialGradient5147"
+       xlink:href="#linearGradient8740-304-201-142-419-164"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.103501,0,0,1.0265131,-4.1555224,-1.8158014)" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient8838"
+       id="radialGradient2844"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1,0,0,0.341176,0,3.047059)"
+       cx="62.625"
+       cy="4.625"
+       fx="62.625"
+       fy="4.625"
+       r="10.625" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient8647"
+       id="radialGradient2846"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(2.4129174,0,0,2.4129712,-126.47708,34.230797)"
+       cx="62.200352"
+       cy="-8.7256308"
+       fx="62.200352"
+       fy="-8.7256308"
+       r="9.7552834" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient12067-267-678-820-366-564"
+       id="radialGradient2848"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-1.5425322,0,0,-0.8455253,60.718461,23.829235)"
+       cx="23.859564"
+       cy="13.066691"
+       fx="23.859564"
+       fy="13.066691"
+       r="18.09778" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient8740-304-201-142-419-164"
+       id="radialGradient2850"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.103501,0,0,1.0265131,-4.1555224,-1.8158014)"
+       cx="62.225391"
+       cy="-3.4420195"
+       fx="62.225391"
+       fy="-3.4420195"
+       r="10.081216" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4873"
+       id="linearGradient2852"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(2.149872,0,0,2.149872,-110.11554,31.935342)"
+       x1="62.200409"
+       y1="-12.489107"
+       x2="62.200409"
+       y2="0.24325986" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4845"
+       id="radialGradient2854"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-2.643979,0,2.93653e-8,2.534421,78.72514,-37.986139)"
+       cx="17.81411"
+       cy="24.149399"
+       fx="17.81411"
+       fy="24.149399"
+       r="9.125" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient8838"
+       id="radialGradient2864"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(2.1647059,0,0,0.87466073,-111.56471,34.661405)"
+       cx="62.625"
+       cy="4.625"
+       fx="62.625"
+       fy="4.625"
+       r="10.625" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient4845"
+       id="radialGradient2866"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(-2.643979,0,2.93653e-8,2.534421,78.72514,-37.986139)"
+       cx="17.81411"
+       cy="24.149399"
+       fx="17.81411"
+       fy="24.149399"
+       r="9.125" />
+    <linearGradient
+       id="linearGradient2490-182-124">
+      <stop
+         id="stop2788"
+         style="stop-color:#1f4b6a;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2790"
+         style="stop-color:#4083c2;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3242-187-536">
+      <stop
+         id="stop2778"
+         style="stop-color:#8badea;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop2780"
+         style="stop-color:#6396cd;stop-opacity:1"
+         offset="0.26238" />
+      <stop
+         id="stop2782"
+         style="stop-color:#3b7caf;stop-opacity:1"
+         offset="0.66093999" />
+      <stop
+         id="stop2784-2"
+         style="stop-color:#194c70;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       gradientTransform="matrix(2.2554569,0,-2.1857407e-8,2.0564463,-32.641879,-17.341228)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient2490-182-124"
+       id="radialGradient6332"
+       fy="15.240479"
+       fx="26"
+       r="15.074549"
+       cy="15.240479"
+       cx="26" />
+    <radialGradient
+       gradientTransform="matrix(1.9524671,-0.05018139,0.03650944,1.4214826,-20.408334,-5.9089096)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3242-187-536"
+       id="radialGradient5551"
+       fy="12.610249"
+       fx="20.038782"
+       r="22.463524"
+       cy="12.610249"
+       cx="20.038782" />
+    <radialGradient
+       gradientTransform="matrix(1.0099925,-0.1119962,0.05668752,0.5112133,-5.8375646,1.7934718)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3156"
+       id="radialGradient5540"
+       fy="10.874998"
+       fx="22.125"
+       r="20"
+       cy="10.874998"
+       cx="22.125" />
+    <radialGradient
+       gradientTransform="matrix(1.3571044,0.01021839,-0.00631345,0.8384895,-10.874695,1.3057951)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3156"
+       id="radialGradient5537"
+       fy="4.7612267"
+       fx="22.944935"
+       r="14"
+       cy="11.222695"
+       cx="22.944935" />
+    <linearGradient
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3156"
+       id="linearGradient5751"
+       y2="24.653727"
+       x2="29.724815"
+       y1="55.647495"
+       x1="30.501778" />
+    <linearGradient
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3156"
+       id="linearGradient5749"
+       y2="20.663898"
+       x2="28.290144"
+       y1="-2.3103411"
+       x1="28.220636" />
+    <linearGradient
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3156"
+       id="linearGradient5747"
+       y2="20.663898"
+       x2="28.290144"
+       y1="-0.81503254"
+       x1="27.888655" />
+    <linearGradient
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3156"
+       id="linearGradient5745"
+       y2="20.663898"
+       x2="28.290144"
+       y1="61.852856"
+       x1="24.335312" />
+    <radialGradient
+       gradientTransform="matrix(1,0,0,0.341176,0,3.047059)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient8838-6"
+       id="radialGradient5729"
+       fy="4.625"
+       fx="62.625"
+       r="10.625"
+       cy="4.625"
+       cx="62.625" />
+    <linearGradient
+       id="linearGradient8838-6">
+      <stop
+         offset="0"
+         style="stop-color:black;stop-opacity:1"
+         id="stop8840-4" />
+      <stop
+         offset="1"
+         style="stop-color:black;stop-opacity:0"
+         id="stop8842-3" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3156">
+      <stop
+         offset="0"
+         style="stop-color:white;stop-opacity:1"
+         id="stop3158" />
+      <stop
+         offset="1"
+         style="stop-color:white;stop-opacity:0"
+         id="stop3160" />
+    </linearGradient>
+  </defs>
+  <g
+     id="layer1"
+     transform="translate(0.20339076,-0.29661015)">
+    <g
+       id="g6334">
+      <path
+         style="opacity:0.4;fill:url(#radialGradient5729);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:0.49589729;marker:none;visibility:visible;display:inline;overflow:visible"
+         id="path8836"
+         transform="matrix(1.9262213,0,0,2.1088276,-97.163508,29.602172)"
+         d="m 73.25,4.625 c 0,2.0020323 -4.756974,3.6250001 -10.625,3.6250001 C 56.756974,8.2500001 52,6.6270323 52,4.625 52,2.6229677 56.756974,0.99999989 62.625,0.99999989 c 5.868026,0 10.625,1.62296781 10.625,3.62500011 l 0,0 z" />
+      <path
+         style="fill:url(#radialGradient5551);fill-opacity:1;stroke:#1f4b6a;stroke-width:0.99815506;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0"
+         id="path1307"
+         d="m 44.500921,23 c 0,11.316512 -9.178384,20.500922 -20.487463,20.500922 -11.30908,0 -20.4874629,-9.18441 -20.4874629,-20.500922 0,-11.316509 9.1783829,-20.5009224 20.4874629,-20.5009224 11.309079,0 20.487463,9.1844134 20.487463,20.5009224 z" />
+      <path
+         style="fill:url(#radialGradient6332);fill-opacity:1;fill-rule:nonzero;stroke:none"
+         id="path6628"
+         d="M 43.219099,18.237303 43.03226,18.957842 C 42.479353,18.498341 41.858575,18.11192 41.228194,17.708339 l -1.383757,0.143595 -1.264237,-1.007844 0,1.247283 1.083135,0.577996 0.720932,0.57578 0.963449,-0.768406 c 0.242517,0.320344 0.481723,0.640687 0.722585,0.961031 l 0,0.95998 -1.08479,0.864133 -1.985167,0.961031 -1.503445,1.058044 -0.963448,-0.770739 0.481724,-0.864133 -0.961957,-0.768403 -1.62462,-2.448926 -1.383757,-1.103574 -0.362204,0.287307 0.54314,1.393213 1.021718,0.816269 c 0.583533,1.18798 1.160774,2.323424 1.927064,3.458986 1.188253,0 2.30847,-0.08896 3.48861,-0.193795 l 0,0.672677 -1.443683,2.497372 -1.323998,1.05571 -1.083133,1.634872 c 0,0.896122 0,1.792244 0,2.688249 l 0.362204,1.058043 -0.601411,0.478882 -1.325653,0.576827 -1.383756,0.816269 1.14455,0.912115 -1.564859,0.962198 0.300623,0.622477 -2.347372,1.874314 -1.563204,0 -1.323998,0.576828 -0.843926,0 0,-0.768404 -0.358894,-1.539144 c -0.465667,-0.964534 -0.950536,-1.92218 -1.443684,-2.879825 0,-0.70688 0.05976,-1.406872 0.119686,-2.113636 l 0.603068,-0.95998 -0.843929,-1.153773 0.06142,-1.584674 -1.14455,-0.912115 0.572274,-1.32025 -0.931169,-0.745056 -1.626273,0 -0.541485,-0.432068 -1.62462,0.721124 -0.661169,-0.529547 -1.5051,0.912582 c -1.02172,-0.816853 -2.045094,-1.633121 -3.068303,-2.44939 L 13.07,21.741935 l 1.083137,-1.151436 -0.601412,-0.479933 1.322342,-2.210651 c 1.086444,-0.953092 2.221227,-1.867425 3.369089,-2.785143 l 2.046584,-0.384204 2.285956,-0.191576 1.564859,0.288473 2.226032,1.583506 0.78251,-0.623643 1.081479,-0.09573 2.046584,0.479932 1.564861,0 1.083134,-0.672675 0.481723,-0.479932 -1.08479,-0.479932 -1.80572,-0.09573 c -0.501093,-0.490204 -0.966759,-1.005508 -1.561715,-1.441076 l -0.603065,0.191574 -0.240865,1.249502 -1.083133,-0.864131 -0.239207,-0.962199 -1.20282,-0.670338 -0.48338,0 1.20431,0.959978 -0.481723,0.864134 -0.961959,0.191576 0.60141,-0.864134 -1.084791,-0.383036 -0.960303,-0.768403 -1.807377,0.287304 -0.239206,0.383036 -1.083134,0.481099 -0.601411,1.056877 -1.503445,0.527797 -0.662824,-0.527797 -0.720932,0 0,-1.729435 1.564859,-0.576829 1.20282,0 -0.242517,-0.671507 -0.960303,-0.672675 1.62313,-0.240609 0.902032,-0.719371 0.720931,-0.8653012 1.325654,0 -0.362206,-0.6715064 0.843929,-0.3842031 0,0.7684043 1.804066,0.2873052 1.804067,-1.0557095 0.121174,-0.481099 1.563205,-0.7678216 c -0.56582,0.049618 -1.131638,0.08604 -1.684545,0.1921611 l 0,-0.8651834 0.601409,-0.9605654 -0.601409,0 -1.321678,0.8641345 -0.362207,0.4805153 0.362207,0.673259 -0.603067,1.1514366 -0.96196,-0.3842011 -0.840618,-0.6715065 -1.325651,0.6715065 -0.481725,-1.5362228 2.285956,-1.0562945 0,-0.5768291 L 25.223524,3.6847867 27.509479,3.3 l 1.56486,0.3847867 2.166268,0.9599803 -1.564858,0 1.564858,1.1526075 1.202823,-0.9599824 c 0,0 4.786235,2.4031505 7.258281,5.7266459 2.405352,3.233831 3.412213,6.909414 3.517388,7.673265 z" />
+      <path
+         style="opacity:0.7;fill:none;stroke:url(#radialGradient5540);stroke-width:0.99647081;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0"
+         id="path3164"
+         d="m 43.501763,23 c 0,10.764976 -8.736791,19.501764 -19.501765,19.501764 C 13.235024,42.501764 4.4982338,33.764976 4.4982338,23 c 0,-10.764974 8.7367902,-19.5017646 19.5017642,-19.5017646 10.764974,0 19.501765,8.7367906 19.501765,19.5017646 z" />
+      <path
+         style="opacity:0.5;fill:url(#radialGradient5537);fill-opacity:1;stroke:none"
+         id="path3154"
+         d="m 42.999998,16.746704 c 0,7.114117 -8.512001,11.02908 -18.999999,11.02908 -10.488002,0 -19.0000006,-3.914963 -19.0000006,-11.02908 C 4.9999984,9.632588 13.511997,2 23.999999,2 34.487997,2 42.999998,9.632588 42.999998,16.746704 z" />
+      <path
+         style="opacity:0.5;fill:none;stroke:url(#linearGradient5745);stroke-width:1.09524393;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0"
+         id="path2218"
+         transform="matrix(1.076193,-0.2912862,0.1952728,0.7143165,-11.182741,14.979481)"
+         d="m 46,24.25 c 0,9.664983 -7.835017,17.5 -17.5,17.5 -9.664983,0 -17.5,-7.835017 -17.5,-17.5 0,-9.664983 7.835017,-17.5 17.5,-17.5 9.664983,0 17.5,7.835017 17.5,17.5 l 0,0 z" />
+      <path
+         style="opacity:0.5;fill:none;stroke:url(#linearGradient5747);stroke-width:1.0902828;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0"
+         id="path2230"
+         transform="matrix(1.1247273,-0.00679075,0.00112312,0.7429216,-7.8873839,2.6776872)"
+         d="m 46,24.25 c 0,9.664983 -7.835017,17.5 -17.5,17.5 -9.664983,0 -17.5,-7.835017 -17.5,-17.5 0,-9.664983 7.835017,-17.5 17.5,-17.5 9.664983,0 17.5,7.835017 17.5,17.5 l 0,0 z" />
+      <path
+         style="opacity:0.5;fill:none;stroke:url(#linearGradient5749);stroke-width:1.12890089;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0"
+         id="path2234"
+         transform="matrix(-0.09940095,-1.1197712,0.6946105,-0.03998764,8.1749534,56.475018)"
+         d="m 46,24.25 c 0,9.664983 -7.835017,17.5 -17.5,17.5 -9.664983,0 -17.5,-7.835017 -17.5,-17.5 0,-9.664983 7.835017,-17.5 17.5,-17.5 9.664983,0 17.5,7.835017 17.5,17.5 l 0,0 z" />
+      <path
+         style="opacity:0.5;fill:none;stroke:url(#linearGradient5751);stroke-width:1.36711621;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0"
+         id="path2240"
+         transform="matrix(-0.1600777,-1.1032472,0.4856389,0.01692093,16.935466,54.089297)"
+         d="m 46,24.25 c 0,9.664983 -7.835017,17.5 -17.5,17.5 -9.664983,0 -17.5,-7.835017 -17.5,-17.5 0,-9.664983 7.835017,-17.5 17.5,-17.5 9.664983,0 17.5,7.835017 17.5,17.5 l 0,0 z" />
+      <path
+         style="opacity:0.4;fill:#ffffff;fill-opacity:1;stroke:none"
+         id="path2255"
+         transform="matrix(0.7873429,-0.2144143,0.2141677,0.7882494,1.2604149,11.541737)"
+         d="m 31.375,37.875 c 0,0.966498 -0.783502,1.75 -1.75,1.75 -0.966498,0 -1.75,-0.783502 -1.75,-1.75 0,-0.966498 0.783502,-1.75 1.75,-1.75 0.966498,0 1.75,0.783502 1.75,1.75 l 0,0 z" />
+      <path
+         style="opacity:0.4;fill:#ffffff;fill-opacity:1;stroke:none"
+         id="path2275"
+         transform="matrix(0.6748654,-0.1837837,0.2141677,0.7882494,-14.193998,12.29353)"
+         d="m 31.375,37.875 c 0,0.966498 -0.783502,1.75 -1.75,1.75 -0.966498,0 -1.75,-0.783502 -1.75,-1.75 0,-0.966498 0.783502,-1.75 1.75,-1.75 0.966498,0 1.75,0.783502 1.75,1.75 l 0,0 z" />
+      <path
+         style="opacity:0.4;fill:#ffffff;fill-opacity:1;stroke:none"
+         id="path2283"
+         transform="matrix(0.7873429,-0.2144143,0.324169,0.6373544,-8.3660962,-9.8985024)"
+         d="m 31.375,37.875 c 0,0.966498 -0.783502,1.75 -1.75,1.75 -0.966498,0 -1.75,-0.783502 -1.75,-1.75 0,-0.966498 0.783502,-1.75 1.75,-1.75 0.966498,0 1.75,0.783502 1.75,1.75 l 0,0 z" />
+      <path
+         style="opacity:0.4;fill:#ffffff;fill-opacity:1;stroke:none"
+         id="path2291"
+         transform="matrix(0.7873429,-0.2144143,-0.01326253,0.7292459,-10.705973,-10.742804)"
+         d="m 31.375,37.875 c 0,0.966498 -0.783502,1.75 -1.75,1.75 -0.966498,0 -1.75,-0.783502 -1.75,-1.75 0,-0.966498 0.783502,-1.75 1.75,-1.75 0.966498,0 1.75,0.783502 1.75,1.75 l 0,0 z" />
+    </g>
+  </g>
+  <g
+     id="g2414"
+     transform="matrix(0.9999061,-0.01370139,0.01370139,0.9999061,-0.86497119,0.33246397)">
+    <path
+       style="fill:url(#radialGradient2866);fill-opacity:1;fill-rule:evenodd;stroke:#666666;stroke-width:1;stroke-linecap:butt;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible"
+       id="path3970"
+       d="m 30.5,20.93716 17,16.500001 -7.75,0.25 c 0,0 3.25,6.75 3.25,6.75 1,3 -3.5,4.125 -4.25,1.875 0,0 -3,-6.75 -3,-6.75 l -5.5,5.875 0.25,-24.500001 z" />
+    <path
+       style="opacity:0.4;fill:none;stroke:#ffffff;stroke-width:1;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0;marker:none;visibility:visible;display:inline;overflow:visible"
+       id="path4853"
+       d="m 31.657235,23.378571 13.475546,13.185793 -6.921861,0.277459 c 0,0 3.872136,7.756567 3.872136,7.756567 0.402731,1.650134 -2.028275,2.412565 -2.5071,1.152867 0,0 -3.683065,-7.844955 -3.683065,-7.844955 l -4.424727,4.708334 0.189071,-19.236065 z" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/wifi/data/misc/icon.svg 3.4.1+git20201022.a0d3415c-1/wifi/data/misc/icon.svg
--- 3.4.1-6/wifi/data/misc/icon.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/wifi/data/misc/icon.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,775 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   version="1.0"
+   width="48"
+   height="48"
+   id="svg2"
+   inkscape:version="0.47pre4 r22446"
+   sodipodi:docname="link-0.svg">
+  <metadata
+     id="metadata46">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+        <dc:title></dc:title>
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <sodipodi:namedview
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1"
+     objecttolerance="10"
+     gridtolerance="10"
+     guidetolerance="10"
+     inkscape:pageopacity="0"
+     inkscape:pageshadow="2"
+     inkscape:window-width="1417"
+     inkscape:window-height="800"
+     id="namedview44"
+     showgrid="false"
+     inkscape:zoom="6.1300268"
+     inkscape:cx="7.092166"
+     inkscape:cy="23.568063"
+     inkscape:window-x="0"
+     inkscape:window-y="25"
+     inkscape:window-maximized="0"
+     inkscape:current-layer="svg2" />
+  <defs
+     id="defs4">
+    <inkscape:perspective
+       sodipodi:type="inkscape:persp3d"
+       inkscape:vp_x="0 : 24 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_z="48 : 24 : 1"
+       inkscape:persp3d-origin="24 : 16 : 1"
+       id="perspective48" />
+    <linearGradient
+       id="linearGradient6326">
+      <stop
+         id="stop6328"
+         style="stop-color:#da8813;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6330"
+         style="stop-color:#c56212;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient3156">
+      <stop
+         id="stop3158"
+         style="stop-color:white;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop3160"
+         style="stop-color:white;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6493">
+      <stop
+         id="stop6495"
+         style="stop-color:#cd8033;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop6497"
+         style="stop-color:#bb5e12;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4103">
+      <stop
+         id="stop4105"
+         style="stop-color:#edd563;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop4107"
+         style="stop-color:#e08223;stop-opacity:1"
+         offset="1" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient8838">
+      <stop
+         id="stop8840"
+         style="stop-color:black;stop-opacity:1"
+         offset="0" />
+      <stop
+         id="stop8842"
+         style="stop-color:black;stop-opacity:0"
+         offset="1" />
+    </linearGradient>
+    <radialGradient
+       cx="62.625"
+       cy="4.625"
+       r="10.625"
+       fx="62.625"
+       fy="4.625"
+       id="radialGradient5729"
+       xlink:href="#linearGradient8838"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1,0,0,0.341176,0,3.047059)" />
+    <linearGradient
+       x1="24.335312"
+       y1="61.852856"
+       x2="28.290144"
+       y2="20.663898"
+       id="linearGradient5745"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="27.888655"
+       y1="-0.81503254"
+       x2="28.290144"
+       y2="20.663898"
+       id="linearGradient5747"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="28.220636"
+       y1="-2.3103411"
+       x2="28.290144"
+       y2="20.663898"
+       id="linearGradient5749"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       x1="30.501778"
+       y1="55.647495"
+       x2="29.724815"
+       y2="24.653727"
+       id="linearGradient5751"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       cx="22.944935"
+       cy="11.222695"
+       r="14"
+       fx="22.944935"
+       fy="4.7612267"
+       id="radialGradient5537"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.3571044,0.01021839,-0.00631345,0.8384895,-10.874695,1.3057951)" />
+    <radialGradient
+       cx="22.125"
+       cy="10.874998"
+       r="20"
+       fx="22.125"
+       fy="10.874998"
+       id="radialGradient5540"
+       xlink:href="#linearGradient3156"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.0099925,-0.1119962,0.05668752,0.5112133,-5.8375646,1.7934718)" />
+    <radialGradient
+       cx="20.038782"
+       cy="12.610249"
+       r="22.463524"
+       fx="20.038782"
+       fy="12.610249"
+       id="radialGradient5551"
+       xlink:href="#linearGradient3242-187-536"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.9524671,-0.05018139,0.03650944,1.4214826,-20.408334,-5.9089096)" />
+    <linearGradient
+       x1="29.01346"
+       y1="29"
+       x2="29.75"
+       y2="50"
+       id="linearGradient5553"
+       xlink:href="#linearGradient6403"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="translate(-5.0000016,-6)" />
+    <radialGradient
+       cx="26"
+       cy="15.240479"
+       r="15.074549"
+       fx="26"
+       fy="15.240479"
+       id="radialGradient6332"
+       xlink:href="#linearGradient2490-182-124"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(2.2554569,0,-2.1857407e-8,2.0564463,-32.641879,-17.341228)" />
+    <inkscape:perspective
+       id="perspective7211"
+       inkscape:persp3d-origin="24 : 16 : 1"
+       inkscape:vp_z="48 : 24 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_x="0 : 24 : 1"
+       sodipodi:type="inkscape:persp3d" />
+    <linearGradient
+       gradientTransform="matrix(1.0408371,0,0,1.0332075,-1.5095624,-1.577785)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient2782"
+       id="linearGradient2471"
+       y2="57.84119"
+       x2="10.728143"
+       y1="9.965703"
+       x1="10.440458" />
+    <linearGradient
+       id="linearGradient2782">
+      <stop
+         offset="0"
+         style="stop-color:white;stop-opacity:1"
+         id="stop2784" />
+      <stop
+         offset="1"
+         style="stop-color:white;stop-opacity:0"
+         id="stop2786" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="matrix(1.0426124,0,0,1.0259981,0.1237342,-1.1239408)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient6403"
+       id="linearGradient2474"
+       y2="44.971333"
+       x2="12.35"
+       y1="3.0447822"
+       x1="12.350002" />
+    <linearGradient
+       gradientTransform="matrix(1.0408371,0,0,1.0332076,20.490446,-1.577786)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient2782"
+       id="linearGradient2481"
+       y2="57.84119"
+       x2="10.728143"
+       y1="9.965703"
+       x1="10.440458" />
+    <linearGradient
+       gradientTransform="matrix(1.0426124,0,0,1.0259979,22.123737,-1.1239411)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient6403"
+       id="linearGradient2484"
+       y2="44.971333"
+       x2="12.35"
+       y1="3.0447831"
+       x1="12.349999" />
+    <linearGradient
+       id="linearGradient6403">
+      <stop
+         offset="0"
+         style="stop-color:#eeeeec;stop-opacity:1"
+         id="stop6405" />
+      <stop
+         offset="1"
+         style="stop-color:#a1a59b;stop-opacity:1"
+         id="stop6409" />
+    </linearGradient>
+    <inkscape:perspective
+       id="perspective8012"
+       inkscape:persp3d-origin="24 : 16 : 1"
+       inkscape:vp_z="48 : 24 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_x="0 : 24 : 1"
+       sodipodi:type="inkscape:persp3d" />
+    <linearGradient
+       gradientTransform="matrix(1.0317991,-1.0287411,1.0317991,1.0287411,-59.146403,28.538123)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient1322"
+       id="linearGradient2179"
+       y2="46.420933"
+       x2="34.162975"
+       y1="30.701427"
+       x1="49.882484" />
+    <linearGradient
+       id="linearGradient1322">
+      <stop
+         offset="0"
+         style="stop-color:#b4b4b4;stop-opacity:1"
+         id="stop1324" />
+      <stop
+         offset="1"
+         style="stop-color:#505050;stop-opacity:1"
+         id="stop1326" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="matrix(1.0317991,-1.0287411,1.0317991,1.0287411,-26.552863,23.963668)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient7916"
+       id="linearGradient2181"
+       y2="32.849743"
+       x2="16.14513"
+       y1="17.130236"
+       x1="31.864639" />
+    <linearGradient
+       id="linearGradient7916">
+      <stop
+         offset="0"
+         style="stop-color:white;stop-opacity:1"
+         id="stop7918" />
+      <stop
+         offset="1"
+         style="stop-color:white;stop-opacity:0.34020618"
+         id="stop7920" />
+    </linearGradient>
+    <radialGradient
+       gradientTransform="matrix(0.914812,0.01265023,-0.00821502,0.213562,2.253914,27.18889)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient2091"
+       id="radialGradient2177"
+       fy="35.127438"
+       fx="23.070683"
+       r="10.31934"
+       cy="35.127438"
+       cx="23.070683" />
+    <linearGradient
+       id="linearGradient2091">
+      <stop
+         offset="0"
+         style="stop-color:black;stop-opacity:1"
+         id="stop2093" />
+      <stop
+         offset="1"
+         style="stop-color:black;stop-opacity:0"
+         id="stop2095" />
+    </linearGradient>
+    <inkscape:perspective
+       id="perspective8055"
+       inkscape:persp3d-origin="24 : 16 : 1"
+       inkscape:vp_z="48 : 24 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_x="0 : 24 : 1"
+       sodipodi:type="inkscape:persp3d" />
+    <linearGradient
+       gradientTransform="matrix(0,-0.8625289,0.8486552,0,3.2697061,51.022455)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient2187"
+       id="linearGradient2479"
+       y2="-0.43754432"
+       x2="20.483631"
+       y1="12.820101"
+       x1="20.483631" />
+    <linearGradient
+       id="linearGradient2187">
+      <stop
+         offset="0"
+         style="stop-color:#ffffff;stop-opacity:0.64341086"
+         id="stop2189" />
+      <stop
+         offset="1"
+         style="stop-color:#ffffff;stop-opacity:0"
+         id="stop2191" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="matrix(0.7241542,0,0,0.7359927,1.978684,11.204435)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3698"
+       id="linearGradient2482"
+       y2="15.5"
+       x2="-0.073089309"
+       y1="15.5"
+       x1="23.996828" />
+    <linearGradient
+       id="linearGradient3698">
+      <stop
+         offset="0"
+         style="stop-color:#7ea8ce;stop-opacity:1"
+         id="stop3700" />
+      <stop
+         offset="0.76278943"
+         style="stop-color:#568dc0;stop-opacity:0.81568629"
+         id="stop3702" />
+      <stop
+         offset="1"
+         style="stop-color:#c9e1f8;stop-opacity:0"
+         id="stop3704" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="matrix(0.7241542,0,0,0.7359927,1.978684,11.204435)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3914"
+       id="linearGradient2484-9"
+       y2="36"
+       x2="-0.097514458"
+       y1="36"
+       x1="36.5" />
+    <linearGradient
+       id="linearGradient3914">
+      <stop
+         offset="0"
+         style="stop-color:#2c79c0;stop-opacity:1"
+         id="stop3916" />
+      <stop
+         offset="0.79722267"
+         style="stop-color:#2970b3;stop-opacity:0.49803922"
+         id="stop3918" />
+      <stop
+         offset="1"
+         style="stop-color:#236098;stop-opacity:0"
+         id="stop3920" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="matrix(0.9976985,0,0,1.0406866,0.1638029,-1.1057939)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient8589"
+       id="linearGradient3312"
+       y2="5.4565363"
+       x2="36.358372"
+       y1="8.0590115"
+       x1="32.892288" />
+    <linearGradient
+       id="linearGradient8589">
+      <stop
+         offset="0"
+         style="stop-color:#fefefe;stop-opacity:1"
+         id="stop8591" />
+      <stop
+         offset="1"
+         style="stop-color:#cbcbcb;stop-opacity:1"
+         id="stop8593" />
+    </linearGradient>
+    <filter
+       id="filter3212"
+       x="-0.14846256"
+       width="1.2969251"
+       y="-0.16434373"
+       height="1.3286875">
+      <feGaussianBlur
+         inkscape:collect="always"
+         stdDeviation="0.77391625"
+         id="feGaussianBlur3214" />
+    </filter>
+    <linearGradient
+       gradientTransform="matrix(1,0,0,0.9777778,0,-0.9666693)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3211"
+       id="linearGradient3316"
+       y2="46.01725"
+       x2="24"
+       y1="1.9999999"
+       x1="24" />
+    <linearGradient
+       id="linearGradient3211">
+      <stop
+         offset="0"
+         style="stop-color:#ffffff;stop-opacity:1"
+         id="stop3213" />
+      <stop
+         offset="1"
+         style="stop-color:#ffffff;stop-opacity:0"
+         id="stop3215" />
+    </linearGradient>
+    <radialGradient
+       gradientTransform="matrix(0.3617022,0,0,-0.3907784,0.8510637,47.517004)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#XMLID_8_"
+       id="radialGradient3319"
+       r="139.55859"
+       cy="112.3047"
+       cx="102" />
+    <radialGradient
+       gradientUnits="userSpaceOnUse"
+       id="XMLID_8_"
+       r="139.55859"
+       cy="112.3047"
+       cx="102">
+      <stop
+         offset="0"
+         style="stop-color:#b7b8b9;stop-opacity:1"
+         id="stop41" />
+      <stop
+         offset="0.18851049"
+         style="stop-color:#ececec;stop-opacity:1"
+         id="stop47" />
+      <stop
+         offset="0.25718147"
+         style="stop-color:#fafafa;stop-opacity:0"
+         id="stop49" />
+      <stop
+         offset="0.30111277"
+         style="stop-color:#ffffff;stop-opacity:0"
+         id="stop51" />
+      <stop
+         offset="0.53130001"
+         style="stop-color:#fafafa;stop-opacity:0"
+         id="stop53" />
+      <stop
+         offset="0.84490001"
+         style="stop-color:#ebecec;stop-opacity:0"
+         id="stop55" />
+      <stop
+         offset="1"
+         style="stop-color:#e1e2e3;stop-opacity:0"
+         id="stop57" />
+    </radialGradient>
+    <linearGradient
+       gradientTransform="matrix(1,0,0,0.9561695,-1.0064697e-7,-1.914922)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3600"
+       id="linearGradient3322"
+       y2="47.013336"
+       x2="25.132275"
+       y1="0.98520643"
+       x1="25.132275" />
+    <linearGradient
+       id="linearGradient3600">
+      <stop
+         offset="0"
+         style="stop-color:#f4f4f4;stop-opacity:1"
+         id="stop3602" />
+      <stop
+         offset="1"
+         style="stop-color:#dbdbdb;stop-opacity:1"
+         id="stop3604" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="matrix(0.8074968,0,0,0.8948322,59.410232,-2.9805533)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3104"
+       id="linearGradient3324"
+       y2="2.9062471"
+       x2="-51.786404"
+       y1="50.786446"
+       x1="-51.786404" />
+    <linearGradient
+       id="linearGradient3104">
+      <stop
+         offset="0"
+         style="stop-color:#aaaaaa;stop-opacity:1"
+         id="stop3106" />
+      <stop
+         offset="1"
+         style="stop-color:#c8c8c8;stop-opacity:1"
+         id="stop3108" />
+    </linearGradient>
+    <radialGradient
+       gradientTransform="matrix(2.3039948e-2,0,0,1.4700216e-2,26.360882,37.040176)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient5060"
+       id="radialGradient3327"
+       fy="486.64789"
+       fx="605.71429"
+       r="117.14286"
+       cy="486.64789"
+       cx="605.71429" />
+    <linearGradient
+       id="linearGradient5060">
+      <stop
+         offset="0"
+         style="stop-color:#000000;stop-opacity:1"
+         id="stop5062" />
+      <stop
+         offset="1"
+         style="stop-color:#000000;stop-opacity:0"
+         id="stop5064" />
+    </linearGradient>
+    <radialGradient
+       gradientTransform="matrix(-2.3039943e-2,0,0,1.4700216e-2,21.62311,37.040176)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient5060"
+       id="radialGradient3330"
+       fy="486.64789"
+       fx="605.71429"
+       r="117.14286"
+       cy="486.64789"
+       cx="605.71429" />
+    <linearGradient
+       gradientTransform="matrix(6.7324884e-2,0,0,1.4700216e-2,-0.3411391,37.040146)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient5048"
+       id="linearGradient3333"
+       y2="609.50507"
+       x2="302.85715"
+       y1="366.64789"
+       x1="302.85715" />
+    <linearGradient
+       id="linearGradient5048">
+      <stop
+         offset="0"
+         style="stop-color:#000000;stop-opacity:0"
+         id="stop5050" />
+      <stop
+         offset="0.5"
+         style="stop-color:#000000;stop-opacity:1"
+         id="stop5056" />
+      <stop
+         offset="1"
+         style="stop-color:#000000;stop-opacity:0"
+         id="stop5052" />
+    </linearGradient>
+    <inkscape:perspective
+       id="perspective8067"
+       inkscape:persp3d-origin="24 : 16 : 1"
+       inkscape:vp_z="48 : 24 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_x="0 : 24 : 1"
+       sodipodi:type="inkscape:persp3d" />
+    <linearGradient
+       gradientTransform="matrix(2.1153735,0,0,2.1153253,-107.57709,32.426559)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient4873"
+       id="linearGradient3526"
+       y2="5.4675598"
+       x2="63.397362"
+       y1="-12.489107"
+       x1="63.397362" />
+    <linearGradient
+       id="linearGradient4873">
+      <stop
+         offset="0"
+         style="stop-color:white;stop-opacity:1"
+         id="stop4875" />
+      <stop
+         offset="1"
+         style="stop-color:white;stop-opacity:0"
+         id="stop4877" />
+    </linearGradient>
+    <radialGradient
+       gradientTransform="matrix(0,2.2874593,-3.0194057,0,36.047437,-50.630156)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient3242-187-536"
+       id="radialGradient3529"
+       fy="3.9900031"
+       fx="23.895569"
+       r="20.397499"
+       cy="3.9900031"
+       cx="23.895569" />
+    <linearGradient
+       id="linearGradient3242-187-536">
+      <stop
+         offset="0"
+         style="stop-color:#8badea;stop-opacity:1"
+         id="stop2778" />
+      <stop
+         offset="0.26238"
+         style="stop-color:#6396cd;stop-opacity:1"
+         id="stop2780" />
+      <stop
+         offset="0.66093999"
+         style="stop-color:#3b7caf;stop-opacity:1"
+         id="stop2782" />
+      <stop
+         offset="1"
+         style="stop-color:#194c70;stop-opacity:1"
+         id="stop2784-2" />
+    </linearGradient>
+    <linearGradient
+       gradientTransform="matrix(0.9584364,0,0,0.9584366,0.9975246,1.9975253)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient2490-182-124"
+       id="linearGradient3531"
+       y2="3.0816143"
+       x2="18.379412"
+       y1="44.980297"
+       x1="18.379412" />
+    <linearGradient
+       id="linearGradient2490-182-124">
+      <stop
+         offset="0"
+         style="stop-color:#1f4b6a;stop-opacity:1"
+         id="stop2788" />
+      <stop
+         offset="1"
+         style="stop-color:#4083c2;stop-opacity:1"
+         id="stop2790" />
+    </linearGradient>
+    <radialGradient
+       gradientTransform="matrix(2.1647059,0,0,0.7529402,-111.56471,36.517647)"
+       gradientUnits="userSpaceOnUse"
+       xlink:href="#linearGradient8838-1"
+       id="radialGradient3534"
+       fy="4.625"
+       fx="62.625"
+       r="10.625"
+       cy="4.625"
+       cx="62.625" />
+    <linearGradient
+       id="linearGradient8838-1">
+      <stop
+         offset="0"
+         style="stop-color:black;stop-opacity:1"
+         id="stop8840-0" />
+      <stop
+         offset="1"
+         style="stop-color:black;stop-opacity:0"
+         id="stop8842-2" />
+    </linearGradient>
+    <inkscape:perspective
+       id="perspective8163"
+       inkscape:persp3d-origin="24 : 16 : 1"
+       inkscape:vp_z="48 : 24 : 1"
+       inkscape:vp_y="0 : 1000 : 0"
+       inkscape:vp_x="0 : 24 : 1"
+       sodipodi:type="inkscape:persp3d" />
+  </defs>
+  <g
+     id="layer1">
+    <g
+       id="g6334">
+      <path
+         d="m 73.25,4.625 c 0,2.0020323 -4.756974,3.6250001 -10.625,3.6250001 C 56.756974,8.2500001 52,6.6270323 52,4.625 52,2.6229677 56.756974,0.99999989 62.625,0.99999989 c 5.868026,0 10.625,1.62296781 10.625,3.62500011 l 0,0 z"
+         transform="matrix(1.9262213,0,0,2.1088276,-97.163508,29.602172)"
+         id="path8836"
+         style="opacity:0.4;fill:url(#radialGradient5729);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:0.49589729;marker:none;visibility:visible;display:inline;overflow:visible" />
+      <path
+         d="m 44.500921,23 c 0,11.316512 -9.178384,20.500922 -20.487463,20.500922 -11.30908,0 -20.4874629,-9.18441 -20.4874629,-20.500922 0,-11.316509 9.1783829,-20.5009224 20.4874629,-20.5009224 11.309079,0 20.487463,9.1844134 20.487463,20.5009224 z"
+         id="path1307"
+         style="fill:url(#radialGradient5551);fill-opacity:1;stroke:#1f4b6a;stroke-width:0.99815505999999998;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="M 43.219099,18.237303 43.03226,18.957842 C 42.479353,18.498341 41.858575,18.11192 41.228194,17.708339 l -1.383757,0.143595 -1.264237,-1.007844 0,1.247283 1.083135,0.577996 0.720932,0.57578 0.963449,-0.768406 c 0.242517,0.320344 0.481723,0.640687 0.722585,0.961031 l 0,0.95998 -1.08479,0.864133 -1.985167,0.961031 -1.503445,1.058044 -0.963448,-0.770739 0.481724,-0.864133 -0.961957,-0.768403 -1.62462,-2.448926 -1.383757,-1.103574 -0.362204,0.287307 0.54314,1.393213 1.021718,0.816269 c 0.583533,1.18798 1.160774,2.323424 1.927064,3.458986 1.188253,0 2.30847,-0.08896 3.48861,-0.193795 l 0,0.672677 -1.443683,2.497372 -1.323998,1.05571 -1.083133,1.634872 c 0,0.896122 0,1.792244 0,2.688249 l 0.362204,1.058043 -0.601411,0.478882 -1.325653,0.576827 -1.383756,0.816269 1.14455,0.912115 -1.564859,0.962198 0.300623,0.622477 -2.347372,1.874314 -1.563204,0 -1.323998,0.576828 -0.843926,0 0,-0.768404 -0.358894,-1.539144 c -0.465667,-0.964534 -0.950536,-1.92218 -1.443684,-2.879825 0,-0.70688 0.05976,-1.406872 0.119686,-2.113636 l 0.603068,-0.95998 -0.843929,-1.153773 0.06142,-1.584674 -1.14455,-0.912115 0.572274,-1.32025 -0.931169,-0.745056 -1.626273,0 -0.541485,-0.432068 -1.62462,0.721124 -0.661169,-0.529547 -1.5051,0.912582 c -1.02172,-0.816853 -2.045094,-1.633121 -3.068303,-2.44939 L 13.07,21.741935 l 1.083137,-1.151436 -0.601412,-0.479933 1.322342,-2.210651 c 1.086444,-0.953092 2.221227,-1.867425 3.369089,-2.785143 l 2.046584,-0.384204 2.285956,-0.191576 1.564859,0.288473 2.226032,1.583506 0.78251,-0.623643 1.081479,-0.09573 2.046584,0.479932 1.564861,0 1.083134,-0.672675 0.481723,-0.479932 -1.08479,-0.479932 -1.80572,-0.09573 c -0.501093,-0.490204 -0.966759,-1.005508 -1.561715,-1.441076 l -0.603065,0.191574 -0.240865,1.249502 -1.083133,-0.864131 -0.239207,-0.962199 -1.20282,-0.670338 -0.48338,0 1.20431,0.959978 -0.481723,0.864134 -0.961959,0.191576 0.60141,-0.864134 -1.084791,-0.383036 -0.960303,-0.768403 -1.807377,0.287304 -0.239206,0.383036 -1.083134,0.481099 -0.601411,1.056877 -1.503445,0.527797 -0.662824,-0.527797 -0.720932,0 0,-1.729435 1.564859,-0.576829 1.20282,0 -0.242517,-0.671507 -0.960303,-0.672675 1.62313,-0.240609 0.902032,-0.719371 0.720931,-0.8653012 1.325654,0 -0.362206,-0.6715064 0.843929,-0.3842031 0,0.7684043 1.804066,0.2873052 1.804067,-1.0557095 0.121174,-0.481099 1.563205,-0.7678216 c -0.56582,0.049618 -1.131638,0.08604 -1.684545,0.1921611 l 0,-0.8651834 0.601409,-0.9605654 -0.601409,0 -1.321678,0.8641345 -0.362207,0.4805153 0.362207,0.673259 -0.603067,1.1514366 -0.96196,-0.3842011 -0.840618,-0.6715065 -1.325651,0.6715065 -0.481725,-1.5362228 2.285956,-1.0562945 0,-0.5768291 L 25.223524,3.6847867 27.509479,3.3 l 1.56486,0.3847867 2.166268,0.9599803 -1.564858,0 1.564858,1.1526075 1.202823,-0.9599824 c 0,0 4.786235,2.4031505 7.258281,5.7266459 2.405352,3.233831 3.412213,6.909414 3.517388,7.673265 z"
+         id="path6628"
+         style="fill:url(#radialGradient6332);fill-opacity:1.0;fill-rule:nonzero;stroke:none" />
+      <path
+         d="m 43.501763,23 c 0,10.764976 -8.736791,19.501764 -19.501765,19.501764 C 13.235024,42.501764 4.4982338,33.764976 4.4982338,23 c 0,-10.764974 8.7367902,-19.5017646 19.5017642,-19.5017646 10.764974,0 19.501765,8.7367906 19.501765,19.5017646 z"
+         id="path3164"
+         style="opacity:0.7;fill:none;stroke:url(#radialGradient5540);stroke-width:0.99647081;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="m 42.999998,16.746704 c 0,7.114117 -8.512001,11.02908 -18.999999,11.02908 -10.488002,0 -19.0000006,-3.914963 -19.0000006,-11.02908 C 4.9999984,9.632588 13.511997,2 23.999999,2 34.487997,2 42.999998,9.632588 42.999998,16.746704 z"
+         id="path3154"
+         style="opacity:0.5;fill:url(#radialGradient5537);fill-opacity:1;stroke:none" />
+      <path
+         d="m 46,24.25 c 0,9.664983 -7.835017,17.5 -17.5,17.5 -9.664983,0 -17.5,-7.835017 -17.5,-17.5 0,-9.664983 7.835017,-17.5 17.5,-17.5 9.664983,0 17.5,7.835017 17.5,17.5 l 0,0 z"
+         transform="matrix(1.076193,-0.2912862,0.1952728,0.7143165,-11.182741,14.979481)"
+         id="path2218"
+         style="opacity:0.5;fill:none;stroke:url(#linearGradient5745);stroke-width:1.09524393;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="m 46,24.25 c 0,9.664983 -7.835017,17.5 -17.5,17.5 -9.664983,0 -17.5,-7.835017 -17.5,-17.5 0,-9.664983 7.835017,-17.5 17.5,-17.5 9.664983,0 17.5,7.835017 17.5,17.5 l 0,0 z"
+         transform="matrix(1.1247273,-0.00679075,0.00112312,0.7429216,-7.8873839,2.6776872)"
+         id="path2230"
+         style="opacity:0.5;fill:none;stroke:url(#linearGradient5747);stroke-width:1.0902828;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="m 46,24.25 c 0,9.664983 -7.835017,17.5 -17.5,17.5 -9.664983,0 -17.5,-7.835017 -17.5,-17.5 0,-9.664983 7.835017,-17.5 17.5,-17.5 9.664983,0 17.5,7.835017 17.5,17.5 l 0,0 z"
+         transform="matrix(-0.09940095,-1.1197712,0.6946105,-0.03998764,8.1749534,56.475018)"
+         id="path2234"
+         style="opacity:0.5;fill:none;stroke:url(#linearGradient5749);stroke-width:1.12890089;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="m 46,24.25 c 0,9.664983 -7.835017,17.5 -17.5,17.5 -9.664983,0 -17.5,-7.835017 -17.5,-17.5 0,-9.664983 7.835017,-17.5 17.5,-17.5 9.664983,0 17.5,7.835017 17.5,17.5 l 0,0 z"
+         transform="matrix(-0.1600777,-1.1032472,0.4856389,0.01692093,16.935466,54.089297)"
+         id="path2240"
+         style="opacity:0.5;fill:none;stroke:url(#linearGradient5751);stroke-width:1.36711621;stroke-linecap:round;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;stroke-dashoffset:0" />
+      <path
+         d="m 31.375,37.875 c 0,0.966498 -0.783502,1.75 -1.75,1.75 -0.966498,0 -1.75,-0.783502 -1.75,-1.75 0,-0.966498 0.783502,-1.75 1.75,-1.75 0.966498,0 1.75,0.783502 1.75,1.75 l 0,0 z"
+         transform="matrix(0.7873429,-0.2144143,0.2141677,0.7882494,1.2604149,11.541737)"
+         id="path2255"
+         style="opacity:0.4;fill:white;fill-opacity:1;stroke:none" />
+      <path
+         d="m 31.375,37.875 c 0,0.966498 -0.783502,1.75 -1.75,1.75 -0.966498,0 -1.75,-0.783502 -1.75,-1.75 0,-0.966498 0.783502,-1.75 1.75,-1.75 0.966498,0 1.75,0.783502 1.75,1.75 l 0,0 z"
+         transform="matrix(0.6748654,-0.1837837,0.2141677,0.7882494,-14.193998,12.29353)"
+         id="path2275"
+         style="opacity:0.4;fill:white;fill-opacity:1;stroke:none" />
+      <path
+         d="m 31.375,37.875 c 0,0.966498 -0.783502,1.75 -1.75,1.75 -0.966498,0 -1.75,-0.783502 -1.75,-1.75 0,-0.966498 0.783502,-1.75 1.75,-1.75 0.966498,0 1.75,0.783502 1.75,1.75 l 0,0 z"
+         transform="matrix(0.7873429,-0.2144143,0.324169,0.6373544,-8.3660962,-9.8985024)"
+         id="path2283"
+         style="opacity:0.4;fill:white;fill-opacity:1;stroke:none" />
+      <path
+         d="m 31.375,37.875 c 0,0.966498 -0.783502,1.75 -1.75,1.75 -0.966498,0 -1.75,-0.783502 -1.75,-1.75 0,-0.966498 0.783502,-1.75 1.75,-1.75 0.966498,0 1.75,0.783502 1.75,1.75 l 0,0 z"
+         transform="matrix(0.7873429,-0.2144143,-0.01326253,0.7292459,-10.705973,-10.742804)"
+         id="path2291"
+         style="opacity:0.4;fill:white;fill-opacity:1;stroke:none" />
+    </g>
+  </g>
+</svg>
Binary files 3.4.1-6/wifi/data/misc/old/icon.png and 3.4.1+git20201022.a0d3415c-1/wifi/data/misc/old/icon.png differ
diff -pruN 3.4.1-6/wifi/data/misc/old/link-0.svg 3.4.1+git20201022.a0d3415c-1/wifi/data/misc/old/link-0.svg
--- 3.4.1-6/wifi/data/misc/old/link-0.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/wifi/data/misc/old/link-0.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,263 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="48px"
+   height="48px"
+   id="svg2160"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   sodipodi:docbase="/home/changfu/Documents/Install/Cairo-Dock/plug-ins/wifi/data/src"
+   sodipodi:docname="default.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="7"
+     inkscape:cx="24"
+     inkscape:cy="24"
+     inkscape:current-layer="layer1"
+     showgrid="true"
+     inkscape:grid-bbox="true"
+     inkscape:document-units="px"
+     inkscape:window-width="762"
+     inkscape:window-height="635"
+     inkscape:window-x="10"
+     inkscape:window-y="65" />
+  <defs
+     id="defs2162" />
+  <metadata
+     id="metadata2165">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:label="Layer 1"
+     id="layer1"
+     inkscape:groupmode="layer">
+    <image
+       y="0"
+       x="0"
+       height="48"
+       xlink:href="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAIAAAACACAQAAABpN6lAAAAAAXNSR0IArs4c6QAAAAJiS0dEAP+H
+j8y/AAAACXBIWXMAAAsTAAALEwEAmpwYAAAAB3RJTUUH2AMKAwIIJA/6vwAAIABJREFUeNrlnXmQ
+Xdld3z/nnHvve/1er2q1pJY0kkbbjGfxeHbj8cIAsTEQm7BVKoEyJhQUBIqislAVEoKzUQmVIpWA
+k4IKEAxUuWI7eMU2trE9xmPPvmj2kTSSWmvv/fpt995zTv64v3vefWpJLck2mGRU0y297n79zu/8
+ft/f9/f9/c55yvP/93/RX/cvVBExMYYIEx705GRkZD7/f9IAyjCaTPmmb8Sju/eYw+51bqfab2Yc
+GoeGjJMc4XleaMxl66qj2uky697+tby2b2UIKMVosrV24+Qt6pA7rPaoWSas1vjK1oOSjxqFdmrV
+nXZz+mX/8uoL9lhrgbb3fysN8ECkdx374egOt80ctHuJPR6NA8Dh5G8KgIQRRnA4MjIcCgWZOsEr
+zGdPtz68Nvet84ZvgQGUek/0wrsb/3D5wOJBPWJRgMJhsXhAozDUiKgRs4UdJHQ5yQItMUyCBlTx
+p8urHO184Pyfefe3wgC/tOfZ957/qfUd/VipCI+n3LwxdnIje5hlhnFGMTSYoEaPFdZYocU5znKS
+o5zFoplB0QY81pNx2v/+6h8sn/42NoCqv+Xw1h9+9mf19o7EtcdjmGQvh7id/UyTUJPYr9EkoUuH
+Lkp23GHJaHOWl3iBRcbp0KVFizYpGn+e98/8n8de9v1vOwOo2o138ib3vmR0inkyFI6EKXZwE29k
+D01ZOHg0EaOMkLJOD48qdhktRgMH9FiiTYvXmOMsF1giJ8dg1w78WutrTzzp028bA6h47Napd+p/
+7HeOqb2cYB3HJFvZyy3cxA5GcGhBAogZZQzLGh0UYFECe16AscSKBmNkrHCOV3iKx2iTAY7cN+bc
++9f+fOl5n30bGGByYvRHk/dyr40Nd7HMHBPMsJMbOcQ2RvGAATQaaLCFiHXWyWTnlSTFYucLxHBY
+DCPiEZo+F/gsj3KaTB4xae3rrT9sf2h57W/YAHv2xn9k72TMobmJ1/E4U0yyh1uYoY5GY2TvIzJ2
+M4bnPP2C/sgCDS44fgGaHofG00MT4VGMscqXeJajzOPIqVGn3fKPpe85e+pv0AA3vl39T7+7WETE
+P+NzGBJex2FGhdgYNJ4ajoTdjNHmNBaFR1eex2Mx5Hj56DEktLDkhdPj2c0Cz/IqxznDEjHjrNNG
+zfmfmPvi34ABlN46M/kz9td8ZIlwTPEeYh5mioPsJZadNygiFIYmu0hY4Qyx7LUOHBBKSpzL16BJ
+jzYOR06GJ8ewnTOc5TRnmWOJOmssoyBXv9b9/YX562UJ0fXB3rY7xv+l/34XKQwROznIXfwRMxxi
+WnheAWuGDMU4syjmWEaTye5bQOMlC1h8CAPHKJoWDosjJ8fh6bPONvo4QDEDHGelKK7+TfM+9+/U
+M9cHiddhAJXs+O6xX7UPFAsZZ4ZtvIMj1DnENEaAzeEwgGcnu8mZYwWDpfAYAF3k9vC8DkfBG2us
+Y7GSIzSeHMc8N7CDPg7FCtuIWGcVB5H6wfGt/Ib63PWkRn3tRHf2+8Z/y76pAK6t7GEb4+ziDIcZ
+x8tuZWR4PBk72Emf4yxg6ZNiSclIyeljixqYjIwcS44lYwTFCjmODCdf8Vh6nKPJOIYt3MBBptjL
+VjQah31g/Le2vUvpb7kHKH3zj7j/4aYUGsN2tpPguZdVphnH4jBogb4Ixy72kPMKHSmFjDA+LSmQ
+gAReHksZpU2Gx0p2yIAchaVFh5tZBW5glmdoso8658hQyh1u/N5erT50rVhwjTbb84v2A3YKHAk3
+MEsEjLGfFRI6pKJsONmzbeylxhOskpELjSld24XvyrFYLD3xmnHOYwUBMlIgF3/JWSDiLvZwNzUS
+IjQ72UWjIFqT6gOzP/ct9AAzcuM/qv1rn4CnziyTQITiAGO8IrGdEeHJiYAp9uL5MrksOcJisMIK
+qVAghcXg6QG7WaWDFkpkSKVCLEJrmWVez0Fq9GlQx5GyjZiz9FD4pP5vD7ujf2i73wIPUPUD79K/
+4qZAk7CTSRISFIaddOiIu1LhfAeIOSYc3wkw2grfy2TnM4n3AgVmWEEHBtAXFmBRWDQ9VkhoEjHD
+TiI0ETDJLCN4NHrK/8qB71f1b7oHqGj796hf97s1joQZpojRgGOcG5gnR0vyy4ix1DhMnWMsYkEW
+ozHkKIx4gkKTo4T7eRQ5ngYXAIXFSXosPKAIL1gjZQTPKLsYEU7pmQDOkuNQe/37ZtfVX1ythHKV
+Bti1e/R9/mYPxEyznUhedsRWJjhGTiwpLMJhuZ1xTnMaxChKPutin8ilRig+OgkFxziWNQwjwhi8
+GCILJuqQAwpDXYQTg8cziWWeHqBumXife45T38QQUHHzT92dHoVimh3ioh5FxBg53RCnFkvOTezg
+HC+Qk5KSkdEno08uFX8uibJLSkqXPilORJALGDwpCTFafiIPFYLjEDkn6OKAWMhUwTm3MCXLcfdO
+/Ukcf9MM8JPx7f+d70AVy9+JISeXUkYzRYcuXpDdktFgP32eoss6HXp0seQS4T1yMvqkKHpioOLP
+Oj3W2caCcEgv9YQVLuhw9NjHbl7lizyOpclIIaRKPlFsZbrM1m85/Jsq+qaEwE/Gq/+g+xMFco+y
+HUNPMj0oYvbSokVMJsy/xr1YHqeNlycvotTgcGgycfyuACNCggtgjFmkjZLvHpGc4UnJMGznMIs8
+TEaPhN1McQovZkK2I2W9QKKfO/Co+uDmfYZNDbByz2v/QiUKqDODoSd1XiFjJUzzIjmeOg6H5yAj
+vMgcGosOVNYFQxTaD0KDfVAFrOBHV8DQk2GAjFxe5ji343iENSxtnmSUSRQ1MryUX3UU2znLCn26
+Sf1Xb3iZR79BA/zybPrTqwdqKDRbqJeSNQqHI6YOrOAw5GgUu9nJAkckep3kci9gmBOFhFgYR8m/
+S2VAkwbwg5w6mgyLZwv3Y3iMZVIsjhPs4lbOcp6UcXYyDqywRouImHXGWD889tONE50L34AB3hD/
+/Xd84ofqRqEYoyn0pdwzhScmoy1pzTPJARRP4MgEnhCw9EJ/MjGfl11XGFIxUREyfYlnL4hSI2Kd
+G7iPOl9kHi8eZVnlzfwAy9SoM88RTrBIH0ufFm0Aw49t/5L64JUT4hUN8KO3fPIXkkmPImaszAh4
+qfIKwSOnK/GvmWaaJ7mAxWBAgM+JqRQIR/ShJVI8kmHI0PITaRDICsKccCuvx/MplrE4MdwIdRJu
+xvMqD/EUy3TweDyOmLRAhcn6z+99iuevMwv8/sgL7+7cHQGaBk3ZQ1/5QUWDjB45npwGd3KGE+Qo
+cnHcFC8uXVaIBedTZDhx/S6OHEsfA6QY8ZBcPOgwb6LFR1giw5LTp0OHGe5hBFCsc5p10ReKFtso
+o4VyiH6g+W6VXJcB3m2WDx35uZ2MYYhohOgv1ZtiBxtY+nhyLLfQ5xhL5PQDh8tCw8vj5PGC2BSF
+TvGVMu7BCnoUwZIzzpvYz3H+kl5AlR6GW/k+Wjwmz2grbbbi8xg1TPFaf/7mG68jBJT6Lf0XP2t2
+TOJpMcJIgCqFE+5lBIN7WFJuYB+neEkKokySlxO0L5ZUcvxCJC0ecfIycmJiwQ0njryXO4EneI0a
+mo7UhVu4i4M8z2OktPgOzklLreAlFlDUGKFDBJjd7mf4J9dsgHepo4fnfjzBs4NlRkK9rqSi12KO
+SPYl5S46PEeKFVKck6DIiCQ/WMDTF+KipQkKFoMjw1NnGkUsXrONw+zlOM8xT8YII7SxWG7kfjSf
+Yo4e8OfskTykSbBSW3gUTcEBg3rv1vcvHL1GA0yZZ35DjXssB7gQihkfBE0vecDgsWTcxgTnOC5C
+SKEKNHGVPR4EUC5ZxAlXyAGDZowZGkyziOIOdpPwGdZYw2JZZZoaS9zBGznFX7IqzZN5HucAET2c
+EOJMckidREolNbXjN9WPXE4o0ZcOgO2z7bcaNAt0eRAlzQ2FJ5IqsEiDSrL5YRK+KmJInx6pMAWk
+nneCBU48wQo1KvABFGPMMstW7uHN/ACHuMAnOcVqOTrCGQz38wAv8SnWBEIdni9guA0rCbSoD4pW
+/AiaGEVM8rY9W68JBN8Tnf6n+ZgCWpxiJ/eJDziRPF3Zn5FW9n7GOcOyVPhpiMRcUp+TnOADuntB
+fgcYLI46u5lCcRO30uQ4z7MgYmgRUCn7eIBH+RI9YRMFze7wFNPEeIw8d51ItqqQ5zxqYusvX04v
+vOTD8Y0rbzO6gLo5jnM/bxCdnwB/xZjPGLdwG3ewnzm6eDJyQfWMPl16pBiRtfqi8ltSYXpWmIJn
+nIPskSDr8gLPc46MriTPHnA3b+QJng7Si5fiC15kgjFZSGGqIqTqRGIWY/T37tpzDRgw8sDK3kh4
+uuMpRniQOi/TEerqiIlpMMt2dvMOIsZYlJmnXIxUjkQUfmNJQsligiaoAc0kO7iZQ8TkGBzHeJnz
+ZFgyAU94A2/j6zyGCSJKiSmwhmcnS+KZWpBH46hjBbzNXv0Ar12lAW6bvOUtzfEWmXC9Ln9Fi7vZ
+zeOcE9HDMMZB7uVmDPtRnEXTLMcZ5GOBCGUPsIcmlkRqBRpH2MYOdjBNm0ewzHArfZ5lUZKrFbS5
+k/v4Gl8lY4xIAsuFlto6L7OLV2lVFpWi0dRFj0xhYvJt+mOudVUGWL/t/L2TyrEmkoejx9Ms8mbe
+wUkep42iwR7ezK3EQjzq7GJRNFwnXMGKk2pxSUtOjQyIidjNjUxTQ3OWr9OjR52EMaa4QJu+6IgO
+eD338SKP4NF0RQZDaoqCY5xjH0korkvZ3VGXDkSM1aP3bbmNh6/KAL296b5F7uMraGqAw9DjNB/i
+Xu7kVhb4MjUOc4AkFLQTHOAkHXKiQEoNnoyasPccjSZlFzezmxEgYpHHOCHMDzpYnuZeFukKTdbA
+Pt7CUR4ixeLJiGmyLtkH0RnXSWiwKpJbsW2FcFYW6Qr2mxuvygCqdu9BNZrR4yCvyH4W8rTmazzL
+67iDX6TOOI1Q1Hg0Y8SC9UawXaMZISImYZKtzDJNHUNOn2O8whJrAlsmlDgnuItInlXjmeItXOBR
+KYI8ij5jtFFiaEuEYp1l9nBeEqMPakUuucrisaMH9qlkY/NsgwF27NXv8MQ8x99hReZ3ohDb6zzG
+izzIW5kKYw3Ff7u5h1FW6GFISKgzSU6dSRo0UfTosUKLVZaZp00iZW9BlcrpsQvkTLNe5CJyvouI
+L7IUSuridYyzJgYpfrbLHDeQkIVOgwsNWEr+qnj7zg9ydBMDKPXG3f4NBUS9wt08RR8ttEfh8ET0
+eIgeP8hMKEAUMMKdHGaFdmB4Eet0abFMRpcOa6zSC3NCWWVRCItXZPSY5iQaS8ZbmOFhzkhTrdQd
+uzSFhhHUhSVuBlGbveQCJVS75Czunht3q2MXj11e7AHab9O1wrFeYzv38EhljEFJlZ6zzBJbKiQi
+4xlepCVyhhXZeomUVJDYhXApX3bZRy47RAWVvcAsT2Pw3MntPMHLAmpOQivGommwLjVFIZutA6P0
+xPHLn/AhQB0a6mom5OLLGiA2B7XWgq8v8J3cxrMD/xB0zWmxREY9mGWVF3iZRQaEO2G86N+HRqiX
+nfDBwYeL2KK2OMPt7GSFXdxBi+eD4bS8XI9njSm6eGm0eRTr9NnFBWmoE2S3UjBNsBjDXszFBriY
+CdZ4sw/V3jpP8Hr2BRGcYM9VjrIUFtDlGGfoBwpULDuWJy+7gRGaGIdGE5OhSGRo3GCIUSRMssRW
+7uUmHqDJR0XzLf4oYYpFVZJUfEmR02a/EKsyOFTwKqTeUG+ivgkVrjeit+nK4NoKf8GDHJBsXpIc
+T5tTHKFDTosWL/I0a/SlL6jCHLySpgXC+A2OmpimhsYSC7XWaGrU2Ma9bOeN/D0OcoaJigqhpPwu
+/rbKaMWzIhxzbK2ojT7UoSpULBr93SMjm4Dg3dt9XQfJU6FY4hN8P7t5RIygxA/Oc5IFesyxg1c4
+Qy9o8+UeQYJDEaGxYVyqH9SkSKSLVHYpYpK93EYdiHHs5oS0zItkrIMYU3qYFbQHzSqOBm2JehMK
+dyWJWaGxE/fPcP6KHqD3aVH9i5JHAct8ghm+k8mQrIoqLOUCT/EEc2g6pCFXlGNxxXhUHF5Q4cIJ
+seTp0pw1YRoJ08zSDDi+ja00qRGFiTPCUK0nY0ReTfGng6UeGjYlD9HSxInQJCTovZuEgN5X/rCS
+csajWOXzpLydndLaLIrcmDWe5CwXGBcRrDBBFF6WCfOhCCHS8vjw52JZI4wwJi7p8cQ0qFPMohgB
+QiUYoumLW0fi5n0c4xWgHsajskO1qQHUjA77U+weQjUe5xW+m/tk1lcTsZUOi/RYJpJJgQgdgMqQ
+yL4m1KgFw8RFgYoRLCgh0MjvzSt5wQhP0MGchii8aCXPoqXfnDETTG5CXyISM2scEWrbZgbYUv5C
+LUy7HGPr8zRf4fX8GE0UNQ5xq8Bai4xR6uK6hNMfRRggzxOJCVwwlBGUcYER5PSkYtS4IKnqsPcq
+DOBpHH0aQaBTWGnP6YpfRSElRhKAestmBtiG/ILiadJwdMFjOM2H6PGj3M9+HmSSFqPEtOiwHyeO
+qohJggE1SjRCZBlJcEnEEFGQWtp0wsBcTps18vC8RaKMAkJFOJrUKkcr1hgXqC37y4MgQFDAzGyS
+BfS0kbhXQlcGgiYoUj7LAzzIdiaBGZp4MtY5SINU2lYDgltkBBV2dfD44JxQKbdq6fku00YTE3OB
+BfoCqDkRPRIRQ0o90ROJoJ5j6LBDQsCRE5FjiEhDOBg0anozA4yaod5fWV9H4oqgeJn9HAbgZo7Q
+wbKEZy9zouEVCy6sbkNUKjFO6bAaLYNVOhDiLXieZg1FjT2cZlkcGSwZiZjKURPd0TFGV9DB05P2
+W4FSeTCzljojQaMbmxpADRHfwrls6N8qFG1OssIUMMabeYpXWCbhHtp42uR0S8CRDqEJHqXlBZU+
+FYnPFHS1ySyK5wJzmwoSlwtab0F+s2DeKbR4HmQYanRDg8yK53nhDnUyGNkMA6LC5WKJzaLCToAY
+TSys7iSP0eI0X6fOrTzILHAb72KWJhGNsLRIKKsJkVumxiTwAB12eTtTPE5Kny45J5iiPpQtSlwq
+6XM5ExAJ12sLThihSSYwEIgZKbKS2cwD1lUYZEIqqtJxo2CtNY4wxUmO4JjmZt7KLHUOscoKGV1x
+ehu6QMg0STk/TIVmIa20UXbQESXAo1jkAm/lE4HwlnVFInTcBVg0oWfsZNOM+EiJMArFRNF3Tjcj
+Qn2CnZX84poMwOrA71NgldP06HOGZzgny2oyTp26JLpiXw0RibQoiseNcAwjmT5BUWeGac7IS4qw
+aF6gySyGSNKnF9bg5bkMCkuNhFi+I5KegJKGiBF5zDPNBF0UUWczRWhRy6hKaUEfINALP8ilzuvS
+x5DQ4QgJd+GocQdnOEOPNn3J/oX9k9AKM5UcU5wh8nhq7GSdJZyoTzU8Xc5yEys4nJjEiich/0by
+QCrYXzZrcsEWI3loB/t5qfiJ5c0UoXlVEZ/KImLAuJWAkpEGdqHCt3mOlAMscpZRbqfHCitkAZeN
+cDIf8kPZX4yxGDIm2cpJmQjwATCP8BZ2MRdGr7UwgJIqIYKqE28rdt1JKVRQrQY3cIDnaRfPOb8Z
+BiyW+z4QlUygqeWeGWoy+FDSnGWep4HmAqdpsJtZZkmxnOW8oEiCpi8ySAwYmRaJiIjYzTpLaBIU
+acBuyxx7WKFLJgK9FbJscER4HOvE8nMxdSboy4GsohrYwiEmpMOsAb+0mQcsFdaLAngoeSlGklcR
+g4ZUYjEjJkexxgvcx1aOk7FOzDR7mGSM/SjOc4aUvgggKvRvi2jVjDHLOTIRSmP5jhQ4xww7OUEs
+s+Y68AIkVPs0WRUj1NlGjqdDH0uNe2mQ8Qgt4R1ucw/glArLJ+RwH8qSIuEkxPTChECJ6sWRuaZ0
+ac+xwFaaTGPYw176rLHEanBxRZ0GDerU2UtChwnW0GSSLQp8d5xjlmVa1MioiejiiciwwvQiGiTU
+eR33sJ8v0iOnxgH20ecEL9MS7HAo/NnNDHCyZPBWREgdqilTKWEiUVsGByIVcI7XMc0ZYgmYDmuc
+YpJxRqkxzXYsXVr0yNCMs51JatRo4NlNR6YEnSTfIrMss5WdnBBm38CRApaYWITw4iB2gzuAKe4m
+xzFGjzYvcbJShVhAn9jEAPEJ75T2oaB0AccJ4pYmErc34hMGRY6mS4ttLEt0F1V5RJt1NE0miYgZ
+ZVZ+8VaaJMEfJthJR84MlGJW0UZfYBctVsPZoYLjpZKlNIZRatzEDjywhx6vcIaWHNGz4ZkMPntu
+bhMDPLl612t+v5KXMKjwqmVRJHFMEEeUZN+UFfYwLfO+RfIqUb9Lh4iEhCYxo9wgrZVBWTRDSsya
+HJNLw1T4CiPsZF1wvSyHx0gYweIZJ6HJfSTkGPqc5zVOB56pK8McvPxsaxMDvNK789Pq55XswEC7
+jyozQuUtACYEgQn8boUZ9nFB+knFcciBQFGcCcrR9JlkunJmzKOoswPNhAxPIIOSBeCNsL/SSvHh
+t5at1ihMLM1xjGVSJlkfktDA4z4rnZkrYEDfPma8V5G4L0GOLmNfE8t+l7pRJD5QFCRLjLObCxUl
+B+F7NhBhg6NNf2NlIhzOBnnFhcO0kzJ5VjybI5c+UMYqOSss82bqLPASy2Ro6pzHUCPBkNGiT+b9
+M2zaG3TmPFZHLqA/QcCMiaWAVVIteBlYiMQIRZNqJ/toSaM8xslXPTWQqXKwrDPPDhIG94hkrHKc
+jjTGFY0hMcxTp00qQ/dtHNCnj8fQJGOO59jG05wnxzDGLvaR0GKR87RJAZWr87hNDODd98xPL/lt
+qnK0qZQkywXFgdoUp0BjAcJIaNFpDrOXo+IfRp6pHJmPhFr1WKXJVBiHT1njLFkodi2r0lQpfCFl
+D5azMlmSC/QaMiIUjpQeGRMYprGMMM8rtOmS4WSUTy1cOL9xVmzDjNDDr6lPEjq/Sn4RlVJUiZBl
+Aw6XljRAxCotRpkBjISLrkhfSoiqpcUCXTkUO89pzrAawkSJqQij+TUu0GCWpEKsS0XQEjHODma5
+h3uY4QKv8iJrIr6WCrX76Ndeu4ohqc7i0ceiXFUkLRcEbBMELk9NjsdH0tUpvlqY4TywjUkiDAmR
+KLO6co+AwtFjjXVWuMApzrHIahiYVaGSHACtx3OecSYkEZtQXSoitnIrszQYAc7RD1OoOsC1yY89
+tb58FQMS3h065VbYqoIqpMPTaKneFF6OLepQJ1Z3OGWeG5hkoeL6utKvGzRZ+8yzJgqwq2iGXqAu
+lmmw4hWss8AsXdqC+MUce84sh5ikgcOxxBoRXRmQcqEjbRcXTl3qRqJLjMm5I+4JH8pVF2RlI5Bn
+gB4xkUgSCKsviZGhRoc20zK8pkKZqsQT4gCrjjW6YeqnOIMyaJWU5awR88Z0WOYgmgTQxEDCLWzl
+vJxkWeUsKREtQadBLesfT5+5yjnBo8df/JrOS23QCIksjzfEgfgacbK40qKIiQXzl4AZakHAGkSz
+CgeuxmQayAXH10K+jISVD35VNFUiFljltqLNRcROXs86z3KMl1jkVZ7kpGBD+ROKHEeUv/C143NX
+Py7/eXdhoKhr6mjp9CAN9kw6tZF0+oolxvKdDk3KEiOMh7MiZXOzNF5EnREyGZ7SlZNIZbBYTOg4
+RQFDEuZZ4zDj7OINbOcllojossRpnpHh2lSacMX5JIPFnnOfv4ZJUfe0e9aHiPVhNCGSDq/CkQcH
+07JDdSLZv8JL2rTZwuhFPcDyVglPFO6LIaBJHFrgqnIuhQCIRdh1ibmD+9lOV/TiYhpwmTUshj42
+tN0Kk7sn7ZFrMMBTq6u/ozIV2k4DLC0rcit9GSMwo4QgRaFi0DiWcGxjpBLJcSVhFtPkStRBHwZm
+EGwnwO8AaIs/Y2xnhgajTEmi9Rha9ES9LFKoC+fPVLr8355Yu6YTI70v+HO+cq1FOSGsBdJSUhpS
+kWuRqJPQ8UWyb84CCVtJZKIwEQGkuFBwlAwnAnwBa4koUa7SPYguAk7HKLuCBkzAmAZtHJ4Rskpz
+LyrOn59eeOgaj8x8od3/V857X07dxYETGrSc9B6t4D4hflXo1SkiOixRZwolHeI4GLEWhhfKRFvD
+y4n0JIgwg7GqcjCjyT6WeJXTnOcMTcGVhFFSaiRoMhLZFI/2mTe+/0tf6V3zmaH//b/8Ee9x1rvQ
+kynL1xjIMTREm0VgSoU6jXA8YoV1RkPpiwSCoibzXFT6yIUB63ICtbxVLgpEXDPFdk6zSIvXeJGj
+HGUHUyh2chO70DQkoySAL9KLc4//6cev7+zwf/BdZ5XzznpfOSilpEVhGQ97Pmh06DAnVKBFwgp9
+xhkVM5Vg1pRmlqlMCpqh/lEiZvWhth9nnBV6ZPRo0aFDm9eYYieHmeI2tjBeSrleO++0JfPt/N9f
+57G5L/2Z+iQ9n+GcV96ESZ1iCS0yxiXeY4l/Hc5zRzjJ1R7FClZMMGCWsZzwQeLchHEWXWmgaxIJ
+PM8WxliiJ5mjVAsiOsywDUWDw6IWGa995FTmer2O+8hnP3OdBphL7W+783RJvXXeeoIkUlRnKaNh
+eGkw7KiDAKkC+fGsAVPUKpJoFGiWCt9bznQOcKS8aEkxyRQrMq9gKsNamiZNkczHC6XYe6+sSun6
+Vn6q9/6zves0gHcffET9J7fS7/rMOucHabEYcc6JmJLcb8U3CMPKtUCCixHXNSxTIozHNMLcjgmG
+QPT+wiPKcqeY+RxlG6fCPFnJKCM5nzgm9HyUBpbEx85nrutW7QX3H7/0zJXvJL3i/QF5/8nPuid0
+y/byzLrMe2ldF8S2Q8oETnB7wPhiTLhPohxjslhaGLZQD5NmudSaRvoORphedTS3SJsTbGUOTyyC
+/WBgRmPo0wE6zPM4Gbt84nSme7TUYueRrz50rP8NXaBw5OQOURC0AAAL0klEQVTL/8WfT9s2ddY4
+5y1eZjQ1K0KSnQgXrnItlquMyJSLyVlEMcEoEQ00ObUAfFHIEYPhWSMT3xGTzJOTiBBSOH4S5llX
+Oc1xjnGSBZb8ohuzE2nczlfyMw//7lNz39ANEkrBS8+sfFit2naaZtZ77+OQpzUrxIyKkw8G4nSo
+wEyg08VReE+POjNsZ5IRRqhJTUkwlh/CjgIEt9AS3UcF56+WapBzkvMs4Lz2yq6n7bZfs4unPvLY
+S8UarsMASimlFKBW1h/9Y/+ibWXdXmYtXnukxIBlIiZC63xgCFvZ+3L/IywxEXXGmGKcUaaZIAlU
+SgcI1UNAN0GffgXyGGrUFjNmii4dMh97bVXmu1lrbbn34pc+7TpDa7muO0Q8nL7wyD+PzmatrNvP
+lPPeeaTk7LMWJvwIcoaSmW5VWbwK3ZwoKI1NmtQqrXIVTv+WswmOUdSQvE2oFwizYI1CXPHaW+cz
+ur6VLuszH/nPx+av+xIVVR0UUvD83Au/YBZdK+n5rOPwnkQq9yUaNCUzR5VL9JRQ1KJ+81KwZJXx
+NS8DdQMG6QMM+qAjj7ISAopQJg2GeYsJ0xYW760jUz3X6i9H8w/9+vNzFQbN5UNBb7J8eZKvvPbS
+b+tl17J9lSnnfOqLYSXoMCI0NhcaWs5qRYExFpid4EnpVG6RKPTgcqAmqhysKPB9G8vhAIxDVZhG
+2XD3NEno+dznzme+n7XcSmPxr97/yZNDx1muYIIr3SChKqfT7KOf2Tq15b1WFy/FawXK0GOeXdK1
+JRiinPwyFQ2oOMrQRZPSoAakZEQ05ehDOXYRhfnRqVLPFw+xIdsQ7iGFCda89dbpzPZty63E8w/9
+8UefCN9Yvbf1Gq/QUBUbKlS3/fDHGjsOvhNSapjYaYdSxZUXU8xLNzkSmqrD+b3BEQdHQk4XS0aT
+nF64RrvP4Paz8mrdGoqVEPFOjswUZ8ysGERRI/JtnzuX5X3b8su1ha9/9jMPdduVszjqyibQlwkA
+NQS3Co0+u/y5PzjxebOUtfIemXfOW+/psoahKSzAyUmw6jUbOhy2Ljp+xenhHn26dFnD0WRcCu5y
+Pi0K51CpHKry4eBFkSIzJv267zuV0XMtt1xfePbzH/34qZWhVz7IxJcMAn2F5Q+O8gj7PLf8qd89
++qnGkl/Lu3mK9d55RYd1JgW5B/R2oAC6UCeoyn2DuZAaS4c2hgkmhPxqYsbw5CQhfwyGNgdB7al5
+79esTX3XrrE0tvDEp//0IyeXNiyeK5lAXzEAVIWXaDT6fOtPfvfpj0eL+WreyVOdK+d8nxUcW6VQ
+QYasy5s9BjPkeXDyvlx0UH53jxU6aCZFRC1OGsaiBzgxXDkvGIvw6n3DreR5Sidb9Uuj81//y9/5
+0Km1Cg/jYg/YFAMuiZNqCAxV6j74gSy7+weUy1w8QqKM0V21pLYzTlcYAKLbU9n5YqarJsNKVsYb
+tSi3ji5dxqkxRo0Yw7hcm+uD7ugYXMNZ97Gvuabdkb7cXW4lK2r+c5/5vT/P7Ibd9xtDfLg4uhII
+VuK/8tFk7mMfmV/5rh+e2N7JR5o66UU1vaRrapScjETa2WqICzgpbLIAc15qSh20Js06Y0zKwS7D
+KG25iWJw41ihH474La7parlPn22vthrLy+c/+mefeSIrJ6F0cDtXiZfrvUtsgzEUumv/6ssra2/7
+wVsOpLlu6loeG7Ogp9WYWsOKIpvIPg/GEwhjFyXSGwFIHb4yKJ4cloRRYlIy8RKNxvhxP+2aNsqy
+/un2ibXx5Sdf+fgnnzrezSqDjKpKgTZZmr8UBFYrEh2mW40M9UVExJjZnW//3u+6vzOhmvWGiZM4
+0VtUpFqq1HWiMGyrKyy+gLUperSDAQjjGE3GGAUcXVp0w51UxT0zzivf8NtdIyPrd863X111yx/+
+2qe/eHJZrinM5d4+G25ldTJoBKXIzWVD4CIE2JgFqmigUGfnP/yRV07/1DvVVC+NmyQuWTeTuq66
+yqjy0AJDnlikSBPuhfCS0Z3MCEJb1CZLX+4bLP3Xe+e1xzVsIyVdb59eX1vNl/7rZx8+stKt7Ppw
+6lMVLnAZFKh4gFKXdviw/wMfKLrehohodt8Pvf2NB/NxOxrVR5Ik3mK8bqlY1ZUPB5yMeEIxYRSR
+s5WMNdH6yiAtjjiMoumGaSK5bsvn3vvcOUs2km7t+fWlVr7y0NE/+cKxhTSTO3vLOxtLDyh9oDxT
+7wcJ6Rs1gJEgEGPUpu6/65333DCjR9NGvV6PxyJMptGx0mg1OMDkK9A8iWFR9EUXBtvBsYNl2fcc
+X7xU713PeZvnLvM93THr0drx+U8+8dCRtW6aV5afh+upr8EA1363uA8yvWBbv/Xlrz938u++cf+u
+22e6zdZIXh+PVZQbr402SilNhFLZEC3OxRAlNyjH6XIy2ihceRGAz513mbV5lqme6+q2aT0zf/zM
+xx49v+hy62SB38B/1+4BF/tBMQej1eS+PfcfesOeQ1O+0W80aybRxkWxNlqpSKEiJXqBUkCTUS5I
+1nIyNgXOF2+loLz3eOuds448t3nq+q7jO7X1F5eemnv41eNn8h750M4P9v6bGgKqcv502AADNIjk
+SqGIJJncsePm3Q/eeOtk1khH4lqS2DgykTFaa1MaQQEYNcnSRcKLBx+hfNvjrcNZi82zPLV93006
+cfvplS8ce+Hs+QvputzJl8v9evayBnAhD1yNAYbSIEMN+4EBLmUCE0ygGYnGxreMT/746+6djEa6
+I6ZG4mITG6O10UYrrZRCK6e20KGvVFi68h7vlVMudd6lVmVZZlPV191aV3W/uvgHL3dW1lbz9bDE
+wYX0l16+rSy/yqUuSoOXNgAXBYEOfdFogxHMkDdoImo0aG6ZunXbj9ywdyyqxbV+zcYuMpE3sXFa
+60gpaipScjGTd97Q85FLXcP2bJ773GdJP+67ftY92frg3PMXllbo0JMLKocXbzd8dCEA/JAHcLUG
+uDgILsYBsyEnDJvDyABIXTV3Te6evH36ponpkfGkHts4Mt5Y44xXXidKbpb13uGVNTaykfVZmuXZ
+Wm+h+9LKkeWTS+fWbIeUVC4fqya6i/9djf2rDIArGYDL4sDFiGBCAFQf0XJeqk5SG7lxYt/4aH2s
+1qhP1mbqo2ZEj+iGVirHe5zyHdfO1+zZ7mqv21/vrfZeWzu+mvXoCw/2YXG5LLC67Dws2l7EAofh
+75oMMLi4Q110XGCjL1TNoEOYDHqdxURETEQcxZO1mXozjqOaaRY50lmH69p21krnuyv9PJMb9PKw
+CBvebsRdtNcDP3CXWLy76P172NQAlwiDYTC8vBFMGBYZ/h5dqc+rVQWhkza4Q7N03RK2hpfvKsvL
+Q0AMm8VV3rlhMH7mLrf7VyZCvnJzjqpIjOX7YQy/TBeujTOiV9jKBQ7VMbDLCRQ+FCxe3oKg+sx2
+6H97iV0fwF7ViEPOfz3lsK/UM4OXaGTpOizaVPZ8+PaK6vJ1RdliqHVU1sC+gtzDy6/+7eJoHzbW
+gPwMreHSXeKNo7JeVUWEYT3VCoP1YWzLh/OQA9dXlYXrMBunLy1Ubth9wgLKxdgNprDh8/Dj/hLA
+d8XlX+GdpoYA8VKJUVUWWcWH4UfV0P5fSqysmsANBUHVCBcbYGOQDH7aVRx/k+Vv8lZbG7LClcyg
+wvGywb9Vxe2r96WoIeXZV4LAD5ngYk/w4a1pho1Thbwr0p5rNMBljEBlKVW6rDb8ry7xWQ1dSTGM
+AQOQHSg5boMx/NDCXThZ4yu6z6Y7f9UG2NArvJgmqUtQ541LH/RJuGwmGEiZDOVvd1FQ+A0LrjK9
+y2b86zbAZYxw8T1oauhyiEs1J3SlE6Eq3e7y334o0V56iT4oEUMFzjDgXf3yr/Ht9jaYYWPvYOPf
+hwus4TvQL34eXxkaZojD+SFgG/6o4Prfkvc63m/wMu2TS7dV2eAvG7/3ctyDDU59Ebbjr3afv6kG
+uAqTqEt8VpcwRfU7qqzDb2AIXMIUfDPelPtb+t7jlzCPuoLnXNoLNvzrm/te5P8XJCZA7MJsq+UA
+AAAASUVORK5CYII=
+"
+       width="48"
+       id="image2389" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/wifi/data/misc/old/link-1.svg 3.4.1+git20201022.a0d3415c-1/wifi/data/misc/old/link-1.svg
--- 3.4.1-6/wifi/data/misc/old/link-1.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/wifi/data/misc/old/link-1.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,436 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="48px"
+   height="48px"
+   id="svg2160"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   sodipodi:docbase="/home/changfu/Documents/Install/Cairo-Dock/plug-ins/wifi/data/src"
+   sodipodi:docname="link-20.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="7"
+     inkscape:cx="24"
+     inkscape:cy="24"
+     inkscape:current-layer="layer1"
+     showgrid="true"
+     inkscape:grid-bbox="true"
+     inkscape:document-units="px"
+     inkscape:window-width="762"
+     inkscape:window-height="635"
+     inkscape:window-x="10"
+     inkscape:window-y="65" />
+  <defs
+     id="defs2162" />
+  <metadata
+     id="metadata2165">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:label="Layer 1"
+     id="layer1"
+     inkscape:groupmode="layer">
+    <image
+       y="0"
+       x="0"
+       height="48"
+       xlink:href="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAIAAAACACAYAAADDPmHLAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A
+/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB9gDCgMbDLhil74AACAASURBVHja
+7L1pkJzHeSb4ZOZ31N33he5Gd6NxEQdBEARFgpR46CB1kdQ58mrklcYOz9hje2ZiJtYb67V3vLO7
+np2JnZ3wIW/YO7Y1pu1QrChZt0jRFDkEeIEgQIAg7qPRjW70Ud11V31HZu6PLzM7q0hbJEFyrLE6
+oqOvquqvvnyP533eJ98kUkr89OPv74fz3/obJIQ4AFz1ydR7Zq/zUAkgBhDpTyll/FMD+MlZaAYg
+lwN6BJAVQCYD5N5DyEaXkK0xcAOXcgMFNrmEDMTqzcfrNyECcAXAKwBeBXCqj5C5BlCjQIMC9Rqw
+BqAmpeT/zdy3n9QUQAghasH7C8DURkp3UGALl3IrIWQjBUYAdEVSUkYIXu99CvWVdnzPCAFNDEMQ
+QspcyqsxMOcAZwVwdk6IUyFwcR5YAVCXP8F59CfOAP5pNuswQkafaTQ+5ROyh0s56BKyOZJyAoAr
+1GJq79YfMQAuZdvvqPV9lhB0U4ouxsClBJcSTfUZq8eqx0cUmAFwDsByU8qXF6R8ZA6Y+0mMDD8R
+BkAIIX88OekcWlx8sNtxPn81CKYvRdFmRkg6ktIsJCEEXEqESQI3Xu2ov3kA8oTAJwQ5SpGiFGOp
+FDYVCvBdF/UgwMm1NVwMQyxyboxGGwgjxBiO9dkEcB7AhaKUf3ZCyr+SUoqfGsDb9PHN3bs3Hrxy
+5Uvnms1/tMz5cFVKlwIkpTxdAAg7njNMKXam07ixvx+bNmzA4NgYukZHkervh9fbC+K6cLq7wUZH
+QXM5iEoF8dwcosVFNBcX0VpdRXF2FotXr+Lc4iJeXF3FySBAqIxpi+uCAihyblJJlNzICMBVAfzx
+nBB/cknKqz81gLfm8alfzeW2jmezn3psZeUfM0KG1jgHsXK5XnyXEIw5Dm4qFLBndBQ37N2LgT17
+4E9MgGYyIPm8lfQFSD4PMjAAks1Crq1BFosQpRJAKQhTxQGlQBxDRhFks4l4dRW1s2cxe/QoXjl7
+FgvVKvrSaVSDANUoQjEIsBxFKHKOupRwkmtbBPDlzZ73jT9ttc5KKYOfGsCPX3j/bkr3AjgQA7+V
+JSQ35nm4EARoSmlCfJYQjLsutmSz2Ds+jr133YXuXbvg9PaC5nLttZ2UIIyB+D7o4CBITw9kvQ6x
+tARZLid/V6FdSgmEIeA4gBDGaABAKm/n1Spac3MISyU019Zw9dw5XJmfx6W1NVyq13ElDBFIiUBK
+uIQgkrJyIJf7zZUwfO7PguColDL8qQG8duHdDcDOSUo/7AD/VAAbhhgjNxUKOFapYFnl4zHHwWQq
+hR39/di9bRvGbr4Zuc2bwbq6IDlPPJhSgwcAgKTToIODoMPDiUdfvQq+tra+6FFkPB6UJp9CmAXX
+j5FRZIyB9fSADQ0l0WFuDvVz57Bw9CiOvvwyvjM3hyLnaKr7yqVEC5C9lM5xKb88L8T3zwOvSimj
+nxoAgAlCuoYI+UyWkC8B2B8CrgfggcFBXGs0cLzRwAbHwWQmg029vZiemMDGXbuQm5yE29dnUgJx
+3eQrYyaU095esKkpEN+HWFpKvL7ZNEYCIcyC2xEjKRtiSCmThdc/RxGI6yYGpx8nBAhj4PU6mhcu
+4LmvfQ2PXriAE82mMQIpJVgCQsMcpc8vcv6ny1J+7ZKUlb/XBnA7YxNpQv5zJOVeAHlNytxdKGD/
++Dgev3gRI+k0BrJZTI+MYHrvXuTHx+HkcskiOw6o46wvKKWgngfRasHfuxd0eBgQAvGrr0LUaomX
+O05baIcQIK6beHxHuIcQ60agogJhLHnNWg2EMVDPM2nEGRxEtLCAk488gpdOn8aRYhEXggAxgEBK
+5ChFgVIUOa8K4MW6lP/9MSFm/14awF2MfYgC/0kAY7AAnU8Ifudzn8NjTzwBh1L4rotdW7difM+e
+BMETYkI9dRwQxhIPy2YhOQfNZODv3QsyMgK5vIzw2LHEcxWANEDvNayQMB4uwnDdMIIg8Xb1M81k
+EC0vQ0ZR8jhlMCIMIaVEbtcutC5fxpWDB3Hh3DmcXFzE6VoNM1GENCEYdhwsc44i56DAnAC+8IIQ
+T/69oIIJIXQ7MDDO2C9Q4DcF4IQAdEk37Dj4tfvuQ9hqwWUMA/k8prdswdC2bWC+D9FqgbguCOfJ
+QgkB6nkApRBhCKe3F95NN4FksxCnT6P1yiugqVSyvpZXG6Rvh37l3SIME6OK42TxLSzA8nnwajVZ
+bM4hpYQIQ/AgAIQAjyKUjxxBbtMmDGzZAua6KORyGFtextnVVcy1WsgzhoYQKCYvOUaBH97O2G+W
+hPjj08Dyu80hOO/i4ru7gD0jjP3PAvhoDDgUgAfAJwR7MxncPDiIqfe/H9/6nd/BSE8PprdtQ2F4
+GEIIECEAIcAoBZQ3U8cBDwIQQuAPDcHbtQugFNGRIwjn5pIFbbVMngYAoXK6DuV2FSBUqBcWDtDG
+4fT3A46DcGUlWfwoguQcXEUCbRBho4FwdRW5yUnEjYYxIEIIxlXEiFdXMadeWzWr/td+Sm/dLMT/
+Rgg5/m4CROddWnxvDyHvH6b010PgDqlqZSivn0qnMZHP496PfQxzBw8i43lm8akqyXQIl5xDcA7q
+OAnTJwSyN9wAd98+oNVC+NJLCOfnQR0HUgiIOE7ytOXJhDGIIDDlXmcSlJybRdb4gmWziFdWktCv
+Fk/EsUlJUkoIFTFqV66ge8cOFDZtQtRsYkBd/2qlgqGBAbiMoTg/j6uca6bRoYQ8tIHSfgjx24SQ
+x9+tctF5Fxaf7CXkI0OM/dtAyq2aWqUANnkeNudy6E2l0JPNorB9O848/zy2bNuGbE/PejnGGOJG
+A6DUhGopJWSrhdyuXXD37IGsVhEcPoxwdRWEEMRhaDybWySS9nxT+omOiKtSg4hjAwy9wUGAUrSu
+XUs8X8rECKzH6cdyziGCANULF9C9axfSfX1olsvo6etDrlDA8KZNWF1dxU2FAlK1Gi6oiMSlhCDk
+jg2U/t8pIX6dEPL1dyMdOO90zv+Y43w6Bv4fLmUPTX4JD8DWVApT+TxSypNvvu02BIuL6BkYQLan
+ByKOIYQAU2WdBnw673POkb/hBni33gq0Wmg8+SQiTewwlgBCjfgtw2kr/6weQmdZp7/nzSac/n7E
+q6sQrZZZfB3yASQYAABXYFPEMZpra8iWy+h773vRWFkBAAxu3ozC5s1Iv/giunwfNzkO8tUqTrda
+aCZOQWJgay+lf3QnQAkhX3unjeAdNYADlP5KJOW/iwGPKivPUYodmQxGs1nTXOlJpzGwZw8q58/D
+9X20ajU4ngfX98GFADiHa+V9EcfIb9mC1K23guTzWHv4YbMIekF1aWdyPKXrIV29pjYU2cEcymYz
+AZsq0jjDw6geOdIW+jXo0xGER5H5FIpDqM/OIrNjB0Y//GFUjh1Dzwc/iOjSJXieB49SxEJga6EA
+lxCcCwI0hNANrG4K/NleQgYA/P5PnAG4hKTvYuzn8oT8LyLBeRAACpRieyaDoXQ6eRxjIIRg86ZN
+8Pr70VQ3manFi8MQzHUBBbaYInsyw8NI798PCIHVL38ZIgzbFoe5LhDHxliI+j+dYb6NLlaeSx0H
+UkrwWg0AkN+5E/H8PMJKZT3Xq/9FHQdxq5XgEvV6QgHLuNlEbWkJXXNzyHzykxi45x6gUICsVpHO
+ZpHxvIQljGNM5nLwGcPpRgMVIbQ+wesi5N/c7zjirzn/00jK5juxVvSdaOS8n7EHHODXYqBHW1mW
+ENyQzWIonUbKcZBynIQ8oRQDExOISyW0ajVzA9te02L3vEIB2TvuAEmn0Tx0KKndNaK3cr3k3CyU
+KdnUzzwIkhSjPnkQgGtUHwTGoHgUwdu8GeH8fJJ+4rit9tcoX0cCDQq5ii5ho4FgYQHI5ZIGlO/D
+2boVgxs3wmUMjBC46n0NpdPYnsmgm1IIJKIURkiPAH7t/Yx9lBCS+jtvAIQQZzchHyCE/GsAY6or
+hhSlmE6nMZJOI+26cFT+FUIgn06j54YbULtyJVkEvXhCQAiBWJVYIo7BfB9d730vaKGA5qFDaM7O
+mkXRoZcHAbgib3gnYleLaJC7MgxtHHrRzdcwBO3tRe3yZZNaRBwjbrXAowhxGCJWxhIFAYQQiBQn
+EIchhBBorawAKppIKUGGhtC9dSsyqRQ8x9ELDUYIBlMpbM1kUKBUdxQBYEIAv7WXkLuV7O3vbgrY
+T8jYAGO/JYDtOsCmCcGE72Mqn4enrDtWXu4yhsHeXnjDw1h++WXEcQyHUoPaAYApwke0Whi+916w
+kREEL7+MyunT6wQOIYYPEEKAKEPQkUFHEM3W6fCtGT7qOIkxUAqi6V/Oke7rg4wiNItFUMeBpyho
+/To2IASQGKv6PSEEcRwjqFaBVmsdbHoenFwOvuuCKkdw1H2RUmIonUYsBC62WqgIASTytB2jjP1W
+zPlJALN/Jw2AEOLe7zh/wRNe34SWCd/HdD4PRghiIcBVY4So8JcrFCDCEEG9noR/zhNmTwhAeauU
+EhsOHIC7cyfCV1/F8tNPG5wghAClFLGib7WnUccB07y+xgOqHgeAuNUyC2DruMzjGENmchLRmTPG
+WOJWC246bcJ+qEgmbkUS3pGGBvbvhwwC8GeeAbvhBlN9uArPMEIQKlWTo4DhhkwGoRA4YwHbGNg/
+wdifpwl5f/NtJIreFgP4k6kp99Oe9wc1IW63W7EbPQ9bCwU4lCLi3OQ2gUSXTSlFob8fcamEoF5f
+F3uopo2+qfmBAWQOHICsVrHw6KMJ4u8o49qaOMoIeBSBUpp4pEovXiaDoF5PWMTXawnU66CUJvl/
+61bUnntuHUCq6OD39KCxsgJKKSKF/M21KyMLWy2M7dqF1E03ofXkk1h8+mn033wzcp/9LJzeXqQy
+GeMI2jliVQUQQjCezSKQElfCcB0KEfLe+1z33xNC/tXbJVl33o7FX2k0/rsy51/QbwgABhjDdDYL
+h1LUowhMAT5d+hFC4DOGvp07Ea6soFapwPE8RFEEppo9juPATacx8olPAGGI5W98A61KJWn+KA+y
+eXwdzjV1TClFGIZgCr0DSAyNc0ir9tepQH+v0xdJp9GYm0OrUgEoBVM8hMs5/Gw2qRqiCEK9VhQE
+5vr7RkfRe+AAokuXcOGb30QchggPHsR4Og1/71509fXBmZsz6YIR0iZYZYRgQyqFhhBYiWMwAC0h
+kKL0F9/P2GFCyFffDiO4bgNYrtdvOVou/09U1fpQ5d5kJmMWX79BYlk8APiui9TGjVg5eBCxqp39
+dDoJ65xDMoahvXtBu7tReeIJrJw/n3gn5+YrISQJ5Qo0QhFIlNKEZhUCXEUbHfoJY4bRs9VAGuRp
+7IE4RlCvAyoi6AgQK6PSeT+2nwMg192NkXvuAeIYV771LVTLZXDOUa/XgR/+EFP9/cj39YEQgpTn
+IYxjRFLCZwyUUjiUIuN5IIRgMgxxoVzGtVYLNSFQ5twrUPrrt0l5FsDh/6oG8O09e0aanP/8fBxP
+5yg1mvqxVAo5xwFXN5VaJYeWXPuMIe37AIDayoph/eI4BqUUhBAMjo0hs2MHogsXMPPss0muVwss
+VNkFANKScAn13DiO4ehoIKV5DqXUVAKaITT0rxURXMcBVJ2v8UUsJYiWhkURvEwGRNHUGgd09/dj
+4sEHQVwXc9/5DsrFIqIgSChiITB38SJ6Dx/G4N13Y8uVK1i6dg1BFKErn8fQ+HhCgQOoFouolUqo
+VSpwGUOqVMJqGGJAShSjaOsQYz/fR8hMUcql/yoG8DO+7/6Lu+6679DJk58sUMqoCuuDjoNuz2ur
+M023zfpZSgnXdSGbTTSrVXDOE9o3jiEZQ6G3F7233AJQirkf/ACSc4QqH+q8njTsYjBlaFJKUCkB
+DfTCsE0iZiN0HT0YYwkg1FWBVvAobw5bLcPs6QpBG18chvBSKTDXRb1axcjUFDY+8ABooYBLX/kK
+iouLyTWp6xUKMDaXl9F34AB2FQoI5+bAslmwfB6tixcxe+gQ5i5exFKphGYUIRYCjTjGShhiLTLY
+jwH47C5Kn1KpgL/rBvCrd9654+FnnvnlDKXd+qamCUG/tfj2jae6HQvA0alAlVTNZhNhHCcGoH7f
+NTQEb3ISy9/+NooLC8ZAdOjlUQSu0LhNADkqdGrjcFQ/wEjHbEZQvQ5zXcRhmDB7YWjShVSEUaTQ
+uA30uMVVuL6P6X37MPihDwFC4NUvfxnlYtE8xja4dDoNN5sFyWbhfeQjcKVE/PjjmPnzP8crL76I
+5WoV1SAwZaFUETNFKRpCIFonyboLlP7SncAxJFvZ3j0DOP/FL6ZPnDv3YCmO9/mEoKXau93K+4WN
+zDtYPRsEprNZiFYLQbOZYADPQxzHyHd1YfBjH0Pz5ElcO3vWpAUd/gGAKdBFCEEURUk0kRJhq2WM
+RC+WThWO55mFJtZ16KpAt3pjBSYBIAoCwxPo/61zvv5+8rbb0H3//QhOnsSxhx9G2GoZTKONIFBY
+aMPkJAY+9Smgt9f8/3hlBYszMyg3m4j1+yMkSTmEgAHo8X30xTHmwxCuSqsxcEcfYw8SQs6/1fbx
+m2YC/+3gIKsuL2/50eLiL27L5zHgunAJgUcpulwXXNW0phWr6n4hBOwqAUBiAHGMQDF3cRyDc46N
+t94KUath5dgxlFZW1mtu1drV4TSKIuOFURQh0q1aIRAorxWW0Wh2Lg5DREFgmDyN4G0iJ4n/iTqI
+q/8DAJFaSG2oN3z0o8i/5z2oP/88Tn71q8aYDZMpBBoKNN6weze2/cqvgC8uovmVr0BWq4mTWIzl
+60Up/XO/5yFHKVxVMTjJ/f2ljznO1LsSAQgh5NgDD9BvHTz4j11ChgczGUgpsRxF6GIMeddNkHQi
+NjQXz6WEo/KgVN8TQuClUhCtFppBkHhdFGF8fByFm29G7fhxXDpxwiyuo8KzZtM09RqqkK0XXi+S
+rhLijhurU4J+jLCaQo7jII5juK4L5vtt+wOElf9d18Xo9DQ23H8/AGDx29/G/Nmz8FIpUEpRbzZN
+dIg4R393N7bfeSd63vMelB5/HKeeegpREODmlRV0/dzPoX7uHKrVqjEabYCaH9CemnEcFBwHpTiG
+r4zCBca4lL8A4F++4wbw2wMD5OL581tfqdX+YUbd9Mnubiw0m8gr0KQl0PqGu9b3ZqEUimFKgMm1
+10YRNt17L+JSCTPPP48wDBELAc9xTA6N4xiu/j4M4ei/KfzAFUqXUiJQKUIvtCZubEZQYwttaLoU
+zY6OJlyESht6cfqHhzF8yy3I7tuH2gsvYPbZZ1FcXEQURUhlMkhlMqjX64bY2TQ5iS0f/jAIYzj+
+h3+Iubk5NBSYDf/iL/D+vXsBAMVqNYmelCKlFj60lFAaQPe4LpqcGyyg0sGXthHy5TNSXnhHDWAo
+m2X/5cqV36ZAQXP6W6amMFsuI9R9cWUARixh5RobhVOLj+ecI+AcN27bBn9oCPVz53D54kVjMK4i
+cuI4RhRFyCiPtL2YIZnwoMs77bUaO7TV+ponUHyCqeNVHZ7p7kZq0ybQ3l50DQ2hvLgIUIpNt96K
+3K5doJkMzv3BH6BWKpkan3OOcrmMvr4++L6PaqmEG2+6CZMPPYTqiRN4/rvfxWqtlmACdU8W1taw
++M1voveWW+AyhoYyNN0lJYQgUCmPqnuZcxykGYNQcjK1lb1nZ8IQfvrNCkjomwn/o319I6tx/D6X
+EDgA5mo1tBoNfPj2280LOR1ll257auPQiy+s7pr+3dhNN4FmMjj+2GOIOEeocmkrDNEMAgOktDcm
+aXrdO00IVVqCtpaw7vhZIV3jgVh5JCEEuUIB3Zs2wd29G2TbNgw/9BA2f/rT2PXLv4zCnXeieeEC
+Tv7+72P+8mVUSiVjlKH6enVhAYwx3HLgAKY+8xkUDx3Cjx55BKVaDWEcg+smkgr1B3/wAxDXxa5d
+u0y4byggCgC+VT1pKr2guogpxb2kKEWG0rsOUNr/joHAP56cdC4vLf2rUIi8Dp8rYYhLCwvon5zE
+3bt2IdIkiSpddN7Xi2YaNYrtAgBH5c3Nk5PwBwZQP3UKxXI5uVmcI1apQXuswRXKGHSu1RHBbsyY
+Mspi8YyS164odK9fCHiZDLK7d4NMTSU45f77kXrgAdD+ftReeAFXn30Wq0tLJiJpoEcIQcQ5gijC
+2ObN2Pi5z2HuW9/CM48/jkYYIrA6nKYElRLVIMD8Y4+hMDwMT8njtPopUu8l67rw1GILAJ4Cgkyl
+WJUeuqZd918QQug7YgCe40wtNRp3uYRQ/U8FgLOrq5g/fRo7PvAB3Ll5swldeoFt4EeT14FDKVzG
+kO7pQdcHP4idu3dj84EDyN5+O1bPnkVdVQUB5+YmBMrLwjhG2Gqh2WyaqMAYMyRRrKoKIYTxTq5I
+JJ1udO7XXIIu2fJdXRjauxferbca9Q8AyLU1VB5/HHPPPYel+XlEUYRGq4VWGJpraqqqY9++fRj/
+1Kew+O1v45WXXkKt1TJer++H7opqL79w4gQy/f3oVg0iG7SGQqCprln3UnKOA19H2PWvjBFy/35C
+Nr4jGCDr+3dca7UmPOXV1LLiwydPIpXJ4OaHHoL/6KN49eJFVMIQUBWArgR8xuA5DvK+j5GREeQ2
+bQLbvx9bfvEXQXwfZGQEpaUlYzxUeYGu+03aUF6na+yGEKaVqvvs3N7Qockji7zRZA+lFF09Pegb
+H8fggQNI3XsvkMlABgGg5OTB009j4cgRLC8srBtUHCe1uFVF7Nm7F1Nf+AKuPvIIjj33nMEUbapk
+QhK2EuvDJ0q1GqSUGB0ZwVKlYu6XrgS4cgYtHNFYIIoikxYUIJxghNwB4PLbagCf9Lzuu/v739vj
+uoWVMERrHXzAoRTVKMKTL7yAWyoVbH/f+zAyMYGjhw9jZm3NGIqrWLzuTAbTW7Zg6sMfRvq++5Jh
+DXffnbzpl18GpRT5dBpVVUppj4EyPO2xURQZEATAoOKmWlzPonZ1dWCXfalMBv3Dw+iZmEBu82Z4
+k5PgxSJKDz8MGUVIT00h/fGPQ1aruPbEE1hbXkYURaZk5ZyDq0WkAG66+WZsfOABzH3ta3ju4EGE
+cYzuTAYuY4iSbWAQVirUINqhFOVmE3PHjmFoYgKZS5ew1nyt/M9lDK04NkaQcxyEFjOookTXmOPc
+xQj5Fpey+rYZwDLnuy5Vq/uH0mnCpcSSVtYoAohLiXoU4fCpUygWi7jlAx/A+x56CMtnzuDw0aOo
+tFqgAPK+j40bN2L6M59B6oEHkjleFtFBurowMDWF1ZUVhHGMQHHfQvXJNa7Q2EB0dPocStvqf91p
+QxQlqcdxMDIxgcFdu5DauBEsmwUcB43Tp3Hhu99F0Gyi1WohlUrBPXIEOwYH4WzciNX5eTRqNbTU
++9ZIXS/m7j17MPHxj2Pl4EEcefZZUwrXgwBZ30dTGav9XpkyCE31Ls3PY3j7dviuC6Lk53b/xDZ2
+rnBBS6WHMGkTI5KS9jvOrZvDcBeAZ982AyhLOdEQYnKu0cD9mzfjG2fOgBGCrEaoyutqcYxLy8uY
+/epXcfvevdh0990YO3AA9dlZPP/DHyLleRjduxf+XXclEzqsshAAyPg4+vbtQ9f586g3m4g4h2uF
+WX0DdH8/4BxpJRkjqnaWytMZIQiiCKOjo9h4883I79wJ1tWV/B/fR3j5Mi5973uYu3ixjWIGgGa9
+Ds45Br7/fQx96lNYXVlBo9UyyF0DWQDYtHEjpv/BP0DphRfw3BNPIFANHB2tPMdBIZVCudls6wno
+9MNUSVdpNOCkUsilUijW6ybkw0p9OpqYikV1XLmU6yUwsMkDpt42AyCE+P8oldpMgVxLCDSDALf0
+9+MFtdlB/3OocNZSvP3TR47g5ZMnsWvrVmy680587D/8B9BCAXTDBhB7X7/dj2cMzuAgHOW5umZ2
+dG/fqtUppcj6PlyFKzzPQ1dPD7qHh9EzNYX0+DhooWB2+IpaDZUXXsDVl19GaWUFZUXDanJJk0Ha
+kAghuHb2LAYVC2lfq+Yn+rq6sPPBB5PS8KmnkrRgdyYBtMIQXdmsiYKUMWPQsRBwGQMFUG42UV9c
+xPjEBOZWVxMD6uBObC2FrbByCUGU3EREUubuzGQmCSHeG+kP/FgD2JMAi/u0uveZuTl8Zv9+LDUa
+qEaR0QC4dr2q3mC52cQzx4/j5LlzuOvKFYx98Yugk5Ntsq3X5Lp9+zD9wQ8iUyigWiyipZo7ntoo
+4qfTyA4MQIQh3GwW6aEhON3dcNTWcV6tJmNcrl1DcPIk6sUiqsvLWFlaQq3RgO+6xkN1I0ljAyMY
+VZXM8uIiZBCgZ2AA1XrdrogQcY59n/gEiO/j1a9/HSulkgnXwkpLQoHP3kwGq42GMTJp9UgEgFYQ
+YPHSJQxv2oTUiROGABKWg9hpIO7Y0kYB0ORvBMCH9hHyVQAXrssACCHkFzKZMSnlTY6FWk9fvIi7
+tm3DoXPn0FDAxG4CUWUEocIIjTDEM08+iVsaDWzu7QXdvv01TQ/zfW8v8p/5DLL33AM+OwteLK7v
+B4yiZCiE5yEqFhFXKgiKRTSuXQMPAgT1OoJqFdVyGZVSyZRmNv8Q6t6+9lLaXgnbqD2KIohKBV1D
+QyAzM+ZvYRzjtnvvRXpqCpe+8Q1cXVgwf2OMGZSvcUo9CJBPpxM21GJJiTV2TgBYKxYxoahhLRa1
+m1Ovuc9WKWmiQbJOt9yWyYwRQi7+uCGWPy4CUCnlICPEj6Q0ZMSJYhGjfX14344dePKVV14rrLQI
+Bl3vRpyjsrKC+PJluNPT65M67I9GA81HHsHyoUNolEptYgxbwOFlMiitrCAKgqRfYDFnOvp0tqPt
+9q/GEHZpZt8n/RhCCBoXL6J70yaww4fN8/bs24fBD3wA89/7Hs6fPm0AIbMaX9pZPMdJGl2UIqew
+gKGvLb6EKRwAAIVMxugooQgmXRrq/9G2rd0yDoUbUhQY0PjxegzA68dCtgAAIABJREFUdQnZzAih
+uuzTqt4Xr1zBR269Fe+ZmsKzly69hlGy85VQBlCrVBBeuQK30QBRgKztjczOYungQVx+5RUsr621
+ATP94bsuuvJ5rJXLbU0m+7VsoGYLQu3w/be1Xk2vglKUzp/HyD33YGR0FOW1NYyMj2Ps3nsRLS/j
+/LFjrzE41lG66Wsp1WroLxQMyUUVb0EttrTcbCJuNDC2YQOurq2ZKGJHCjsV6PXQpWBa4QuHUgZg
+Ql0Ovx4m0Adwp/ZovfhSSqwFAV44fhzbb7kFOwYHzU3tjDg6HwohUKpUUDxyBOLixddKutfW0Dx0
+CMszM6aX/5oqQS2243ltoVvX+PpxjuMYLkB7GiMEnuMYAsdXO5RcxuAoatpRzyGEGFBZXl6GOz2N
+6fvuw9Tu3dj8yU+C9fXh2T/6ozZFrwam+jrshpjdH/Fdd111bL8vBexalQrGtm83709rKOxIZk9G
+1QwrAARqDdQE0wNIhq+8dQzQDWQ8Su8SVjhnhCSEBoClRgN//eijuO/BB8EeewwnFxfhM2aMJLb0
+cFJKVJtNXLt4Efnvfx89Gzcmo55XVwEArSefxNwTT6BaLqNlaf/shbcjgtYdOFYE0FUC5xyuQvUp
+zzOCUwBIqa3lnHO4rmtawDpSUEqRYgy+76N/eBgbDhwA27kT+T17kG80IJtNlP/8z1Ho7kalVGqT
+kXeSPa6F+LmUWK3VUMhkEOgtcFafxGUMAedYmJnBro98xLxeZEU2LiVizuElNX8bGRcKgbSac6w+
+3t8LpAFU3rIBfD6bHRJAylizVvRYQORarYYf/NVf4b4HH8TYqVP4L8ePt1OtHdFgcXERvadOoXDu
+HGS5jPqJE8hs3YrV557D0pUraLVabTSuTfLEltf4Vv3vqtIwtvYeSCnh+z6CIGiLDjpCGI/0fbN3
+wI4ghd5e9O/YgezHP76erjIZkDhGdvdu9L76KoJmMzEga8gDBZItZmphHUvAqqOoxgUmZ1MKqLq/
+XC5Dco687yelo6oEdD/FppDt6OBatLsSknR9KZ8fQDKx9K2lAEbIJOvQ9Ot/Rix512K9ju9/85vo
+HR7GfbffDq0Usi9SY4Faq5WAt7NnsfS97+HiE0+g9sorIIyh0WggUKxZWy62LtZlDI4K00xxADpd
+OB0RQ0qZlI9KqUSsUG2HYN/313M4Y3B9H11DQ8hu2wYyMNAuE3McONu3o7BhAzK5HHzfX78e9T86
+r8OOWGEcI6vk8Mx6j/r66s0mZBQh43mv2UhjN4TsT/07T31NM4Z00oafuK5uICNk0nD5HYag0b1m
+qVYaDfzwRz9CFAT4wP33Y0qRPZqVIxaB4XgewqUlnHr2WVybn0d1Zgap/n44KkebTZ76hqqcTuzN
+JZbHdnq367rwFE6wH/+3/WwvVjqdhpfLwRkcBFJWGlWDqpDJwO3qgp9Om4XXimVjSOo1dTTUi9UK
+Q/iua3CD5k+04TSVyrlbjbztBNM6ktrYiFosqZ2qr9sAKDDALAtlVg86ZYMw5SG1MMRzx49j5uRJ
+3PHRj+J9N95oCA8dpl3GUNiwAVG5jKVSCY0wRHV5GdTz4ClJtwZnzPJk7Z2aFNLe4Knn+b5vPNk2
+GNd1TX7Xz7eBpP4dYwyO55ltaYSQpFRttV63UtBqpk6wZhunYy0w7djLqEGnjkj63kZqRkH/4KBp
+reuFcqz/pXGHp17H3mfIlRCHEDJ4XQZACOlllkXblqZDj90a1psYnjt7Fkd++ENM3347Pv25zyGv
+PCXtutg2PY2+978fQm0FF0KgVqlAtFrI5vNI+357yLVvuuWxjmru2FiB2elBtYWFkng7asaQnjcE
+K8Lox9ijY7kigWClM8JYMjJW7S+MFL7oNAK7WdSWzhQ/0ApDZNPptlxutpTrDajq73aIt9OF12Ec
+WihCrddjhPRebwQYtEsP7f36YnR70q6fdS6+tLyM7zz8MKJ6HR/+0pdw2623YnpqCjf8zM+AjY+j
+tbqKQiYDz3ESfqBSwcjOnQaxay8iCjT5aka/3cfXBuHo7duWAthEABUVOieEMjUDiDCWfK+8WuOJ
+VqUCrmpxpTRJtpG1WhArK2itrJgmkn29dinpKOkWtWp4XZ3kMhmkVSro5B+axSIyvb1tgNaW0tlq
+J9sITNudEKQcB24yY+itl4GMkD4ttBAd27xsvRpe528UQBBF+OGjj+K9t9+OTV/8IpwdO0A3JoKV
+/Pg4sq++mkifogitUgn9t9yC7FNPJTq/Ds/opG0JY4BSAxFC4HiekXBrNY+96Nog2urpDvGo/h9R
+FCFsNEAzGchLlyCXlwHHAUmngUwG4dmzqMzPm70KerH1TqRmEMB3XcPg6RayY8nltDE4ipjSBBVj
+DK1aDT0TEwmjSAh89bxIlYChqi60RsBRUUunBiti9F2vAeRc+0Z17O3r7Fe7Vi6zDeHCqVMYPHoU
+3ffdZ35fuPde5J59Fg21sbKytIR+ITC2aRMWZmbaNHc6l9sW7zgOhBoWbQxPGYPNrtnfa8JI8/Z6
+86htHPprYXAQEALVb3wDrZWVZJEzGeRuugnVU6dQLhYTrCCESUWcc0RRZEpURgikouJSnpdoGzV4
+FgKFXA4NhTF0vpdRhKDZBNOViZbREwKodrCOKnalxRiDPj5HVQBghGSu2wD0RXTmDaIuWBtELAQc
+3RrWm0NUWKs2myieOoWumRkQ1Q2kw8PY+slPIvP447h4+jTKxSJoJoONH/kIml/9ajJmrV4HjyI0
+bf7cdc1efR2ybW6/s2XbSSjZBmRv3LRlZJlcDoXNm5ONqc88Y2TmcRhiHEB6ZMQgcn1desOIzWBq
+Uoqp8k//b1f9vru3F5RSQwwxa1MrdRyk1TlGJk1Y/89WPBmvV9eU0UKYhAi6LhDowBIj+NZkK2Kp
+WaSUSKnF0I/xFcWqP+YvXkT5L/8ScmEB/MgRrP3Zn4Hl89hw553Y//GPY3BsLCnBHnwQu/75P0f/
+xo3IZrNgrouMUg45CqhRNTxCU7b6Ztsg0dC0VmmmS8NOhtEGlgDQOzYGb2wM89/5DsIwRNhqIVDG
+uHzqFPzRUfjptDHCzqrC/qqvQVPOmrvQj/HTaSOX0wRXo1YDcd11LGHRy/Z9tbkPfe/zrmvWQvUE
+risC1PTmRGmzVrr7BLTtWiFq2JFn3WSjKqpWMfPss/BHR1E+cQIXDh+GfPxx9AwMYHT/fkx9/vNw
+brwRpKsL7gc/iP6FBVSLxQQfWN4Da3+/vePHrhZcPVjKooDNriVtENZzpJpHGIchsvk88tPT4Gtr
+aFQqbc8lhKC0tITmhQvY9pnP4Mgf/VHbVFENNqnVo/AU9Wz6JOqaNDnlOE4CIpXAg+r9jypF2cDa
+jiJ6LbgC4hpo9mWziNeVxOH1EkEB2kGF2Zmqyz9GCDJKmqQfR19nDKvW94XXrqF44QKCZhNBEODa
+3BwuHzyI5pkz5tQPAHB6e5Ht6YGfTsNPp5OhT3qyFqVm/74u/bR3uypF2KUftb46nmdwA1NjZXSl
+4KfT6N6wAamNG1E5e7a9xHRdgyGuPv88nN5eDI6NJYvnuqaq0KPnbI5Bz0IgHYQR5xxeKgXfdeG6
+ruFK9DjctFI82dUQsaKANko9fW24UEBPPo96ECQSfEob17svoMisvGVTljZFzJVWgFldMJs80qpY
+bRitRgOBmprBFAU8e+gQ6t/4RnKS1/IyaC6H4Q99COP796N/bAx9Q0NIpVLG8/XCG56fUri+b3CB
+qc0tYGiXlqbHYDGGXiqFwtatiIpF1K5dM16o04aXSiWjbBsNNE6fxvCttxoPNgSU4yQGZUnXbG/v
+bF9rPoN0UOYm1amy0t53aYzLooen+/qwbds2lGo1xAqAIjnq9roUQcs26qcduYdLmWzy7MilnfSq
+JkR0ONZbrPXf4jBEo1bD1UOHMNxsInvHHQgvX0bt7Fl4vb3YcPfd4NUqmouLaCwtJQOXGg3j7TYQ
+tAGeYx3nYnuz2azieWY8bByGyPX3IzU5ierLL7dN/mqrt9XzZw8dwubPfhaDk5NYvHTJ/N6uLLT6
+x7EAm93VjDu2qhFLWgdlOEx1+HQzzBaSCAAFz8Om4WFMbNuGMydOoKJKU3U9y9eLAYq2GldYuZ8Q
+AmLtB9R9aZu7NuBL7wZKp82QJXPOjkXiVFZWED/3HCa7u0EYQ3l2FvGFC0jlcujZtg25rVuR27oV
+otGAjCJUzp/H2uxsGyni+n4i/Wq14Hhesi1MeTrUhlR77rAO38x10XXDDYhXVlBfWABRTSFCCCJ9
+bIyFIzjnqJ48iZ6dO1FbWUGr0TCGrY3ADLNSi6uFp/o9CyFQr1aTKNRsJpJwhWGcXA75nh4EQYBq
+vb7eI7GUTkP5PDZv3Ypcby/OHjuGhbW1RO+g1kJKuXq9EWDVtbToeg+AqUOt6KAJI89G2Mo4dA6k
+jgPebLblRD3dQ+/1q5VKWDx0CGMPPYTChg1YOHUqiRCHD8PxPBSGh9G1ezecDRvQNzCAnn37ki7a
+hQtYu3Ah6TS2WiYdaJbPrvG9TGY9lSmDSfX2IrVjB4JTp8CDAK7vGzma0yEf0yNjSpcvY3RiAr2b
+NmHxzBmzldwmlwghgDI2rlKhNjzJOcJWC5lcDuVyOblHKpWxfB69GzaYSFRvNiHDEDGAtOvi5ttu
+QyqXQxyGOHroEEqNhlEYWbKx64sAAGaJ1VwQ67kleXLHjXWsmtrekuW7bqLA8TxEaiCkHa47UXpl
+ZQW1V15BanAQ6bk5RM1mMroFwOqVK6jMz6OwYQO87m6kx8cB308EG3v3QtRqCJeW0JifN3P6pZRa
+MZvk+kwGXqEAt6sLTi4Hls8jdeutQC4Hd3UVmf5+NFZXE08PgiRVqBHzGoC6amxM7fx55LdsQX1x
+EfVyGV4qhTgMjRbBThuO1gEoQ2CuCxEEcBwH2XQaru8jlUph4y23IPOzP4uxO++E+wd/gNaLL5qN
+LpNbt2Jg507EjQaWTp/GuTNnzOLDIuXUCJmF6zWAK4ZpUjlbb2fiVk4zXa2On1mHAFNbfWcNrnOe
+nTbKly5h6I47UBgeRvHSJTP8SZddQbWKxuoqimfOJLlbnQtMczmkNm5EessW9EYReLmMcGUFca1m
+5gen+vuR2roVbHw8OUo2nzd7Fdx9+5ArlSBOn0ZUrYKkUokqWQgzjs6UloyhtrSEzMaN6JmeRnzq
+VBtPn1apQEcMrlrhjuIktBqJOg68VAqO4yCdzaL3Yx9L7sXUFAY+8QlzJlGqtxdRvY6wVMLMyy9j
+Zna2Td9oN6PUzzPXZQA+YzNSSkEIoSZn2zyAVgpb+d9ud9rAy3Gc5OQvNeZF30SbzdObNCilCGs1
+hCsryE1Oora01Ja3gfWxsMx10apU0CyXQS9dgt/VhfTQEKjngfk+nP5+ZJQMXe8KYlu2rJ8f3KE5
+xPg4Urt2IS6Vkqlc9XqCfVSJB306qTUypnHlCvI33ID86irqxaLxeD1bSM8mdF23bdSd3cXM5vPw
+UilsuOUWsN2712ne22/HQKWC8qFDWL14EfVyGY1aDXPz82YKiV1uW5E4+tHS0twvXY8BfHdxsfzx
+oaHLAthErJ2psPbpMas81ICvrYWrwrydizu7eXZDRZd0URCgubiIrt27kR8ZQWV+vm24oz5IQrdw
+dWIKazUE1SqY68JJpeDMzcHr7gZNpeD29cHft69tc0png4gwBrp9OzKNBmgqhWB5ue1YOD0q3paP
+15eX4ebzKGzdiubhw2ZkDVXHyunr1tJwJ5Uyo2allMj09oKl0/C6u9H1hS8khql2J6NSQevsWSy9
++ioWZmfbWExbn9nJgAI4+7UwrF5XBHiU89ZHgR9Q4JfsLct6U4LRu1nTQDpnBGnEbHfqqOOYSeA2
+XdrJ2tWXl5Erl9G1dy/Ks7OQhIASAqpIGcZYcqSMJdJoE18IkSzY8nKCxut1uKOjIFu2tO3/72T7
+SFcXnF27kGYM3vJy8jjrsAjowyZUyaU1gU6hgIE9e8zZQp0HVbUdeOm65vk0lQL1PBDfX79Pvg8Z
+BIhffDGZlra6ijAM0dXTg7q1rY0qPaFuFZtpKEI8BqB1vRggiIV40aFUEimJBoI2wGN2va9oYFOS
+KTLEUxEANldgcea2SJNZc/R5EKAxP4+uoSH0bdmCsuUBmhHU2EELOpxUykz7sFkufYYQLxbBKhVA
+jWT922kyCpJOg1AKhCFoobAuC9NpqON4WX9kJFlY61ga4rrmRBNzMKUqLUWrhZZKcfXlZfRfvYru
+f/JPgO5uiLNnUX7qqaQ8VtPQUqkUFhcX4VCKlFJDMcYQRRHK9TpayTQSKYDjb4QK/nEGIBxKFwFw
+RogjLF2AtIgdWxuv04CrvNS1Nl1qL9A5UjdMdB9d53gT6qVE7do15BsN5PftQ2t11QAqPaFTpwOq
+J5QKAUc1j5jvg6tBj0AyMzAqFsHOnAHbvRskm33N7iEpJdBoQMzNof788+YkMj1TmBACV+8ytvoK
+5gxjIcDyeURra0nJq04eier1ZNK5wi5Rs4lQRQrGGFKFAuIwxOrZs/C//W14W7di9TvfQXlmJhl7
+7zjIFQoYmJrCyLZtYOk0WqurKC8uYnlhATUlqFWVQEwTNbC4LgOQUor/sbt7eTSbXRXAIO1Q+Xbq
+2+zf65albpPaZE0bAladNBNRLIUOU8+rnjqFnjvuQPeNN6J45Mg6zar1ALZAVIdb5fHUIoCo4ySb
+R69eBe3vB6amzHOllJD1OlCrQczPI3zlFVM1COt8AhHHaC0tme/tE0iBZBp5z86dkFGE8oULbYda
+aOygjUUzkPr9Cp2yqlXIZhOpwUFQx0F+ZAQijuHlcqjMzWHm5Ek0ajU0Wi0zeCpS/0eVgCsz1eri
+G5kY9mNnBP2ncvkyBb7bmSvtJ9uL39kGtflvfdq27o61hXOLIGmrDlwXjZUVRMvLcPv6kB8fN39n
+vm9unpZ36f+hMUGb1EtNDYuWlxGfPw+obdiyWgWuXUtKv6NHEZw4gWBx0RwPS60UZRuVnYr0Nbjp
+NGqXL8Pp7kbX9HQyBMuigrVRS+se6AlmjuMg09uL1PbtcG68EfnPfx69n/0sshMTKM3NYf74cVw4
+cQJVFZWMyNUS6qgS/Zt/Ui6/oTExP9YAVoDii6urL7qMxbaH240IbvXebW28Lu10BNDh2U+n19Ww
+KufrZoteMGqlBOo4qF9Idjqnp6eRGRwEVV09lk4nJZ9iGo2h6UWzThzTFURcqyG+dg1ycRFyZgbi
+1VcRHT6M8NVXEV6+jPDaNQPk2ioEQl4TUezqwaQQIVC/cAH+wADSAwPmOvQ16vdoN7OY66KwYQMG
+7rknaYv39Zl5wtULF4z8zN7O3llKqvWIj62sHLv2BhpBb2g+gJRSfMhxZoUQJQD9neGfdrSAbTFE
+srvUbUPELJ1OdHCWJNrItjQwtESa+mvcaqF56RKye/YgVS6jceXKelWhQj6s00Htnj9Ru2z13zQY
+E7Ua+LlziBYXE4DYbK6fG9ypKbQbYgoLMaVghlXv62tqlUqgV64gu20bomo1OXVERQDTaNKTSOMY
+XdPTKNx5Z6KZ7O83Zx3Fly+jsboKx3HQajSQSqXWR+GtnzG4noKEKF4Mw9kfty38DUcAJJTiK1zK
+lzq3UNtdLLmuRV/nBxTAM13Aet2Eba3DN/yBxc+3lXTK05xMBlG5DF4swpuchN/X1+bZBmBax8VS
+WwqeSrVFA5pKAXGMaHERcaUCrqTetkcDAFOSdjvM6+syxqY928IvjuchrFQQXL2Knve8J8E6apMJ
+Ue8dSOYkjt12G9ITEwjOnIEsl9ePtZudRfPUKcStFpjroqaOy7FbzDafotbhSEOI43iDH29oRtAT
+cXzpH6ZSz901NHQvIcSxDcEWN0B5bKw6Xqa276B57XOAXdUjsEtDW7+vhRZGrj03Z0a5ynPnEm+1
+vb4Dnbdt6dCkkRpFI0ql9TOA9cZTndOFABT7RzpJLM9LUoSqQEQcg6g8T3SFpLZ/1WdnQT0PQ/fc
+g7XDh83xM8R1URgbQ27rVlTPnMHqq68m5yLWashns+AzM6i9+CJKZ8+2DcK29zLoGcq6rewyFj+x
+sPDcU5zPva0GoD7+Wgjx85TSDZ1bsiilZj6fo2hfE2LU8a1Qkiujydcg0fOMdzHLQx3PA1NHtOl5
+/cx1wZtNhFeuwN+yBd7gIFrqVE97AYlFF9u5WZ8HzNJp0O5uxHNzpi5Hx9GyEkiMwCKVzFZ2tYDU
+0hPYp45DysR4oghOKoX6TELJ9x44gMb588gMDyM1OQlerWL52WfBgwDMdRHWamjMz8M/dgxrzz+P
+xsoKGqXS+pBs3287vEK3m5keISflNS7lX7+JNX3jBsClfJlLeYJIucEuBWnHTADd69atTQhhwJ0Q
+AiIM2zxeL5ApjVSopGpIowFbVqUQra3BKRbhTkxAtFqIK5Wk5do5UEJFEXNiiVbaeB4Qhoa8adtr
+YDemPC85PVR9NY9TYNKcVG7nVN3rj+PkPSi0HlcqSG3ejK4HH0w2nC4uInj88USzoE86VSlINBqo
+Ly6iUakknp5KIazVkkpBGZ3WFij1r1ZmHY2kfOXNGMAbHhX7l0FQXm42f58QEtnCRNGxycJGpPoA
+RiOSULtr/K6u5KwdHWLtQQmq9Wojbjv0ad1dMDsLxDH8LVvgFApt+dh4ugrD+nW05pD19SUL2Gwm
+7V3fT/6mqW2buNKG7nmv4RvM/7RKUBvM2l+9/v5kY8z27SB9fSBDQ/BHR9tKWX3sXbS8jKDZNKLW
+Nkm8hbv0iFslwQuXarXffbjVqrwjBgAAtTh+Qkp5zRybapE+nXp4m+c3O26CALzZhFcoJOHLyvFG
+sKnBkt530AG2TA4MQwSXLoFks/CnpsDSabB02ng5S6eTiKLAH/P95HvXBRsYgFSIn2n9nlpgpk42
+Z0q9ZISeGiBaeEMbqQ029esRywm83l6kbrzRHGEvOTe7jnUq0ZHOKxQQWtjEz2bNQRm2ttF0WBnT
+W+qvXmk0nsab/HhTBvDvy+V6M4p+g0vz0bYhw7PqYlPLq4vVJ2yKOIanRrp1In2Tw630YEK/Jf4E
+paCeh7hUQnz5MkhXF7yxscSbs9lkAqhefI3cNU2bzZqfNS6AtYAAwFSbWBsVIcR81f17Xca1jcWx
+ehMaN3jd3cju349oZgatJ58EP3IE4pVXwI8eBVNnB2rjclTHUh9Rq5XOURSZ7zVuUk4loyiSjDHZ
+jKJ/9nu1WuvNGsCbPjTqny0sfOUPN278l4KQnRSQsRDEEYJ07oZpY8/UoAYACehyXSNnsnv8mtAx
+oVbX9xYzaJ/LSxhDsLAAmsmADQ3B4xzRwkJ7Htf9BXU6CdP8vzpNxLwmpeZkM2nxCQDA8vnk/GEV
+JXizaQCqZgalLSJVz/eHhuCOjKB1/DiiajXhM0olEwUk58hu2QI6M4Pm8jK6N29G5gMfAGEMtWvX
+4OfzCahUEdbzPD31XCpFHgBIIcTRX5yd/TbewsdbPTbu/5BS/r9CCM9ljEopCeecMEKIzluvOwNQ
+8ecyipDu60N9cbFdFWQteBu3b2/41ISPCr/EdRHOz8PPZuEMD0NGEeKVlTb80GZgfcl+Sdlsru9D
+EALSPltIRwitttHloxbDqPSiCSXNQUjraHqvvx/uwACiq1cR12oQrVZC2GigJ0RyMvnyMrp27kzk
+bfv3g0xNIZPPI3f6NCTnqC4s2JWIpJTKOI4lpVSoKwsizv/3t7iOb/7UMAD447m5vyKEfBdASyRz
+jIQQQhJCJLO9yM5ZyoOba2vgQYBUf38bqaLLvrZ2sUWcSClNZWBCs0b2lCK6ejUpu4aH4fT3r6cN
+C6AByXnAukNnpxdtTMTaNm7ndv1abaJZhRn083RqSI2NwR0YQDA7myy+Amt64YU63l6XxHGpBH96
+GuyGGxLD7+9H74EDSbRRw6wYY5IwJh3HEYSQSAjRagZBQwjx9d+dmXn0XTWA56UMOee/x6VcBNAE
+EAqAcykl51x2giVbs2+AYG+vabHaDZVOttF+HW1UJmKo8lCni/jatYR+Hh8HVSNW7FwNShPRhaUR
+gK0r0I+zNmIQxgz4bMvzVr/faAMohT8yAnd8HOH8PHiz2WbkndFQv77b05NEJqU/RBiCjYwYAxFC
+SCmlJIRwUBoCaEopq3EczzbC8MtHpWy9qwYgpRS/Ojf3AiHk3wkhSs0oakopI865jgTtO3QtJpAr
+7yO+j+zQkH6DhjAyANAKzyYEE2JyuE3/mtwbRUmTJ4oSI8hkksXzfZB0Gk53d/uE0jhu245GrI0m
+oNS0lLXhaMRuqhH1d10puH198LZuRePYMfBms52/0Eauookp6fTo2pGRRAIGAKUS6OAgvEIh0RL6
+vnQ8T0gpI8l5UwhR5pwvcSn/z6/MzBx/o7z/22YAABBIGfxgfv4xLuVLlNIq57wVcR5xzkUURdIW
+W9qnbVNKEVYqEI0G0gMDyfYrhdadVGrd6yyPo6qlSlOphLyxmi66hNMGIKMIfHER8Dy4ExMJgLPy
+ugaAZsGVERDXNQyf/gQAmnmdLfaaIbTKTH9oCN6mTWgdO5ZUG75vUpZNeJljbrVu0HGSPkSxqNqv
+K+BnzqD81a+CBwH6pqel6/uCUhpRSlsAqoSQYr3ZfOHrFy8+/SPOA1zHB72eJz8SRVdeWFr6j1LK
+xVYc1znnoRCCM8aE5FzqrpWru2ZqIerLywkfn8sZ79HeQC2WzSyYHqxod/s6y0SLrhVhiPjixcTT
+Rkfh9PeD+D5oby/gOJBBYA6LsLkFQxhpANoBSO1IYfoTUQTqeXDGxhCeP59UGgqf2OyhjlYG51hC
+ktbSEoKXXwZ/6ikETz+NxksvoTY3h/rCgqwuLIh0Tw/P9vWFjufV4zgu8Sia/9b583/4l0Ewh+v8
+eMuHRxN1V37YbB7fUq8/MpjL/WwsBAuiiDqOQyilRFHCRG/KysqwAAASSUlEQVTZ0qd3EddF69o1
+pEdHkeruRqxFlK+zP6CTaTOhVIdunYs1Fx+GcHp7E9RdqYBNTIAOD4MGgQn/tFqFVFy9poO1sNMA
+PsVaEsYglfCyTUiqWU7XhTs6Cr64CNFqtVcfdlPJcOq8PeXovYFhiPrRo4lGcGUFknNJGJNESt4s
+l0MRx3UpZYVzXry0sPD1rzSbZ/Q6vGspgFgf+leXgdr/t7z8sJTydCxENYzjZjMIIp4Q25IwJm35
+lAZDjWvXQHzfyJ46qdXXHCgRRW2h9G8Ky7omp6lUkre7ukBGRkAnJ0FGR0GGhsCmp8FGR0Gy2Tae
+wPZsG/W3XZtteADckZFEV1CvvzYadbCGBsDq6kQrjHQXVQ3L4kEgme9LSiknhEQQohmHYbVWKq0F
+zebpr8zM/CAGGn/Lurw7KUCTEYelXPqrubn/wWVsIYzjahjHzSAIIkKIkFJKIYSugdbP9202ES4t
+mfzehu6tm2eXaUZ713GjDUizjSWdToY6WYMeNXDD4CDIwEBSKXSyd1ZVoSsCjQ0M8CQEiOOk3KQU
+sdqC1jaNzAJ/nddsa/illEZkqngFSRiTIo6FlDLSiD8KgjVK6fx/fPHF/+tHnC/jbfqgbzbkd/5a
+feKbUTT33Pz8LzPGikKIqud5LSll1KzXlWBFmkMitdU35ufhdHfD6+5uq5UNeNLUryaIdKloh1Hd
+yBEiKfH0rh3V6IF1zk/baLVMJokAiruHpUoyrWMbCOrX13sNczkwRfR0piebeNKebv9dv76ZUVAo
+IFxZ0fdAijgWACJCSEsIUQ1brTXHcZYfPXLkX38ziuY67/0bWKfrM4C/ZfHbLuR36/XLhxcWfo9S
+uiaEqIo4DlT3UAghZNxqSZ0KtDYgLpXgFArrAEyBJwMEtXrH4t3tPGvyuGbuKDULJjW6bjTaaV/t
+keoxNu7QoE5jAmiGkNKkYtB5f9s2RLOz60yiVQ6+xts7xshokCilTHYtZTKI6nXJo0iKMEzKPSmD
+OAyrkvNSKpcrPvX881/+jWLxSse9x/UawVtNAeR1vlIA/D/Xao/Orq19xXGcNc55lXMeSM4jKSWX
+SQdDaiVRVK+jPjMDmsnAsSZytrVwNZpWfIBepLbGkYXkjVFwnih+FheTWX8LC0CjkSz40lIy+y+V
+SuThHVFGq4B0hDEGoPCLOz4OsbICoU74MHhBpy7dHVW45XV5Br3/cmgI0eKilFEkZRRxwlgEIQIe
+RVUhRIn5/vJzBw8+/BtXr76EZOIctZyO/E1G8E5WAeRvsEICgKwC9YeXlr6V9/3h7ZOTHwaSA569
+hBJ2JedUUgqRDAdIdvE0Gkht2IDG5csm3xr5tbULh9hHvXCeyK/0hVglm+QcVG2tEqUSSBSBNJsg
+AwNAqwWpRrIDAMlmE3FFrQZRKr0W5FjpRkaR6TRGV6+2RxP1WG08OhLo5hdUKavPPtJzB6nnyWap
+JHkUCSFEJMIw4JxXIcSal0qtvHTw4GO/d/Hi06tAXb1VaX3F3/C7ty8FdISTzrDf+UkB0KNSrv3+
+7Oz/392VxMhxleH/LbX04p72TDsz9oztTBIbO1GMgMSGAyFCEQIEEiICwQEhIY5w4ISQEBInxCZF
+ggMgIXJGbAoyJBFLcGInCowlGxsnduJMHNuZ8ezdPV3Le+9/HKqq53Wlqrp6bCeBlkrVPdXqqqnv
++/f/f/Wry1ev/pUxtiqE6CghfAAQkU+IGqXUgAii04FgaSlaFq3Z7K+PkwCZ3OBkji6zeyduGTPT
+q0myJ2n80EIAdLugNzb6YOP6Oqg334wI02oB2707chwN522gkdS2gbZagMa6A2+5X8nDrYyxsH6C
+yShwqSAAZ/duLVZWtOz1kBAiAMBHxI5Was2q1ZZfnpv76w8vXPjjC1FHNhmyDQhlWTNAtwk+ZBDB
+/EzPaL3249de+8XF+fk/VavVVa11W0rpKSHCqMMsjg7izKBYWQF7z55++tS8uQMqOVWpSzzygXYw
+I1evgyByCOMqpA6CPjkgUk+Aq6uAy8tRs8j0dBQiGunepDDFJif7uQYaSe9g5JFy9tJrH5g1AF6t
+akDU/vKyQilDrbWHUrYBYLWyc+fyf06devI7p0//7hTiagngYbskoDeh/tMXQU0tAAD031p3vnb5
+8i/mzp//I+d8RQmxIaXsKSFCSqkkhKBWSsteD/x4Va7qvn0DRRSzyzeZtev7AEYX0sANDoK3qHHs
+diPieN4gWWLCYbsdNYmurkYZu717o4IMYvSouvHxvr9AXTdyNJO6QlzD0PE4eLoDud+SnpgGRM2b
+TfQXFiRGCwb0VBBsAOKq22wunX3mmb9/aW7uNy8gts37mSNsN+ULkLwkUgZ78k5uAs/iPY83CgC8
+CuD+YM+eL3zwyJFPcdseJ4TscOv1CqXUZpbFuOtSwhipz8yQyoED4M/Pg2y3t8KopGUrpQWIubZ/
+WuoAgNbrgL4f/YbjANu1C7DbjRzBGNgkC2impAEgMge1WrTt2BE959i2Ix/i2jVQr7/eTwCZoWm/
+fcwoYiXaiFarWguhWa2GbGJCEccJ2ydOeL2FhQ5znHWgdOnk8eNPffnChT/3oiqrjB2/ZK/iORCM
+7X2yH2gQSfsCRZnC7TqBmbY/5z3rAeB3rl//3Ve73fXPPPDAo41mc9LvdqVTq9UIY3bY63GrUqG9
+69cpq9WINTERTe74fr83D6UEksTwceu3VgpAKdBG7gCSaV3X3Zrfjx3GvmQmNj4e/kzstKlx8MYN
+YJOTQPbt6z8zCBJnc3ISyPJyP7zUxvoH5vh48pBLwhiwsTHNZmeRtloIjYYExND7/e83vaWljt1o
+rG0uLi7+9vjxP3x/cfF0b8vb7z+INANYzJB4/XZEAaMSgwAAXQVQP2u3T7x58mT784cOfeY9999/
+twgCSSmtEcYcJYRFOWe9K1dodWaG2K0WCW/c6LdXJ0DS2EnrZ+dgcJUPrXW0nk8izYlWMDp++k5Z
+IvVmDG/6EKl29GShCAjDKHpIGkw2N6NBESH6xOynrS1L86kpze6+G8muXQpcV0CvF6i5uc2NM2fa
+bqu19sqJE5ceP3Xq+K97vddWowab9D3EHLt/86CVNAF59t6UeGbsmWEGzM0CAPY+QvZ8ff/+jz/8
+yCPHgk5njBBSs6vVKuXc4q5rcdellelpQm2bhMvLpN+UYZZ/jSJQ31NP1DpszQaaKWK+bx9guw1q
+ZWWQAKmQrz8A2moBnZoCMjnZt/V6bQ1wYSEKGcMQwDBNkKwaEhFQE0I0HR/X/N57EVotAQAC2u2e
+On9+s3Py5IZWau3pxx9/4SevvvrMKcS1WMWLWOWbm0qZgLQpSMwBZJiEQhOQSYAC+5+n+mkK/IQA
+LAE93ifv+RRA7bPV6rFvPProJ4DSnSoI6sxxapbj2MyybLfVYu7UFEXfJ6LTIaxSIWZxpp8NNIs2
+yXN+zFDRSPDwmRnQnhcRwBg367d+e95A/Z9YVuT87dkT+Q1hCLrTAWy3IxPV6w3WJOK+vaSSBwBo
+zc4q/tBDIQCEenFxU54+3RWLixv+9eurP33ssacfX109N79l72UJApjgY4YfoEfxA26GAFnOH8sg
+ATfIYBvvOQDw9xFy57cPHfrYBz784XuUEA2Uss4sy7XrdZu7rlWZnmaASIOVFcIch/B6nZjp4IEq
+naER+h09cWoXwxDsu+4C7XkgFxa2mkDS/38cOiZzjmzXrihujx9VC4jRSqVBkJ4r1BiGGhCjdG5U
+DRW80Qid2VkfELvhlSsdDMP1c0888er3nn32b89IudyNABcZ4KshBFAFzuC7jgAsZQYGiNEA2PmV
+ev39X/zQhx6YuuuuXYSxuvT9qlWruVatZjkTExwAGPp+tBSh65JY7RNzENSsGqajAq11tECUZUE4
+P7/V0pXYdaMXMPmslQLn8GEQb7wxIO3J+j6QVDkBNCCi7HZRa60wDKVWSgCiTxjrEcvqUttuL589
+u/SHp58+/cvFxXNXAbzuIOh5kv8/TwDTDPAscxBv7kGA3d+anf3ggf37p+85enRX2O3WUMqKXa+7
+bqtlaa05hiEjjFHKOSVRswnpmwTOSbpP0Bw44XfcAaRS2SriZL2MgVD0fXAPHgT/4sXE29cpj1tj
+GCIgogoCpYWQKiqD+4joUUo3qet25p97buny/Pz1H7300j//rfWKBJDhIOAiJfH/dwQo0gbM0AqU
+AjQfonTf53bvPvDgffftmzlyZCcgVoXnVZ2xMYdybhPGmFaKM8ehxLIoIYRQ2yYAQKhtk9TiDiQB
+lI+PA2+1ILh0KToeL1dnZhqTcFArpYHSqLc/6s3XscRrlFJrpVALgQAgMQwVhmGIiIFWqgeIPV6t
+dt+Ym1s9ffbs1V9fvfrKP5S67kfLthXZ+izQ37UEGOYEZhEgyy/gGdrArgM0j1A69dFGY+bTDz44
+e+fRo00VBFXleRXmOA6rVGwthEVtm1HbZpRzShijxLL6RIi1ATGcOmJNT0N45Uphg0ti0+MIQou1
+tQR4BADUQigAUBiGQgkRopQBIHqsUukxx9m8/Nxz60+8+OLlv7Tbb55DvNEF6MYg5Um92gYBbp8T
+WBAGQkr6yRAClCUByyABBYCKC7BjBmB8D6XN7x47dvjehx9uUtuuiE6nQjl3AMBGRItyblHOTfNA
+CSEUKCVxjp5opYizdy/I9XVQm5vJv6iNwo7ut9hFdQokhKDyPNRao/I8RQgRKggEShkCpQGl1OPV
+qgeUeueefHLlm88/f3FF6/WrABt+BHwaRJEB9CjgqxzwMS8bOHIYOEIVkGbkAlgqJTyMCKxAMyS/
+4QBAFQBq9wDs/GS9fsdXH3lk7x2HDu1gluVQ13Vkr+doISxE5DRasJ8xx2GISCmllNo2AUqBV6uE
+2jYRGxtbtX9CotDNskB2u5raNirPQ2tsTMluN3LqtJZaa8FdN2COE2ilAhUE3tLLL3d+/tRTV/+8
+uXnjFYB1iHr1fANAHAK8KvEeM9S/LtAAcKsJMMwMDPMFWIkIoYgc5jEXAFwKUHuQkOZ7K5XmR6an
+Jw4fODA2NjlZqUxM2FatZqGUFrMsprVmKCXTSjGIhlgpd10i4xpB3DKm4zX1NCFEUc4VtW1FbVsB
+opC+LzAMhbey4q8vLHgXLl1af/batbU5z1s9o3U7jEAP4w0zAExL8rDjeTb/lqr/W1UMKuMLDPMP
+WIb6z/uOecyOCWE3ACoPcT72gR07Gjsdx21Wq84Ox3F3jo05E5OTbrXRYHa9Tu16ndqNBgVKSdxp
+FEkSpTpstzHY2JCba2tq8do1b63T8TeDINjwPH/J8/x/dbvtE1Ju9CIJD2LAhSGRKgdoHAK2zABa
+DckAFjl+t40AkEoHQ4EWoEMIUIYMNMOU0IzzUCO0TCIKywWw7gRwDnLujnNuuZTyGmOsaduMEEJo
+nGeXUasytqVUa0KIJSHCi1J68wCBPxinixRYmAJGGRoAh0i1yqn0lQEeUzYf8yqB2yZASVNQ5BRu
+hwhp8NmQ36E59fK8+oRZx4BUGxWm7KpKhVo64zuYA5IqIEUacFkSeJVxDVkEKAX8zVQDTTVDUqVJ
+c9VyyFBLdMjNNDcW/9MmiAiDpdIsIpCMxslRGiZ0RlHFvF5VcM2qYK9KSnqWo5dHxFy1/3aVg9Mn
+xZRUmRfJUqDTDKBZjpSzHD+DFoBPczpo84iQzvKlb3jW5yzw8/42zK4XESsr4ZOLwyijYmWWitUZ
+ZkBnqND0Sxk3Wqc0ADXe95+YWqDySQ7gad8jT/rLaII8yYcMANLAqBKkUBmfi76vSzp72wa/lA8w
+gnNYNlQkOUDm+Q5F3yUF0l+2iTKPBFhgBvKIMIwAZcxI1rkxR93fFPjbIsAIUcJ2yWBKe9FxkqPq
+acb58q4PCm5oXnw9zCnUGfZbZ+TuMYdQeVm9kZM8t5UAIxIBckDJSymTEntS8jPJyGPAkH46nePE
+ZnXgYAli6ALA07+jc8C/JRJ/ywmQQ4I80wAlbHORthgGOmTkKGAb0UBWAyYUxN04xEzoEgDnZfJG
+ju3fdgKMSIQsAPLmDMqSJ30OmkGGPK2kM47rglB2FBDTTiQUFW2KnLvbAf4tJ8CIZIAhqeayfy8q
+WuWRrcz1mPN2WbN3OIQgRaYk/Z7EwCK8za/bRoASZIARCEJKgFek3smI5xuW74ASarrQYzfK0Bre
+wRd5h88/CklIyc+kJCnyfiMvx6FL5A6gJCneceDfdQS4TeQh29Q4o2iCocf0u/gm/xfj4khT8YnR
+LgAAAABJRU5ErkJggg==
+"
+       width="48"
+       id="image2175" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/wifi/data/misc/old/link-2.svg 3.4.1+git20201022.a0d3415c-1/wifi/data/misc/old/link-2.svg
--- 3.4.1-6/wifi/data/misc/old/link-2.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/wifi/data/misc/old/link-2.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,452 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="48px"
+   height="48px"
+   id="svg2160"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   sodipodi:docbase="/home/changfu/Documents/Install/Cairo-Dock/plug-ins/wifi/data/src"
+   sodipodi:docname="link-40.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="7"
+     inkscape:cx="24"
+     inkscape:cy="24"
+     inkscape:current-layer="layer1"
+     showgrid="true"
+     inkscape:grid-bbox="true"
+     inkscape:document-units="px"
+     inkscape:window-width="762"
+     inkscape:window-height="635"
+     inkscape:window-x="10"
+     inkscape:window-y="65" />
+  <defs
+     id="defs2162" />
+  <metadata
+     id="metadata2165">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:label="Layer 1"
+     id="layer1"
+     inkscape:groupmode="layer">
+    <image
+       y="0"
+       x="0"
+       height="48"
+       xlink:href="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAIAAAACACAYAAADDPmHLAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A
+/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB9gDCgMTDHC7HbYAACAASURBVHja
+7L13kF1Zft/3Oeeee1/sfp0zuhupMcDMAJiMCbvDTbOJSQxLFUVaosUiRdIsl2mpKIs2LZqU5Sr9
+oSqbpuQyJZOmRZkUTW4gqU3khpnZncHkGQwGwGAQu4HO4eWbzvUf55777sOstAG7K664XdXV6fV7
+951f/v6+v98VSZLw3Y+/vh/qP/c3KIRQgJt+Oul7dr7CQxMgAkL7mSRJ9F0F+M4RtANUq4JhDRUN
+5bKkemqEeU+xFMUcjRJmJBzwFONRDMoB+zUV+jXgDHAWeGNUieW2pimhLaHVTNgBmkmSxP/ZnNt3
+aggQQohU4GODiv2LgxyTksNRzJIUzEvJNFALYqQSoL/C29TpV3nL98oBKUA5aCnYizQrUcyycrig
+NReu7fFGoLl0I2QTaCXfwXH0O04BfuHxipJSzj7zcvOHiy4nopgJT3EoiFgAXA1oDUpCpHv/FyXG
+2vO/k6L3fbUAIxUYGTCPiWJod6Htm++lzB4fSslV4E1gox3wyo0G/99yyPJ3omf4jlAAIYT4jZ95
+RC2/evoHvOrg39pd3z54YZlDyqEUxMZqrUCjBIIYgqhn9SoVnufAYAmKHgyWoVyG2tg4ten9eEWP
+bqvN5tVzXLvW5sZOqgi6pyAqVRirDOnXDnAReGuzye+92uCjSZLo7yrAN+njf/0H3zt/+ZUv/9Ty
+1e3/cnWHqXoXV0pE0TFuW2sj8PzHzBAcPlxj8tCdzMwfYGZmipmxIUZqZYaqRZQjKQwOwMg8FAbB
+34X1K+ztNtjYabHT7LCyusHNlZvcvPoWaxde4cU3zesoCcfmjQKs76ShJIEgIknziBWt+dfX9vi/
+LneTle8qwDdm8cVffNfA0uD4zA+/8OXzP6scJjfr5tCtVVvhew4sTsK+pf3sO3I3x0/cxV0Hphie
+HIdiFUqDuaCvjcALEyCrEG9DdxM62yb6O2lOLCTEEegA/DbR3jaXbu7y6htXePON16hvrFIeGsFv
+NgjaTTqNHerbTdZ3oNk1OYTWrAG/dXRR/Mn/cTq5kCSJ/10F+OqCL7x7mnuAR6KYX6uWqM5PKy5c
+jWj7PRdfLcCBWRieWWDh6AkeffQBjuwbp1Qb6Bc4QKKNYFURKlPgjkDUhM4qdHbN34XsPTYKzOO1
+7v0OjEIAulXn5laLerPLbrPNxcvL3Lx+le2VK+ytXufKSkQ3hG4AnoIgov7gPUO/2t7bfea3n+el
+JEmC7yrA2wXvzrjceWCIDyqHX9CamZlRxPzSItcuXGF1xyRii1MwNj3GxIE7WDp2nBNHFlicGUJV
+B0FHIBU4MpfPA4UyVKegOANJAK1laG32hB4FJpjHkfmdlEb4eQggDMzj4lQZamMwOANhGzavcH1l
+i1ffXObVF1/k7NNfZH3HJI9grrsbk4xVWI40v7W8y7+/2OVskiThdxUAWCiI2lSVH60W+CnggSDC
+9RQ8/PidtLbXuHhhk9lJh8HJOUbn9jN/4BDHlhaZnxikNlDKLFS61n0rUOn31TEYPgSiCP4qNFfB
+b/dbvJA9K88Xh1HU8wiAjjRRpFFKIgeGeo+LUw/TqbN8c5ePffJJzj/7F7xxvpEpgU5MWPAUwWCF
+Z29s8zvrLf7ocjep/7VWgEfHxEK5wP8dRNwDDFhQ5v77Z1i8814uPPd5KiOTVEfGmNl3gLvvOsLs
+eI1K0cWRAscRONJByl4VID2PyA9QB+5PrV7D9qvQrRuhWuWIcy5eecYDJDnhW2VINDqM0AnEcYLj
+CLSGdjfAkQKlVKoMktLoMK2NLT7x+Zc498qLrF14hQtXI+MFIhgswlAV1ndp6ITnmwF/+6Xd5Ppf
+SwV417R4Qgr+lU6Ys/mZp0yJ9ku//g/53Kc+hXQUXtHj8NG7uXtpgaGBIkIIHCmQAhzHwZGCJEko
+FV3iOKFQcmHhFHgzEK7D8mljxdbSxX8I/DSClq5CB0FqtZIg1CRJgk7AVQJVKNLYaxDFmiCtEWOd
+EIYxSZKwuH+KjdUtnnntEm9deJObb73B5vIVLl6HcgHmJmF1E9brIGFZw08+u5V8/q8FFCyEkHeU
+GV8c5Wek4Fd1ggpCI3QNzI3D3/h7v0jXD3CUS21klINLhzk8P43nKvwgRilJrAWuI9CJcRlSQBjF
+lAYHYO5BcKrQOIt/+TUKnpMWAFFaw6dW7sieFwC01kgp0UGAlJIo1ARaE+cgRFWpErWahFFMrBOS
+JCGMYvwgRguIgogLF5fZNzHMwblJlFJUBwapTc1SG79IY3MNr1ymWmqzbpz/nITPPDomfnW7w78+
+12bj240hqG+j8N27qpyYG+a/1wkfjmKUlOC5RgEOHRpieukE77x3iX/5O3/E6MQkh44sMTlWQ2ud
+fpocTQhBkAiUI0nCCCEEAyM1mL3XJH83n6G1voaU0ggnASeF8ZLIgAaOY54vSRIMqmz+ZuRt8rM4
+TjILr9VKoBQ79Q6xTohiTRwbBcgrRLsVsNfssG+yRjuI0Gk1IYRgcGIufZ0zyDXfhi0F/E8TVR6M
+NL8hhHj125kgqm+T8L2TNd4zM8SvBCGP2qSI1OpHZyYZnJzngx98H8+cuYJXLGfCV0KiE3OASZIQ
+xwmx1qg020+ShLn5Kdh3CuIuLD/D7uYuypHEcYwfa1zlZFWd8QKS0I+yeP62YJBafhTrHlxcGiTY
+2SaME+I4TjN8bUKSEiRhgp8q6vJGnSP7RlmcGqLrB+jpSRCS+u42Y5NTKE+xs/Ms19ZNWQsomfCD
+c0OMscs/FUJ89ttVLqpvg/DFvTU+NDPM/9INWLLQqhRweN5haHaR4sAI1doQh2ZHeOGl11m6Y4nh
+wQpaQ+wkOAl0/NAAQUgkkiRJ8IOYAwsTMHs/BHWCi6fZa3YQQhBGcWbZWutMgaSUJInxGlFsFOiW
+6yVJUgvXJvaPDpZASDZ2W0SRzv6uBcShsf44Scz1xjF+EHLl5i5HFsYZGShTb7YZGR1hYHCA/fPT
+7G5tMr+0SLl8hXNXeuWi1jw6N8Q/Lzb5FSHEH387woH6Vsf8HzzEj0QR/zKKGZbSvKDnwoH9VWpT
+CyivCInmwYfuZ3O3zej4KEODVXPAOsBxHKSUKCVxEoEONJ4HQaw5NDsC+x+DuMve60/TaPuZkLXW
+OI6TKVuskzQMaHTS3wiyQrclmw0XOoGuH1EYGUbvbeIHJtGLk5g4SrL/8dOwEkVWsTS7zTbNdpdj
+x5fYqrcAOLAwxf6pYV56uUShWmP64BGK5aucu9g1QJdERDFLY1X+z3eWkUKIP/pWK4H8Vj75Y+P8
+YhDye0HEsNXyahmWjowxNHMAqTwAyoND3HVgio29Fp7n0Wx38YMQnZjkLgxD4jghSlLrCzX7JmrI
+Q4+BM8jyM59kc7eNH8QEocZPmwNaa+I4JkqTvcyqtTYKlpjfhZF5jInrMa1OSBBGJEkq5NocV27W
+iRJNjHn9WCf4cUwn7Ak/jGI6fpg958pGA9wi77j/CIcWpjh56kFKBRfP88x7l4rh2YMcO1JlbLDX
+hgaGpOT37q3xc9+RHsAVovTuOf7uYJn/UWs8a01DVZjfP0ZleNwkYspFOrD/0GGGBsvU37xBHMco
+pYh1QhBGuMohTswBK6XAgYmRKqXDD0Ciuf6F3yUINXHaiY1CjfIUUQhKSKJE4yCycGA9gkn2dJZH
+CCGIEo0SJry0OqZqWJofge1rNDo+jg0PqVEqIenqKEtSrdIlSULXD9nYbeCvrVA4/qMsHYxADuJ1
+65QqFQqlEomOiYMOtcl9HHLXuHJ5m91mdn3eUJlf//Ci0J++yu+ESdL5jvAAQojiEwt8v3L45Sg2
+lq8cqJZg4cA4leFxHK+E8opIB6SjmJ+doNHyabU72QHmPxwpkCnaM1AuMHbsXlBlOueeJoyMa9cx
+xFGa0SfaIHepoGKSPsEFcUSU6OwzCCMiHaEj8731CGEUI+fuoLG5hZMqSJB6kzhO6AQhWpvHWW8i
+hCCOY6SUdLo+G7stEFWQE0ARJo6xb3YSR7kI6WResDI8zuL+EUYGUuRQgnIY1ppffmKBDwshin/l
+FUAIoY4P8F4p+MfAnHLMmykXYG5+iMrIJKpQRqZdtzhKKJUHWNo3xsr6Xgam9Mo+I5BYm8y7oBwW
+j98FhSH8c09yc7NhhKJ7btyPY3zfPE8URMSpi46TGAcjRITEQaAjg/TZsJIPB6GOjbCLY1xf2zPv
+DyNc3w+JooggNJ9RrE3I0uZrkiSEofl5q96BpNlDFr0pDs6OUiqVcAtGCYR0QCpKQ+PML44wVM06
+igALWvNr99b4npT29lc3BDw4wtxUjV/TCXfY8qpchOnZAWpTC0bbE42OTXx1lMvI+ATDIwOcubRK
+FEVIqYjjXgZvSjhNN9acOjkDA3Nw7TRvLW9lNboQAj/N+rXWROnPtsxz4jgNAz3vohyZKhsoVxJH
+CZIETa/cHBkoQxyw3WijHEmlWEBK2Zcf2LwCIAzD7PdCCKIootnugu6mNFQJwqNSdI0HTL2acFxE
+YpSxMjzOvjhm5foeu01btnJsfpxfizSvA9f/SiqAEML93kV+P9Lck140ALOzFWrT+xHSMYLXsdF6
+IVCeYmBgAB0EtDp+mrQlaUNO92XoDx6bh9mTcONlnjtzHdd1iOMkQ/DCMMy4AkmSpDiBSp/TwMa2
+HATohlEmAMIeo0Q5Ep1oHEcwNzEIq2cyZemGESXPzdx+1w/SHkGcCd4qr1Wik4dnIOnC3hdh8K7M
+6bqum1IPHJIUqhaOSxKHVEenmIpCmpfa2XVFEQ8cmOTflKR4T0d/84Cib4oC/JOffdT98WP8i3qb
+h22SBbBvpsDw7EGko9BRYCxDOikmb8q70ZEa9VZAu93NrNN03cgOtTY8yMDRhyCs8+Xnz+OHMbLb
+X8ZZb5DRAFKY1tT9CSKK055BgXanmwFJt36041Shohhv3xIbb7zSQwrT6xkaKLK12zKPC0w4yMrI
+VMm63YBjh+apHLyb6Nxnefb16xw/+BoD9/4oA4MlSuUSQhhDyIwjDiEx4NPg+AwHgitcWcna0kJJ
+3vG9h/lnQoi//82irKtvhvBbO1s/vt3gJ3NlDFNjUJtZQDqKsGsOSzgm5lmhOarAHQsTbNe7NBoN
+XNclDMO09gelFMWCx0OP3gdxwNmnnqLeMoriql44tDW+beCY/EGk7tpgCVZASaebho1eHW+bPfb7
+rEfglrmx1aTe6mbNJ601MR7lUpEobhNKmVm874fZ9c9MjXH3nQuwdoFPfuksQRDxTDfgce+jeAfv
+ZWTkdVauqSxcCOkYBbDSlg7V0QmmOjdY3QbpGI5BucDPPTHHc0KIP/hmKMFtK0Bze/P+Gxcu/CMp
+8azwhwZgaHIGx3GM8AWZ27dvFsDzPKYmBnn+9WXiNH4Wi8XUbUscJ+H4oRkoj3DjldNcWllHSpll
+2dbdSmngYq01Ua6xkyQptp8+HqAbRDhSEOZidV8pmArfVQ7oiHanmzWbdGIeF4RRBjKFofEAxq2b
+39VqAzx6fAHiiM98+Tx7ew2DL7RafOEleN/wCKNDAwghKJQKRGFAEiRI1+QFjuvgFcoIMUNtZoGR
+5cu0tjdotWO263hDVX7lkVEuAM/9J1WA3/zl75+O/c5PX1vn4GDJaKmSMDI5gipVjSAEPQKGkCQ6
+JtExjlugUCwBsLXbMI9NARWZWtXM5BTjiwtw4xzPnXnLdOmiXt1tMfm8hVsXbHEDrTWJEOhEZ4ph
+yzWLEFpcwIJuJodwQSq6QdSX9MWxyICfkk0KgyjLA0ZHh3nfI0dBeTz5zOtsb+8SBAFxFKO15url
+q7x1bowHjy9y/cYG66urhIHPwGCNmbkZhgcr2Zns7TVo1us4jovjFvCau9RGIho7raWZUX56VImr
+W1Gy/p9EAf72CeF+6O/8zPv/7N9+4oeGqgY9lQLGRj0KlVouQMu3MXCsy3Rdl6Ab0Wy2ieMYJ46J
+078ND9c4ccg0UT73wlvEcUIQBFkzp5cvRJn1WhjYWnUYhtn39u/2sdZ7OI6DH4T9YSIXYrp+kAnX
+PofWhh0UBBHFoofrOjSbTRbmZ3n3qWNQHeIzn36a9fXN7JqQOusVbNVbHNz/o/zwDw/RWb9JqeBC
+dYidGzd55swVrly+xu7WOkG3i44jYr9Ft7FNp9HIoBHgI8fH+UIaCuJvuwK8/yf/7rGnPv77/1W1
+xJDF1stFKNWGbykPDBFDOF6mBEKq7PDDKKbT6RClsRopkVIyMTqEmjrAmWdOs7q2aRTEcTLXG0XG
+6sIwJo57wvE8lQk9Qw/pNX3yiGD+MTZ2h2HYqw7iblb355/Deh/riQoFl5N3L3HPvXdCovnYRz/D
+9vZuZvVSkClcsVymXPAMZ2HmBynNaFj/JF/87FO89OIr1Hc38ZsNUy6nIcd6zGarQdCL+kNDVX7+
+nRO8jBll+/YpwBd//x+V3nz9tR/oNpv3FQtmgkY5UK0VKVRrRsj2oG/pZdj4Lx0oVSoEYUS30yWK
+ItwECEMGBwe576ETNK6c5+K1G1lYsO7fCMPB942Fh2GI67qmVOsGmZJYYUVpC9LzFEEQoZTs8wzt
+dheljFeJIo3WvRjv+6EhoaQlp1WavAI9cNdBFu5/mODKGf7dp54l6HYJoxgSoyih1oSBjxCCfQv7
+uOsdj4EY6WFxu6tcW16l3apnwBVSQWyaS0iH4sAQw8MNbq77eCplSMc8OjHEDwghLn6j7eOvGwn8
+737ksLO5XT986cXTPzc6t5/aSCWjchXKAyQ6BiGzakBrbTLcXP1vPyqVkqFW+Sazj6OQOI6579h+
+6NQ5c2mV7c1tg7p1uykE20MLLdpmv7dAjNYa3/ezktIKLkgJGkEQ4fshQRARBFGWwdvvMyg6DHAc
+QRjG2XPYsBJFEbXaAO9/9G4Wjh5m99yLfPQvX8TvdAgjk+fEOkHHEX63g+M4HLv7Lj74Nz4MOzeI
+zvw2pJxQHUZZPpN5Td5e5pZqwwyWTTc1G27V/PwPHmL/t8UDCCHEx/7FL8qn/v3Hf9bzmKqMjpMk
+CXvbLcqDRbxStYfFJ71WbKJjA3Kkhysd46YLhQJ+GNNNY50MfGbnF1hcWmT50jVef+Mtk8SFIY5y
+ITAUbiswI8wgywnyQrJVQt5ahRBZSLCP0TlGiFLKeCLXpaAccFRGGLE9Cq01rutyYHGOx+5bAuD5
+Z17m4uVlikUP4TiE7VbmHaIoYnhklFP33cWxo/NcevFFnnr+DIEf8AP1DuMP/ySXb+zRrNd7TSXL
+dE7fg1UKt1CiUi3QaPgUC+bXXsJcFPMzwH/7LVeAf/jDh8SlNy8u3bx89ScqJdOAGZ5ZoLmzTqFU
+6ZVTsid84bjZ4WfJW2JYtK5yDOlSx5kw33nfErq+zfOvXyIMfHQcoVzPKIhQREGI53nGCoMAx3X7
+Kgd7YEZJ/F6ZmEcMc4igzS2sF0mShFKpwPTYAEiZhQ0rnMnJce5ZmmXs8DHWzr/Oc69fZmNtgzAM
+CcplSqUS7WbTJG9xzMKBg7z31DEcKfiDjz3JyvXrBF2D8P3Rn32Rnzt8BID67jaJNuWq8EoGGIr8
+HlchMXy44sAgYbBBmg/juSAFP3WkIn7rfCt561uqANXRCefSy1/6p1IwmCTGvS0eWmJ3bRkdmitK
+YuPqk8Tg6lLHPcgzX3sLmUGscRwTRz5Ld59gdKjClRu7XHnrUqYwpoeQQBQRhiFQyQQmHIckjjO6
+t8Ua8kRP6wXsa9vfWzzB/t2ST2oDFcamJ6A4xsToEOtbu0gJ9x07zL7FWShW+dQnPsXeXoP6Xj0T
+dmN3h+GxcQqFAjvbTY7fc5L3P3qUC1c3+fRnn6JR3zEKmlr49uYqL335OU4cNN1Bv9PJlFM6ikQI
+CLvEiU2mY9xiBderoxPftLwlSJfhk/P8MyHEj3y9BBL59bj/sYmZab+x907PMwJtbKzQ6XR4+L0f
+zOKWzAnCCs96hETHmfBtohgntvEjufvwArJU5i+fftEQLMLQUK79DkG3nSVS+f576JseQhLHJLnM
+3Fp63iPYzN0qh31clJqTEILBwSqL0yMwcy8U7uDBR+7le99xFz/4Qx9g3513s3FjjY/9yae4fvU6
+9d1d4sjkHlEYEIYhqyvLOI7DqYcf5P2Pn+CFsyt87BOfoVHfM4CPTllFKaPoM5/5AtJV3Hn8bnQ6
+fhb7rex76RZ7ybTWCMehUKmgJJSKAqnM12qFxx8bZ+xblgT+xs88olaXr/39rs+ATfA6ezvcvH6Z
++dkJ7nr4e3qWZsEeW1unAJAVhKNE1hIuKBcpJQsHDzNaK7F8bZW9nS2i0NTfOo6yOG+FKYQgztX4
+lpUbhiFxivmTxmyT2feSO1MVRH3KIJXKfi4VC8wdmAPvgDme6e+HOz4C1QlWz5/lubNX2VjfythK
+Wpvupk0Mw8Bn/4EF3vGuh/n8l8/yuc89SeC3iVN3nv9IdIzfafDkC28xMTqEW3DTktlNOQ2mf+IW
+KyYHSsfWpPJMHiUdXCc1NEHtjgX+GyGE/JYogFLe/vbO+uOeh5SOMhqZaDavXuTCW8u869TdLN37
+CI7jZDV+prn2TQmJW3CRjsJxXIaqZRbue4A7j9/NQyeOMHT0fi4ub+J3W6mV+MSRictBEGSWFnS7
+dDod/G6HMPBN/R74KccgJOgavD9OrTuOYkLf8AV1qqQ6iojDMPuaJAm12oCBnmceS6OjHf/aZvXl
+L/H82Sus3lglDEP8TovQ72SW302rlHseeIDveedJXnjmJV556RW6nWZm9YAhroRplZCWfGfPXmB0
+sEK5OpR5yww5jXx00E5LZ4VwHNxSBel5JqQ5ruExOo7jSPGBB0eY/5bkAMVS+dHW7saCUiqzaqvF
+r7/4HOVykQ+/5yH+olTk0rmzBO16VgEgJKRghnI9CqUBpmZmWJiqQe0UH/i+LnhFKM+wsbmDlBa8
+kcRxmNX9NmxYq+uBMS3TcYwjXM/As9aFmoOTqXKYxyc66CWqUjI0PMTc9Bj3H51D3fEEyDLQBTwg
+gjc/y8sXllm9uW5CS5zmIqL/dU7cew/ve9/DPP3kCzx3+oUsp4ijXotYOhAnvbMDaNT3SJKEqdk5
+9rY2+jwmUoGOiMKgRx7RMV6xTDc042yWxCocd0GJ4FHgyjdVAX7sqBhauvf4OwqV2mBXbxP7vrkQ
+IU23r9Pg9Bc/T71+P4/edyfz+2Z44bkX2Ll5NVMUR7koV1Kp1ji4dJh3P3AHpbvebw55/L3GGbVf
+REpJuVKl3Wr2OnU6QubieBjFBp9PsQXQ2FkK3e0YFrHr9fYCCZMLOLJH3qiWS0xOjjM/OcLC9DCl
+mX2wt87Kl/6EKNLsmxxAHvsRiOs8/epVNje3TabfNbC1CUdxpuAn77uX9z18hKe++DxfeupLRFFA
+pVrDcVziyCiLQBNHSeYZdRyhY0Wntcdrb15lfm6KKxdLdPZ2voIHVoS+j3CMErjFCnEUZgoYGQ9U
+W5zkcUeIj8dJ0vimKcDqNndNrl59oDI8LhId0wm30ozaCDaJY8Jui3MvnWZnc4Pveccpvu9D7+LN
+q2u8/Pxpuo06CEmhNMDcwiIffvxuWPoIUO6PRN4QC3OTbG1uGWAndesmVmuSJEYmKj24FBWMY3QK
+3UpH4UiR1f9eoUgUBkSAcj2UKrA4P8ex/VPMjFWR5SooxerVG3z2Tz5Fp+PT7XYpFou8XHD5gZEp
+GD7AzbUt2s0mod/J8gjriQDuPnmCJx5a4vnXl3n2mefSs3HodtoUS2XCoJNZtDFgAcJBSJOnxKHm
+5o01lhZmcN0CnfzEcto/0WkCaD2HVyoThz5R0CWOQpxCAR1Gcmi0+OChcvcu4MvfNAXY7bAQdbuL
+jc2bHD31Hl77/J8ZLSyV+sqtsNNibfkq/+4PV7jn1MM8ds8SD965yMpWg7/83JcoFAocX5qHg08A
+1TTG6p4CqHmOH5zi0tUbdNtNYzm42VyfpcRJR2U5guuVegKJI0PtkhIhTV4wPbePE8f2szQ3AgMp
+/OoV6dy4zpNfeJkrl68ZS8oBQp1WiziOefn5Vzn5aJXtzU26nbYJNyk+b/sF+/Yf5IPvuoc3zl3n
+C1942mAXOkqvL0a5HsXyIJ3WnkkUwx4GYTyVJAo07WadgudSKldo7ip02DXuP82hpDDJagZsCYlb
+qmQJd5IkCM8FOOBJ9n/TFEAIUfjZh5xDwhHV2DcWMnXkJKvnXgQMtTkRhrMklSIKujhS8MLTT3L2
+1Zc5fPRuHj55mF/6B38PykNQmQNnjP7FbJairfBGxvA8lc4CxIBGSoVteNmJYCklhWIFpRTK9fA8
+j9rwMJPjwyxMjTI9NoBXLYPrQbdL0OmyfO4SZy5eY2trh+beblZRRFHURxmzWf3Fyzc4eSrI0EMh
+BJKEJMUnhoZH+NA7T7J6Y5OnT7+SwtS9eI+QBH6X6sAg3XaKfXgyS/6M+1YgJJ3WHhu7DfYtLrC5
+esMMr+goUzjbvra5SxyFpiyUjkmw4xQGD6PqO+8pLgohvK+lP/BVFeBkjQUhnfcncYJTKHD1tWd5
+6AM/THtnHb/TIkmpXU7KcTMNEHDw6dQ1r57+EhfPneFd734Xp554L6gDuWf/CpjF9Cm+5/4bDFQr
+bO/U6Xa7OI6D53kUCi7FYpGx4SphGFMueIwPVxiseGYyWEiiVpNWJ2Rjt8XOtU226002t+tsrq/T
+bjVxvUJGShVCGHKHFH10dIsqbqytQdhldHyUVrMXUt0Uffzwex/GcyWf+Nyr7GxvZQinUdqeYsdx
+THlghHZj23gok8chpGNygkTjtzpcub7K/vlpzhQLxKFvLB/dI6qmAu8pT3/XNU12BfDE/UP8AfDW
+bSmAEEL83COFuSRJTgplGjoauPzmGxx94B2cf/HLhH4HZMGgcbYXL6ShXSUGw/fbHb74hadodwPe
+/ZExKBz7ClVo+r0zwtB9P8R77lqH3Svo3c0coqfN9Izn0dhr0eiEx80XaQAAIABJREFU7NQ7rG83
+8aMN2p0uzXbXIHS7u/jdTh9H0Ix9B329fUf21+Z5plEYhtDaZWJ0iOtXRPa3MAx5/PFHmZ2q8cmn
+zrK6smz+lmEfMg2NJk/pdtqUK9VUSDE2wc9wgXQYZWdrixN37M+RRXseIPtdmnQKIUjy1U5ilEM6
+ikTH9z90ojInhLj01ZZYfjUPIJMkmZBKFnQY4XguQgjW3zrL6MQsxx56J2e+/Pm3/1du8VKi47Rk
+C9na3oPtizB96D/w0m3067/Pc2+ssNto4/t+NoyZJ3CUSgW2tnYIfZ8gCEyb2C5xyrGJvxIPwD5H
+Xgnys4H5xwghWLm5w8L0KC/aw0187rnvHu6/Z4kvn36dN8+dzxJCK6BUCBY/MVWMlBRLVTqtPRwl
+zBCLdHBSGlkcOpmXKVcGCdptEqmQqbsXQmRVTxbzcy33fMc1gaIQYjy1qvh2FMCVrjokpZRC9siL
+JJqrr7/Ag+/5EAePP8Bbrzz7NkzJNmGsEsRRSLNep7O2QmmqDWIoFwbS//WvcfrsMm+ce4vtrc2+
+xMx+eJ7HwGCN3d3drOGUvU5OmNbi80wfAMctoKPgba3W/M/Wi0lHcvnGFo8cX2R6dpa9nR3G9s3w
+2IkDdHZ3eO3M+bcpHDkgx8l1QBv1PWrDoxnIZcJ2jrUsBJ3WHu0gYnpuHztrK5mrv9VTJHFsKgJh
+kl27wUx5RdPfcJQDLKTMofh2kMAC8FieuWonaTrNPV59/jT3nLyTyQNH+xout3oDG+vqe7u8enEV
+2hfffgnJNv65J7m2sk7XD/po2HnrlVKiPK/PdUcplds+TinVwwJsoiQdHDeNrUIawMhR6Xyiyj4d
+t4AQAtcrUBseZnN7Fzm7xLsfvINjRw/x4cfuxBse4vf++HN9jF6ZMpnsddjmlwkrvSTSdQu9dq+T
+U0IhiYKIRqvD0sH5PqBKils8mR0osYhr6m2jtCGX0vAeMbNotwEFD0nKjnIft28qH39INO2ddT7z
+6c/w3ve8k5nDd6GjqNf4SZK+RozZntHk8rWbrLzwJCSbBm2Lb5jPNz/KU69cor5XN3mFffPpa+dZ
+PtlBpMhgnuPvOI61ArTWeAXDtHVds1jK/hzHpkTLcxSklDhS4BZKFIoFJifHedcDR2HwOEMP/h0e
++qFfQB55ghtXbjA4NNTfqk0PPh9OHOXmupOaxt4OlepALpHrNc0c5ZLomGvXbzA7NtD3Hu2CDBJN
+HPgphTw9W9Gjydlpo/TzPSMOpdtKAv/WOyqTJLpotVkIe8G9N9vYXOMTn/gzvvf7PsT5fft47Zkv
+mCpAiq/AbtFsrN7kwrVRZuvnoLPLxqW3GN83y8vnb7C8sorf7WTUbKsEVrB5V+t6haxsc9KGkoij
+rEmSJIkhnPi+eY7cdThKZuHDKxSzfoJMcQbHdRkernHHwgS1ez7YC1eyDDJiZv88k1fX6Ha7KYcg
+B1gJiZS5tnOKWWQKIp0sLzDd0d6WMyEdGrs7xDqhWK0aEqiQphJIemeQgUqpd4hTBbbd1nTQpPYT
+7xoZB9a+YQ8gpVy07s1qsm1ASNETRnNrnT/9+J8yOTHKqfd8gMrIeAbD5mlgWms67ZYZpFw+y8vP
+vcwXX7jAyuXrOAjaLdPyzd6IbR3naOWOck1dLkx8V67Xy/Id1RcqdGIUxXXN9dp8QfZO3MS5QiGj
+sNmSc2J0iH2z46AmcoBVajMTdzE9WqNSqVAoFFBKZa9pB0huzYOsBUdhQLFUvuVsJNKx/MQ2UaTx
+0iHaPLnGXp+p/Z0stNnH2da78oo4Xgkp5cJthQAhncWsz5+6SAtI2IYMqRW2drb4/Kc/je+HPPH+
+JxibXTSuK73IHgMnxHMVW3sdTj9/htUbN1he32WkVsZVTsa5y4gRwgxp2MO1nsdm6bcmco5ycV03
+awrZ/7GNGasIypHZurks6UuFVSqVqBQLMDxzSxhNFcEpM1ApUCoVMqu2jOU8ypcnn9hz8H0f1yuk
+lm8UOovnrkMYmCVUA4O1npKmOUQ2+pbmYXnDyHcRM2aRdG5PARBy3LrPfLIj0kGF7AVTombQafLq
+c8/wxoXLfOC97+T4qXdmFDHlpTHWcZkeNfOAu1vr+N0Omzt1PCVxC4VMuDaRy88A2EP2PC9TSs8z
+KKBXKGaW7KTxXgpMwqiclJyikMq0VJVn+Hv2d44yv5NKZZvIzPLo7lc4ph6bKevE5Saf8i1xiyL2
+gCEyxo+UvfdoFSSOzHaSsYmJjDuZeT/rWWRvdly6XuYVrIczNHIXIcTEbSmAFIxks3zS6dO0DHRI
+kiwrtUMM5196ls89+SwPHl/iI3/zI5Sr1TSzLnFg6Q6O3ns3cdJL1Or1Jn4YU61WKRaLfbN6t5aV
+1mJd1TtcSJdIKGXfuPma0sUcx8Fx3eyw8ziAtdL877SGUMdmmTTlfvdPBHHTrIjxDSUtc/OpEljv
+ZdfR2Nexwgn8LuVyOYO3ezmWMFyBlJdo6/osFKThUAoj+LxyiCRGKo9EONnzSSlHbtcDTOTLFIs7
+W20LAz/rUGWHmRjLXFu+yv/7Rx+l7Qf8xI99P/efeoTFg4f4ofechKFFduodKtUBXNelUW/QaPkc
+PTCbCUM5vbxDuR6uV+hz09nBCwNDmyUPUV/yKITIvEreAvOlollApfoqjSRJaDQ7sLeZHyExn0kX
+Outs77UN0yhVMGut0jG9CaukWQKa1vCOcol1QrlSxTVx+m34w3ajzfBgBcftCTNffWUDI/nZxjSB
+VUpleYBw3PHbg4KlM2rKqh66l0dObQKWL4HyPwfdgM986lM89NjjPPH+x2D8OKhFszdg/NOcq1ZT
+wQXstTqcODxNsVw1bWCLblmrTPrdaFYdqNTdpgyZ/OjYrY/Pl2h5pegNkyYZc7jdDaBUheASdNdN
+HFZlUGX08llubu1lswcIiasgjMBTDn63g/KK6CjoGycDlXXvdGKEZanoSnnEcYhyJc12l/nJkVSp
+YsB4Ax0FCFVARj44Lo5yiYKu4WFGkTFGrU2YM95o9HYVoGoy/tTKk9g0f/I3YUrXdyY6xlEKpHob
+renCuQvceWCamenvzX49d/J+Bl67RLvVRscRG9t7aD3N4v55lq8tm8ULtk0rTB2fnzhSShG77tuS
+wTz9/NbvLQs4wwHS4dG8ctiv4yNmwmnzhT9nu2E2jJc9xdzBRS6ubLO9vZuBMnZRue0TuF7B9EKk
+Y9jMOs7KzSTlK2itTZew0848hxBmarnb7eK55uckj/Mrz6CY6WhdvkfgeA5JFIKUxvpNpVC+fQW4
+BSrNEhIpsgMQQqCjCO0oZKINApn0Yl+71eTCtXVmoiu9bmBphg+/426++HKFN8+/yfb2LqWCw3sf
+OMRHm22zqavVIg5DOp0OjvSItUxjOX1zgrfG9FsHSN/mZlMF6i2OTPpIp9VqmQPTQyAkp1+/0jds
+CjAxVO0RSqVEp4mw3fphXHQIKSiFdAylK6+8cczgyHA6XRz0zVMEQYRyJK5Xwu+2egaV7RGIcNxC
+D19ITNiM0/PwymVCM89Yut0kUNkaVCkDk9rWb4a5pxWAWyhkNGYLu9pGB8CVq8vc+PLHDerXPM3V
+pz5GoVzi1J3zfODdjzAzM2X+/9hH+KGPfIh9M+NUKhUc16VUqaQhpyc0G7e91PXbMq8Pr7ilXPQ8
+rw8HsB4iyzXSpHJmcozh8WGefvZ1giDA933a7S5hGHP+6hpD4yOUSoVMCS08basKs8q+V/7mIWeL
+XdjHFEolc7ap8Fy3QKvVQinj9Wx5aHJAc64W77DvO9/ncEsDqJRKnvYEbssDNO1wogGAnExjhONA
+3KNgZwlaYmjLjur3HM29XZ478xbfN/KnnLuyyQtn3kQ/qxkbG+GeOxZ433segql7Deo28SHuv2OZ
+rd0GYeoB8vh3FOm3TfzkqwXXdTPef/6A7IGZ/+1dWxAkuK5DEEQMDFTYP1WjU29Rb7b7/lcIwcbm
+Dms3Nvj+x4/zex9/+m2NKOsRHNLFFCn/IMZBJGZE3HGcTLhW+FGss3PU6RCsVXILctmuYFaFAZHl
+CKQ5WHVoxNDlDJM4uD0gyHF8y5sX6cEJ5WYZLVKamrpYzmBPIZ0+4ds3YGf7N3Y7XL6xgd/p4Hd9
+VpZv8swrF9m8vgyil1TK2hjDgxVKpQLFYvEWbKC3jcP+3lq3m4YIpWR6uMKsmU2/ep7KpoMNCwgK
+BSOMUqnA1PgII5NjXF7Z6ksgzVIqk0O88MZVZG2MmZmp7PXttVliiUi9g8UgXNfNSLR2DD6OY7Nf
+wCvguSqDtLU2C669YhnH6fUTDKWezLum8wAGTEo0g2NTDNSG6bbbFjVt3+5cwJYt8yz8ml/zkiF8
+OsoWHxocmtxjnYwVa62l3e7i+75JxBxJu93m2TOXab78UUi2Qa9DcZBT9y1x79FFZqfHmZgYo1gs
+ZlaWVwhr0YWCi7I4f66HkP+ffKJoR8btcxQKBQ7ODNPZ22Ntp5FZoQ0bxaJhJbXbXTauXee+I7OZ
+Beet2SqjLVUtFO0q523ta6s8FvXMppbSqkc6CqW8vrlLR/VCTEoHZ2zuAEtH76BZ3zUtZPO3ndvz
+AEJs2PrfLlHuw6Rti1iqPiTM4tq3cgLye3XsnT/seFaz2ebZ16+y+cz/A40LRKuXuPDWDYqe4pHj
+izx8935O3rHIwcVZhgar2cG6rpNauNOXZJn8QH3F5NAK3ArKfh0dGmBoeorN3bYZ8c5tDMmjfEpJ
+nj1zmZGRKgtzk325RB75yxBB100RRpmFpyRlLudH1fr+X4DruTkFVn2Ak0wJo265xtyBJU7cc4Ll
+q9fotut54G7jdnOArT4YM9EgFVJHKSage30CR6Uujr5NYBYvcByHYsHLtmhacMNxXUjHtba293ju
+bMS7ywUcR7CytsPlMKJaLnJobowDs0McmB2i45ttnpdXd1hZ3eoDRawwfd/PuHuWxwemBxBGcbYC
+xlWO6UEoh6W5EYKdbVa3m6Z1nE4h2yw9n0fEcczFK5scmR9na7eRJolhJkQ7l2iHT4UwSGUSx9l7
+1lrTaLQMBJ2Wb1KYa60UXYaGBvG7Pu1m3Tx3bJZd2usYHJ3g8JHDDNcGeO21N9jeXCX07YYTSZIk
+27elAFKwbce7Ex0jlAEksjo0j3C5jmG4OIWc8GUGF7uui3IkXT/KfjZoYojrudkh7e01eO6N6zz2
+6EmmR7c5f2WFMAx5sdnGcxWTIzXuWByjUhvn5FCF4wcmQEiu3dzl8s0t/CDE9308zzOlVAoU5Wv8
+ctHLLNpzjWUNV0sMLBymee0iQRhR8FyiOJ0vzFU9ViEArq1tMztRY3F6jDev3cxGyfPgUt6q4zjO
+QGXH87JFFpVKhUaqpIaPUKBScpmeGCUMzTRxp93C9xPQEa5X4sGH7qdSLhGGIc888zyt5l7GMMrR
+xm7PAwDX7ZiSVF5uEscmib0pXx3TS0xu6eF7Xi/RaXeDvi0c+X1/1rq2dvZYuXydsaEyK5Vytqgp
+AK6vbXFza4/p0U1qVTPHr1zJ4sE5FpfmoVlne6/N6lYz29NvBNerIkrFAgOVAoMls7a1UnLN6nlV
+pdrcZHSwzk6jhSMd/DDGc1OL1r2SWDmG+Hr15g77Z4dZ321SbzQpFj2CIMq4CHlMwu4i0lEEaQ4T
+BIZ2XipXcAsm4b3n6H7knT/Dg4cvUv3MH/Jit5sNuhw8fJCji5N0gpALV1a5cO4C7eZub7WMHSsT
+EpLo5u0qwLWsyZGWGkkcmm0fubl/U+f2Wqo2Xtk2qU4JJHYNfB8Um++X575eW93mgWP7mBypcfXm
+Rq8mTpOQZqfLTqPFm9c3GB0aYHSwxFC1SLmoGJkcY2RuDqKAqFlnp94x9wCIIySS0VqJ4X37YGgR
+vEFwBkGkswr7TrG/3kAva5rdgGLW1BGotEmVAVDAxm6D2fEB9k+Pcj63Ts4IvJRaeZh5ANd1wTX3
+DAhDw+1XSuIViyilqFRKHHrokZQAeYBjjz1mbl4VJwxXS7S7AXtNn9fOX2b56pV0eIacLMDumxTS
+uXp7IcAtXk2SRAshZNZ4cNw+inJW84v+xUsWrLCdOlc5FJRDEOu+v+fRPDukIaWk2QnYqZubL23s
+Nvridr437iqHRqtDvdlGSslgucj4cBtPSTxXUR2sMj4/RtYV8YowckdK9Kj2k1KRoOYp7L+bifbz
+6K0mbT8ANI50zEZSyO0VNBj/ykaDQ/tG2Gl12N5tImUxG0vPU9pd1+1bdWfxFMdxGBgw5JJ7juyD
+2sleB7L2GCfv3+WtM+e5cnOTeqNJs9nm5vL1dDwuyo2ckXliHRO++cKLy7elAC889crefe+45wqJ
+PpBl/HbOP6U/K1f2Cd+WLPkuosq1abPevhQZtpDf32NLuiAI2NhpccfiGFMjg9zc2utb7ugq06Tq
+3f7FPE+r69O80TVrZl1FYbtJrVyg4DoMDRThwCO3DKfIW6aUFAwcY+xQk4L7Jlt7HYI4QsdmH0A3
+jLLE0lYFm3tNqmWPg9PD1BttMx8gBUlu2sg4O0mxWKXguVRKhSzHGB6oUPQUtWqB8VM/lipmOp2c
+1Nm9fo3zV2+yfP1GP6wtHUQ6N2mocTlAykku/P5ZGv/mdhTgz6/Sve8x/UmE/PmMFGrBHdFL8ISw
+8dvtw7QtYdNu9jKWbg4tvgWKzWP7Nm5v7jVptGscPTTJ8sYuQiQIKXGV7O32ieJ+hmzOujTgd0O2
+AuNV2n7EzPgNKCz1z//3MX6kQSNHTzLgKAb2Vk31E0fo1HqjGGIdZ7emsRzGSrnAXQem6KY3m8wP
+n+TLaOUYQomfxu2Ca/KBgitya/WKRgk2nzHb0rZ3CQOf2vAwrXRhpD2/OKbvFrjpBpJPp1p0WzmA
+r+PoeemoJEmEUJ7KxpstzJzh3TIdiXK87M1bEMVxDW/OkjkyckcO0OnBuD2ChR/GrO00qA0NcHB2
+nJWNnexveXpaviFks3etde5G0r0l0jTWYbSe29P3H62Dzc2nhYQoQFbMXcW99KBL9naz9h7DsWZk
+dJDID/o6pmYFPdmaeSlkhjP4YZzhDpt7TY5s/yEzj/0XRgnb57j0yhm2dvayrWbFYpH11VWkoygU
+CrhewZS2YUizUSfwu8SRn5DEr34tUPBXUwAtHbUGxEI6ys6x2dJPufkuW09wyvXwXNPxsnRn29N3
+6LVobSPFbuu08G6+obO21eDATJcDR+bZaXayGKq1xvMUWpsQ4zk9qy975m15rjKzf64DidkZ2Nnb
+o1Q/m8bZ6i0zijYctKFzjc1zr1JvmaolJkGm9OzBitcLY7aR5NiWckC55FFvdukG5m4iQahpdwMa
+7U6Wu3R8U67acxiolAjCiLeWN5g6+0fIuWNcfPZLXF/fIQyNt6sODrIwN8nh/bOUCo4Zi9vaZe3m
+Gq1WKxunR8gIIde+8vDl16EASZLoX/rAxEZ1bGabRE9YVLCv3W9Rqjx/LRWQHcywWzzzYI0Fg2S6
+ii2fDNpcwE1x9IvXt7mjNsKxxTFevbjaY/IIiSp4vdY04ChTkipHEpPu/E3XyCslaXVCStvXoDSR
+7gFSOcE3QTehs4y++jJ+aGK5H2tkas1xYizWun7r3m2I64YRd8yPEcWaKze3M1qYvQeB9QiWPRyG
+YfZ+tdZ0g4hWJ2QgaDM2VEY5kqmRQaJYUykVuLG5yxsXLtNqtsyamjA0k1dxmG4/iUHIzfratbWv
+ZWPYV90R9Huf3biCkH/W5xZi+mjVeeHb8e2MHpX2EOzQhef1+u55d56natlDsln+Vr2Fv71FqVZj
+dryW/b1QcDKgx1HmU9IDf1SanNrnimNzi5fWzh5snQO9bQSf1CFeheZZWDuNvvIiW+lNImOdoHIY
+Qhz136sgz1N0pKDkuVxf22OgXGBxeoSC52YEUvt+zKRvP3spik3fYXiwwsDCQRi7l6EH/iaLj36A
+uYlBVjZ2eP2t65w9e4HG3l7GAehNBsneejkdf+zf/sXa17Qm5qsqwGbM1vqFl59XnoryFt4bXeoN
+JOR78rbrZcigbkb0LHkupVIhs2Ib86WUFFL+nk2S7EErR3J13dy4aW56iPFaBc+ROMKh6ClDEJUK
+x1KtZU/o9jbz5lpNBdHuBkRbqxCsQnQFGmfgxpfQ116ldXOFjd0Ofhj3AVZZR07Z4REnew0r/Iz+
+lcDV9T1GBsuMDZb7SmEbKoxH6jWiXOUwPVrj/hMHYPReg0ukecqVm7sZqJTfcJo3oF4CrKLVN8+8
+vBp+9UbQ17QfIEkS/cF5cX36WLILjL3d/cuMLp6/GPuzm+Le9nCKnm2dhn3zdDZbljJnwU6vQvC7
+IRs3Nxg/dJjxps/KViOrKnQicZVI7w2UnyPMD3z2PE2sze1klF+H1bO0tncy9xvrJLsRtH0uo/Ap
+cyhN6NAaJyWo2KQzQ0ClYK/R4YaULO4bodkx8T/b9ZMmgBb3j6KIxekRZu86AYOLIMd6JNTti+w0
+WiilaLe7FIqlbL+B1nY2QOc2mUdb1661r3+1sfCv2QOkZc+ZRMcv3jpCne9iWagzb/027tnlkW0/
+wHNVrm3aCx2lYqHXas65bcsQLhVc6q0A9tapTM8yUi1mqKAZVOmVmPmyMPMunglN9n8KrrkjSGt7
+h2YnoO1Hb0cpgWKhh02Y5xSZV7LPpRyz6kWqnvJ6rqLR9tnYbHDXkbn0GtxMQbyUSFj0FA8cW2B2
+fIDOtTch2O3hEcE1Nq9eoxuYJLlZrxvCTTr4aj3PLUyoF5pdXuVr/PiaFOAzK8nl66+/8IyjRHQr
+R9C6+fwSRx1HKSHBwU13CvR1Bx2Z3tJNZy3SvOu3b8rzFAXlZBl+kiRsbJhQMDY9QanopuyaXkv4
+1hIx38K2ZZkjBXJkClrbGYHD3ijaKlRWY+ske26ljDKViyqrarIcRDjIBKQyHdFC2mVc2Wqwu1Pn
+oRP7KbqKUhryXOWwOD3Goyf2s9vo8vSrV029/+pTEFyAjU+yevrPOX9to28Rdga3CzIlsIij47jR
+8qunn/nczWT5a1WAr2dX8F/EUfLTjmLmVoHme+pZ4nfLtK7rugQpbz87tJQalSVRaQJpS7hSwYyV
+O66DTjQqvYVLZ22F0uxBRmt11rZbWSaezdDl7iKWj82uYyym4LlQHoGtK4SRyfRF0tcFBZ3uOs4p
+T3Yjitjg926q+Appl3gadC+d9YtiTVEpltdNj/6uOxdZXVlnYqTK2NQYUavJC+dWslvktjo+q1tN
+RpZPc/aNa2zVW+w1WpmQ3UIB0lzA3q7Ohtwo7JIkzmqi47/4OmT6tW8KjUJeSXT8Wp7tk19akM/i
+7S1XbGy3yZ0FQizl2SZsUsqsNJJSUioW8ByZCV8JieeoTBh7TR8a66jJRYaqhiVkhZsPIzYZlAK8
+lAZmrZY4gCjom0CyIcJ+FlOcw1O9mUKL5OXXzuT5hdaLWUVXjsQrKJqdAAplph54grFTPw7Tx2m2
+gywU5MfpdafN+m6T3XozQzy7XdMRteRT40WdW+6vGL8UxsmZb4kC/O4ryV5nd+N/lw5hzwP06N9f
+KSO9tSdu77I5WDZzfI7jZHf+zCOBOn3OfLmVRxBjnbC9vg1JRGXffqql3sII1+kpQ8F1+lrOVjDe
+8BDEEUE3MsrhKlxHZIsYrLXnrd5Tsh9vyOUTPVRTZMljXrkdBMMDJZg4bvYjiTEoTDE0PpKFCvt6
+ypVs17t0un5GarVZf3b7m3RdTn4HMsigsbXxv/2r59O7UHyzFQAg7Lb+Uses9l5U9+3lSfLt0hz1
+ylqKH4R0/YiBSiHjA7rKySzVhANJUamMVqZELtlSvWQniDSdG1fBq1KZ2UfBcyl6ykCuiUmuhDBK
+YJOugpeWboNTELaJdWLImLI3xlX0esmZrUxsZWAFn1dIT709b7HCt2czPFCgcvDO9LgDk92n94I2
+79vJkt1qqche089yk3KpmDGNMgjdDrimyXQY+CRJvNLYWHmSr/Pj61KAf/7prVbkt/+HRMdJ+tHH
+l8tGxVIvkOfN2/vrRbHO3La1SOvO7AWZfXyyL4GzWbh1w56SpipYvwilISoTk0gBpYJLKWX5Fjyn
+r+Gktfk7QmXlk7lG0Se0UsHNSlarSParvS2tLePya3HstWWAWQK1aoGRI8dh7SL6/Kdh7zS0X4Wd
+52FgIk2gk0zphgcK+EFIseBleVUYhtn3Nm9Km25JEEaJ4zhJ0On+17/5+Wb3W6oAAL/++6/9ro45
+Q5JWwzpKdG41u3LMcuRbaeGWkxdGKa5dLmZQataqTz2CzMVrI5y3bwixCd72Vh3qqzA4xcDkeA6h
+6yWhtgyUEgrldKw96vbxAOydSvOkTqs4lZKbhaRSwc2ElSWsSr4NBnccweRIhfF90zQvnWV1vc52
+vcvu+ZfZfOUp1s6+wo03zrB/psbkcAUpYf/MKKVj7+Pg3ChSSqrlYjrfQMasShXOut9UBvqFf/y7
+z3+Cb+DjG71t3P+cJMlva609x3FlkiQijmMhpCNs3OpDDUX/Qqc4jhkZKLO+2+xb7qRtnE5A5OKr
+db02k491bkTckbQ2NqgUq1CboxIGtHYbffmD/XCVA7V0ZL7bxlUiG2/MbaXJyiyd6OzvxmOJTPjG
+o5hbd9lWbxT3hkNGBouUhoZprm/S6ob4QYxPnIUSrc3t6rd2WyzNjzFYKVJbOgHeAQp3DzK5/NvE
+OmF1u54ps9YkUsokiqJESpkuUNZ+HIf/5BuU49fvAQA++fHTHxVC/JnpN+sQ0LFOEiFEkk8A+zn8
+5qV2m22CMGKkVs4syHGcrOzLZ/AFz+kTvqdMAmhds/29lKDXr5nMfniOytBAzyXn0EajBeaW8DoI
++sKLYQcLXCUy+NiRDjKjufG2EXML7tjM34aG6dEKpaFhdlPhW+JHJvhE95XEjbZPbXa2d3dxOcax
+Ow9ki69dMwSbOI5IlFJaCBFqrbtBt93WWv/xH//Blz71bVUHbC1CAAAWAUlEQVSAZ7YJolD/ZqLj
+NaADBCQ6TnScxGlAk7esMrMH4AchnSCmVi1lt22VUpoLuaWkzHMA7cKFPMffcUTGPtYJsJPiH2MH
+UOVyRmXPBC0AVcxR3lRfeWcfZ52HzeiNp5D9uYjsX4lnbxA5MVxGTizS2NzK7lNsE9hbvaHZWiIZ
+rBShOpEmhpFJFIfnMgXRWidJkiRCiFhKgv+/u2uLlesqz99aa1/mci7j4+MTxzFWCMGihlJICaWk
+DyhcVCTUVq0qUFFB4qEPVaU+VOpbqz71glRUVIRE2kKhCQpKiGgCiZPGIeQeBxzHwSZObMdJ7GP7
+XGbmzG1f1lr/6sPae8+e7dlz5hw7hnakrbnsY++Z/X//7fv/9S8AAYi6Sqm34mjw9SMbCK8pAIwx
+9A/feeEwY+zLRNSWcRAYY6TWmojIIJcSphqa/nip7G6fvsuw1JjJeugdYYcoZ/l7csPSqD4li1If
+nAZ1aSOK9S+xBYGOgcWbwKs1cNcB/Ap4pQI+t5DN2wEAUmTPFwCRLcxwbIDGGeC7LLEQaRFomIen
+mUJjtgK+9wCap1+x9K0YzlNIQSM4AzeAk2Qb6UQQ1PbYFjAAoDZQ3Y3Zum0b8zzPuK5L9h6bgIg2
+tNYrRPRPh+5/+ti0vP9VA4BtFTLR8aeff8SQPsI572qtQ6WU1FqTjKXJT6+IYzVC03YHEYJIY2fD
+7v5VSYghP6kaDjXbCqLiWvPquyLb+DnjHPiQLyCpLAjay4DwgF032wnldoHjcKiSCjOBpyDgrgOS
+KnudAsOvupd3yZihxUjXFexs1MH37Ef/9Msgk3ALjsiC1ZRDSK0YKbIlbFcgiCQQJdNIaA1on8Dy
+8z9EFGu8c+8u43succ4l5zwE0GWMrQeD/uGXf/zwk4eWkxl11xoAAHD3L/Dm+eMv/osx5pKSYV9r
+HRORdgQnIjJpL6CfpFWpP1/bsMFfvWIXQ2okG0GbdDs3M5JmyeR9ejPzws+75bT9HDIEVl61r3fs
+s3m/VwFmF20KKEO7WYRIBJ3O3kmi7KzPIbUOhX2YXGdYFFLaLuTku/ZBnX8VUuksPpG5bChd65cV
+lxxu+yoMYa09gHr9CLD2GHD2UbReO47ltQ4utbrm0toGNeZqemF+JnZdt6+Uaiullk88efCO/3wJ
+53CFj20DgCVqePBIfKzXXPs+Y2yDtOrLOIqllBlRkBZ60mVWacS81u7Bcx3Mz1YhwEZy6aKvzBi1
+tNGEWyFwjlH/DtjGzVrDtq4FbcBtADsOWBZu5kbAXwDqC0B1DvBqgFsBnPyoG8dOB2Pcpga5sTj5
+MXNpDFL1Bbzr9wHtZUSxzli9bL5/WrErcAQZM5mASyqN5qkTWD6/hvOrXRCREZwZxpjudAdxtx/0
+jTEdrfX6hbdev+/fn1Mn83K4JgBguUf60dkIvUOHTt5pjHmFSHWllEEUBlIrO1lICFtmSQsXKflz
+qdWH53LsmqtaIshhEBgGd8Up3+k84HTdW6lZ9jzrBrya1Xq3AYg9thVc7AXEbmB2P9DYB/gzQ+E7
+XnI4uTUCTlrgGFLdrjMCOL5rLxB2EA2iEWuUXyGVr09kVUqwzBWkMUV3INELQkRKG89zDOdcM8Yk
+GQSxVN2NjW4rCoJXHrv/qYMKGEyQy7VxAQkRgcNNrLz446f/Wgj3gpJxV0oZxFEoGWNkjDFENvnN
+lzXDKEZzw673E64YKTDZhl42Up1LW6kAuoxts/MAcz5e2sILnFpGuQ5/rgfwJcBbAipzSVjPRzuB
+WS6wFDY2gOPZ6yZWQWnAaSwCjCNqtnKE0mi0n9YX8t853/RqjMmaTDUZxDEZIZhRisjYnbACY0w3
+juMW53z5wTu/+8+PLmMVV+nBt2ryix+nKzLufRXn3jr+wl8IIdaJqOt5XmiMkf1+QCl55XvusMYu
+OC6u91CfrWK+5g+jYdjhD2mwlLZXp91BNuXLbfjsJX5cE7jrDRs8o0GuV754cIDVAHfGuoDU5Buy
+rw0NLQIAXk1mBfrDXTy9agWY2w1aeTNpRLnczKf1haIbsNXSYQGtXvXR6gZQdgKoUYoIgGSMhUTU
+DaO45TjO6s8ef/jv7n018/vZvZ9CTlcGgAnCH/kiX3u8d/bcL458jXPeIqKu1jpijEnGGBGRiWJp
+Uvo3JUL63QAzVW/Ya5fbrj0FhO+KnHmlEZaPpLIaKjhgkufKjBWi7AF6zbZ555d/gYZaHvZGRq5C
+xRYU6Z4C2dYs3L52EsDd8D5g7cyQSdQmaU+jEVeQ5zLS6mLFd7IUeW6mAr/qYhDERsXKxNpqvjEm
+iqXqajLtmVpl/fknfvL1L//32TcL9x5XCoLtugA25pkD0Hf9ZOPh1sW3vu04TouU6mqtI62NNMZo
+Y4zhyeQzIQT6kcT5tQ1UfYFqxR0hVjJAJNE0UUq8cEiVCxgZH4nkMz5AK6DfBAYXgfCMHU6FQdL6
+vQKoFYBXgLkl6wZSrWepoJPYIN27V/BkdCyAXTcB/RVQMMjIIdvhBHDGM+6+WOtIS875x+J8Da1W
+3yhNRpLRQjBpjImUUl0iavuuWH3mqWfu/Np3jxyB3fyB55SOlYHg7QQAK0EhA8CaGv2HDv7i/vNv
+nn5IuO46gG4cxxHRkDLWZEy6h6+ShCDSuG6hngxvMFn3btrpk66qSefupy3e6eekaNSHq0SAcQgM
+mkDQBAZvWqFHbwK9M0D/HBBctG5gZgmYWbDASVf6DNmi4XsVW+vCuaWeGR+pAtpyuA3q0gxFKp1z
+X8h+k12m7sJ1hdnoRUYqTWRIxrGKtNZdMmhVfG/t8OEjj9z/vcefbGr0J9z7bYOAb9H8F81+8eAA
++JENtO679/C3zr9x+pAQoiml7EqpQwDSxoRklCZDBuiFMZqdARzBMT/jZ9WvlDRJA6h0Hd2w1WwY
+ZHEnEXrin+HYXD8ToBwAFAOqB0RtIOpY69BvAhvnrOuoLwELe23wiNxaO+4M2UM3sRidleG1ijeU
+8aRLeJjqKU2XgSCOFZZ21MxGNzBBJIkxJgGERNTVZFq1qrd29KUTh+79zoMPPLOO9oR7PtYSTOsG
++DaFjzFAyL/nRzfQuvuup+544/TJB2u1WtMY01FKBUqpGIBOswPGGLr9CO1uiB0L85n25N1BGjSm
+N5gzZDV0O1aNRodLp+7AkLUC0cCadR1bFlDmqHMVA901oL8CcM+mhwv7hu7A8azp92pAY491+DK0
+NLPn5fJ4k3UNp2MPxo2zT7OhasU1RDDrG4FWmmJjTKAUdQA0GzO1tcMvHDv47a/fc99Tq2hOIXhs
+FwT8Csx/8UvwvBUAwI910f37bzx1x4mXfvqA4zjrUuoNpdRAKh1zzlUaHA5ihZWNAWAU9uyaQ5As
+ycoTQYwxRLGtrOV3FLnMZNvWpdH3WgGh3b4W8SAbtZ6meeAc6LeB9bNAf81q/MKN1iKkmcHsIlBL
+4gWvZl1BEhOo3NYvKfuXWrFhLwLPpoqQgZmre7Ta7iupdAxgECm9YYxpzterq08+9+KP//Yf7733
+mXV08vezRNmuKBZgZXWEMegpu3he8GLY1J4tunNqDJW/+vwHP/f+Wz/yGc9zFhhjs/Vatco591xH
+CN9zuRCM7dk5x6674To0L66gO5C2VSrh0YdFGOR25mDDQJAlgVo+p6/OWYFzJ6GCd1sgRL2hYClZ
+2SucXMQPW41zZwBnBnDmkh3FPTstPD4HtM4AQQc06GV7+w5jE8qC1pS5tN1IwkhljF/zCfNLGk4l
+Pvfy0eBSq9/1HdHmDKsHH33i4b/56sMPDQyCpDSoc886l8vmm0LSA4XX+QaSqwaAsX4/d4hE+CI5
+XABiQaDyhY8v3n7rJ3//jxqNueu01rO1aqXuuY4HwKn4Hvdch990fYPVqy5WWgNEsbYpE8PIAgjP
+5eBFft4VoxPNK7VRy1CZSQDQti4hNf8pB5DbSi6L9uf3ALMHclvcpXe0CbSPARsXQYPeSNdOuhg0
+32fAOQefbRjsvJngLxHEnIKhmE7c3T92ZqVbq3it1Wb30kP33fODb3z/5JE1jcFwadCI8PUYUsOU
+HFMBYLsdQZhACo21Dk0N/c1H157oNf+j84GP/94fHHjfgXdFsVSc87rgzFdKuY7DxfnVLr9+cZbt
+mK2y9Y7dQMpzhmPd09U1aWCV+djcbtsEDp4GhalVyGu3ioe+Pf08/5olTpw7BS9JVh4mBrwZYH43
+uN8BD3tAOEhc07BMnTS7GizuNdixn+AsaaAiYQYR1g/3T7y+1tk5W209feTka0/+4L9+dPcz4etN
+DTnmHlKJ379yoU1pAcr8PStoPs9pvjPmcAGIW+ax5w8/+9Hfvf3jt/9WdxDNM8bqtYpXcwR3fd91
+K47Dd++cYa4jWKsbMM551uqdrqpJzapNt3iWh2ccUWoJ/MrQLSzeZC1Ae8VuKl00+8m8nSz3n1sC
+qnsAb3cCLgXoJtBftullCqSUM9BJxqEJIGXAuMHMosHO9xP4ogQgYToDtI/1Lx4/uqHJtO6650fP
+PfC9Q48/tYpWouGyoP3jLIAeYwGo4ALMti3AJtHjNFkAKyGLGAB2ZAOry9965r7lV46e/+M/+8tP
+c4YdgzCOfVfUAXhaG6/dDcWuHXVer7isF8TMTQYQ28UluKznT2szGm0n7oDCMCngcJsK5s+neT93
+AFL2b6u1oTvorAwDRtWz/z7s2CqjDDMiKCtFJ317mowRnBkA5M0savDFGEAMfbGPC4d70frqhlS6
++a9f+eoj9zzy1s/PRghKNH1SupceJveZKZNnGQjGWoAp/f+44E8Ujrz2i6Tlxcmfu2UeN37+S5/+
+1G0fvfVmqfSc0jTjOqJSr/lexXHc3TtnhDGGNzsh8z3B6hWXpSuP8q1n6RiWfHCYNXl4nu0B3LMf
+kAPQ2rIFheNdnkFoAsnYcguMA43dtkQcNLPzCHqIJSUNnpn/N1LZKnisiDQZDUDOVt14ds8NIYh6
+vUsXu1Lp9oNPHD197x3ffOzR01jrGcic1suC1o+zAEUrYCbEApvGAdcKAKLgBkaAMcex44sfm7/l
+ts989kPv3Hf9Ls75TBTLWq3qVeoV190xU3UAiEhqDoD7rmCJO2D55WBp0DV0DblmDkPgS/sA4YEu
+nBpSyGbIJPI01lDDBS/OPsv557U9kpngTe7+Uj+UZIzRUmmltZFkEArOBo7De57DO8dfv7T66P33
+Hfn+D0/+/FyAoGdGhF5m+v/PAyDLBArv3QIwKvtruP6Lf3rbR/bdtP+GD/36/l29MK5rrav1il9Z
+mK+5xhhHSi2EYFwIwV1ha+BpmigEY8U+QZENsgCchSXArYFWzpb6t+HYOcs+Vve+G8G512wVkkbo
+JpNoPRljKJJaK00qinVaxQs4533fE93nXjq1+saZ08v3fOfhF461sK4AFZsRgcuCxv+/A8AkayBy
+VoFzoPGx67Hvdz5xy7vfe8ut+9737n07yKAWxLI2P+P7gglPcCY0Gcf3BHcE54wx5jlW311HsMKG
+USx9WZ2bBeZ2Izh3OonQ05FvJlsjkBaaiMhwDtvbv95E4kYNAEtjE5HUhgAoqbSOJcVEFBFoQBqD
+qu/2jp4823z5xZ+de/aRZ0899iaWQ4OwIHQ1hdB/ZQFQxgFMAsC4uMAZYw28GYbGBxax+8O37tn7
+4U985p2/+d53NWKpaoHUVd8RfsVzPKXJdR0hPJcLIQQXnHFXsAwISfsZG9YPBKsuXYf+xQsTG1yS
+e2KS9i7T6Yep4AkAKU0agI4lSUUqVpIiMggqnjPwPdF/9uhr7ef/54Ezzz2/fOFYEys9g14ipDKt
+19sAwFXhAraaBqKg/WwTAEwLAjEGBBxAtcIwu9fHwt4GGl/48z/5tds+8hsNj/NqL4irjuA+AI+I
+XMflrmBCCM644/DUMnAbIjAIzpgmwxYXGwj6fQShTH/iiNDTgJkMDGcgxhgFsTXzYaQ0Y0zGUkml
+KeYMEec8qPpuwDmCR58+un7HV+58dW2A9rkIG6EVfFGIcoygtyJ8XSJ8KmMDrwYTWJbm8TFcgChQ
+wpsBQUywDOn/4cNu4Vm/uYIdn/7t2aVPfe5L79h/4+5Zhzu+7wk/CKWvNLlE5Dgud0hDeK4jiIhz
+zrnncsYYQ813mOsI1hnE2dhZxpghIuMIjn4gjedyCqSmuaqn+4HUUmlljFHGGOl7buR7ItLaRJHW
+wak3LnYfuuvfzh18rrdyKkQ7aToIcwKkTQSvp3hNY8y/mWABcLUBsJkb2CwWEFNkCJPAkT9XAVDh
+QP3DC2h88D1+48YPfnTnze85ML+02KguzNa8WsVzU/dgjBFKkyCQIA1mjOG+57IoltlMwaSBmRIL
+oIUrtMe5dl2hjTEyjJSUSstmdxBeWm0Fp1450X7j2LOtnx4Pm0db6MQGA9h13/GQLhwRYFGTNztf
+5vOvOhV8NYpB08QCm8UHYoz5L/ub/DkvAYQ3x1G9/SbMv+s975irzs5XavMN36/OVhqNhr/rul2V
+2Zm6qFd9PlPx+Gzd54wxJqUGGatJnMF0BxF1BqFqd3r6wvkLQWejHUZhPxp0OuGgvRa+emK589gb
+2BjYYC5KBC5zGqlLBE2bCFuNEbTehAGcFPi9bQBAgQ7GBCvANwHANGDgY1wJH3Mdnkst04zCrTC4
+N1bhH7gBlV07mCt833H8mqjU5wTLDTgmpQgAyaCrw25Hrqyr+MR5BGcDRKEZydNlQVhUEIzOWQDa
+RKt1SaVvGsFTwedTWSVw2wCY0hVMCgq3A4Si8MUm/w8vqZeX1SfydYwifUoFv6oLqZYZ8zdUIiQ9
+ARRFgaspBa/HfIdxAJhK8FdSDcybGZb7AvnKFcYg0iTnJ93M/CGSH50XIuUaI8ssARvTOLmVhgkz
+pqiS/756wnfWE571lJo+LtArA2Kp2Z/2caXl4OJFqaBV+S8pCkLnYwQtSrRclMQZfILweUkHbRkQ
+iixf8YaPez9O+GWfbebXJwFrHOFTKoetrBaeZlSsGeMGNq1AJT+IFYDAc8+8AAY9weSzEoEXY48y
+7Z/GEpRpPsYIoCgYPQUo9Jj3k/7eTBnsbVv4U8UAWwgOp00VWYkgy2KHSX/LJmj/tE2UZSCgCW6g
+DAibAWAaNzLu2lRi7q9I+NsCwBayhO2CIa/tk86zElPPx1yv7Pthwg0ty683CwrNGP9txnD3VAKo
+MlZvyyTP2wqALQIBJUIpo5TZFM9syvdsDI8xzgKYCe6gLC5AidaOM+E0wYJgkwbPq6bxVx0AEzqI
+2JQk0mYE01aEjjEcBbaRDRR9azHNKubdtImbMFMIuIzJ23Juf80BsEUgjBNA2TqDacFTvAYfA4Yy
+q2TGnDcTUtmtCLEYRGJS0WZScPd2CP+qA2CLYMAmVPO0n08qWpWBbZrvY3IAMWPAQpsAZJIrKb5m
+iWAJ1/jxtgFgCjBgCwBhUwhvknlnW7zeZnwHpjDTEyP2XBna4Jf4YL/k628FJGzK91tZOTvu/yjj
+OMwU3AGmBMUvXfC/cgB4m8DDtmlxtmIJNj1nfoVv8v8CsQQK8WD3w5YAAAAASUVORK5CYII=
+"
+       width="48"
+       id="image2213" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/wifi/data/misc/old/link-3.svg 3.4.1+git20201022.a0d3415c-1/wifi/data/misc/old/link-3.svg
--- 3.4.1-6/wifi/data/misc/old/link-3.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/wifi/data/misc/old/link-3.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,466 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="48px"
+   height="48px"
+   id="svg2160"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   sodipodi:docbase="/home/changfu/Documents/Install/Cairo-Dock/plug-ins/wifi/data/src"
+   sodipodi:docname="link-60.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="7"
+     inkscape:cx="24"
+     inkscape:cy="24"
+     inkscape:current-layer="layer1"
+     showgrid="true"
+     inkscape:grid-bbox="true"
+     inkscape:document-units="px"
+     inkscape:window-width="762"
+     inkscape:window-height="635"
+     inkscape:window-x="10"
+     inkscape:window-y="65" />
+  <defs
+     id="defs2162" />
+  <metadata
+     id="metadata2165">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:label="Layer 1"
+     id="layer1"
+     inkscape:groupmode="layer">
+    <image
+       y="0"
+       x="0"
+       height="48"
+       xlink:href="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAIAAAACACAYAAADDPmHLAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A
+/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB9gDCgMYNlVDHc8AACAASURBVHja
+7L15kCTZfd/3eUdmnX3fPfc9s7PH7M7e9y4ALi5xQZAQT9CCeAUhyQ7LimBIcsimZZmyFbYcjhCp
+sGyKEiVLPEAcAsAFQQILLri7WOx97xw7V3fP9PRVXV1XHu89//Eys6oHEAFpAUgQ0REZ1VVdnZWV
+v/v7+/7eE845fvDzF/dH/5f+BYUQGgiyQ2XfWX2TtzogBZL8cM6lP1CA7x9BK6BeLzNmHTVrqVbL
+1O+8hd1hwOHUcCxNmZeS/WHAVGpAK8gfM6FfBF4FXgfemBgWC50eLSnpSEG71WMDaDnnzH8x9+37
+NQQIIUQm8MnhOvv27uU6KTmUphyWkt1SMgeMxDFSa7D2G8+Rvybl9t+1BilAammFEJvW2kWTugWl
+xSln3KmLF3kjTnh7aZVVoO2+j+Po950CfPgndmuk3HHp1Qs/Wq5wU5oyHQYcjBP2AIG1YA3oANKk
+/39p2j/yHyn7v9eHYGg0oFyv4IzFWksSJSTdhNT490rhPYVQ4gJwGljpdtxLS4t8YmGFhe9Hz/B9
+oQBCCPGLf/s9evn0K48GldpPR5trB1YWGge1phLHfUFK6QUcRxDHfavW2v8tDKE+LNGBJqyVUDqk
+PDrJ8PQ8QRgS9zpsLJynvbLM6tWYNOkrTH3Inyf/HClAKIEQogucAc6ur9rffvktPuWcsz9QgO/Q
+z9/6339k98WXX/1Ye2XprzbXOrPNTQIpEeWKF7A1XtiDP1NzAaM7djKx+yA7j4+xa+c0++ZHmRut
+Mz1cpaQlJTmOELuAYaCBcxdY6a6xuLbFlUaHcwurLJzbYPn0MmsX3mLpzApx7D3L/N5RhIROs13E
+kjS1LssjFp1xv3nxIv/83JJb/IEC/MdZfPnDP7X38ND49I8uvPrCLykpZpqNeFuszoUflmBsdpjR
+nfvZeXQ/t929l7uO7mS2Po8QtUzARdQHhhFMA3Uc68AqsA7IgZxYZgVBDHRI7SovXFrhyZfP89bX
+Fmmtr1IeGiHutkl6HXqtJml7k06zTdRJUFrgjFsGfn10x/QnP/MHV08556IfKMC3FnzpwXvkzcDd
+NrW/GlbCem1ynM3LV+l1beHiqzVJfWqcoel5dl93kPc8cozbD8xR0+MIMXRtqpcJtgzMIhjH0QKu
+AI3s73LgvXH2fjvwGuTh3dLg7dUGa1tdVjbbvHZmgcXXmzSuLNFavUJrdY00Tol6jjCAOKG567r9
+f6/baj792U+tvuCci3+gAN8o+GB+kuP79/M+pcVfc8bN1yeHxOjO/TQW3qa90cKkjtHpUcrj00zu
+2sfRO3dy3017uGHHFEqMZRarC2H6IgGgmgl+HkcMLGRWnws9HrB4mR2W7flcnB02O/cEMA90cO4C
+b11d4olXL/LC4+dZePFpus0top4pks9eFzc2oRastb++eMn94ZlLvO6cS36gAMCeWTEyO8dHqjX5
+MeC2NLGBDiR7Tt5Ou7FOc+E8pdFx6pPTjM3uZO9NE5w8voej8+NM1+uFUCThALShBwR1MLP+K9nR
+ucbi5YC1Q/9+pAMeASwpiU0JpEaJsYH3WYRQOLfF6ZVlfvN3vs6Zp59n4+KlQgms9QmkDmRcqpa+
+trHS/a2ry/z+uSXX/AutAPfcJvaUyupfmsTcDAzloMzc8evYdfwIZ599nurIBNWRMXYcm+C2W/Zz
+aH6U4UqJUCgCJVBKoTNrF0IgKWNcFy1vz6zeAi/j3NaAl2CbixciyCzeDgg/f4/FEuOcI3UGLRSp
+czR6PUpCEQQK4RxOCGp6mmZ8hf/n88/y5pPnWT1/is3LV7GppRdBra6oDJVorXe2rOPZ1hb/1Quv
+u0t/IRXgwXvkDwkh/l/n3E4AZxwqUASh4mP/4Jf5wu8+j1SKIAw5cscO7rphDzMjFYQQaCn9o5aE
+QuGcY6gckjpDSVYR4o5M+Fdx7usDbt7+OeCnF7QkxNLDOYcSAZH1rj+1UFYKJWo0uhv0jCHOasTE
+WqLY4rAcn93LYuMKn3v2FKdeWGb57fNsXVlg88oaQSWgMjpC3GzSWI+RkgVr+ejXXnCP/4WAgoUQ
+8ug+pnbsCX5RCPH3nHM6iR1hSeJwDE0M896P/xitboLSmuHJYQ7fPMOJg/OUS4p2ZAi1JJGWstQk
+zkAAAZIoTakGYwhxW5bhv07PvEBJljPxxlmosAOZvh0Qf4pEY+kh0UQuJnUx6QCEqMQIxm3STVOs
+cTjn6CWGbpySWkgSw9cvnOW6HRPcsG8OrTVDkyHLZ2eojF2k01glKFWwlSgPLTul5Iv33Cb+3voa
+v/nmOVa+1xiC/h4KP7j+EDfN7Aj+e6z9gE2tFkoQhAIdaMb27WRy3xE+dM8x/v7/+kUm5kc5emKe
+XTMjGOOwxhGToqRGOkHXpoRa4iJIpGG0MosQN2eCfZrNaBElJdAjtaAL2K/nv3jmyrdXAf69IsvP
+EuO9Y+wMU5URQHNls03qDHFqSYwjTlOixJBai3WOZitmdavNsflxmr0Ya/PEcQ9Dk9MArF88g5Rb
+Oaikgf9peprb05T/WQjx8vcyQdTfI+GHJ47xrsmZ8O+a1NzjnENqf9OHJoapjM9Sn5zlx376JI99
+/SylWlAIP9ASi0UI7eOwtaTGEShVlGeHpvYgxB1AD+e+xnLnKmWpSa2lZVMqWmMGLVlKemlCoMSA
+EgwEA+OInMGktqgmhBiiZ1bo2ZQ0tZmCGJ93SIm0EKUJ1lreXGpwx/5Zbtg1QbcXY3dZhITG5RLT
++6tIFRC1t2gsb+VIo5aSD+3YJSbB/ZoQ4o+/V+Wi/h4IX9xyPe+fnA7/YRKbw32LEAzNTDM8PU+p
+PkxtZIhb9k7zxNOnOHpyjqnRurdG49AKWr0YiSQxjkAJHJZOYrhxbg9CnASa9MxTrDY7CAktGyMy
+w26bBCEEzjmkEjgLQkLPwrUOV0j/mkktqTOkzrFztA5ILq03iVMf65PU5wXGeOtPjCue96KEVxZX
+uH3/PDOjddaaHcanhxkaTTm6f5b1hR7tnftReoG1xbWiXLTW3bNjl/jH5bL7u0KIP/hehAP93Y75
+j7yn8mPOmH9qrBvzXliitGJobo7hqTl0GAKW+3/oIAvrLaZmRpgarZMYg3UGoxRSSkIt0cphU5/I
+JcZwcs8MQtwD9LjaeZxGq4d1DiUlxlp05mW0EIXikELqXFE55MqYJ8OpcwRZuEidox0llOQ0xq3Q
+SRKchTj1zaLcqbSjrOZPDAJJYhJWGx3W213uPng9VzaeYh04vn+W63dP8uRTZylVhgh2HUCVyzQW
+LudAlzCpOzwxJf7Z/eNOCiF+/7utBN9VBbj3dv6GScz/5qwJkRJjHKVqiaG5XdTHpoouTrk+zF1H
+d/LyxVXCUsBmq0c51JRLAcYalDQIEeKcI9CSNLXctHsSJe5DMMxbV3+XTpwOWLGhpBTWOKxzWCEQ
+QhBnLt05R4z3BtZsr4Ksc7RNQkkplJTeW4gdvLr0FnGSKUlqsdgs9lMIP05TfyQOZw1nljeYHz7M
+j9x6gmcvnue2PXfQM2cpVSVCa7ApIzO7EFLTXr5M1Etw/npGhRK/fcv1bgr4J993ChBoUXngHvVz
+5Wr4PzhcmKMh5XqZ+sxOqiNjPhZrjRCCAzdPMTM0RKN5EWMMSmsS4xBJQqi1b8cmBgJFAOyZGqIW
+3glY3lj+Z/QSn5TlwgkCRZykhIEgTrzli4HWrxIC41xR7uchIU4cYeBDxGbkQ/Cte2dx7hLrWxGB
+EljnSLLPCrQk7qWZopkif3DO0eolLK1s0dt/gYr6SW7fkwLDlFWTar1MWC4TO0MaxwxNzqKDgObl
+RXrtXq6k4fCI/PvveahkH38i/q0kdd3vhqzkd6OR8+B94Q8LqX7FWTPmLVIRVEoMze6iOjKGDkNU
+GPoESikO7Z5mrdtms93FWuuFM6ilSiCVd9nj9TI7Ru4AqrSSrxAZg1beqq31/YL899xiE+O8686e
+dyJDnLji6MUpUezdei8yRIkhMYYoTVHiGI3uMoHyHqQb2+KcrW7iq5M0xVhIMg+TGIOWkq1uxMW1
+LaAOTGeI5HUc2D2N0hqEQqnAA9bD4wzP7aAyVPG5ipQoJcYc7lcevC/8gBCi/J+9Aggh9I1HeLeU
+/I/ATiEVWEtY0QxNzVIdmSAolRBSZ07BUhmqcMuBGc4sNYgTg7Nk8dX6bDxOSY3DpJZaSXH93Elg
+lJ75MmdXNogTRze2RGlKbAydOKWXJDjnSBKDMd4y49R6ISYOIYS3ZmszZfGeIxd6YrwSeGFP8sbS
+epErGGPo9lLSxBDFKVGSkKSWXuQrgHbkPztK/PPFjTbQ6qOOzHJi3xSVoQAdBBmnQIGUVIbGGJqZ
+p1wrI7XMc4w9Dvert1zPgxnt7T/fEHD7CXaOTZZ+1Vl31OGtTZdCymPT1CfnfdzD4myKtT4ETO4t
+M1sf56k3F0gTgwr9TU6yJK0UKKy1dFLLB05cB+zEua/z/LmVLFEzSCHoRL4ks9YSp4IOxpd5FgKV
+opUgTr0LBzBKZTfYobX09bqVIHw9nxjH3HgViFlutAiUYrgeIqUkij007LJwkOMFUaZ4znklSxPD
+ZquHo4co7C1kpFwmqPjkFkAohXAS4xzV4XGsMbRXl+klHrMQiOum5iq/emPSfQ249J+lAgghgh96
+OPz/TOpuzi4agNrEFMNTOxBKYI3xnREpkdIrwNDQEJYezXaEzWr8MLPOZCBDf+/NBxDiJpx7icde
+PUUpUCQmd/uSJEkwtt/Q8TiBVx5jQCn/e17Xt11aCICBTn2YKUOgBEdmJnDuNQKlcFjavZShSpCF
+F0O3Fxeln8kEbzJswDlHahwPXb/b4xP8KYLrC6cbVrIqRCiES3FCIKXG2pTa6CQ2TUm6S/0mlTG3
+ze2u/OtKKN7Vjb9zQNF3RAF+6e/8UPCBDw7/RtLp3ZWhW174k5MMz+xCaolJTNE5E84BHkCZnRxm
+pdNhq9MrSrEktQTaCzJyjonhEcaqdwNNPvvii3QjQ0duUz7vDQYyeud8bJZSZhZpcM5RrZRod3oE
++ptHv3bHK1ScGMrqGAsbz/nzO38e6xyTw1WWN7aQSmASn/nn126NQwjo9mJuPb6LkdLNpPaP+OwL
+Z3ng2IuMV3+C0coQlXqIyHoaKIFLLdam/t4IQW18GmsSWqtrxddUWtz38Lur/0gI8be+U5R1/Z0Q
+fq/Z+Kleq/tRJUUh/HB4mPrkPFJL0l4vs3pPznOAFAIVBNx+eJblzTZbzRZBEJAkCUoplBDoQFIv
+h3zgxN1AzJNnvsR60ytKKeiHw7zGTy2EgS/trPUKZuIYlVkwgOt4yxTCFUJzzvW9BxaMKbgEp682
+WN/qomXmRYwjrTjq1TJJaolkv7Ts9dLi+vfumOC+g0dx7jS/+aUXieKUz3ZiPnL3Jyir25iYeJZL
+arMIF57uNJCcSUllZAKXRLQ3W4Ag7qaEFf3L77pffV0I8TvfCSV4xwrQ3dy4tbFw5u8IRCgy2mxY
+rVCbmEEoRdrzZQ1CIURWjgmFA8KKYs/YFF947TRp5HAuplwuZ6FAorTjvut2A+OcWXuCV89f8UI1
+xrt9Y1AZFJtmyWOcyCIsaJfX6aaoItq9tMjo8/Lv2lIwzz0gpdXpoSVEiUFZryBRJuQ87qeJV5gw
+U8rx0TqP3noYSPlXX32RRqOFMYZ2u83vPQkfvW+KuYkhXpIQlkqkSYJ0CegQpQRCasJyGSFhaGqO
+5vIinc0NXNyj1+qEpVrl7959a+sU8PX/pArwK//nh+fSJPr55urmgXI1BCFRWlAenSQoedamEAIn
+fEbghADjB3BkEFCq+49fXtvCGodCkJoEmSnL3vkZdo4dwLm3+OLXzyKVIM06cTawPvbiLTO3ZmEt
+SgjfqtXa5xJOIDIFkVIWgJCWkCSgJaQWXNr3CIEOAE0nSujE3sUb5zBGZFVFylCllCWFEcb4EDM9
+OcrP3HsLEPLJZ59lZW2TOEowicOmcHbrMi/ue5P33XCMMxdXuXKxQdI1DE+H7N49zdRYDYDLa1s0
+Gi22NroorZFBQNzeIqwPk3Sah0enqj8/MSwurDXd1f8kCvDDj44FD3zs0Uee+/SbHy7Xykpk7j+s
+jxBW6/1YnKFwGfkgS3b8TQ7Lksj22NzqkiYOFQiMsDjlGB8e5l3HdgGS3/3aK6TWYrIaXEpZYAVp
+Ygo3mtfPLvu8KEmKz87BH5W9NzEGIzyhpB0lPtHLKwTnCDMOeKubFMIVwjePrPHZfxSnVMohYaBY
+32pzcN8cP37XSYQY4bef+BMuL6/hsEX/waaONHEsrbc4sfMB/usPjtCOF6gGFYQY4fLWJT7/7Bne
+fvMqG0stkijC2RQTRUStJnGnlVUFKOAv33CD+EoWCsz3XAHu/dkPXvdnv/v4Xy9VgtEssUcFIWFt
+5NrqwJMrlCyUQAgJQqACQZSmdHsdTM9iAh8ipBLsnB5Fy4N89cyfcmlpHWN9Kzh3vWmaYlKfjUvj
+iiZOqTSQFCYGnbnlNBfuQA/AZF2YUOvCrSdJ0q8O6PnmTi/dRhfzlYUpsIpyWXPXLQd517GTgOU3
+Hvssa2ubhdULCWnir7E6ohiuhgjqwIeohxbHY3zimT/mqa+co7naJO62vbFkh7UWqUNsEmHTQtaj
+5Vr54/ff0X0RP8r2vVOA33/mb1ZOfW3x0aTbPilViLUxSIWq1ChV6/3EZhvHLk9l+/Star3sgZtW
+ShJbQqtII8fwSI1Hjt/BRud1Xj59uQgLqUmK/rpzkl7kLTxJEoIgwDlHt5ugBjJ8aW0B3ZZCTRSn
+BFoOtHkFW1lVkNf11pjiHL2ef39qLTZ1hfLlP2macu/1Bzk+9wA98xL/1yf/jKibkEa+YjBJ5jG6
+vjzce3Caew++GxgvsDjnljlz8QqdzS7OpnkWCAPt5nJtCNNr0dnYQGnlJ1Osuac+Xn1UCHHmP7Z9
+/B+MBH7047eqpdXmoatvvfDLI7M7CevDSK3QWhOU60WtXbByrS/9rLX5JE1xrnq9jEktvZZH5JLY
+kiaOh0/uw7ktvvrWJVavNkljS9T1pW/ujr0bjgvUMEkSkgyIscYR9eKipMwbPlHs84co8lYdRR7N
+c5biubODSht7ACkxxTmSLKykacroaJ2fevcJjs8d50r7a/zGZ5+h1/bCN8Zbv0scUStFaclNd+7m
+5x76UZy7TGL/b6BZsJVMar+hrL32eVgbIayUkEr7oQipMKn7+CPvqez7nngAIYT49S/8gnziE1/7
+JSf1bGV43NfbrSayXCWsVAqXXyRlQuCcyUAOX2hJpZBCUCmV6CQJUdsnSbJr2HVkguvnjnDq6hme
+f+kCNoW45whKgqTniRUudB56NY7YxD7GDjRkcjduUtu31oSMR6i3vccOEEW01qRpShAEVEt+ktwM
+uH2PAxgCFXL0wA4+dPImAB579WleO71IpRzS1tBtZNcRW9LEML6jwrvvOcZdBw7x0tKTfP6J14i7
+hp97tM2usY/xyuIKzZUkCy39e4eUuKwkFUKgSyV0uUrS6SBVxoLWbqe19heB/+67rgA/88snxekX
+rx7eWrr4MzL07dmR6Xm6jXV0uVq4/ALiFAKkRmS/y6xpI7CAohTKgl9njSPuGj58zzGMW+OPnztL
+1LG4xKHKkjRxBEKQRo6w5F1j0rPokiBNLFL6GGtsHq8FUdxDIAtB54jhICKY5xa5F3HOUa2GHJge
+BWQRNmxWRczPTPHwjbvZMXITFzZe4AvPnWX58gZxzxIPx1SqZVqyhU18/2LfDVP8+MPXUxKKf/zp
+L7Lw1gZR23uzX/83T/G/fPw4AM2rHZy1KCWQMsSmFmcS2GZQEl0ZIoljRPY9JRqk+diRveLX3zrv
+zn5XFaA6Oq4uvvzyrwnJMM7hbMr+m6dorkxhTVJQtHxcczmGORDrfONFKUAIn3lbMInDJAnHbt/F
+3Ogwr15e5uwrK0X2LEPfl0+wJD1LbRSsM8Q965smKRBasPTDj/JuWypLmlmRsxaBxDqDRHk8Icst
+fKWgkVIyOVJjfngnMMnO6VEWrjZQQvDwLYc5Mr0fIWr8i698mvVGi+ZGmzTxsb55JWZ8p6ZcU6wv
+djl5/15+9v5bePbiAp/45As0Vzu+OZXdm/WFlD954wkePLobpTVxr+evWYLUEidCbBpvq3KCcpm0
+G5JGDpzHN4RTYwevq/8jIcSP/YcSSOR/iPuf3DMyl3Ra9zupcULRWluh2+lx96MnIbMoKfU12X9A
+3sRy2ZdzSMi+VJzaDBwS3H3DHiR1PvVHL5PGliTymXbcSYlaKWnHW651/ZgcdXyMtyn+yPoD+f/m
+sTWneRV9e+cZR0mSkPT6NLWRkRrHd08ixM0IjvL+G+/mF951Gx9/36McnTnJYmOB33jsM5w7u8zm
+WpskciQ9S9qzxJFh6VQTFQgefO9hfvb+O/mj18/w2//yGZprXdIkwRUdSP/4qd99GUnIjffu9L0S
+wERRxnwCqcOBZNrnU7pc9TCyDnH4RxWWHrj3dia/a0ngL/7t9+jls2t/y5lkSGbCjtubLL7e4PCe
+Ka5/+LoCEcsTM5HV1nmXLssJPYkyK+dqpQCpBPtOTDI7VuP0ygU2lnqkcZp5Bh8aPAjUF1Qa2wLF
+S6IshPQsJvG9/+JwjjS2/ZLK+OdmIDlUgfDPrWWoUuLQ1AEE+wGJ4IeR4iPANOfXX+SxF85y9UrD
+e6Tsc23iFTuNLUkv5cihHXz4tof4va89x+c/+QpxN8IMYBIFRmItUafDJ5991Ze9QeB7AVJnjSUf
+klSp4le5yKjsUgW+gyglQinw+MrI6PzkfyuEkN8VBdBBsK/bXH/ASS2FUgj8Td1YushLby3yIw/e
+yOE7j6KUR/FUwdrN2qNK4YRABwFSKZTWTI1WOT53Dyfu3s177jjCbO0uXnz7KlE78jcgSTAZ0BP3
+UpLIkEaGqG3obBqiLUPasehAEHVsoQy9lhduGjmSbqZEHVuEGwATe4GZxL/PWRgdrXPf8V0Zz7A/
+IOpY5/z64/zR82+zdGmNuOvoNlPiTkra896m2/Ix+fZ3HeAjd9zFF157imeeOEev3S2svrgfNgVn
+ipLv+ecvMj9RozpSK8rkwouaBJf4dqW/twpdqiBV4I1JKaxzCKmVlPK9t59g93clByjXw3t6pzb2
+KJ1n8xKRWfurf/o2tVqJn3n0JL8/pDj77BXSbjtLYHzChhXIwJMgykMl5g4Oc3x+EsGd/JUHexlb
+Zp6lq43COzjApH6cy1mZuUDf7HFpbsUCYxwyELjEoasSpQRp0scfdNajyIEZYxwqu9FSw+jEEAd2
+TvLem/ah5XsRVLP5gRBIce5PePzli1xeWCfu+uQuiYxPOgc+59YH9vHR+x7iU8/9GU/8yWmUllk1
+khYh0YcwWeRHAthaiXAW5g8P8+aTjaJyKvAAazFZ1ZIntKpUwdm0j34CUqk9WnMPcP47qgAfeP/Q
+6PThm+4LqvVh295E2KRoZSqlSHsdvva519jcbPO+e45zas8cT37pDJuXlwtYVgUKqRS1sQqHT8zy
+k/dfTz34ABAieLdPEnkeKSXVkRKdzaiwGGsMMu/apZYkcsRRnuSJbUmn2fLCVWVZUL6t8Eic9DxM
+ACrjivmZKY7smuD4zknqwT6cW+H0yu8Qp5ajs+No8REcTT79/Jssr3rhRy2PQPZzCz9YcttD+/iZ
+e0/wyWe/ypc+9wZpnFIbraK09kqc9UMKWjz+HEI6ulttnnzlAgf3zPD281fptbbPjIqsRE2SCCE8
+kSQol713MHnJGQOMjM0OP6Ck+Iyxbus7pgCt9db1ldWl2yrD48JZS2QaRTYvtcY5QxJ1eeOJc6wv
+dPjgB6/np37qVl46e5nn/uQsUbuNQ1KqVdh9bIKff/j2LK5Wr4lEoxzeO83alSZJZEgyCNZa672J
+tUilvAAyhM0kDqn6sTyv/0VsCWvKu+gu6LIkCBV7j8xw59F5DkyNIRkGNBc2zvGvn/s0nU5Mr9ej
+XC7zp6WAX37vHLCfC0vrtDYS4k5a5BG5JwI4cf9uPnrfTXzhtdN85Y9OZZ1FSa8VU66HGaZvrwF5
+FMisvHOGxfMNThzaQVAKiNp9mnreP8kBtfx+BKUKNkmwSYRJU3QQ4Gwqg9rQ7Qd3N68HnvqOKUCj
+wZ6JJNrb2Vjh0J238vqfPumtLCwXFySlJI07XD1/ld/6p49zy7uO8OjdR3nfLQc5tbzBZz/9CmFV
+c+8Ne5DiPRlR0jI4miXYzYPHdvHG2ct0NpOMRKKL7Fhk+ILKYFuTJATl0AtEgkkgdSkyI5EmXdhx
+aIx7btrHrbvnEWIsD2i0knP8wVNPcfbUFZLYbqOHt0OfgH7pzWd4+Gid1StNes3+PGA+YIKBPTdM
+8FcfvJuvnTvNY595laSXYjO00iQJuqQo16t0t9oFp7BoUClPirXG0t6IqJY1laESnYbGptniR84V
+JJEcqOoDQxViD1CAc0gRAOwPQ/Z9xxRACFH6Sx+ePeiEqNs0pttOmN5/mJW330RlLtBlCyxIqTFJ
+hDOSZ7/wBq989SJH7tjB++88zP/xKz8HjAK+vmbbkCbkk7tlNUMp1CSRH83CeeQwtyAVCKT2DaNS
+rYQOJbqkKFUlo5N1ds2OcnTXFAemRynJ4SyO94hsi7eWX+epVy+yurJJczkpQmwSW5SWhSLlWf0r
+py/z8NGYIJT0Bqw3xydG58v87Htv4cLGIo89/npWgfQJIghB3E2oj1XotYRvgOm+QtvUIpUvi7vN
+DgsrW+w9NsH60ioucQhrt3EM876A/1+/foGUEqeUP6dPMOsHb9mxVwgRfjv9gW+pACeOsUcp8Yhw
+DqlDFl9/lds+dDedzQ2SXgeHRCpR0JtzXpwCeq0WL3/pFKeeWeL9P7rBB2/+QFZeMSD0a3/u5MP3
+X+DLw1WW17boRV2U1IRhSLmsqZbLzE/WiRLDcDVk18QQk7UK1WAMnCkeoQAAIABJREFUkBi3yXqv
+x6X1Jsubl1leb7G02uTq4iadjYSgorBJ/6bGkSeX5NaNFajAC3v50ibQY2pmhNbaKkj/96CkSGPL
+z37oVmpa88+/9Azri10yJMorbd5RzPKW2liN9ka7QCF9ZeTLY4El7sa8df4KR/fN8VJQwmSopBig
+uOWeNu+JfEO/wCfPQsAP3XoDvwOcfUcKIIQQP/KX53c6504glEfQDJx9bpmj9x3j1JOnSKMIVFAg
+gLmmWmv9lK0KSKIuX/jMq7S6ET9x9ySC675JFZqHgXFmaz/OT95zFTiPcStZJaGyFTokkjKN7iZr
+3S5XGh0urDbpREu0Oz02Wj0ajRaNlS5RKx2oub3lpj3bR9YYEFR+FVkFIaTDRg7nNtk5M8KFN1cR
+wk8lJZHhvT98PQcnp/kXX3mOpTdbnh9os/CUJ59Zy7jXiqmOlHwiODCGVnRMs/p+7XKbiZvK2d8U
+2GRbXyWvAERxHlkogstG4qwnv966+/junUKIt7/VIpbfygNI59w0UpacTZEqwAnB+qWzTO4e5boH
+j/Lql76xFb29HWywqSeFXllt4pfUO/jv+egOqfvXPPbSOVY323SjiCSjbuWxU2lJtVJidW2DuGuI
+OpY0ttikT8r0+UJf8IPPhQStZE5O3vZIZm9CgtYSIxxnVq9wbPckf6beRmqJco6TD+7nkeM38dkX
+n+X155d82DAOIaVPVLV/xIAOAt9eVoJyrUJ3q91vQglVlLw2UbTX42xIpEqz18NJX2q7rIzMPUCO
+Ig4SbfJ5SCUlFspOiKnMqsw7UYBASH0QKaUQOZvHJ2AXXz7D7X/pJPtuOcy55976Zt6joAd7SDZl
+a7NNO75IPexk+QDbkkDHRf7wxbd54dXzrF3qfsPcHkBY1gxPhzSu9IrPyfl+Oa8vRwGlEuhQbOMk
+qJLCxr55NMhg7pMxvSI4CVIKXr2wwg+fPMKOA2M01raYPjjOh+44QidZ4Zlnz/cVLs/uB06oAlWg
+kc21LiMzNaKM/SyzuN1nLQu6W202uwk7jozQuLKa08G3cRe8R/AeMc8JciVXQQlnU7RH4fb4UuPP
+V4BvhQSWgHv7VC5ZuKSovcVLXz7L3XcdYGrv3gIG/gYCSBYPrbVsXol5/PUFHGe+ySWs0zNf5vTF
+q/RaffzeWbbdAKkEQVluc90mtRmZMtPa0OcluuwHUlGeeq1KChMZnARdUQgtkaH0j4FABv49QghK
+FcXYXInLK5socYSPPHCcW27Yx8+/+xZKcpJ/+C++UihcXnXkhye/9gWTW7mQEJSCohm0TbBCYE3C
+5laXG47s6n+/DG/ZHjbkwP1QBdZi07ig4Tkh7s7Qtf94KHi0RlVq/UB+EYPxRzhHt7nOZ/7t8zz6
+ozcxd2gf1vaHLZxzBUiRK02n2ePNc5c5vfIn+KXaejiWcCxh3af55NOnaG60iTtpEY9lJlh1DY8/
+t/Q8LPR7+j5Oy4weHtZUX2k0BNlzk3hOYm6hSnulkRrCmqJUl8zPTPFjDxxHcCNztV/ggyf+Jko8
+wtn1txmdrG7zNvk1DQpLBap4DefYWulSHy0X5exgl09pjTOOsxcuc2RupBCPGKgCnHOkaZwZoiny
+h3zUTgUlECo/3jU+ROUdKcDDf2n3jHOurDIFkFKSN4Jysmd7Y41/+1tP88FHb+Dk+24uFCCHLd1g
+A8Q5ls9t8fzZyzjexPHHLGz8G+BJvvzWWc5dWqa7ZbaxY3KLKgSUW3lF9ZUj9JastUQEAl3yFleu
++WydbA4hP4JQEpYlQkK5nnmLQBCWPYwcVATj48PcdniW6eoPZ+GqDkwimOfgxCF2zo1Rrkt0WRaK
+OugRcqWUSiF13vySoHw/JO+ZCCkHRsQEzSsxiXGE1WqfUV3gBioj1vSXNs8Jti57faAPM/Lwhw5M
+vbNmkJR7lZT+g7KbZ7P4NUj76jTW+Z3fepqds+Pc9ejNVEbGBlyWKt5nraW7FdHtpRj3Gl9682n+
+4M/e4PTKWbQStDcMSdcUSJuQFEduYV7QulCKXNjOggj6SVwukFJFFcIW0mP/mcEU5y3XVPG7CgRh
+KWDn1BhHpndmy8ragZJVA9ezd2aMWq1GuaYIQlmEp0GPlF9H/7MsaWQo18MC2PIzE6K4n+1mTJxa
+T/3SskD/tiuBzO6r7wjmrynt+QwqDHNvsOcdKYCScm9uwS6b6pG54K3NAA2vdd1mgy9+4jl6vZRH
+f/IkYzvmikbFIBfQJIZyqLncaPGVr55i6dwGpxY3mBute9pXPuRp+uCHDlQ/thav9b3BYJs1t+5S
+1bv8XPAqENvOse253C6sSrXMcD1EiLlrwqjNJnyrjNfLVKuhF2zmQdQA2TQ/d96vEFIipCTqpAQV
+VVi+CvoCFlKT9GJSZxiaKn3TZHpbhzX/3pknGWwze28p35kCOCGm/BSPLKZ7kD7mCB0OeHYPfSbd
+Li8/fooXXz/PRz5yMze861iGiKm+dgaKvbOjrLa7rC+2iVopS2ubVLQmrMq+ZYcDrjWPqVp6Vx1m
+FqS9oEtVSbkuC0vWpb5wg4oXtrOgQn9ITZETqNArhwp8nqAC4aeNhMisvfcNt8nhl6wpIGFPJ0Lm
+yqa3f49cIQbzF6lUdvjQmiuISVN6kWF6x4i/z4MhN0smfcjIkFHl2+v9ySuZUcsChBDT70gBhBDj
+gzG9UILMfclimKKPTpko4tRX3+bffe4V3n3HIf7KX3uISt3Hs6AccvCWWe7cfytxarNSyLG52aaT
+JNTrdSp1vQ38GCzP8kw/F7IuiW25ggr960LiFSjr/vlQIYq8JO8lFKCVcdteM84RJQa/mHT1Gvef
+Ai0Sa+n10gKWzpWg8F6SYm6ggHGVb2jFbUNtJOg3iAZKwbzFW62Gvl2s/NRwHkrznCATcN8DYH1j
+Dtk/n5Tj78wDIKcLN5QnLDkTRQjSON4Wo/oQp+Lq+av803/yBFvthP/mr9/PXY8cYf9NU/z1D94O
+7GWl0aE2HhKUFFvrPdZbPW49utP36rUsrMg3PRS6onxtPtDHzxVCl7yFp5HbnjxKP3846N4HGcC5
+h9Gh3FZpOAuNrS7OrQ38R5odPeAqVzbafkwtzTxIdr0y8OXnttAl+1WLytY7qI4FBOWwnyPk9w/J
+lY02M2M1n90LNeDu5baBkW2AWyZKHXj56DBEKPUtk0D95+eAckIONBoQ23n9Kgi2AT+Df3NCkMQx
+n/m3z3LvB47zs/e/G7gRwV4ADs2P8tK4ZstC3LOsbnZ56PguvjASEHUNwmZj064/9TMoRO+ZDCqb
+JgrKfU5AHjYGsQIpFEJvr6dltnmYdZ4cmo9xJUnCVifGrzj6NnA1u1VVoIpxr3Hu8iZRFBUVhipB
+EkFQkkRbxvcc4hy5yxDKwBYMaOccOpQEoSSNLToIMGmKUorNVo8juyaKZDsnj5jEIFQAJkEohQqU
+b4dL75m8MdpBjzHxznoBUtY9/UsWJAaH3LZxQ47kWWs95172M9fcPb324gJnrnuDQxMfLF4+PH03
+Q8NnaG9sYlLL4mqD1O3kwOFZzp9b9jlF5LDGCyusCJztgz1aa0zJd/GKKoHM1eZWo8U2pC2fKs4n
+jHU2PCqRBbaee7G5qRHAsrj5aRY3fCt3pBJwePowz11YZmVtM4u5rghFaeJ5ibqaMZWVAOepLrqs
+SLrZwE9qsSkMTYb0mmlWnfjcKokcnW5EOdSZR8juu1B42WcbGA2QYPx3CrHWL3mvglIuh+o76wYK
+Vfca6K5NDlBa9N2SEFib4pzK2L75DKB/T6cR8/zpZQ5OnB/oBs7zC4/czO89eYrXX1pkbW2Tehjy
+0/cd59dbHZyFdrtNGls6mwapJBZvNSqrdXOXrTIS5aAXygXf9xbbvZTWuk+nyh7zxsrQUIUbd08C
+kj987mzxP0mSwAnYPTVUZORSebOwKYTlPsCTWIeSApOAU5D2slkE6b9DmjjGZ6tI1SPqGpx1RSYf
+xSmBUgTlkKjT8wlepuI5qqpDvY1n6CekveEF5TJpkgDvEAjK1rH1W6kFChUERet3EJd2zhEEpT6N
+WUpkRv7Mf06fW+TM2u9lyN8zvHb59yjJYT548gA/8eET7Nox4wUjfpy/8f4Pc3D3JLVaDR1KamP+
+PLrUX+1Ta+1jfDag0q+PxTb+nRpwo2EYFh6gCAMD/5NPDe2dn2S2Ps2nn3+WOEqIejHtdkQcW547
+fZmZ6izVSqlQwkGkUYUUwJIaQDFV6OFmnWEXPodRlGuBV+oMwwhKAe12m1BLggyWLkKBUP6+Fots
+UVQGeUjW5Wq2+CYopdQ7qwKkbBWlRZbt92/eQHzCFmWKyICia9usW8sJX/z6WYz7dzx55vP8u6++
+zK/9zuf4/afeoFYK+Oh9D6DEI8AogvfzyA37qNVK/ZJvoOZPslkCmc0cDn6WEB7ICYKgyPh1oAgy
+l5oLrRRqSqEmDPz3CAMfNoaHq9ywa4J22mCt2dnW4QRYutrgYmOBX3rvraQDS8PkuYqUmSJkuUmO
+RxQlbYZJhHmiqDU6U6JcJCYGY20BMOWI4rbKSChPbM2+v8u8cW1kxBuAZxLH77AMVFE+7NHvPukB
+vNvHex2WswvRWdmyXSDOQtT17nWh0eS1C8v0tgxRy7Jwbo0//NppFjfPZeydvKKaYma0TrVSolwp
+FYKUytfp+WocSvnB1LDkBR6EGiUEQfZ+LaX/PXsslVQxHay0X2egXPIerVoN2T07ztzQHC9fWNlW
+UYSBKnKIL75wDiWm2LVjBiV1JkTdb9VaCiXIMYiw0kcJdaYcxhgq5RBdlYQlVWAf1jjKgaJU18Vi
+miKj1PtKIygUQgiBUH6eYGhynOHpMlG3mxlk0HmncwFreUKnBy6k6Avk2IC1/iKUKMqWAt7MadED
+pVi7HdFrm2JRiE6nw+efPUOj+wn8Dl5XgWE+cOJGHrp5H/t2TjI3M0G5VPGzfvlOIdlNF8IrRbkU
+FIs/5Z9VlGdKbCst87+XQl2UapVSiZv2TtJJ1ri02vCxNlDZIIugUgkolwLa7YiFjXO866Y9aK2L
+MKO1RmlZKGNu+bm1ByWx7T445zLvJLflJ8Y4Uucy2Fqig2DAy2RYRgb+eGegGN81x7Hb5tha7WGN
+yRPxjXcKBK2IgTZwIfDsQwuO2oAyXHsUHDbjimGRfMRaav96Ehm2trr84fNnWNj85zhOkdozPHvx
+bephyKO3Hub9tx/k/hN7ue7ADqZG696iMxce5LhBXiFkbr0UfvPkML/WcpYT5I8zE0PM1nZxaWPL
+7wAy6N5F34IDLfn8c6eZGxrj8J6ZbbmEzqhxgwqnS6LIDcKyLEbZBtc7MBlglCOHWmTIZPa9BsNq
+gcdg0ZUau66b5fb793LxrTV6rc4gcLfyTnGAtW0kB+d8eZHRtAfnAaWWvkQcwKWLjDv0llEvh9kK
+np7qJIXsgzhpypXVJo89/zY/fX8ZLRRvX17j9fNXGamXuXn/NDfu9EcrjomM4dWLq5xdXNsGiuTC
+7EYRpSAotnUpZVYUakmUmGKVsVKgCANFKVHcvm+Gnlnh3NWmX1k8W862ly0MWWTc2lPPX1xY4OSh
+GS6vN2m3o0Kx8/LS2BSpJGnG6FGhF7zW2ZIxxtFsdryglch6BL6aGCmXGRsdJpqytNb7PRIx0A8Y
+mhzlyC2zTI8N8fVnzrO21CBNkmzoReCcW3+nnMD1vHXmnAchnBuoQ0W/Ty0y3FVmFpCjhzLjyIVZ
+7G1lS6kGWYcu6TqCiihuUqPR4g9fOMeP3Hone2fGeP6tRaIk4Y9f7FANNbtmRrhz/zwjpTkeOjLG
+A0f8OkJvXLnKaxdW6PZSulFEOQwJtaSU9eQH2UJD1bCw6FLow8iBsQpj1aM0um8RxSnlUoDK9gZw
+LthWWfRiv4/QW5fWODQ7znW7p3npzBKlkiKK+vOR+WJXeXVhjAFtM6OQxUIWtXqVJjFhxYemsKIY
+rpTYMz/uF6dwTboNQdRJwRiCcsj9P3SQeq1CEqd8+Ytv0W50cDb1whcKnMFa3pkHAC7lY0pKBVm/
+WQ0oiN5GVhBSb0Pg8jo9rCh0VVIKAprtpE+iUGzD8/Ny7spqk9MrZ9k5XuftoQqtXowxhk4Mb11a
+49zlTfbNjTA5VOHg1BhKaI7PHuT47GGgyeWtTc5fbXJlY6vvwnPIVQuqlRLj9TJTQyVGymWGKyWU
+uA+oM1JeY258nauNFlopuhGUQ5/cJcavKBZq7fcuMo7XFla5afckC6tN1pstKpWAKE4pqbBYpSQP
+oX66xy+GobTPq2KToANFZdQ3w8qlCg/cvA8tfon333iGJ6v/iieiU35dhJri6PX7uP3IHM1uwotn
+lnjzucu0G52Cau6QCGeyx/TyO1WAi0XJly1q7Izxtaftr9glsxk48uRQqaIFmjdZZIaNp85s65WL
+a1q6+eObC6u876YD7JoZ4Y0LK5SyDDjIBNnYiri60ebFs8vMTAyxY6zG9FCNoXLI3NAc88N7cS7B
+uA2ubLZp9Hp0Ir9+8OxonbmhfcBe/Fayw/1ZBXEHN+1e53njaHR6VEvZ+kBWEGi/oGRF5RUILK42
+OTwzxvE9Uzx3Ot2G0wf1Mtb41UxyDxAEAUHgMYkk24Ai0JJSTaFVQL1e5uZdD2Wwz37uPvgwvTQl
+OeaYHauw1YlZ3ery9MvnufjaRjY80y8NZTZBlRFMLryzHECHF5xzVgghC/Zshp/neLDQ2sf8weXg
+MvBiELfXJUG1pOhmY906ENu8RJ5Jp6mf7Gm0Yq5stjk8P87iapMotpTCfs6a7+YVBorGVpeNZgcp
+1xgfLrN7YohQa6pBwEh5lJ1j0+zsj7kCR4v9g7dvGiUR7KasbmbP1FPYFUuzE6PxiW5qLUqBkmBs
+n6t/anmDk3tmWN5sc3W9hZTlYqlaKy1V5bGLAE2cKYNUAhIKQGi4XqdSDnnopj0IThQdSMG9PHy0
+wYsLL/PG+VXWN9tstdssvrGFTW1/ampgJREhNTiXXHnzpYV3pACXXnxmc+fNd5zHuf0yW+FTSlMs
+9iB0Xo6IbQnfYN9bSE/S0KFPEAcbNjlhoxh1ypk+WZy9uLbFHQfm2DM9yvkrDQQSJb3wfV3uBaFk
+n9LdbMW80lpBa02trKmEDaaHy5RCzUx1GCHuumY4RV4zpaQRXMeOkRbV4E0WN7foRB7tjNKUdi/d
+Np6llGJpbYuxWombd0/zpWaHxHhP45wiymlaWelZKdeolQKGqmWSfHHJMf/aVL3KrrGfzhQzn05u
+cqV9lmdPLXHp7dU+m0n0SSZsmxUoOoSnPvfZ5tY7UoA/fjzufeyEe8wJ8XE5MLIshMAKn/1/A7HR
+sq0KUBlJMxd8UPDlbNG4KRC6Aa/hnOPyepO1+VHu2LeH04sbhNLnIKHWfvpIKYw1OUre5+Fld8lY
+6MYxi2uel98ajjk4sQQcZvsG0VxDUR9FcIKxqma0spy9nmKzLeeSbJ3ArSQpWMkAw5UKdx3dWewt
+lCed+e5kgZSo7DrLStHJ/r8aBASBoqI1DpupcjkjzT7NU28ssrbeIOoaxuZKbK0l/TAqped9Z8TT
+gSmiPyLfI+8d5ACRtemzUmrvWbJE0AFKi228NpkNMuZZf07KUBkdW2uddd1sH0gaAHTyLxQG/Xq3
+ExnOX20ytWeCGw9McXZxo086zRUn5/JluUalFBSbOg3CHKHOx79WEKJJf52+Px8mEaKSnSdG4TuE
+SllQUA3MAF/QVwZzQxMY193ODhYBNtuQOkp9pt6LPWLYSRIW1ltEacrltS1OHmpwaOIXgFEcb/LS
+0rNcWfXT0lIJyqUKy422h5OrAaWKQgV14p6ltRYRdxNMkjiBffnbgYK/lQJYKfUyYBBK53NsLmtF
+5hZbsFuzBC0oe2gzTRyyIvvj1Fi//YtQOJltAil9nay1LuDdQXe2sLLJLbvb3Dh3hCsbLxLHcdHD
+L+sQa5TPorP8wFgYqfhStBxqenFaXGdsDJ1kjVr4ehZn69fMKObhoIPjIoubz7Ha7vrlYIxDZxTv
+yVplG+9PSChL3S8zy2VWOi16UeK3mUlTtjoxG1vdYkn7VjehG0XFfRwfqtCLDC+/fZV947+HEsd5
+4dKXObW4Rpz4hSuHpySH905z4+F5aqWAlUaHhZUNLl/aoNOIi3F6hEgdcvnfM3z57SuAc87+5b9y
+dKU+NrUusNMOWWSag1h/zm8bXJ3GGIfOUK+crGGzasBnwH3SRikDivJkMMxygVLWoHnuwjJ37Jvk
+3kNzPP76QsGjCzJUTgtVYFUy8J+Vl2k54BNoSagUjW5ENbgEYjrLBfSA4FtAC8cCxr1AJ07RQtEx
+KfnoQZxaFrLyMjZ+M2mLLXYiafdS7jwwh0ktr15YyyqI/h4E+bXky88n2cZYQghS6zelaHYjxqod
+5sbrBFqyZ3qU2BhGaiXeXmrw4uvnaa2n9LYSksjgrMUkJutDWBBitbV6ZfnbWTHsW64R9OVPvXXe
+CfG5a2f/cl5A3qkSA664wOd1P/mT0gsqj9+DffpBpk++SHOYVQlhoLi83qJnlqkGExyaHy1cejkI
+KGntl1XLIN5AecXxHb6MGJpJLzGOxBia8SrwZtZ3sEATxxUcr+N4BuOe43LDbxKZOlNcSz4cM7hX
+gVICmSGgWiiGKgFvLK0zUS9z/Z6Joj+R37O865hvM5NjBElqCbVmaqzGWPUwgluYq32U6+ce5cjs
+OG8vbvD0a5d4/oULbF6NC0TSG06/CstG6T/9p59589taJuZbKsDqJmvrF956VqogHaR8CdkffMhn
+4vPeuJD43ndO16pku3phGa4EVKv9vnwe86WUVEolLzgtCZQqQkKgFK8seFTz0NQMuybrVAJFqCW1
+sqYU+EUnw+zztRLF1rJaiWLfYCW9Emx1YlK7lAn9PI5XgScx7iU2owssNJo+kcP2p34yV18a6EKG
+BUvX7/0qpd930GJ5ZWGd2ZEhdk7UiusIA0WQlbuhloQDzawwUOybG+GR48cR3JLhEj5PeWVxhW6+
+9G3PFh3DYp2j7YMo6dqF0y9eWf/WjaBva30A55x990PhJWttA5gU17r/rBSRAxejtSyQt3z8SmRD
+JfUwzLp4aZEI5lYQZD3z3CUGmWdRSvlsvrHEzrFj7BpvcepKI1sASmKUo6QUqbCFsKUQqIwhI4XI
+Ssh8R1CfjOmwiXNv0IyvYo3fJTR1xu9F5Fx2rhxUkTgsSnvWsMYRKJ3V+3bbwlNaSlabHc5cXef4
+7DyNdsTGVrdoVOVbzGgJZP2K47snOTR1WwZOTQ6QUM+wstFGB4p2O6Iy5HMrP9KWLZVnGBxJX2uv
+LF/6VmPh37YHyFayeBVnnh885+C0j8jGk3Te1sz64FJ7pm7OdtlqJ4QlHwZU1pvPzzNU8dYvMopZ
+oAYsTUuGyqFPyNwKI6U9zI9W0WpgL4Bsh/B8u1iPK3ihSyWolRSB6iOJ5SAAUprxVRqdHs0o2oZS
+5spSLwUF/iCQhYIFWhafH2r/uVJKSpnylkPNeqvHYmOdew4cQgpFuRQU3qCU4SW1sua9t+zn4OQk
+reSNjIru8QifiJ6l3fNL2m9ttj2zeKDFnBvRwFzic1EveZlv8+fbUoAvPZGeu3r6taellOm1ix3m
+Lc98uTQp/QrZMpu+CSoDCKHsl2Q6W5VDSt8jEJJ+Upd9qXJJUSspKkF/zcHFhh+bnh/eyVA5RGt/
+03MhZBNNvgzNoON8n+B8zwAtFErMAesFQzexduDvolCCxLji3GGmUCPlEIEsNpbIXbqW/fmJaqgp
+ac2p5Q2WO6u8/6Zj1MuaoVKAzHKhY3umePTWo1xtdvj082/yxJsLLDUfx3EKx2OcX/8UXz9zpdg1
+/VoIXWUNtTRb40gFKl0+/crT/393XxYj13Wm953lLrX1RrLZai4iJVm2JVv2aLzGsDBOMLaTzAwS
+ZJwESIAgQB6CIEDyFORlgARBAiTBBJNkYiCKgIwxToTMyBqZskhLtiRLojZK1kLRliiJIil2s5vd
+7K7qru0u55w/D+fcW7eKVdXVFCk7KaBQVV3VVffe/zv/8v3L+dnzZmlSAOxmVvCTxph/xDlfHOTt
+swyWEAzMNWEUAaKVgefZYsfMEcpUe+B5NryCZRWzFRb6EpXA8g5C2C3iAp+jlSRoJx+i4t+JA9N1
+nN/YKmwDb4WXsdXZZlJZSBly6bSBB2AORBfRVdbTZ6ywvbybq6A49YGHFSIBX3IEnLvppSKnh5nW
+jo+xY3ArgYf3V+rALcDXbv80LtYv4dZ9NSxOLULTFp448wHiRMH3BJrtGBfWtnFL7RW8eO49rNab
+uLrVzvcg9EsCiausotTOKBTCLjSVaBDxVTLmyV3IdBf7BZB+E6Tfomv6A3hfrVqW38/as4gIQejn
+HnSa6jyxk3ntXFhPXTh0V8o+Sq6BQggB37N5BOF+c73VAdE6JL8N81O26yjkEt5AUYrnnEEB63Bl
+piqQ0nEkSf+x8572kUygnNcQSEjG8rtfaCARnOdkVOawZlFH4BxVmwWNwVgJR+Z+Bwen/wEY+yyu
+drsInSnIpqBYVqKFpavbWG+07OIRAt3I7imQF586M6sLAyrImNdJ6zM3BQDHfljf6m43/htjLO2p
+9B6lmzlAwlXEZlVAGVkipUSqDJQx2DMVohQE8NzK7vUd8Hyn0IwHyH0O8NyRSzVhpXkFgMJ08AnM
+lMMeCSWspy2dacly78XEU8CtkxWbyBWR9rzzbF5ABpa8olhKpylYTmln/oQFgQUzwfRAlIFbMOyf
+rrjGmLtcm/mCrS7OClPdxlVScqxut9DsxnnLWl4K7kLkfBsaxyaSAcBY0mls/tdjj1zdvjkaAICK
+u08R0Wreu0f9c3mMydqferVv+WZOgqEdp2hFCnNVmwjJCjaysM1zxRkVV6SZxfLS1SD4stfmnSiF
+dvKBzeEHR1EJPJQCL8+IVXzbuVv2PARuNdc8z/ks++08ImOyN+bmAAAZHElEQVRQ9jz4zPLwPfMA
+VHzfajLnq2TnKAd6DErO/8g0WehLCMd5ZNdmfqqM6eBzOaVsvfswP6fAE7mmm6sFWG928zlAU+Uw
+3/wqy51kDrb0bYFpGqcgY5bbm2vPYZe3XQHgz773XlvF8R+QMeRuOe/PmO2Jy71oR1JkdG+a2Cxa
+qjXma5W8cjfzqHtNHsjVt3QVwPnfnWNn1bB0UcE5ADOYDg7Agy07q4ZW+LXM1DinSRFhJvRz9o+R
+3Tc4E17ghJaVrlUCLwdSJfAKyR1L5gjwPmIsO7acDSXCvmoZi1P3gugcND0OwikQToPwKhjb53Yw
+s/9fDjzcUqugEylUQz8vLk0TlT8XQtj9kWw0QEmsSUhOKon+2Q8evBjdVAAAwJ/85+e/R0RnsgH2
+RmvKJ2i61V8coJxvdOBsXZxqSMkxXbU7b8oCC1jyuWP2eN6lK52NLYZ32cqSnGOluQFgFcACZkq3
+9Ox53gFk1XPF8yAZQ8CrTmhxPr2EnOA8T8BzZqc4nmbGhaieJ1ANbel66MbcZ+ahGB1pt/fwkT3T
+ODBzGI3uW7hYX8fqdgur7VewvPU0LtZfwfsbP8dnD+zDkX01SA589tZ9qPjfxr1H94ELhtmq3UQz
+27bGD/LqYHIEhZMB/fyB//jMo7iO2/VuG/fviOgBY4wvpORkwFRKTApiNhxhfXmB4sVJtYZSBvtn
+qli6um2FjV4ixy9M18jsKwB4OVkk8vZrzxMIhMBWvILpoArGDmDKT7CdbDpHr/9mY/SsYbaDUPS2
+lCsOXhTchnSZg5VFAIELLzKtYBihi4zUsTuZ2gwlx+J0BWVvH7aiVWxFEdqxtpFFtmGFtgTS5c0l
+fOm2BczVSpgvfwEMt6EkvoNDe78LRRoXV7dzLaiJiHNOSqfEBTMAGTKItVL/9jrluHsNAAC/ePLp
+R5jND0QgSi0fZIgxRqLgAGb79YiCZ7ze6KCTplicKxA5kudhX94EUfDCPRdN+FLC6J5q9pkdwyYZ
+g6aLABIHgrmCnRb53d7slvAGUa+IhTEEUiIUAqFzICUTrkaBOZvOcjAWG0YqgZebu8w03LZ3BmVv
+H650LmMriuw2tY5RNJqQpISuKx4NpMRGK8J8+Uhhd/G9+Ortn4ZkthnFs8kykpyT9IRh4KnRFMUt
+1TGaHn710Z88/rEC4KXXkGit/5iMuQKgCyAhAw1NpFOrr4p978XpmVGcoh2n2FurQGmyoZ9T88Uc
+eqYFvML3ZCu/6Ikz7saiEYFo2X32KASr5alejqL5CAsn71/Tx5Bpm+x/JbOgoAJYMl+kmGvLUt6H
+Zqch2FE0ulcQxWnuNPpCXKMNs2zonmoZwLw7NpUDOQsljfO5GIcWjCUAumTQTBNzKenG333tDKKP
+FQBEZL7/Rz87xRj7D8aYRhrHXSJKlTJGayLG0ZfpEgXiKE4tD1+SEgf3TuU19L4Q+TRQKXqxtiLb
+JSNgI4DMBmdOneDcbUcPF9cvuwt4FBxVcPgAQnCUIdiePqtnoNz7/YDIjtXjEspteFFyGiKQEoG0
+vXjSFZkEzJql/bUKBLsbl7fP5NvRFr9P8Cw5hdzX0DorKlkstMY1ACxgrhYgUQah75PneYYMUqWp
+a0hv6ZTWjKZ/f/aZn56elPe/YQCwzhzFy2dOPUHGvMY5b+qUIpWYVKdk0q7NRGcnHyeqUK7FsdmK
+0EoSHNhTsSo9tE5UKZS5Pc27fBhD2YVvZc9DrHWffyAd/24FmpE7KwB8MHY7GJsuuDu9LWEzgWcg
+sM+T/HkGjIBf22KvjC0PlxwoBbYC+paZKQj2SWzFr1tzFViH0jg20hN27pDS1Df2VQiBRpTAzk0E
+gKsg/BLvb/wA3UThriPzVAo8IzlPuWARgCZjbKPTUKfOv/zcc0+f1DE+wo1/lH8+/ljzw/UPfvlH
+RHRFJUlbK5MYTVp4zBhjKNvlM3Txeaa2VzaajlO3BE5WJZOkli9QrsEy8+Sz4smYNHxnyzPhywGV
+ak8pAtF77vlhMLYfjAUuy2YHP2WbRVhB25w6z80DzwEy7DKFQuRxfqwMAikh2K1Q5h10lcr9k7RQ
+sq0cF5KFk8WpqyubLSjzKghPwdCTWGm+ifdXtnBxbZsurTXM3pmynp+rJoHntZVSDZXqy++9+OL9
+x35YX8JHvF03AJhb3m+cXDnd3ar/gDG2ZZRpp12dJJHRZEAEQ55vKdjQtVkpR64sbW4j9CX2Tlln
+sFc/1584ysiXLE7P7K8VArumn8A6d9NOrTZghzzeBeAel2qdAzAHxmqu3i/s60q2AClWCfGCD9E/
+H1EygarvIxRHQbSCdpqi5CjnzFexxyuu4QhyYivTkkrh8vZpnNtcwrkrdRhjSHJOjDFd3+4kW81u
+WxNta603ln+x9fBjf7F6tiiHjwUArHDL/nRhBa13nn/l+0T0jtG6mca6G7dUqlPSAEi6qcypa63O
+qmsurDcRcB8H56rwXeOjV8inFwsxsspb7jxyGnLOGW3LEYIozYXLMAOGRTDcBoaDYFgAw50ADgOo
+grFszpHv7rKvRDwDhZuVkWuF3rb0h0DURGxa/drI9A+JzB1NbkGeJamMMbZiiDHU2zE2mzHasabQ
+l8QF04yxVBt0o0Q1G41WPeok75x95qc/VhqdMXL5eEyAIyJw6g2sXXr95L8QnlhRiWqmse5GLZMy
+cENEZByTke23AwDdKMFKcwtlXxbGpiLnA7yB7dM8N3mbZYUUA4IXLCicToJsoFP/oEfuhDzvGkOm
+cvXf/5lir4B0voXvNIHVCqkxkHweAEds1nJCSfB+HiPLL4jCbzDn0GYmYM4VmSrSSJQiTzBKlDFk
+kALoEkwzSpI65/zyyw/+6A+fPqnXcYNufLcqf/DPWUfG8ROdpctnf/FPheQbRlMzKPOIYNJWu2sy
+8irbJFIZm+G6sLaNKX8K81Oh3RXcXfPAtwkfxhiEyzYGrjqIWC8DZldg4FalcTa8V9nbez545w4c
+VaslmMg/m03a6mkEgOcdRGEeP1hGcQGaLjoVL3LHMGc2ZW/2ABf2XCSzCaPAtc8BwFwlwOp2C0lK
+MESU2OR/yjgiY0yz1U3rUsr1n594/V8dP9FZGrz2E8jpowFgjPD7DuQvHrx4YfW9t/+YC1bXmppa
+mdhlD40xhtpxSklqvfzYNUVsJ9uYKYd55k9yjjgx0IXNFsuOxgWsBiiyfAaJW6HcxdAcjFXyKl/C
+1QIY0Gfbe5XAvJDaTp3DmJXUq8L/qdxxZOxuEJ0vhKraETfUZwp4YUaCdpnTauBZU2aAPbUSAl5G
+s5NQmmrqJsYQUUpEcZyoptLUmK2GGy8dP/Pd//3f3/xw4Nrjo4Lgek0AG/LIAeinj51/vLG69j3P
+53WdUlMbFStjUiLSRETS7nFo5+F1Y5xdqaPq+3kCJve0C5x8Vykol2sgxhAV+uGsk+b3qXKi1HUx
+bQJYBeEDEC47ILQArIGw5lb0fGH1ew4EuuAYhtf4BIwdBbAGg1YhCSQsL1EoTol1L2rJUtVi4JIf
+mqtitdWgRBmKtdaeYCkRxUqppjGmUQrE+lM/euf7j9z/3Gu2+g+8sOjYKBDcTACwEShkANhmE+0z
+T798bOmXV09In28AaCZxGhttKeNUEyljyBgDpRSUMmglCY7umYYnOWKt8+pd6cbN5Hv1ceSkj3LT
+yYg0DNTAKSkw5oEodiDYBPAhCGsgfOiGPy65JFLV+gRsNmO1B/opVOF14rQLd9Tz4Pg5WxwaSKvq
+PXB0lUJYIIS4AwjjQLXkweM+bbQ6FCtljDFplKhYa93UBvVS6F995qfvP/HG8ePPbTbRHnPtrxsE
+fJfqf1DtD945AP7aGdRfffSp/3nprfqTgsvNVCXNJNURgJSIjNFEqdakDdDoRFhptCCYhz3Vst0M
+0mRMn84rirM+ul62r0et8nyGb9blI53wMwF2nEpvudBwuwCMJfeZeTB2wEUPRVMhC9FApjHWBjqK
+0NcnEKtefWEoBCKt+0DgcY4oUTgyO01rrRa1uqnhjKUAIqOpqTTVa2X/6osvn3vy1EOPPPrCq2iM
+ueZDNcGkZkBep/AxBAjF1/yNt1E3Dz1+P/Ct5FNfOfjXtNZG2cQ3+dL3yEDYyh/JNpsxrlS3sVDd
+i41WB4L3Bkjkqd+sqkewXANI57xlGoBfg2sDohiMZQUYiWMBi9R5xsJl+xgdBmMdayYoMwsGgOc4
+BPud1jFUzv8wSN2UTskYNLPCT1mvumgwZK2FPikiWm20dKJ1CiBKlGkCaOybKW/8+Mm3f/yzBx46
+9sKr2NxB2FR4TYVHMMbYTjQx/wjqf/CAeFELAOCnz6L5/T98/P4zz51/VHpiI0n1lkp1J0514iqM
+jdFE21GCS1dbABTumJ9DM1J9YSB3NGo7ThErg1gVV54ZshKjgQuu3arnTtBmYA1wEG2B6KIDgwRw
+xCVkMi2wN/cXGCs5U2DXT2p6TmXsWsczNc8FQ80N2AxdKlsR0d5KyVza3FZxqhMAnU6st4hoc+90
+af3ET95++oF/+dBDL7yaHzQfsP3YSQNMLNBRABmiQkb9eFHwouAtZXSaLAcI//Y/+frf/dw3PvE7
+QSDmGGO16UqpxDn3fU+IMPC4Jxi7Y2GGHZ45jJXmMurtGIHP4TnKN8v9F/P1vRq9jK3rj+kZq4Go
+C0A6z37BAaFVEKxxnr/o7dgNOOFXLVmEKRc22l1ICUsAPgBRE8bJKPtfRTof85Z3STNr96u+T6lR
+FPCqYWyfBsLk3bVT3fPrzWYlEA0Ovv7nf/764//jXx870YnRdbZJFx6L7cjFohAqaILi82IByQ0r
+CBlp+0c8F50Y5tgDzz3c2rjS+OLvfelvzc7W9m+1u2qqHFaMYH6nG8tS6PMP1rb5VHCF7a9VbM1f
+rG1jqQGUMnlzaYXZn1Wk81P1uJ+HgdzF+Vb4mR8QDNht7syDcA5jWhC+cA7ioptuPlMkcMGw4KKI
+di78zOYrg7yCxxPMFaEICDZLwB1GiHnDMKUAkyh6sL202WrOVcP68tXtKz/8k2cfeexPT73WiXNv
+vxizDgrWDFnxu84KXm9F0G6AwQDwzSb0Ew+9+2y0vbl992/d9zc+/+VDt3cjpbhgFcl5oJTyjOTi
+3St1fnT/NFuYrrClRguJMijJ3qzBUiALSZjB2N5eF3vF1ACzV9hFlFIw5hVWvR7QALygyPjANVfO
+b6jCtiCUQGhDsA40pUBhA0fBOQTziLEDBNxpGOY1EKZAJyacar94bnl7cbZSf+yFd957/v88+diz
+x5fPbzaRDrmGZoi6vzFCm9AEjLL3xRUvCo+iYAaKdw+AuPczWPzC7/72t//6dz735XoznmaMVWpl
+v+wJ4ZVC6VUCj986P8VKUrIrW23GBcubOriwuflMrUpXkp7F4b1ijkwThIVw7SiABojWXbq4X+1n
+ILHmAs7mL4JhIX+fsAngsosgkj7GEFBO6xgAigBOjO0hhnsMsDcFkALbHcLp9oXNU1uppvp/+e7J
+l948/qOfnTyFulPxKXqNgWpA/WcmYNAUUGEFDJqE3ZuAHUKISaIANoIsYgDYa2ewfvnyTx5e/+Cd
+5b/zz3//rwqO2WYnScqBqADwU01+ZbsjDs1N8VopYFudiMG332O0rcMrDdT8KdJDViuHQadAFCV9
+79v2+cwXUO6z1dwcMLZmPwc4vyFxPkQDRHFOBBUrgxVZnsMlwUwo9mhgry1UwGqbcKoV6ZWtKNWb
+/+YPHnzixR+9debCCrojVvq4cI8VPf6B59fIcxQIhmqAMQ7gTs6fGLgXV78opNvy9+79DI7c9/d/
+75t/5VufviNRaipVpup7IpyqBH4l8Lxb56cEGfArW21W9iWrlQJGRDkA8pm/kvcKNbLB1nmRRwiD
+CIJ9EkAHmpYdKHwMmxNkEDluIeshkCCqF4DVQmwSKGPAXMUSAOoqRWRAiVImNUYDSPeUSsls+XAE
+mFaju9zsKtX408d/fu7p+x9+6vnnuldbEdLCqk8HVv0wDTCoBYY5gxM7gh8XAMSAGegDxlQZs7/9
+N4/e+9Xfv+8Ln7ptYR/nvBrFablW9sNaKfAWpysSgOikKQfAy57HnDlgAROFvLt1ujLTUNxmFTAQ
+7FYAPrQrFsmSSD0eQealYln4KPk9IDrft9q7SmWCzz1vMjBbUWSISEepVsqYVBNFkomOL3mrJOX2
+C2eX10/8r+dfe/mxU2eWVtBtRX1CH6X6/58HgMhs/8BrbwAY4Z234pZv/L1vfuXIb+w58Fu/+cl9
+9XZc0cqUpqt+uDBb8chAxkoJyTmXkvOQS8Y4GOccJSnhCcYG6wSz+UCSMUi+ALvnz/lx9Y45Yxel
+KSr+p9BO3rFZSGNowOOmrlKGDEycpjpRRnUSZbN4mrpcsHbZ85onXn5v/fxb65dffujYK6d/gQ2l
+oRLVJ/B0YMX/fweAcdpAFLQC5wwz9/0lfvi2r3ztE3d//fbDX7771lkDU2520/KeWinwJfelYEJp
+kmVfcl9yzhhjvpQMACtJyfr28wNYlp0re7NgbD9a6VnLLXCb11fG5D0CWaJJG0O2HnEftqI1MA4i
+6w5QZBQZTSbV2gBQcap1V6nEaIpTTR0i6lRDv/Xsm+c333jm/NL5l559/+TzyeUoRTQgdDWB0H9t
+AcAGWKpJADDML5BDtIFfDTHz+XuwcOAzdx384u9+8eg3fvP2mW6sy804LVUCEVQCz0+U8QJPiNAT
+QkrOPc6550Zll6RkKQx81kOClJxVvQPYii+NLXBxdQkU+hwAp41WhwCQE7hJlNEAdFepNE5MopSJ
+DUy3Enidki/bJ156t3Hq2KkPLp3+5crpM1hrRTnzNGrV6+sAgBkSCdwYAIwJAzGw+tkOAJgUBGII
+CDiAUuihdnABcwcOsZm//I+/8+lv3/eZmZLPS412XPKECAD4WpMnJfd8yYUUjPtCZJqBC3DmijCZ
+MYYtTs2jk25hK0qyU6SCF0+Zw0xExBgzjDHTThJDBqYdp5pxpFGs01TrhIPHQrBuNfS7gqP70E/f
+2Dj+n/7s3avraCytYitK0RoixHSIoHcjfD1C+GYUGzguDNwNALCDGRgEAB8h/EEgiDGaIfuOwHGx
+lTsOYfaerx+Z/+Y//Nahz9+xWAt8HpQ9L2hFSZAo42lNUkouiUiEgRBGE+eC8ZKUjDGGauizkpTs
+aqcD6RozGQcZTeRLjkYnodATphkps68W6EYn0XGqXXSHtBzKuOzLONUUdxLVffPcSvPEA8eX3jp5
+ce39S2i4ZENUEKDZQfB6gudmiPqnMRoANxoAO5mBnXwBMUGEMA4cxfdCACFnqHzpNzBzyx2LM4t3
+fX7PnV+8Zfrg/Exp/0zVn6p4XqqM50spCEakyohUkyAiRkS8FErWjVSxNJuMJRCJc2ghhC75XAdS
+aiJK23GaxqlOV+vt6NKVevfdV1Yay2+/Wb98dnnzjTPYTlSeb04KdKEeE8rt9P4om39D1f+NSgZN
+4gvs5B+IIep/1GeK7/lZXfdUGaWvfq00PXP4jqmwUgtLtVoQ1oJwZiEM9i/OhLO1iqhVAj5bCfhc
+NeSMMRYrBe06bQVjtNmKzOZ2pNYbLb18caO7dSWO4nYcR61W1G3Wo/qF97dPPp9sdWJEAGIn8LSw
+IvUIQZsdhK2GCFrvwACOc/xuGgAwQAdjjBbgOwBgEjDwIaaED/kdXggts4jCCz14Rw4iOHJnOfQr
+VY97npR+KPxyVbDevuzGGGUAGBV1dNJppXFzO7nwbqd7YQlxlPbF6emAsMyAYHRBA5gdVrUekemb
+RPBmwOabUZnA6wbAhKZgnFN4PUAYFL7Y4Xv4iHz5qPxEMY8xSJ+aAbuqB0ItGvIZM0JIegwoBgWu
+JhS8HnIMwwAwkeA/SjawqGbYQGqSD3Crg2qJ73Axi3fhTrooRFMojBylCdiQwsndFEzQkKRK8Xj1
+mGPWYx71hCt9mKM3Cogj1f7HlQ6ma4j0/lVVPEgxIHQ+RNBixCoXI/wMPkb4fEQF7SggDLJ8gxd8
+2Othwh/1t53s+jhgDSN8RsphN93Ck4yKpSFmYMcMlDshNgAEXnjkA2DQY1Q+GyHwQd9j1OqfRBOM
+WvkYIoBBwegJQKGHvB73eZrQ2btu4U/kA+zCOZw0VGQjBDnKdxj3WTZm9Y8DwCQgMGPMwCgg7ASA
+SczIsN82I9T9RxL+dQFgF1HC9YKhuNrHvc9GqHo+5PdGHR/GXNBR8fVOTiENsd80hLs3IwA1itXb
+NclzUwGwSyBghFBGUcpsgkc24Ws2hMfADvV0NMKJHVaBYyYABo0R+OD30Ajh35AVf8MBMKaCiE1I
+Iu1EMO1G6BjCUeA6ooFhBZgYE3ebHcwETSDgUUzermP7jx0AuwTCMAGM6jOYFDyDv8GHgGGUVqIh
+79OYUHY3Qhx0IjEuaTPOubsZwr/hANglGLAD1Tzp38clrUaBbZLjKXbZ0BCwmB0AMs6UDD5nTrAG
+H/PtpgFgAjBgFwBhEwhvnHpnu/y9nfgOTKCmx3rshTQ04Vd4Y7/i398NSNiEr3fTOTvsO0ZxHDQB
+d4AJQfErF/yvHQBuEnjYdWqc3WiCHd+jX+OL/H8BIzpUmyuOJH8AAAAASUVORK5CYII=
+"
+       width="48"
+       id="image2257" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/wifi/data/misc/old/link-4.svg 3.4.1+git20201022.a0d3415c-1/wifi/data/misc/old/link-4.svg
--- 3.4.1-6/wifi/data/misc/old/link-4.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/wifi/data/misc/old/link-4.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,474 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="48px"
+   height="48px"
+   id="svg2160"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   sodipodi:docbase="/home/changfu/Documents/Install/Cairo-Dock/plug-ins/wifi/data/src"
+   sodipodi:docname="link-80.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="7"
+     inkscape:cx="24"
+     inkscape:cy="24"
+     inkscape:current-layer="layer1"
+     showgrid="true"
+     inkscape:grid-bbox="true"
+     inkscape:document-units="px"
+     inkscape:window-width="762"
+     inkscape:window-height="635"
+     inkscape:window-x="10"
+     inkscape:window-y="65" />
+  <defs
+     id="defs2162" />
+  <metadata
+     id="metadata2165">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:label="Layer 1"
+     id="layer1"
+     inkscape:groupmode="layer">
+    <image
+       y="0"
+       x="0"
+       height="48"
+       xlink:href="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAIAAAACACAYAAADDPmHLAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A
+/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB9gDCgMOOkBt5DMAACAASURBVHja
+7L15kF35dd/3+W33vrX3RqPRABrAABhgMPsMZ0gNl5AUl5FsUZsteVEcW4oVy06lXHaVq+LEjuxU
+2WVXJX+4LClxrKikkhPJNiVbsWyREilalDgLOZzhrMAM0AAGe++v33bv/S3543fvfQ1SZdkekjYt
+dtWr7n79+i2/3/md8z3f8z3nihAC3/76w/ul/0v/gEIIDZjypsrPrH6fhwbAAkV1CyHYbxvAt85G
+K6BDpzOL9228b9FqdcQTTx6VRp/G2rPe+UNIeUIavYi1oDX197jpV4FXgNeA18X8/DWGwz5SDpFy
+QL+/DfRDCO6/mHX7Vg0BQghRbvgCU1PH1ZEj9yHlKe/8aSk4ipTLwLQvrJRK4n+/j+l9/C7lXT9L
+JeN9WnuB2A3eXcfaa2h9Ae8vuOvXXyfPL3HjxgYwCN/CcfRbzgCmfvy/00Kplb1nn/0BmSYPeecP
+SKNP+sKuAgbv42ZWp7v6cjnBObB+cp+Uk4VotVEzU+ipabzzBG8JoxFhNI7PI2X1+AIprwBvAut+
+NH4p3Lr5z7l27dq3omf4ljAAIYQ4/TM/ra8/89wnzPT0nxrfvHFPdvnKSalk0xe23kgpwDsPxZhQ
+uMmp1hKBgiRBdjuIJEV226ikQfPwMrOrxzBpwrg/ZvON1xlfvoy9cwesJXhXG4hUcmI4k9sIeAu4
+6De3fiG88vKvhhD8tw3g6/T1+P/7y0cvPfvMnx1cvPjn3Mb6Qb/XNygEaYv6tOf5Xf+jDh6gffYs
+S+fOcWR1lTOtFodmZphvtphpNNBCMpUmHEgbtLWkbx23RmM2xmPWBwO2x0Oubm5zYa/PjUuXWH/x
+y4xefz2+jtakJ+8BKbFbm6V3CQRbhBJHXMf7n3XXr//fYW3t+rcN4D/uxDemf+Ivnu6urPzArc/+
+1o8LqZfszk484WFf/PYeaTRmZYWZ+x9k9f5zvP/ICueWlzncatNQmraeAH5PoK0Uc9rQVIqetewU
+lj1bIIRACVG+PngfKEJg7B2745xLuzt88doNvnzlIr2bd2jNzTHu98n7fcZbW+SbG9itTcJgGMOP
+97eBn0pP3PMrw1/4+QshhOzbBvAHb3yqPvCBR4DvwNqfFK12J11ZYbx2CT8a1y5etlskh1fo3nMP
+x+9/kO8+fZKz8wtMpyktdXdiE0JASUEiJXNJwrRSDL1nMy/oW0sIAVFufAiBAo9CUq2LF+X30vL6
+heXWoM9uNmZnMOLLvW2uvX2DjStX2bt6hezaVUKW47McaTS+sL3pdz/xN7LNzWdGv/hPvhxCyL9t
+AF+78YZDh86p1dWn0fov4v0htXRAzD7wANsvv4xb3wBrMSsrNFePsnTvaR47dg+PraxwfHqabmJw
+IaCEQFCe4jJcN6RiLjEsmoQiBO7kObt5UW+69R4hBA6PDAIhBCEE3L51scFT+FAbxVSSsJAkjIPj
+9mjM2u4uL12/xr+9dJHL/+ZT2M0twngUDcd5yIZBzcxfC979lLt581/z1luvhRCKbxsAIFZXp8WB
+pT8m260/C7yLPDckCYe+62n6d+7Qf/lVzKGDdI4eZfHoMU4dPcxjS0scmZ5mNk0JNc6LO66EQMm4
+udPGcLjRIJGSzSJnKy8Ye4cMoj7dMoj6lAP18znihhflyXd4rPdoKekaUz8uEJBSMCwcV/o9fv6l
+l3njM59h8OqrEyMIRACZJLlsd561d+78XNhY/2dhba33h9oA9LvfvSoazZ8PtngE6FakzOz73svx
+hx/l/Oc+R2vpIN2FeVZOrPK+pYOsTM3QNqbc6Ljx1YYKIUiUJLOOszNTLJoED1wcDBhYhyOgSg8R
+KF07oKXA+0AF3V256YGAD9FLVF5BiWgwg9zWocUTkAjm0gbr4xG//MbrvPjaa9x+8SuM1y6Btfgs
+R7XbyKkp3NbmHt5/0Q/7f8a/+JW3/1AagH7/+z+KlP8Y7w9XoE5og0hT/tLf/J/55DPPo4zEpCkP
+nzjOY8uHmGk0IlhDIiRooVBCEAi0lMaFQENr7pueYtEYtgrLG3s9Ch9qAFkBva/lgQNF8BghyV3c
+cC0leXAEH/+uhaShNVvZmCJ4CudKg4HCOUII3Ds3y7W9Pl9YW+NLG7e58cZ5euffJH/7KqLZwCwt
+Ydc3sVtbIOU1vP8R//xzv/2HwgCEEJIzZxb14ZU/Hwr7N/Bek+fQaIC1JCuH+ZM/9mMkRvGpV15h
+amGexxaWOL28RKI1ComRAoTEiBivjVJIEU/xTJJypjtFS0luZhkXdnukSpWZWqhDROUt9n/26nRX
+3/OS0/H7KMTpNGWQF+wUGd4FHJ7CeTLrogFZh5aS1ZlpLm5tc2Vrg1cHfW5fv8HGmxcZ3ryObnfJ
+Nu5QXL1W8RdWCv6G2939Wd54Y/2bzSHob+LmG+6/7yF9cPl/woXvxlqNlJAkiCSl89CDHHrwQT5w
+6hR/97c+zfyBgzy+tMjS1AzeBbwIeBxSKBAePCglCTai+IVOm1PdLlLAq709bo2GKCHInKvjNIAt
+ubrKlQc/AYzWxZOeleHB+YlxzKYpCsHWeBw3PgS8CxTOUXiL8xDwjLKC7WzMkZlpRkURDW/lEEJA
+fvgQAOsvFxTXblTklQb+lpqff8KdPPm/CiG+8s0EiPqbtPmJeOiBD6sDy3+dPH8qEKoCDGZpifbR
+VaaPHuZPvOtdPHNljaTVrDdfK4EvUX3wMT4779BCAZ5cwKmpGc51u2Qh8Fqvx+3hCC0lPgSsdyRK
+4tzkJCshGDmPkhAC8FUErgsB50PMEErjaBnFdpZRhIArGUYbHEKC8pKAJyu9wvWdHqcXF1idnWVk
+c067gFhZYXd7mwMHDqB0wpXtbdz1GzFLAC2l/161vLzg4O8IIX7zm5Uu6m/C5gvx8CPfpQ8c+Lsh
+y05X1CpSkh4/xtSxe2jNTdOZmeHU7By/df0a71o6yGy7XQIvUMIzyi0S8FIipSTIwNh77p2Z495O
+l4FzvLy7w84oQwhB4Vyd6jl87fIVskb/1nNXBgDUWYFzHofHW8FCo4EMgvXBsE4HrfcEooE5H18j
+hICzniwUXN7Z5szCAnPNNr3hkKOmwejAEmfm5tic32X2gQfoJQ3ytUt1uih9/pRaXv7fXSP560KI
+T34zwoH+Rsd8813f/YNY+zPB21mkjBg8SWidPMn0saOYNAXv+cipU6wPRxzXKbPtNtYFvCtQQaKQ
+KF0icA8JkHvPybk5HpyeIguBZzc26RUZ+H2xXKpyUwPexzBQ4PBBIPdt/H484EPMLhDgvWDsCmbT
+aXbynLF39SY7fJ0K5mXRqfAWIQTWeXaGQ3p5zhMry2wO+zAacWpugeMzc3z2+nUanWnMAw+w2+kw
+fPMCjMYgpcDa02p2/h/x1FNSCPHPvtFG8A01APWe9/z3oSj+HtYmKEHwDtnu0Dl7L93lZaJWA1rT
+s9x/8CCXN7dpGEV/PCZRhtQYfLnYqTAEAVp5rIfjczM8ODtDWyl+9crlehOqDTVC4vDgA04KFFCE
+gArgROlZKB+zHwh7z9jFbECVhrHYSHl5awNXggLrPZ4J8q82v3COwjmc9QQJN3o9Tk3N8KHj9/Da
+5gbvPXSIa8MBqTGoVON9wcypexDGMLp4ET8aVgWsGaT8BfHwI4vAP/yWMwBhTFO/7/0/Kjrdv0lw
+SVUwkVNdOqdP0144EF88UQgk5w4vM9do8NJohPUeoxTee3JXYJTClQtspAYEBzodHpyZJYTAL66t
+kfu46NXmGK1weJSSOOeRUtThoNjn5osy+Fd0sHPxf0IIDGwMwadn57kzHrOXZZEixmNLPKGVYGwd
+3nt8eZ93MUSMi4z1HtwaDvnIwSWenJulrRQDZ5nRmqTVxNuAzcZMHT2KSlP6Fy7g93qVPiGR01N/
+23z0Y95+9jM/F4pi9I3YK/mNKOToD37oe9D6r2HtbFwpjei06N4bN1+nDUyaIpBIozg5M0svK+iP
+x/UC3uVJiHEfoJs0eHRhgVQpXtjaogi+jusOX4LFgAu+PrG+jNvV77m1McaXt9xabOFwIf5cOIct
+Ef5qp83t0QiFxAZHYavn9IyKAu8jH+D30co2OKSUDIuM2+MhLSmZNYZESo612pyamkGrBKkFShsA
+2ouLdE6fRs5MR05EKoRUswT31/QHP/TdQojGf/YeQAihxf0PfKcQ4n8JIRyuRBmy06B1fJX20kGM
+MYiyru6Do9OZ4tTiItd3d8lCQJcoXOIRTpB7R2JAWEGzkfDE0gG6WvHC5hbXB/0SrDEhZUJAiUjZ
+Fi6idC0VznqUjh5BSBHxgIu0cPBgiW494BHI2r1PG8PbO7t1aLHB4m2os4CKIfTl62c2jxRyaShb
+wyFD75mS0bPMG8M9C3M0m03ybIS3AYEDD63F+VhwunCBkI+hcKDUKsH9pHj4kb4Q4tNfb9HJ19cA
+Hn/XYb2w8JN4f4byfYpmk+aRI0wfOYZKNXiPK0qmLVEsLCxyoNHk1Zs3yfBIJM766JoUGBEZPusL
+3rt0lMU05fXeHm9tbU0QPpK8cHVRxwVBTjyFwQakcrFQlEcXXtUOgo8lYi0jFpAefOnmvffMdlpY
+79kaDdBC0W4kKCR5iJvsAWfjYwFyV0QjCgEhIXeB/igjL/8esYmgbRJMI6m5CSlNLFbL6Am8Kxhe
+vowv9iJoFuo+fejQT1prXwXe/s/SAIQQxnz0Y/8kOPdIvCMi8ObRw0yfOIaQqtx4ixA6UrrGsCQ1
+ufMMsgxLlOVWXoDqhIbAE6tHOdnp8Fa/z7M3rkWcUObdCklubc3lBzxaKExpINhIGztsXTcYC4v6
+fSKg0hLvAlJKjnS7rA3i5ocQGFtL0ySRCLKePI+GUHmCyiCqrMICjxxaJveeF3s9TrRa9SsaE5de
+aoHLXNQiGoUvoHPwID4rGPXfnLwxa9+ljx79RdFsfjiMRsV/VgZw7//xM6bx/d//064/eE9l6QCN
+IyvMnDyJlAbn8hjblIpIVymkFCx1WvTynL18soE5kLhAEOCxLLa7PDo3x8A5fnvtMlmZbn01kNlf
+wg0iUHiLFIqAp8AT8LRMyiAfo4XC8rXe1OaRbSy85Vinw4vrm5EM8nFTA56ZtMmmHSCVICsiZqiS
+NVumnXt4Hlla4sz0DM9tbvHMtWs8uHyQp5eXmU5SuiZhXSqEEAil8L7AlzI2gaS7soLPc7JrVydn
+TKn3JR/56N8XQvzVr5dkXX89Nn+wufknbW/3R4TU9cboxXk6J44jpaEY9RFSI42KqZ8AKQPaNDhz
+4ABb2YhbwdEUghEeI0AGSSKhqRM+fvweihD4jctX6GUjQghlRkANyGQZY6sT7IVAKkFe5CgtqULn
+IIxxISCEn+T+pdum/h53syEUNwZ77A3H0WOVz+3SQKuZYocOi8SKSAoNfGAkPAlwvNvl8YPLXBsO
++fXzrzN2gVGW0dCK+6amOWIMl5UhhCFSBkLQd1GSQktay0v44ZBiawOExo/HyEbjL+gPfuh5IcQv
+fT2M4B0bwN7mxuPbL738PyJUUokz1VSXztGjqGrzkQgtEUFGAKajkZiG4VC7y/PXr1M4S5CKKSlx
+IZ4k4+HBQ4foGsPv3b7DxY07KCGwLqBMROVVdTCEULt7h0cFSSjDh7MeqeJrZrlFSklRVvkqqrf6
+uUontVE4AsOKWfSWUChGIZB5W1LRkHlbA76GAIJksZHy1NFjuBD41IUL3HSOnMB6NoS3LjF77izz
+3W4sXzdSbGbx3qKSFKVAKkPabCIOCmYOr7J9eY3h+m18f4Dd7SVyauqvqyefvAA8/5/UAJ785X+6
+7IbZjxU3b94j2x2QEqEUzUMr6E6b4C0COZFfS0lwDudANwyNpAXAxmAvAimpGJdvSuI5NbfIyZkZ
+3h4MeHZtDSUERfBYICkFGgBBBoKvJFwxBhch8gYR3AlCEDVecM4hfOQGfFlMCiEQ3EQG1pBRezp2
+BbkrIrIXAVuUfIJztEyKEoJd4SlC9BtH0gYfv/c0Wko+ffEtbmQjRs5hfeQLXsxzjq+v8x2Hj7C2
+tcOlvT55njM93eFsu81suw3A5t4et4uCjTxDpYqtZkq2vU2yME++tX2aA0s/Jubnr4TNzTv/SQyg
++UM/ZP7Ij/3ox1549gvfL7tTCiUQSMziIunU9D6mQdanDO/j7+WCm1SRectOVuCcx0tPIQRewIpJ
+eGhpCQl8Zu0iFhjiQIAOE81e7gLB+7pYJFWMwRUqF6IsJlFusogb7n30HlooMpujlKpFIsEHTFlG
+Hud55P09CBmrhy4EcmDsxrS1pBEkG67ggc4UHzt1io7W/NNXX+VSNsIDUkpUCHgi77A5GPDwsRO0
+H32UW6MBLWVoJ5qr/T7Prq3x0u4uWxvrFKMxrvDY0ZBsY4t8d3tCjcAfV+fOfa4MBe6bbgAf/bEf
+ve9Tv/Iv/pJstmeq3Fk2GzTm5u7ODsqNqXj5qOSVCCHRUlE4zzYemxUoFY1DKcnS1AyH2y0+ffVt
+1gaDCAxDrAMAFDaWZMfCY4NExlSapoNQGlzuAknp+iuQJr4K+Bc4jFLk1kYBSOHqcJGH6GWGlWco
+I64TnrwEfLaAthS8f2mZDxw5gheBn33hBa66oj71FcsoBLQaDVompaUk75+fI4RZntnZ4Z+ff4PP
+XrlMb32Lcb8PPoJWTyAUAdlMcbdGhKJOAGZkd+oneOqpF4mtbN88JvCvPvOF5qvnz3+i6O08JtNy
+S4zCTE2TzE4hlURy98LXBlGeLIFkRmvG3jEocgpfullnmUfx4dVVLvR6nL99mzEBCYwJDCEi+hAY
+4AkBRiWJ4wPs4Ri7wNjFtMyXP2dlbj52sY4f/OS97eU21vZt3Ni+DXWMH7pAUi6Ul9FLjWuYCJnw
+PHTkCN938h428zH/2wsvcMXm5LbAOYfNPdm4YDgcMBwOOZkkPH1slamyHC6EYCvLeX1vj2Gvh3dF
+DQLjBgmEETSnZkhnZ8EFhNQIYxBKPaXm5j8hhEi+aQaw8rf+trqzNzh1/Xc+/xem7zlNsjCPMAal
+E8xMl1AEgo7hIBqARWiJxyGUQspJqjYnIkOXjePm2zy6yCePHGHoLK/cvMUVm1E4z7As9uQllRND
+AjV3MMIzEtEgbIC9coty4u8QN98GGAYiYg8TQ+kLz6jM5b2c1BU0MA6T5xgFamNcVorvOX2ahxcW
+eHFzi1969VX6tqBwNmoMfcA7SzYeoIXmvcuH+dFHHmUzy/gXN24yKNlD66M32+81796keJjSuQVU
+p400OrKERhGc+wnzXd99/JsSAoQQ4kc/9Wn5a5//tz8ujD7YWVwgCE++sYmemiJpTSFFXPGgfX3S
+g/VIo0o+HpSJrr5pDOPgGGdDvHXk5JzpznH/4jyvb2/ze5t3ItfuLVorchtPjFeKAR5LoA9oRGkU
+ARBYETcuF54s3lVbe1oa5qh8jJ2IAqF8fNNLEhN5ilooKnwUiAIt4OGpaT547AQAv3n5Mi9vbdBF
+ooRkNBqVFcICV1hm5+f4+MpRHjm4xOdv3eTXr14hKwq2xvfxg6tHWevt0Nsb4H1cn0m40jhfunwt
+0M0Wptuh2O1ReV5vzOHg7Z8H/so33AAO/eTfEi9s3jnde+31Py2bLQKe+SNHGN68jZlql/w+CBPV
++QKJSEpXFyRKxxp7BIMx1SqcI7hYTSsY86ETJ+hlBc+tXSEfW7yz6NRE5K4FzlpyFTm83FqM0uQh
+VvxkeeKr3H6vPK16H8M4EjGLkPtJp/LvvkTyXSNZ7kwhETSUYOwCrnzMybTJw4cP88DcLC9ubfLc
+5ctczDJyW9BvNJhWir6UeGvx1nLfgWWePn0KJQX/6KUXeWtjnXwYDeT/GlvOzcV62e7OJsF6lAKR
+NiIxlBVIBJ6AsIEgJWZ2BjseE4poutJovBd/Vtx770+F8+cvfkMNoLO0qC793hf+DlJOVZz+mXuP
+snXtJr7ISyLFIjClVNpPunG1wvt9QkwhIx9f5um2GPPkyj0stJus7e7ylc07SDRBOFTQ0bVbS5E7
+SMtJDoVFCYkLHo2KaF/EGwgsAY1gXEvAo5FU9+flAlR/T4gCvZlWi6PdDtPGsDQ9ze3dXaSTfGD1
+KPfOztJQmp/7ykusZxm3ixznHK4I7I73aMxMkTYM2xt93n98ladPn+H81ia/9Mqr9Ha3cEWoj/jm
++i1+4/IVHlpaQquE3I9wLr5/KQ0ikbg8AxxBCygCpt2haDSwbkTwDiEVUsrZ5Ox9f18I8YP/oQIS
++R/i/heXl5eLrZ33C6PBKPZuXGfXOZ7+jvdAiZxVydBVlqu0qQFNqGRaMqYGQoiaO0dKHj6yQlNp
+fuXiW7jCYm2G955slDMejyjGMa2zhNLdQ1bksR5/1y2QOVf391UeoQiT/4vPAaMQyEulqAQOaM3q
+/DynOl2ONRp87NgJvufsOf7bxx7j8QMHuNLb4x9/6Uu8vNfjVp5hraPIHbbIyV3O1Tu30VLx8XtP
+8T1nzvLFGzf4uee/SG9vB5vFbuMQAj44goN/+tJLaCn5jtUjuKLEHqMhvnT9Kknj+tsQaWKh0d3p
+iKfSRqwhpA1Us/kB9Z73LHzDQODpn/lpfevq1b/qi7xbAbzx1hbXrl7l2MICD7/3KZyNbzoUIboz
+aQglMeP3iS+kUEgTUXZqDFIJTh9dZb7R4s3dHXa2trF5Hitt1lEUYxQKW9bzJQJrHVU5wNqqlh9T
+rxDCXbfCRXBYaQwL57F+YgxKqfJ3aJmUM9OzrDRShBC8d36ODx5YZNYYXtrc4Pmrl7lUjCNotQ5v
+A97G2oQrLMW44OGZGT5x+gy/cfEtPvnqy2TjIW5c3FW/iADZMe73+dzlSyxNT2MSEzc50aVnLAjC
+kzQ6yCSpB1koY6osAGFMWVsR08mJ439ZCCG/IQZgdHK8v7HxAWG0FMaAixa58eZFXt64wydWj3Pm
+PU8gtUYKkGWaU22ClAakxCQGaRRaGWaabd67fJCnjhzhg0eO8Mj8PBfX1xkPh3gCthjjckvwkBcZ
+1mYUecHQFgxHGdkwoxhH/iAf29oYxnmOC57C2doosiIvQWiFvF00HOciDR0iqn/w0CEenJ6q5WAA
+vcLyu3du8fyVK7wxHlEUlvFgTDbKsUVOYTPGWYzrHzp5ku8+eZrfvHyZ3756hdHekGAndYeAx7uC
+4Fyd8v3enTvMt9u0Z6bqNLnKBnxW4MoWM2Xi9BLdjgYR8Ahjqu9KSP1x8fi7jn5DMEDaaT41un17
+VZo0JmKly/fB8fzLrzEjFH/q3rN8Mk15643zZHt7dQYgJARh0UmCTjWNToejC4uszkxzf6fDn3no
+YRIpWUwM1wd9VLkIXkqsK9BACKp0geB9E28tNliEF/iBR2qNH3tMwyClrDe6OuHVplchQkqBK1m6
+Q7rB8Zlp3rWywpPz8zSkJPceU4pLv7S9zYvXrnGh3HxnPYXNQEqKYvI6/9XqcX7g3Dl+/a23+NTa
+W2ihY7k3n9DNgqhojsRSQCrY290lhMCRpSV27mzGx5bvX+i4hjbLEUYgtURaj+628du2VA/pSoq3
+KpV8Crj8dTWA9Hu/b+bg+556XzIzM5VtbOGyLFqqlCipKfp7fOqlL3MrOJ4+cpS3O11+6+JFNifd
+L2itUVLT7s7y2NICHzl1mqcWFtFS8q7paYQQnB/00UHSbE8xGvRqD+J8gSpPj7MKax25ywnOR3WR
+hCpb8sMMKSU6NfWpE8LX2sCq06edNjiVNDmyMMfx6RlW2m128px/+fZVCh840u3ywQOLDKzj81ev
+cjnP48kfj/DW4mxsKAgu1vI/ePw4Hz19mn/11gV+/dXXKWxOe3oKrQwOCyKiIl+xtt7jvSUgGe7u
+8eLb1znb7XKh3WC4vfu1G2U0RT4mCI0wAtNu4/O8ZgbteAwwbVZWPiCU+pfBub2vmwG4jfX7d69c
+eVd74YAIM57xxkYtnZJJgneevD/ipZde4s72Lt975gw/8vCjXFhZ4bcvXGC0twdS0uh0uG9+ju85
+e44PLS7QKI2jio1dpTk5N8fVbBjdfZZFYsYHkDFdlCrU2MC7AHWlr0BqRRAS6yzFqCA1zeiiAW0S
+dKJ5oNXlzMoyK60OLaNRCC72dviNN87TC44dAjMI2kjm00c51GxwdbdHLxuRjfLYMOojq1gJQd93
+7CgfPX2a569f5zfefDOedCXJ+iPSTpN8PJ6MmkHGzialEK4Mkb7gzWGfs0tLJCZlJPcxqGX9JHhb
+q6hDEUiabfwow4oRPs9RSQNvrTRz80+MT568H/jC180A/G5v1Q+Hx/o3r3P2Q9/Jy7/+/yGkRreb
+JcJ2SCTF3pBbb1/h/7x+gw/cf44P3HMPTx49xvV+j0++9ipp0uSRlRWemJ2hqVSNDyoDWEpTHlxe
+4vWtDYY6xn+tqd15pSVUOsq5bDEmaTTxrizwWIfzkcsXSpLnOScXZnji0GFOz87RNVGAmSjJ9cGA
+X3vtTV7c28HmHr8vexqYyFB+9tpVvuvYcd7OBowGWaSeQiiLTgIInDyywvfed44X79zmV19/lSLL
+cM7VIE6nhuZUh+HuXgSK+8QsSsWsyfmcwd4eaaJpttvsbRmczaL7jycAgUQbiS3zfyFBtzv4YAnW
+gwiUy3OCRB//uhmAECJt/Td/5iRCddw4Z5yNOPjww9z60peBJsFbCAqviyj+yMYoCj77lRd5Zu0i
+D584zvuPHecffPRpOkZzIEmYNvvd82Q6hxKC+aRBE4m1GTbEGKeUwpcnSKUykj5K0Gi1UCrFtA1J
+qllOUw53uhybnedQt01HG7SI8XzoCl7c3OHlq9e47Ap6u3v16xe+QAuNwyGCqlH967c3+OjRVbTW
+QFa/V6liPJ+Zn+EHTp/hyl6Pf3XlcqkPjNlJCHGXsmxMtzPNSPRBSJRK6hTPFR6lY8V0uLvHeq/P
+fXNzrN+4GXGWpS4ISSK9LkzZ42iLWFgTGm88FEXMdIqi0333U8eEE4WZLAAAIABJREFUEMm/T3vZ
+H2wADz2wKqT+GMGhGgmXn3uO9/3RP0p/fZO83wehEFqilSlzsoAvCdZh6PGFl77CS2trfP9Dj/LH
+ztzLocZE3fz7dSafm+ry4VOnmGk0uJUN2Q2BBEE7SNpS0EoS5rtdikOWlklZ7LSYShJmkpi2DcrR
+L+uDIedHYzaHfe7sDVgbDxgMBiSmEVm6EKeK5S6PoJGyyUO4WrN4ud8n84HjOuUVMcAHBcKhdYpz
+GX/6zH0kSvD/XLjE9sZ27a7xEW/ECpLHBkt7bprB1i4+uAgEifI4H6IMbJwNeGN3m7Ozs5g0xRXj
+WIL2URsR2UCLLDmVijOYIF2BiHsggI+KRx/7JeDiOzIAIYTo/uifO+wDD6NMdDUUnH/zEvc/9R5e
+e+Z57GiI0GlscpQSKSBogcMhc49MEvLhiH/5yisM85zpxx7leLN51+nf//OU1jx9aJl3Ly5wc5zV
+rdhSCayPgo5ESbazjL28YHs04k6/T144+kXGYDTilrWsj0aMh9k+jaBDoilsNmkEKbOAu3sQVJld
+KLwbMrAFB6emeHV7Gy0F1oG1Gd979hyHu1P8+vnXuXbrFlKJKHQRukb5zheRlBoMabanIhAsdYVR
+KhFqzQTec3NvyJPLy3XVNNii9gD7M4KgRZx3ICWurlGHSLgZQ7D+8e4Tjx8WQlz6g4ZY/kEeQPog
+DkgpU28tKtEgFHfeeJXFlYM8+N538+Lnf/drDcfGiiBAKFu7rMu5OR5wfTjiSJr+voMaxt7zqdt3
+eP7GNXaGQ8ZZQV6xeMQUMAmSjlFcKQrG1pIVBbZw+LJa6ErCSQRVb/z+30VQaClqI9j/vSoaiaDQ
+SuK95mqvx+r8POLatYg9soL3HTvB+44e4bcurfH8rTsRf7gQN805pNZ1Gmd0ErMYKWh2Wwx395Ai
+nvxYHY2e06qcQZn5tKfb5MNhlNEh8TbWBIL1cZOtrz1YSbHWxiG0JEADoRZLnse9EwMwUuuTQimp
+gqvdPS5w6YWX+Mh7n+LUY4/x5nNf/JrxyxJR56ceh8sd64XlxmjAeHqKzj6iqDr9t/Kc565d45nN
+dTY3N2uUfdcbahimpqbY2dmpPYcsP0YQMYYH4WINgbjA+zdXpwaX26/xPPt/VyKeSikll7Y2eWp1
+ldNTU1y3OSfaXd534hib2ZjfuXNzYnByv1inKn8kJdCF3t4OM7MLjIdDggMpJN4XSF0aYYg4YJRb
+jh1YYvPmrZIrsBNthY7TUGI2JEtPoHCUtHErxRceaVDAavlm3DthAlPgvXzV5ocQGO/u8LtvvMYH
+V1ZYPnO6poG/Ziav90iixe/0dvnKrVtciznrXRvQs5YXNrd4a3ebcZ7fxSJWiytkdNGJ1ne5bhfi
+CatOuZEGhUKbJCpylEIohU4NNisiI9lIkFqjtInsZXnTqYlizVQzP9Xhdq/P0Vabj5w6xXsWF/kj
+993HjEn5B19+gRCitxCqBKYlOBWydOEh3EVECQSJSescr6LUq1qILSy9bMTD84vI0pCE1NELlGFA
+IiaTURGRUi/FKy7LqXsyhPoO4A9sJ/t3G8DMTEum5gOV3DvYyAAKISA4+hsb/PIXv8gPPvggK/ef
+xfuiRqmeUNeyQynBHvb7vL69zedu3mS3KMi9ZyPP2chzfmdjk99ZW+N2kZON8hpty/L1lP6qk1oz
+gwIlzL5TJ7GuZAaDJ2mmSCExSazvJ80EKWL3kUmiDrCSk0sh68c0kpSTaZPvPH2ak60WP3jkMH/l
+oYd5Ym6ON3d3OdBoRrQv3F2DpoWY5PAqiesmiDF+b2ebdrc7KY6VYa3qkgrO8Up/j0PT3buwQcBH
+j2oDNo+MoK/GlwiFNCXZljZj2Ii3DzM313xHIHDqh39oCRcaQsuSxizn6BGiRxCC3q11fv7zX+BH
+nno3X1lY5Jnnv4THoipXuB9kec/bWzucb9/h8tJB+tZyfnub4zNTvHD7Jq+NBoxHOW7fhJS6fars
+M6w8RpIkjHMb47XRSCERziKVxqi4qWnDkI2L+Ld9rl4nkzlBacOQj23UI1ZydaU5KhT3HlziQ0sH
+6nDVkBKnAmdmZjjfbtPzniJ35BXPX7KCUvl62qg0KhqEpVZNG53gZEHIJFKqGrkIpdjd2cP7QGOq
+zWhvjyAlohw/E9cAfBEm3kGI6ImMibhCgBQa5+30zI/814vA7f9oDyCkPia0rF+oBk0muklRqi/3
+1tf5hc//Hkc7HZ5+9xO0FxZrpFv1A1RduqPBgKwouNzv85m3r/CZS5e4sLWNEoLBaERejCPFKyau
+cb+sXGlDA4FQEXGbxJSnKSDLKaECgRTRaJNUY1JVv38pJ53GlVGkTTNpaJGKplIsTU9zYnqG2ZKz
+CPuGTB1vt1menmZeSdKGwUhTd/gIIZDleNr4ehNjw3uKvCDtlFmQVLVsXiCRMjAcxikkabMZNQGl
+t6jChdSRCpaqPukoqZFCoYxBCo1qNSpvsPqOQoDQ8lgVX4QxdxuCj2qdSEbAYHOTX33uOYYu8ENP
+Ps7i6tHSdal6YQCsy0mUYXM04tNvX+WtXo+3d3eYb7bQWmEzW5+eygiqmB4XOb7pSkH81UBOJxKT
+KpJGxAnV+9VROFH/rpRClZ5BMjEOgFkk7UbCQpqQ7PNgvrw1pWAqSZna19qlhUaLSWdU/MylF1Ci
+xiF5NiYxDaRUsT08mYhDpTLk2QiHpzs9Xd9fGUENOG2cX1h/bjV5TJV5CS2RQr0zA0CoRaFlGfdB
+6IjspdaoZIIvvItpSTYY8LuvvMqzm5v88AMP8+S73kUQPn5QY5BSoFXC8swUvSJj+84m2XjA+t4e
+RipSkyBktHJldEyT0DWw1EKjlKS97zQkabylDVOfZKN0vbmJNmipyi5ghZZx4ysgqaVCqXh/ojWq
+lJvFEynIS5zxNZmCijStKhFqZeQiqNoQqs9R4Zn6/4mbrcr+SEUE2EIqXG7JreVYsx21k2Gf9ytT
+RqEnF7iQiUGqfYdTx7qBVgYhxIF35gGEmJOlB5BCI1B1nBRaIpUmCF+76KqJ4bUvfpFfOX+e9x89
+yo9/5CO02lUbVJMHDh/hqUOHY7uWUXgfuGMt4+A4IBSNtHmXy92/6NUJlmWc1kbuI8LiZhoVF0Lr
+uNHex6kfRukaqccpINTeoHpMvI96/Eu/cDSkvMv9uxAYOo/zUVksZQSPlRFIwYRS9r5UQZUyLxXL
+vFkxotVq1fR25A8iePdlF1JXxy6qiiuIBkIdLlSqJ8ahIiiXSRKxmYyHRmg59848gIoWJMTEzchS
+4iWEwOajukIlRbxVYOXWlav89Oc+xzDP+Uvvfz8fvfcs55YO8UP3n2O5kbI9HtJuT6ETw2Y2pj8e
+88DSEs6HeNJFPM1SgEkMppHUuTklg1cZhFEaT+wpmKDbuLkNrWPI+CreKS3zfSXAKBmNSoja1fey
+Eb191yFw5SCI3Hu2i4Kt4ZBMRAmaMrFxtDr1RqfxfUtTl82pmlcTjfeeVrdF0mhO+iTUBPNsDUbM
+tjpIZSJPICayubsaRoSvOYIqVFcSPNNMEMYsvqMsQAo1X/Wsl/Pa7nKHKk0ncUeLyZspXVaRZfzy
+s8/z9AMP8Mfvv5972m2WG/F/Ds3M0NnaIvQDRe7YHY556NBBWp0GeWaR3iOUqbOPKCWTX5Md6DIO
+J0rXs56UiGmolOIug5D7GjpkeR/7RKK+vG+EZ5RlNLXiepaxXRQoBA0laUjJ5X6fWzs77O0raGkt
+sTi01mTDDNNIcLnFBFM2rjrQEJyPtxBQRmOkwSmL0QnWFSip6Wcjjs7NxW5qKyCJ4hHncmRq8FmB
+1hKtNUU2RkqD10U8jMGjpK5C0vw7qwVo2RHGUIWBmhDaP2a1qlcXAWHKWLZP1oSQPLu+zn3b2zxV
+SqABvuPAEs+sXWGgojD0Tq9HWD7Iw90ZXlZ7d2nuhIoDFYIOtZE1EDgVMYGcBFdkqez1TCThlRq4
+UgHr8udGLRefGEf1/UB3Gg98+sZNtoZDhBQ0EsO5mTne2triRjaagNQy+3DCU2QO0zARxCoVy4LO
+kepmHChhIm3tvafb7TIejCeeQwjykDHMChJdpngVmaYlkOBcHjGAlFFiT5ThKxJCOWhCtRplQUu3
+3hkGkLojfr/hyioyUCLISQEoWMK+2XkVSSMUDPt9Lqzf5mY2Kc4sJAmfOHuWx2fnEUJwxVsaSvPh
+U6c4olMOmwbtZoNmM8G7UIM6rSNIS8pMYCLnFiSIuo0r2ffhdPmz3Hdf46v+tv8kLAjFsflZJPDc
+lTUubtzhrTu3eWHtCq/ubHGg06kbSqow5AkYo0mbEdxV8wSqLMEWOVJEAkupFOc8C0lKq9uqyaDq
+4AxFnHCSpM1YQKrSSxlqhtAYc1ftRaFiS56AtFHve/OdgkBdo15tUKZRl35FkCXDF0urpswKVJJG
+6XLD1IUOgK/0evzatets5Dmv7fX51StXaRvDk8dW+eFzZzlbvukPH1jkLzz+GMfnZlhEobWi3WrU
+BE0IcbNS4snvlK47+aqNrk6zEZMP2Q6xaqD2dQqp8u9CQFref3hujuVmi09fWmNkPcPC0SscY+DC
+zdscbLeYRpIQZ/5IGbOKCogqIaNnkvECFkrLmAVpjValMFYKjICONiiVoso0LjEpm85jpECnOqa9
+0kQtgFJ3rWu8GspkjVUjwXS66GZSiUjVOw0BfRFkjF1ETbqsWE8l8S7SvFUYkJVsOdWTsFF+9Xb3
+eHZtjYOtFm9sbPDbt2/grsBxY3j0yCrff999nO506GjNe2ZnubO8wubeHqPCs7sv1xciuu8qhtuv
++hASoqAkRJechH15vACJRIZ9ll82lzaCZIRnQWtW52bo5Tm90WDyv2X17e3xkCt7Pb7v3Dn+4Stf
+qY2pyioi7oiGZr0jaeha0RScwMuoaEq0QXpJQ3i0krggoWQSrXe4EGqCKRAZRZu7u3gGhcOWvZcV
+0OzOzeJdrSTO36EH0FnV7CFElHuLVBG0iLm5lAihMe0GwdtoqUrdtfkVXsiLWABaHw+5tLnOMM8Z
+5xmvD/r87toal3q9OAq+KkMkCbOtDtNIukqhlCSRso7XaUUJE09uu1z0ZukZEhG9hN7nHRKgKSZh
+wpSzA9rl/0wJxaHpWVbaHS5ubd91ShoilqQ18KUrV5hJEs42WiQIUhFvleg0yuBlzTuEEDGMUHHz
+KxKrEJ4uEtMwJCpBJQqpYlpqlCRtpdHblhmCTpIoDSu9gPei1mXiPTOLS0zNTjMeDuOBTJLhO+0L
+2KyulaeNrpF+1bIsTEzTgo3CD6EiuxXwZeyKOj7r8ghOyk3bdZZsXJSTORWbeJ65ssanb92mZy3b
+RUFbKz5wbJXHV49yT7fLySRlOsg6XmslaFQu3Mf728h6foCui0OiviKYrip1+64Q1lDxZwk0jeHE
+3Bzb2Zjb/R4uxPkCsnxMl0hC7Raei7u7PHL0MI19eKOBQEtBsyR4qlTVmAk3sZ9x9IAp0XzFSUT4
+5OM8YynLtDKZYHCpStp3MmpHSsPiiVUeP3SIvZ0ervAVM7j9DtNA1qtND/i6wBMou368BV3yA8TW
+byFKEymtNjqqqOjVpb8c7XOX3nsy59gCnr1yhbG1PLqwwLXBkEu7O8ykDd57ZLWUeQ3Y6PfJvI1p
+WunOEfE0V5lJouLwx4bkrjlAFZnjVYyfiY7uWSVxQMR8t8vhbpvXN7ewxWQOcP0cXqBlnGD2zJU1
+PnHf/ZyaneX89nadeTTqsBTdva+xSyjrQbIchwNj1GTEbFXZrJhDEUi0QWlBcKIsKZdZkS5ZQT8i
+nepw6Ngqj8/N83vXb0YFNiBRBOHX3ykG2BRl1alG9lpSytzBy9oClZkUNYRUdbyOqpgUqRUNkxJC
+7MuvhCDV4oyBm+Mh+dXLTCUJSgiu7WxzyVo6aZOTi/OcmJnhxMwMY2cpfGBtZ4trW1u1UlcIQZrE
+K4uMbE6idT1BNC0/g1Jq39xhMFJjtMRIzamFebazjFv9PaSUNIgxeFyyc5UxmHJQ1YWtLe5dOMDm
+3h67RZxPIPell3mZkmaEuh4RWcfKIAJ3giPRmpGUmCSp6eu2STgsFOPpafr9fqyRYHHK1Ydw6sAi
+jy8eZK7b5neu32Lz9m2KvEApQEm8V1vvzACQW1V7d7AemZpIT9agoxwBIzxSpXhXIBvJXSIHqeOH
+TVSC0pJxebJMEt1hbgsSbchCQArB7aLguetv8/GTJ1menub1G7fIreWF0YBExW7ds/PzHGglzDdS
+HlxcQki4stNjbWuDrCgYuZyGMiipMFLXY2qq761yoQVxDoBCMjPb5OTUFBd7e+SFI010fbGoNOi7
+5GNjV4CDq1tbHJnqcmx+kfO3b9NCMizpkWpGgdx3EnIxibpGxWloA++YV4pdIk5Q5XWJ2tqwMjfD
+eBPebgeGYkg+ClAUJI0mHzl1im7SILeWf33pTQa7cbqIUtTStBDCO/MAwNtVm5LSptax1QZSDn0Q
+IapcpTJR7lTGJl3SxKZhMA1DKjXDcrpmxSOZfRd69GXatt7rc2Frm4Vmm6lGg5HNy4lgBW9vbXBr
+Z4eDMzNMN1IOtTtoFPfNz3Fufp6htWxkI273+nFOf5USVqoiJWiZlG4jpZsmtE1CWxsenJ2hJSW7
+RcF8p8V2f4iSksxbTKLj7MHSTRsV01PvPWu7Oxyfm+HOYI/d/pCOjvMEush6Ssn+8DASZZ+DVKRC
+MCpT2manSUNrpoXgyUNH+MShZR6bm+UXL7zJ7u2b2MKTmiaPzx/nzPJBRnnB+Tu3eP72LQbbe7XU
+vJrEhpRQ2Jvv1ACu1pUuqZCh1LFJQzWjUKJi06JQIGSs/JWZgFAqxrDa3ccx7tWhqEiU/eFCegkC
+rmxt88ThwyxNT3N5cz1W78IEQPXHY7aHfd68s878VIe5VovZpEFLa1baHY53prDBs5cXbI3HDIqC
+3MYZgXPtJsc7Uyw3UtpK0Vaq7lU41+3Sy3LecoF+kdFw8aKUXrg4R7i86kj1tb63x0p3iuNzC1zI
+b5XXIYoNJPNILDDYN66mKQRoTTvIcqRNnEHU0oYGMKs0HzocL6S2kqZ87NgqeXD4+cBMu8kwK9gd
+Zzx3+yYXb9zC2fyu+UuiFJGXv195RwagkvRKwHsRpKw2sSIhhNCEYCc5f4n6K/FC1f5dsWVGaRKj
+KMp5AJVObj+bJ4lDlzSSQZaxNR5zZHqa9X4PWzj0vuesxsIaLdkbjegNh1wViqlmymK7jVGKVGpm
+05R7pidj6xIlWW02mTWm7k7arytYSlNOT0/Ry3N8H4Zk4ECVQ6sRE6Ip4HEhcH2vx6mZObZnptja
+G6ASWV500iJDQDsZN3+fMVQKNyklSkuWLDQTzSNHjnC63aoxx0PdLv3DR/ni+m0ur2+yPRqxjuft
+G7dij6KbtJyFchyuVIaAL259/nPX+Mv/w3+8AVz/1G/srnz86csEfyLy1aIelRacizVtqe/a/Cpl
+2Y8DjDQxBWIyslWJmCLJffloo/IMAcauYH0w4MzCAgenpri507urfGu0xNkJ41fVoQbjnP4oQxtF
+Q2tuasNUI62N4Vx7+q7mlP11jSo9PN5sMpqbJdWKzeEoDqIW8foB4/LaAtWiawEb/T7tNOWe2Tl2
+RyN8HkfXKqFwpYxNlqPw21qT6oR2mtZDpmdbnej+05TvPXyYplJ1d/LAOdb29jh/8yavDvoTNZOs
+TrwD60pMs8+gg7ww/uQn996RB7Cf/tSYj37s3yDlT0gZ6s2XMuCCRJlSKxjL0ahU3cVpCwFKGGw5
+oKGyeC0FlpLbL09+AhgkpfiVEALrwz4rxTTnFg5wfWsHUXIJSk3m/3s7GcVe0amVi/bA2BYU/dgv
+OLSWg80GRxuNu/r/93cqCSHoaM2pdhslBFvNZn1NgLwUYlaXkc32XaUEoJMY7j94MN6/D3VKKepr
+EckQ36cR8QqnAKlWJFJipKqrlUnZov7q3h6v3L7JVWvJM8v8VIfdcgjV/jS7Rrjl5/DBfQoYv1MM
+kHlffFFighdKaKPL9mZR5/RCqpKvjpo3maT1QiqVoqRApyYyZaXlSgRSUhZwIC3pWikiw1epZ4rc
+cntvj4VGgxNLi1zf3q5ZxkotXHkQVQpXU2Pqizrtj9VxXHys5Q+cq+f0/buZUEhlfJYCT1tHnLD/
+iuLVoOnqamJLzRZZeSIrA9MyXtHEu0AeXBxvX2YY4+DY2BtQOMdGv8+t4ZA/cWyVrlJcGY145s5t
+1nt9MueQQjIdJDcGfaRWpEmTJI0qpqKw9Hs9smyMGxcB57/y70MF/0Gr4KU0twEntdBVH1stbpD7
+9GxyQgHrVJOoBBssSsfu3SpuKjEp11YUbSY8aZA1vSv3uebb/R73zM7ywNwCO4MRWdkP710gUQqv
+fJ3LV6e+WaauidblBNBSN28929mYteGI0+0WzdJT7Q8BIcTL0d3OMl7a2KJXxFYy70tVtIQpk95t
+hEHEaxiXl6dtJ5rdcc7YFRQhho5hVrA3GtUgeJwVjGxO8JGt7Dab5NZyceMOn221ONbp8Jlr13h7
+Z4txiFjp/+/uS4Mtu6rzvj2c4Q5v7LlbEi0QyMTgAJHjlAKxi7JNXMQmFFWp/HKcqpjyj1Q5ZcCV
+/EglOCGppCq2w2hkVzlmsiEgMBjCYAmBwEKykIQG0NCSWj2pX7/5Tmfae6382Hufe97VvW9oDZDc
+rlf3vb7v3eGstdfwrW+ttTDXwg2HlvB3jh9BS2ps5iOsbPXweDHCcDhAFaqtQhpIudKgP1ydAjAz
+HXrPu1bnjp3aANHRQGsWjZMllANXpIp2kEUsMaIoAbHj3zfXsXRYQgoXqyqWaAnUdQCthMvdhYCO
+3N89sbWBm44fx6uPHsaDly87/woJrRzHMOwSDuafhJv0STQeK699sDUsDa4UOZaiCKdS51KC4DNr
+kVmLK2WJxwd9lNb402rqtfTWENbMsDb9ys1Cq1nQuTH4qcNHYIhwdn3TZRA83kEQ3osDhiRKa+ui
+DxGhKA2GpkJBFofbbWgpcXzepcGdJMGlrS3cvb6GwShDlo3c4ClrYWzp6hCGACHXts9dWNnPxLA9
+ZwRt/K+PnYWUX96hGNg5eLcpfKU9hi2cWdaR8r7eCSeWEpWgnXj9zl602qQDQCwU1gcjbGQFlpIU
+JxcX68cTqREp5TuGZL1cqv4/5ZdMB+zduu0eG3mOc6MResala0NrsV5VeHqU4Yf9AR7r9bE2zFAR
+19vHwse1oB27CqQSNYlUQaKlY5zf2sZ8HOP0oSWkWruNI/6aRVJ7i0L135NwiygjqbHU6eAVc3O4
+sdPBr506ibdedy2umV/Axc1NPHz+Iv7mygq2e0Owb0RVekydF0L4PgT7l+uf+Pi+xsTsPSRqbW19
+9YH771U6Nju6ecNSRu1QJyGd8IVSEKwcI1a5TplYR2NKdRxhwVfpQpUtdAC1fL+BY+nK8elVAs/0
+3NiUl3XncaTdRexPdKoiRFJDR8p19yi3PyDM+lWQUKG5xNO0h2WFtTzHelXi2aLAU6MRHur3cGbY
+x8XREKv5CDnbHeTUUEQaWxRVK5aQgAqoqM/Cn+lt41CrhUN+/LtbfK3HxSnlUErlXUgkNY4vLuLm
+a6/Bq7puRmGIU85ubSLz/YxV6WIBYhrzI5WoQTellFl56KEHcPny5n4UYM9IiJkp+qVfPE9stwAc
+fo7597z/uoMHjvQQ+HuxD5yktxypcv5aWYJmH9X7sqyUToCRdzPhYmmhkJsK53t9vHp5CYNOGxf7
+Pp2UAhQWRfohExBO2gFUghQQjdXxFoSSLYaG8EwxwlrutojklXHrYokBZqc45DIT4RtNpBQ+oHMx
+hts4ZusWdveegK08w8WewssXFzEoS/R95B5JXW8kc1zGCBUZXL+8hJuOHsWJJMGi1jUJ9UKWY2M0
+QqQltq1B2ordBJJKgJg9UXRcuLLWrudnz57nfa6F39+YuMo+zNbe13zOkPdb2Lo9SSnHhpVKu3Kl
+lKisqUGfUekKNJHUiFmiJURjOXNS5/lB+CF6V9qZ1l5VYKsscardwVLaqqN8yY6foKSox9IrdiPq
+ld8okuhxA2coDlkQ1vIc/arEyFR1gAYxLl2n3oVJz/9TNRlV1q+vhbMGSnj3IwRirdEvc6wMh3j9
+sWNuook/0crXIAAgiTV+9rrTONWdw9P9PvrW1HjE5aLEk9vbKAu3QHO1MjXXINRSXMnZXzdHLfs+
+ZaMHsc/bvhSguuObTz/7vXu+J4UykxxBLfSOVSuuV97U1a9YRzXMO56No+rNYMqfAuGZMtrn+lJK
+xCpCrHXdncMEPDtwAdh1c120Yg0lFWIlETWFL4SDpYU7sWFPMPmNYQoSh5IE/dLAejNvafy4FFwr
+gQskhS8sOcG0ff2eBI/jDe2GuCghIVkgUQqRUrg46GE1y/APr70OSRQ5mroPdE8fOYQ3nj6NrTzH
+d86dw4NXVnDX6irOZTnu3tzE1y5dwGOrq87iNFbPBQhdJxEEK5jKTR/TKjYXv3fP98y3v31hvwpw
+kFnBtxHbfyWhTk62ZEkpEEUplHTs1h0NG359K/xShgDfSh/IxT6ADKY+nLxYa7T8KQ1lVB0p5NbN
+GDjdncPhpIWV0bAGWsbCcwOcwjzAekOJcD11LaUxF0VYyTOUZH0WweMaKAtAkNtiWCvPOOit2HH2
+IhG5VfZwDSEk/DLJMJOYLVKtcaHnBj/cdOI4zva2cbTbxTVzXQzLCvdeuoSysoi0g79XegM82u7h
+/ssrWB8NsDUaOfaQIaRaIw+DMPyMZSUdsFSVFqT4Mlt72wFkun8FYLI/IMMPiYhOCtFI+aTcsXtZ
+R+7n0HrFDHR8u5X1OXGgPIeTHiJ16QOaxK9ZDcIPBEs/DR7bRYGtOMHJThsFWfSrEhGEB2hEszWh
+3vknfSsXExDFEobJgTfUHA8jx+7NSkTabReNlKp5BaEvn9g2iSyDAAAa5ElEQVQNfVZe2ZqAE0uu
+dyAzAUoz+qbEy+QcfvHkKSxrjfWqwneHrshVVuOt5ACQGYsrwz56wwyWGa1YYQMGFTNi7cbaKiiQ
+ZlQl16AVW7qfq+rhgyjAvkfFZp/+9PZofe1DArKqiz5K1tM760hbyjptIqKadZuwrBG6+TRFK4p8
+rk47ijGR1PXYt2a6VTd1erN8aTSEZcbpbhdzUVwHYFrK2j/H3ueG/T8hal+MEli//UtIp6zaK2KT
+XBLuw3MoyB1WL8QTIZAN08OUHxSh4IJaKQUOJSlu6LRxfauFhSjCoSjC8U7buQo93qOkpcRGniMr
+ClhmaP88psGDJHIdQaZyk1DYBYNlb231A6M//1TvRVEAAKiGw9sZdJn9gMPQoBimb4a0KXTruGKP
+77gRbq9uXll00xSGrYsFImf2tfCTP5RAGilIFnUuH05mJIXPx9xu3/PDAVKlcU2ni5bSSFVUn/LU
+l48TraCkQCI1Eh9jLCcxcuui/cSnYrF0Ak49JSv1RBYFv4fQU7dUY6qHU9KxhQpKFwLPgD0spilu
+XFiAgBt0ZZnruEYLlw6GYLebptguXVZCADpxioJMTXfX8OV26TAWLTTKsgBbujg8f+FOHPB2IAXY
++IPfH5Z5/u+ZLPs0uU5nHHIX7+iejTwDV8NRrytDMGyxFKc7ijfhwzdh4ID2SR7n8HVg54OvXlni
+UjZCV2scb7UhBdCONNqRYzAndWDmyasMtL2ApJ9i4gI8f4r9iW5HGgxGGmmk3l2l0ZgVVLsVFjug
+5PDexjR0xkKS4GeWl3FxlOGejQ08MhjizGiIHw0HWIpc8BsCvFRFWEpjFKVBS8doeVyjMFSzngOz
+2aekXNqStdBcZdlvb3/kj/KDKsCBt4ade/d7/uyGD37gXYLFTwOKLVVCWi3cWlX2o9dt7QZCDSC0
+dFfWIpIC3TStg58aBdQujVLCmWMSjMgHXkqqHXh96BZayUZItcLhxJn11TzbyUcMaZuQKNmi7U94
+SePGSunjh9i/Vo0nhIaSWMOSdwNCIDcGqYocZmCdMgb6WPh7qQSOJB0cSVt4bKuHQVVAC6e0hpwr
+tARcP7+Ii1JhbTjC9YeXcfPhI1CQWBn00IlabvhkeB+QGDqgiRuBBxPb+5/87X/zJVzF7WrXxv0X
+Zv4TMhyrRElmFoaNiFgJIhe4yRlmxlhXOVtudXCF3Mg00ejKDQhenTKKMbgS3EsdIyiXml0ZZWhL
+hSNpAsOEzaJALJ7bFBMLhcU49mVOC+0F7tIs3sEcFhA1LsAcup9F7R6kQL2lnAneT9s6TllKUxxK
+UqxkGYamRGEIBah+zgBLr48GuHH5MOaTFK9dWsKpJMGbjx3FmY0NWBBWtnr19SOANcA5wFJKB64S
+FcaY912lHK9ubdxTH//kF4QQXwaQezIaERELIbiuvDX29URivO9vKxuiIIPlTmssXC3rtM+7eOeP
+A9zs5/qFjeHBNCsh/KQM4HKWo2LC4TTBku9aFj4wC18AkCiJigmlHQefkgVioaCFhPaDopQv1iiE
+ghGeM9tQCYGW0nXgGVzD8U4Xh5IUl4YjDE0Jaxt7ii3DWhqnxN6VXdft4hXtFoQQWNQaN5047pSK
+LRItEQnBGuDE4ZsVEeXFqBgR8a1P/NEtX3tJFYDvubu0ZD7IZFcAZABKEFm2lo2PlpQY19RjluM9
+e6VBURksJakzlT6wclwBsXPPoBfGGGDy8QbGVkH6jmBmxlruyqEnWq3a1DOh9tVCiB2WQTdGxjQb
+MxTGwJMLUMd7EIWfgyDEzpF4Fm4vwtFWByfaLaxkGXJb1c8VYpxmj4KbjyyxkMZYin3qy27NzeEk
+raFjsszMzBKw0tX4M2buV1SdL7Lsw/zA/flLqwDM9NS733OPEOK/E/FWWWQZMypjKViC2r9wow9P
+SKAig9ISIqlwtDPnlzQTtO+JC6c/+G5iB/JIdgJqR+OBFOzx/TBDryKnBBUTTrRaaGkH0cbKWZP5
+JEJz2lx43UmFqHv+vUBCtK+FrC2FhEAk3cQQJZ1yLsUpTne7+OHWJvLKLZiuy9TejSg/9jnS4yUW
+TMDhKK4HVAyMwaE4wlzqaGNJrDmOFBFQGSAz4G1D9gpb+9/OfOrPH9wv7v+CKQAAcFEUz9z+119n
+Q/dJKfrWUG5tUdmKqTQVU+PJM4y7ghQk+mWO3Boc6rZBRHWknUSRXzMrxqVmwUi0q/wlWqEirkek
+Kt9dFE61IQfurBclIiFwstWuR7yFqpsLRH1pVshaCZwCjr8PipFOYQ4xPDkEAomvNxzutHBtt41H
+t7fA5LCF4LJqzECK2lJYdlwCLRVGxmDbD9rcrio8nWX48oWLKIzFyw8f4SSKSEpZKSFyAH0JsZ4N
+snse++KX7zR33FHgedzk8/nj8tbPn7t0331/yIyVqsyH1nBJTFYpRURuVnnIAJjGnMC1wQBKCHR0
+7CZ115Ust/zBkkPZQkoVImxL4+g8CD8INZhUNwGccD7LIAEcSxMsxzEiqbAQR1BCoCB2yyJ8FTGM
+t4nVmJrWBI4m1zDpRrHIsGvkPJ62cK4/RGmpjk+a6CGxwwZaKqCg0lPIGWujER7d7uH729u4d2sL
+D29t4tntbaz0+3y5t02L7bZd7nbLOFLDArRVEl364Ve/ekv2mU9fwPO8XbUCCG8rh7ff9uBgbe1z
+QmCbjBmWVV5WlbHs6CgcunWTeJxHSylxZTRCoiUW09YOgmYt0MZVD2QPJUXtf7UvukzWJUpL6HoQ
+Z2ANulrjdLuNGzptnEgSzGuN+UijrTQS6ciYTTdQo3pirFA1FqEmYgUhkCqNU6021osCBVnEaqxQ
+dSMq5HMwgoB/CBkWVVs8vLWJp3t9XNruw4JYCcFCCLudZWV/lA+ZuVcC6xfOPXPr8BMff6wph5dE
+AUTjVldOzp4dXPr8X36CGY9aqvqmMFk+KipD1sKnLb5O7S6uD4au9AeIhcKhTruOtmtoVY7nrdbz
+BYnGwoGYFpf4+rrD+YNw55TC4TjGyTTF0TjGoSjCdWmKY2nsYgSvaDWEHIJOjIEhJcfdxHpiyOTR
+VoqhsRhVBk1RED8XNRShSsnOegVXoD1iOigqDPIcpTEca81SCSsgK2bOSlv1V6pqc2DMo2c++Rdf
+hTGjXeTy0riAAEbwvX975em/+srvahU/W5mib0yRFXlV+Wl2bMLv8RhSzUyJtSJD6nvohWy0RzN2
+DHgS0qVLbrUr11lAU/ChLBuCwTDQqTnoMQR2S1GEZR2h7c3xJGZRj8P1p7wKQmJRD6+2ICwlbhPx
+pidjSowVRTYMWRM1bCoEk3tszvdTWhBKIpZKsDVEzFyFiL8ozaYGLn3nIx/9H+Zbd6ziBbrJg5r8
+5/SP+vJb+aUvXjh3773/Wgu9Tpb7caJzAqp1VzBgApDouB6AoIXCSm+A+TjGfJrUCx9DbuwmhTof
+z+QQvZDy2QbZNfL0MWZGLJSbKAZG7sfNUqNG0dxRlCiFtpJIwpTvEEPIcVEmnPaWctBwiBGYgLaK
+sJzEuJzltWUK/5pdSKGAJJX7LFKwL03LGpuY0zHW88LhBSC2vhFSCJET235elpuRlqvf+u53/2P5
+pS9emLz2+5DT81OAXYS/4430PvLhs+cfuO+DUolNIupXzIUEnCWwzIUp2RrHZSs8Q7ZXlpiL4jEZ
+VLrgyTb4eIlWtXkl8I5c3pBr0hB+iKMUQKoVSDAyS9iuKuQTFcdAUSMwRmR34ASGGJGSdbNHCFAF
+ximflhLXd9t41tO8SHANH1s/Abx52oOgSbCvK6g67llIUqRaY1SWXBnLlSEiwRUJLkpj+pZ5q5um
+61994KEPr7z3985NXHs8XyW4WhcgptxLAHb7k5/62vqFS3+mtd601vZLcGGAipktASyEi4S0UBia
+Ehe2e0iVK+A0QaBIjQmPJVkwe9cAAdOID2ougRibXUMO2u1VButVhYtFjrWyRE6EzFpsVhU2qwqx
+UFiKYj/lC9DeEhBxffqDC5ENJPBEO8VWWSELO4fZl6mFqx6GrLyinTWF4Eaat8OtNtaKjA1brkBW
+KlExc2Eq27fMW4nUq1955EefOPuff+8+uOUPsnHoxCwleDFrAWKGFrqvjY3hxU9/+otpt3v85Tfe
+8CvwDZFuhggiIpJEAiQhTAUYTcitwbF2B+f7fce2EdJTsVStFFZyDfrIcBrhWtKgCLIRcFlyTSMV
+WfQqgYolcstYjjQKZgyMqU92S0koEWFkBHrGPOfD2gbGUhGjHTko53KWj+cOhM1nnkauPb4ghYvu
+IyFRgTwxRaAyLpVp6RiRltwbFFxZS2S5qsgU1lCfgM1WFK195cwTX3/0j2+5ExsbQ3+NuXGPGf/3
+wrmACXMiniPwnV8SgOQH7t988k8++qfnzp69LYbYGIH7uaAcQEWCiSyzIbepb1AVWM8yaCkx30pc
+7d3Tr6y/aEKi7qNrpmvj/jjpsIMAr0qBkscmvLAEw4QRWQyMwcgY9Cr3tZqXsMxYjCMcSRIkof6A
+8Sq7mqamJJaiGJtVWccCkzeH3497ISMha6UWjcJWaQyOtVq8WRScmZIEZAUgJ8t9C9psx/HaHZcu
+3vaD//mBL9m7797a5ZpPtQT7dQPyKoWPKYrQ/FnyDx7afOz9H7rl8bNPf+UQ1AYzepWhrLK2hMt+
+mNiyEAL9vMBmUeBY2q7NefPqkh2b5ACl2gZf34Lqfr3woUIZuiKL3I9dM+Rm/RYNEL8CYbussFVW
+0ELiWBrjaJJCh8GUvh6RSIVDSexnEhNa2pFRQ+ZhyCF8oXDk2OliJ7bRyFxasWYSzBvDzBqikkGZ
+YdsDsLHY6qx9/fwzX73rff/1VnvXXRv7EDyuVgnk8zD/k29CNq0AAMkPP9R/9Hfefcvdjz32pQRy
+PWdsV4ZGFZlSKmGEEEREnFUVVj3F69R8F7kxO9LAAMBk1sAw1TFAOIWTJ7Gknf9BxBj6dfN5ozJX
+K5QQGBiDlTzDdmWghMDxVoIjSVL79YU4wlIUQ3r4N1V6R59BcAelb38PJWQlhIOyPeroLJzg+Tim
+1eHIVGRKAKOystvMvLHQTlf/6uknv/nd33znZ+3dd/ewc8ip2EMGB44FxKw6whTtmfXiTcErjKvA
+4yms7Xb6sv/0vn9+82te80/aAstCiLlumrakEnEktUq1llJKcXJhTlw/N4/zwwEGnguvQnHI1/6b
+9frQ1yd823Xg74dbW2kU5ACoSCosxzFG1iAzthGwMQzvXCwNAIeTFG0l0fITRFLpGE4FM66UJS5l
+OUbWOACosUfYMnvXNR4uGTaJpkqzIeJ2pGkxjm0sZXn36pVstTfox1pvSWD1Lx564GsPvPO3/g9G
+owxu1pRt3FuM91Zw434HQWQyFtitWHQ1CjDV7ze+lBe+8l8RAIXl5XTpX/7Gm9/0lre846TWx4zl
+uU6SdOJIxQB0Gscy1lq+fHFJdHSEK9kQhaGaHxhIlg7tE1ATxivye3aDMiRa7TjpqdJYjmMMTYXc
+F4OC4CWLHVYlWJ/DcYLrW626oBRuPWNwZjTEZlFiaI071Y2W8do9CUdCkUpgLor4mrRFS1FEHaUM
+AeVfr1wZPri60u9E8eaV/mDlk7fd9oULf/D792FtbeSFbiaE31QAmqIAfFAFuFpGEHYBhaZbh40N
+u/nHf/Ltb1y+3PuZt739n9586sQriqoykkRHSpmYykZaKHWx35MnuvNiOWmJNc792ndVm9qWxwsM
+Uw3jNmYjgAkgyXVQGDp6muBR+Ntw6sNo+WABgjVR2DkePwyKMERoSwUkMZJKIVMWhbEOO5CAtVwX
+q7SQfCRJ+NpWi5aiyMZSVjlR8aN+f/jDtbXeoVZ787Znzj7xjc989sv9Wz/3NDY2qinXkGb4/ecv
+tH1agFn+XkycfNk4+XrKVwRAide9/uQrf+ud//gdr3vDzw3yfEEI0WklSVsrESVRFKVay+OdOREr
+KdaLXChI39Qh6tWxwawKX2Nv5uFBKSQL/7s+f09bGJoKm2XlkMUJs1/PHfIYxFIU47CvH4THe8Zg
+tazQrypUIEQN7oJhoLAWDIZlZiEEL0QR39Bu00IUVQCqobWjM6Ph8Purq9tEvPnB7/7N9350y0fv
+sHfdtelPeDVx+qdZADvFAtCEC+CrdgHP0/yrCTcQNe6j+rHjxztzv/a2n/vN3/j1XxFCLFWl6Uax
+7qRax5HU8XK7rY522jInK4ZFKVKlhWxwCgIsGxQgCL3pGoJSRMJlDsdbKQprsVlWdaEnpHqWGTlZ
+tBpj67QUWIgiHI0TZNaiIsbIGvStQWWpBoKazGASzETM0pX+6Jp2x/69hYUSQLlRlsMf9geDtTzf
+XhkNN977sY9//conP/Ewzp7NGsLeSwFeUDfwfBRgWvCnpiiBbihD3PheA9Dida8//Xd/912//NZX
+vuqGytp5Q9SNpE47aRynWkfHO3OKBMvNLBOx1qITRYKZETf7AH2NPhA1VL0pzEG6sZIoLeHabhuF
+JawWOSIh6xrCjoyBUY9xkQJY9lNLe5WpySCZsW50m3cfYYhoaYlJMFfWkiV3mufiqLym082ZeXBp
+NOqXbLc++/jjT37tD99/e/Xtb61hMKgaQq8mhL6bAthdgsGfOAVQE25gp2LMzy8t/Itff8Mv/eqv
+3vRTy8tHFGQ3N6bdjuO0E0XRUqulAaicrQQgU6GEdwdC+Zn8IdqOhasDBD8e8nQm4HgrhZYSF4Yj
+V2EUEsSo44NgPZrM3VfMz+HZLNtx2iuyQfANajZoaEpiZltZMpa4IsG5ghxFUgwiqXqPXLm8+plv
+fuu+Cx//2MO4cCHDYGBmCN/MyAD+n1QAtcP0T3MHflYEXvWqEze+63f+wSuuv/7UL5w8eWSYlx3D
+ttWJ03S53Y7ApEtLSkkhlVQy8jVwqRwtTLnt7Dt4ggFAkiywnKZIlcSzo2w3vmMdMxRk8PLuHJ4a
+9AP8zBOlcC4tEQmm0hhbMZvSGFfFs5xJJYapVP07zz6z+siVZy/94P0f+lt++KF1GGNQltWE2bf/
+PyvAbtZANayChJSL6k1vuu7at739lX//Na++7g3HTiwR0M5M2V6I00RpGStIZUE61lpGQkghhIiU
+EgBELJRg7CjC1J9mMXb0sLODQd3KFQZChIzCjCFkFgI4lKS4kuWQAkzuxLMhYgsi41p6TElkK2tL
+slwQ0YgEj1o6Htx37tzGd544c+HpL3z+jLnz25eQ5/kevn6a0H9iFWCvIHCaAkyLC/QUaxCj211U
+r33t8aWf/0fX/MKb33z9zaeuXSyNaefGtGKtk1Tr2LCNIqVULJVSUkklIbVL4kUslSBnDerPEkkh
+jrbaeHY03JXgEsoKsWsY5e28dIJnSwCoctMubWVtZSpbGqKCgCzVepRoNfzWM2e3br/99qc2v3nH
+s/aRR65gMBgEZHrGqbdXoQAvXhC4SxqIidMv9lCA/SqBmqIEbvtLms7hmmuW1YkTiz//7/7tq9/6
+stOLkVStQVm2tBIJgJgsR1rKSGmpFKRUWgbLICU7ppRUQpBlcaLTQa8qMDImfERuRPEshGDfIcxC
+goQQlFeWwESZNVYIUZXGVMZyKYFCKpG1dJxJgezWp55cv/0/vPdx3ljfwoUL28jzwRQhVlMEfRDh
+2xnCp1lo4AuBBM7Cn+UULEBNQMJ7KYLaxTKE50gAtAF0cMMNSwu//Jaj/+wdb7/2xqPH53SkklSq
+ZFSZxLCNyLLWUmoSrGKtFVmWUgkZKSUUA2kciVgo0StLyNASJiRbEEdCYFhVHEtFuTE0l8R2WFW2
+stYws2FClcS6iLUuyHJRWpM9sXK5/6n//bkLvW98/QrOnNkCMIKb0BkESHsI3u7je5pi/nkXC4AX
+WgH2cgN7xQJqHxnCbsrRfCwFkELKjrjpZxe7r/3pxZfd/MZDr7/22oUT893WcqsTt+M4MkRRpJRi
+ZmWIFBEpEiyYWSZRJIqqqmcKsqMwEwAWElZLZSOpbKyktQJVUZqqIlNtDLP8Uq+X3X/+/NYzd921
+OXjggQ1+8Ac9lOUIrmMnMOEnBTh5kvd6fJbPf8Gh4BeiGLSfWGCv+EBNMf+zfqf5WOwVIsb8fCt6
+45sWFl/3uvl0aSHtLMwnabebLi4uJjdEaTrfaalOkshuHMtumkrFEKUlkGAGQJIF98ucellhNkcD
+++homPW2tvJ8NCpGvX4+WlvLt+97oFd9585tjEY5gMILvGqcSDtD0LSHsM0UQds9EMDdAr8XTQEw
+AQdjFysg91CA/SiDnOJK5JTXkY3UMqoDyzSNcPp0Er3yhjRaXI5UkmjV6ahkcV4JlmH5ABFVLrjr
+DWy5tVWV66tl9cSZDGfPFsjzZp5eTQiLJgRjGxaA9jjVdkalbz+CpwmfT7MqgVetAPt0BbsFhVej
+CJPCV3s8j5xRL59Vn2jWMTBBo6IJv2onUi2e8js0Q0h2F6WYFLjZp+DtlPcwTQH2JfjnUw1smhnR
+eAPNyhWmaCQHptUuF7P5pfyHbgqRGsTIWZZATCFOHoQwwVOKKs33a3d5z3aXe7vPkz4t0JuliDPN
+/otJCp12sTChCNMuopoQupwiaDXjlKsZcYbcRfhyBoN2liJMonyTF3zaz9OEP+v/9vLruynWNMBn
+phwO0i28n1GxPMUN8BQT+hxCbeNC84QFkI3vgzLYXUy+mCHwydhj1unfjyWYdfIxRQCTgrH7UAo7
+5efdfp/3GexdtfD3FQMcIDjcb6ooZghyVuyw2++KXU7/fkmUs5SAdnEDsxRhLwXYjxuZ9to0w9w/
+L+FflQIcIEu4WmVonvbdHhczTL2c8nqz3h92uaCz8uu9gkKe4r95CnZPMxRqFqp3YJDnRVWAAyoC
+ZghlFqQs9nEv9vmzmIJjTLMAvIs7mBUXYMapnWbCaRcLgj0Ini/YiX/BFWCGEsxyDdiHb97NWuwl
+dEzBKHAV2cCkb51MsybzbtrDTfA+BDwLyTtwbv+SK8ABFWGaAGb1GexXeSZfY9aUumlWiac8zruk
+sgcR4mQQid2KNrsFdy+G8F9wBTigMmAPqHm//79b0WqWsu3n/TT77ab13tEeCrKbK5n8XnjBEl7i
+24umAPtQBhxAQcQ+hLebeRcHfL298A7sw0zvGrE3ytCMH+NN/Jhf/yBKIvb5s9inUsx6jlkYB+8D
+O8A+leLHLvifOAV4kZRHXKXFOYgl2PMx/gm+yP8X80Zz8pHr5ZQAAAAASUVORK5CYII=
+"
+       width="48"
+       id="image2301" />
+  </g>
+</svg>
diff -pruN 3.4.1-6/wifi/data/misc/old/link-5.svg 3.4.1+git20201022.a0d3415c-1/wifi/data/misc/old/link-5.svg
--- 3.4.1-6/wifi/data/misc/old/link-5.svg	1970-01-01 00:00:00.000000000 +0000
+++ 3.4.1+git20201022.a0d3415c-1/wifi/data/misc/old/link-5.svg	2020-10-21 15:04:44.000000000 +0000
@@ -0,0 +1,477 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="48px"
+   height="48px"
+   id="svg2160"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   sodipodi:docbase="/home/changfu/Documents/Install/Cairo-Dock/plug-ins/wifi/data/src"
+   sodipodi:docname="link-100.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape">
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="7"
+     inkscape:cx="24"
+     inkscape:cy="24"
+     inkscape:current-layer="layer1"
+     showgrid="true"
+     inkscape:grid-bbox="true"
+     inkscape:document-units="px"
+     inkscape:window-width="762"
+     inkscape:window-height="635"
+     inkscape:window-x="10"
+     inkscape:window-y="65" />
+  <defs
+     id="defs2162" />
+  <metadata
+     id="metadata2165">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:label="Layer 1"
+     id="layer1"
+     inkscape:groupmode="layer">
+    <image
+       y="0"
+       x="0"
+       height="48"
+       xlink:href="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAIAAAACACAYAAADDPmHLAAAAAXNSR0IArs4c6QAAAAZiS0dEAP8A
+/wD/oL2nkwAAAAlwSFlzAAALEwAACxMBAJqcGAAAAAd0SU1FB9gDCgMDLAEXLy8AACAASURBVHja
+7L15sGXZVd75W3vvc+785jnnOauypizVREkqjWgGycwG3G0a2gP0EB1NBBGmgzbdHWHCdIf/atph
+sDF2dzswyIAwAinQgJCqVKiqVGOWMmvIynl687vTOWcP/cc+99yX4AjaKklGRi/ixcuX7707nL2G
+b33rW+tICIHvfPz1/TD/ub9BETFAUn7q8j3r/8CvBsACxegzhGC/YwDfPgetgbZOW9MhuFYISdOk
+pj2175H9ovXx4MMdeL+CcFh0Mh+8Q5QQfECUAKoAfxF4EdQZxL+ctmYu29x2RYq+iO65vLcBdEMI
+7j+b6/btmgJERIB2kkzP6XrjUGP6wJ2IOhZ8OI6wXyRZBia9y5VShuDdf8DlBQkC4glBQEAkoJQB
+AaWMR9RW8O5K8O6yKDlH8Od6W1deDq73erZ9YxXohW/jPPptZwDHHvsxg5rYc+vVJ79fmea9wYcF
+0fpocOEAgSQQCL48RO/xeITo6cE7gttlCKLGobBWJ2lOkjbaBO/w3uLyDFdk0XjEE22OQpRcCMgr
+Qrjlit5zg+1bH8+2z1/+dowM3xYGICLyrp/6ZXPxxRc/appTP9bduHqkt3rlqEjSCM6BGIQAYgi+
+wFuPdzkEX56zRkQjukZSa6GTGqbWRKc1OrOLzC7vQ6V1bH+T6xdeZ/vWVbLtW3ifV5HD1OqISsrX
+Uz6nOFBqAP5VQV7Le5v/evvGM78bQvnE3zGAN//x3T/7+/svPfeZn9i+9vp/NdzZXrJZPxHRok2N
+EEL8tI6AAPG6NyYWmdlzlMUjdzN98BT7lmdZmWszPZEw0TYkWphoGhYnNM0UelngxqZjdcdycytn
+azvj8o1trl5bZ+f8k1x+9QwbV87jXR+lDJ3FAyCevLtNwAEeZ4sghCKIuxKC+xfDrdd/vb9++cp3
+DODr8/j6sXf8zPGp+b3ff/65z/1drZLFvNcHUYxeb/ACwaO0oTW9zOKhE8yefAen7z7EnYcm2DuT
+Uk8VzXT8uBZopcJsU6in0B3AxiCwMwwoAVVmBCUQXKDwwrDwbPY9r10f8MLZG1x46at0Vy/Smpxm
+2NtkOOgz2Nmgv71O1t3A5b0SVPobHv8rnYVDv3Pxz/7VuRBC9h0D+MsPvjZz+J2nFTzqHb+YpI12
+a3YP2zeuYvMcJQrvwaQprZk9zC7vY+7UO3ns4eOc2N9hqqlo1kaPpnAEJASUUhgD8y1hsi70C1jr
+xYMPISAihPJ3rSsNIYBDkPL6eA+OQC8LXFsv2OkXbG8Pee2NW1y//Do7V15m/cZFumtX8TbH2xzR
+Ae/s9sKx+39hsLP15UtP/cZXQwj5dwzgLx58knb2n2rN7PugkvRnQtArjYl5WTh4kpvnzzHc2SR4
+oTU9z8T8CnOH7uLQXae558QChxYbtOqCD9FzS6BWeXNqFPMtYb4t5A5udANbg4DEGoDCBZSKHh9E
+UAI+gAshMgOA89EwfPn9ZEOYb2sGNqaO128MeenVNV5+5mleffKTZL0NXDEAPN7neJuHtDlxOYTB
+rwy2b/xhf+3cmRBC8R0DABrTeybT9t4fTJLJnwAeDC4kWtc4/MA72dnYYP3CqzSm55laWGJiz13s
+OXyCO4/PsXe+yXRbV4eSaKnCt9bRoycbmv1TitTArV5goxcY2lgVxDIwGkFgfA18KL2/NADrdhmB
+BWOg3YiRCCCEgFbCIAtcvDXkdz99hotf/l3WLp3FFn0QCMGhlEd0kif12pPDnZv/Mutd+e3++uXt
+v9YGMHXgbQeSpPavvOM0QXWCD4jU2HPngyycei+X/uz3mZieoTmzwPSB09x9apm9c02aDYURBQq0
+kYrNUhK/z2zg1HLCYluwAV695ennHu/HkWFkOIRoMM7HAw8EvANfRoIQyu8DWA9GxX/3MoeRmFpG
+0We2rVnftnziC5e5+OxnufLqS2zfeAMfLN7mJLUaSaPBsLe5Q7BP5Xn3v9y5+vSlv5YGMHf43e8D
+888J7AVFCIJSdXTS4Mf/wT/myU/9HqJrUJvgwKnT3HN8jom2iYesBBFBa0ErIYRAvabwDmqpcNeK
+YbElrA0CZ65ZckcV2lMpDUDip/FjgOgdKA3OhnioGqwdG4I2QiMRNroO68AWniAB68d/c2JPjSur
+BY+/uMrrr1xn69XPsXr1dbpr19GJpjk5w6C7QdZdQyRcDhR/a/PSlz//18IAREQ15+6Zb0+t/B3n
+3C8QMN55tG6Ah8bMMu//qZ+jlmie/+LnkbljHDu6hxMHJkmT6PFGK5TEkK8EjFGVUUy0FXctGVqJ
+cGk7cPZ6QX0UHnw8cCXVa0GFCOxGEWFkJEog3xX6Rx8zTUVvGNjsewrvwENmA7n1hBBwRSDRwt6F
+OuevDbh4rcvVy5tsXDnL+qUX2Vm7QdKoMdi6RW/jWgk+nVXCLwyHl/9F/9brt77VHIL5Fh5+0l68
+897GxJ7/KQQ+HLw2IoJSCm0azO49wtzxR3js9BL/7Dc+S23pTk4eW2JutonzgSIEcJGq9SL4EC+2
+LyJDtzSruXMhRogXrjkub1oSEYZ2nKcJ49BvVPTY0YGPjCCEME4PJfL3HqZbGq2E9W5BEQLORs+3
+zuOKgPOxouhljnbPsm++QS9zOB9wcpygGkwvXAYs117z9DZuEfCIJCbg/5d6c/9DYab2v4nI899K
+gGi+RYefdpZPv6fRWf55b/1bCQolGlA0pmaZXjjAxOJ+3veBt/HkS2tIc5ZjxxeZm2litMICiUSk
+73xAPDg9PrSjyzXuWlFYCy9etdzc8ogO5CEQCkEZsLs82SjIckDtwgK7PzwUPuZ+xKNQtGuKtZ6j
+cIHChSo6iAhBRzBR5NF4Lt8acnxfm4NLTYaZxflJlMDWxgwLixNI0mLQ3WKwGdlGCEZEfawxsWdO
+wT8SkT/+VpWL5ltw+DKx/MCHGhPLv+SK4njwIwyu6CzsY3ZpH/WJOWTqCIf31Hny+WscP7HCVKeJ
+D1CEgAkwyBxKwGmFVmACZBaO7alx55Kin8Nzlws2ei7iehfxPYDyVCSSVkI28nr3Fw2gKgN9wHuP
+DzDbiWnm+pbF2+jp1sff885HL/cBR8Baj/Xwxo0+d+xtMTNRZ6dbMD3TodVpcHTvFJtrJ1g6eI1b
+V2t0b8aoEGL4eWttct8/EZP8vIj8u29FOjDf7Jy/dMdHfiA4+afBhWmRBJSgdMr04gGml/dh0iYE
+z4MPHWF12zM722FqooFzDu9L71UKo1WJwCMU9144ulLj9J6EwgaeeC1jaxDzstLgXcCYcb533qFV
+rPtDiMzfiA1QwphhLImjUXTJ8sBcS7HRd2SFi2nCxbQw6jUMi/i1sJ6gAq7wbO7A9sDz0Ik2a9uR
+BDy0b5KjS3WeeqFOvT3B8qE7WKu32bz6Orboo5QSHMdrzeVfrR+YUyLy299sI/imGsD0gXf8t97y
+j4P3qUhCcJ6k3mJ6zyGm5paqC+0m7+DuQ9O8dn1AUtN0+0NqicakCm01vmzThgBGC9bBoaWU+/ca
+2in8xjN9iiJUHi9eIoL3UjJ90QgKF0O2eLAScYBzYGUcBkII+NyhNCilKIJntqN5/uIQWx6Fc/Hw
+c+urCJJbj3URCFoX8MFxZW3AsaWE99w7zfOXh7zjZIura5Y0TcG0UW6T+T0H0Dph6/oFirxX9hbC
+VJDav55YfmQe+D+/7QxAZF9j/ujdP5nUJv9nPCkIIQhpo830yiEmpuaih5kpvMxw7Ohepjuardcy
+vLMoo+LFLiAkHuUVwQZSEw1mYTrlvn0pNsCvP9Ejt75C696CTmIeNyqG6kQgiN8dmSJqR3DEQ0xE
+yHyo6nw/BCeWO1YaXN/xbPUdSQkcRxhAGcFl8bkjjSC4Mm0UmeX6ZuDKVosP3Zny8OGETir0skC9
+mSKNabQf4LKM6cVlTJKyfvV18sF2SVT5NK3P/K8LJz7ib5177l+GcGnwzTgr9c1o5Mwfv/d7RSU/
+F1yYBoWohCRtMb3nCBNTc+i0RUj34GUKDOxdabI1cPR7luAEH8YvKyCgY5kH0GkmPHiwRj2Br1wo
+8K7kBbzEvL8LLI48tiiR/ej7vMzTWfk7rggMy1ye2VABvcI6Dsxqbm5atBKGPnr9CAAOh/FvRmnF
+ujIFuEDQQjZw3NosaCTCTFORGOHgnGL/ygQhmSaoBpLUkCB0pmaZWTlKrTkNQYGkiEqmxeufWzj2
+wIdFpP5X3gBExHQWT79XJPmHBLVXqRQ8JEmDqcW9TE7PI/V5nJlHyBC/ge5Mcnxfm4urOUNnsfgI
+vnx5iLkHFw9Pp5qHjzRo1+HJCwWXNyy59xRufHDDwldo3BYxIkD8eyXxq5ScfwXkQqz7vYXCuurw
+i0KYbQjnVzOchCqNDIv4nLn1ZDYe/DC3eO8pstIY8mgct7oZvWKML2ZbwqG9LZJmA9ImKEPQCShD
+e3KK6aUDJPVOKWgBMAcI6hcnlh94Zyl7+6ubAib3Pry33lr5xRDk5IhW1WmDztwy04sHotWHgLi1
+CLpMk9n5SWYnNC+cz6ocbd1IfaNQSaAI4HPF2041me8IL16zvHYlqzwxqEBROLyKyN5JTB9owCvE
+RmCnJOZuCRplIlbwZShXZUkHCvGRGp6aSMg9bG1nGK2oNwxKQZa7SovgXKwWAIo8VP8vIuTW0+17
+rB2nnlQH2jVDmqZkuo2wg9IGVEwd7ek5nHds3byCHZRslKg7m5MHf1Gcfgm49FfSAEQkWTz+Pf9v
+8OG0oAgiEBSduT3MLB0nqDbYLiHkoJJYliUt2p06zgZ6g6Iqp7SS6E2Mqd6HT05wcsFw9pbjya/t
+oBIVyzjvQYPdBch8GDOFOBcJJBOJpJhJLD6PBqKCgl0VtzYB7xReK/bPp5xb9Wit8SFQZI60bnBB
+KKwjy4oYacoUwAgflIfpvef0kQ65hacuW47OqeqC6zQ6c1A1go0GLyYQrDAxs4ArHFvZhdiRFA+e
+B5sz+/8fkQffE8JXir9SBvDu//p/T/be8yP/VzHMvktQIAoVhPbcCnMrd4JuEuwaFmJoCwFEg64z
+P91iaxDYGRRVKVa4gEehg8MHTXsm5YGDKTtZ4HPPb5EXFsn0LuMb9+xj3CyFIzbiAx9AuZgW6nXF
+YOAwOhpQ7PqP+4LFMESCyMLhOcMzb+SRf0DhiY/V6iRsbXpEaWxe4IpoAF5i6vJAkTnuPDrFqZWE
+x9/Iefxr29x7qMP33F1joqmoNROCCiAJqALvCoKTeGlEMTm/iC8s3fXrEIQgXkSZty+fOvLLIvKz
+3yjJuvlGHP72hv/RrN/7W0oZBA0B6p0FZpYOg1YUw2uIrqG0RpSOwE40pA1O7O+w1i3Y7g4xiSG3
+HqMVIh4SRauu+ej90+QO/v1zXbZ7OSEEklGNT4waSsVDN1rhvEf5WMblRTxsWxrXYBBreCdhV+0v
+jMrtUFLOAA0jXFkfsN3Ly+aTxnmN84F6w+BcIFMGxGFxuDyQFx6thZXFNg8dbXNp3fGJJ2+SF5bB
+sKCRznJqJWFuqs010wF6iBhEeYJ10XhFISrQmZ2nyAdk3S0IClcU6KT29+ePfPgrIvKb3wgjeNMG
+sL3RfeDWa+f/gYhORaIcJ21MMDW/F601drgJKkVERxWuGCTaCEnaYGXG8OS5Abn1iHfohokUqxK0
+F+47MkG7Dl96ZcAbl7oxr1uPUgrrfCnlUmXIDbGd6+PPVfAVOh9VEVnuyrQiVa6Gcd62LhpCYjTW
+Q3/gq3yuy78pimgMAcHlrvwbhTaKBM/kRMJjp6bwDv7w6TW2t3Occwx6BZ97DmZbC8xMpfF61OuQ
+B0IRUGkpYNU1pDlPTYTO0iG2r55jZ2ONIuuRD7bTpD798zP73nkO+Mp/UgN478/98bId8lO9zVtH
+ktpkRNcqpTOzTK3RwPmCILoSYCAq5mwPkiYkjaiyXd0a4r3HaUVhA1qBV5YDS5OcWKpxft3x+Jl1
+EgRnHXiF9gFvwYrH6Jj3dRCccvFQixhBvI9E0Cgni9J451Elqg8+HrALUjF7IQTqWjAKhrkfM4DB
+4pyUpWRGs54SjGaQZVC2jWdnGnz4gVm0ET79zCY3NgdkeYF1sbp59cI6T620eeyOKS5dW+H6jTZZ
+XjAz0WT/8hRTEykIbGwM2Nge0N2ZgyRFJecYdHdoTEwz2Fk7Xuvs+amkeeBC0b9w8z+JAex9y0eS
+x37sl97/wr/76vcl9Y4W0SgUjYl5Gu0ODoegK88PaAixTh/x8kmSkNlAt2fxFpwOiIt5f36qzgOH
+2iiBzz67ifOB3FlUUOhRJ0883kIeYiQIXkpMEKO4zmNdDqEif1Sw0aPLikNrTZ7b2FkMMaX4QEU6
+9TNLsGDxVZ/ABwg2sGmHNNM6xhi2dnoc3jfFBx6YYbKm+L//dJUbt3oxpSgDweO9xTvL+lbO6Yc7
+tD60nyubBROpollXXFot+PKL65y/sEZ39SoM1sENKYYD+ttdsu5mOcugtIIfmlq480/KVOC+5Qbw
+0N/8pTuf/r1f/W902pqK3T2FNh2anamKYghoRJk4fmXGVCtaQEzMzRZ6g4K8iBy/SEB0YGmmyd4Z
+w6ef63LtZg/rPIkWnHEEMbFm97EtSwCDIgSPFkGVoDBzsWUciGVeFIIIXuL1UkFR2JzEaLISK2SF
+RVQEmKMa3464/gBBYlVhywrE+UCS1rj31CLvP9XBB/inn77K+nof51zVMSxcIEGTNpq06gnNFN55
+1BCC5kvnHb/1xC2eeeYqxdoruO4OBE8IrjIcnTaw+S2CKyJdLDKVNKZ/em7/R54FznxLiaC/+dsX
+GqvPP/7RvNd/izYNBEGkRq3ZIW03CUrHIQ3RsS5Gxk+lVZUOGq2EfuHpD3OstYQQyZVWs8YH7p3g
+lWsFL1/aYuhsFGlYj8sjui8IZHkRL1DusXgcjjwryZmirPN97NcXLvIFufXgI2aweALCYBAPNbce
+7xR5FjGDIGSFQ4zgFThi+insGEBaa3nL0Q4//NAkt7qOf/KJC6yt9ciKMaE0zHKyXsb2oMvyfIMP
+nW4zWZeKG1jrOS5c2aLYuQJuWF6eEWZSKKVotFvUOpMRq6gE0QlKmbcm7cmPikj6LTOAg997Udsb
+9tgbLzz+92f2HKbZmYpSLlOj3mrGUkxMGeYF5wKiJU7YaKJRIARxtBspzgf6mY38uY2A6uGT0+xk
+gaff2GFtrYcvPIMslr7WjWtsm1Mxhj6P3zsc3vvYh5eo7Y+ijMgWOh/i4eSxceOKgMUzLHz1b1eW
+AUVZXRTWjcmeImKMwjo6EzU+8vAKDx2s89TFnH/zhRvkgzwako+fzgXygUVrzf2n9vL33rfEWjfw
+8ecy+rmvWErrxkcSlOCFcl5RgUoJCI2JaXStFYkj5+Okkvc/vXjHDx/6lqQAEZGf/JWvqj/75Cf/
+rtLpUntqjuA1w+0+aXOCpNmKLzio0uujJTsfUNogXoFY0BEBp3VDlscLhO+S5R0O7J/i9P4GL1zJ
+ePHsagRueUAlxPpfhCRAkUW0P8x9VQI6H8Ns4R1KqdhSHlEmRSSByukubB45gt2SL5+Az0GngklV
+lIuHsfgjhEAePKlRHF2Z4j33TgLw75/b5NyFbdJaHZQh63ejkRcB53pMz8zy6P0rPHi4wefP9vnC
+09fJ8oLV7iF+9IE6r94Ysr2d430KbvycaIW3LvIcYjC1Omljgqy/hTL1KFbR6V7xxd8B/sdvPgb4
+2/9QXnllcHzj0tkfN2mbEDSdlRN019epN5p4VJy21QJBYnzRChl14LSOSDt4AprUxFKO0I+Dm3mX
+9953gs2B58mX12KIt6BShXKxY1dYR5o6vAh5YTHG4G3M20qoyjgJgbya+CmrD6XweVkNiGAlUrlG
+x5+HPALFdq3OvpkaGiE1ityC8w7vYc98hweOTXDPvpSvXsh4/Mw612/1sUVOvRFoNBp0e0O8K3Au
+cOjwXj74wCJaCb/2qctcvrgJw1UInn/zh3DPnhNRU7BxneAL0C20GILL4nCJRHIIBBFNrdOhyAcE
+VyBSROGsqJ/ozN77Kztrz732TTWAd5mWvvrM7/wjhZkIXgguY//RE/Svv4G1NoavSnkZkKDHY9lK
+lcAmIKIIotEl8g6uIOQZx+45ysKE4ZUbGa+8foNEEkIIpIngAgTrCbnDtxT4iAeUiqFWj/T9UnL+
+jA/dWl+i+4jkI90MYiPVXJTx1+ioUZzppOybS5hqwOJsgxtrA0SEh++e5s6VOrVU+LU/vsn6zpDt
+rWHUBTrP1tYWs7PzpPUmvdVrnL7vMB95cI4zV4f8/mcvkG9eBGuRErR3b17kD55d4S2HG2DaSH81
+GgEJ6GachCqGJTEVo2pSr2FqdWzmwcX3jyTTU8v3/bKI/MB/rIBE/ceE/9ridy8Pu9uPiU7QSrN1
+a43+0HLPd38ExKBQiNbVI4cQUCat2L/gQgUOJcRcmvlQEUSnj05STxSfeuIKoQgURewPFENHPrC4
+zIGoSq5lxWNH/Xg//uq9Jy9smYNdVdpZ58eiDj/GA3lhIxUsQruTcnCpyckFxeEZxYdOT/GxRxf4
+ex9Y4eEjDc6vFvyzT13l/KUNtjYHFNaRF9EYXR64duUGShsefeQk3/fIHE+8usPH/+Al8u2rSD4A
+H8EuPkd8xh995lW0Eu66e3/06qCxWZfgBmUzrFmmVV+qlQxJswOSotMaIhqVpKi0/o6p/R+Z+6aB
+wHf91C+b/sXHf9bbvDPqSva3trn1xmscXJ7iyKPvj+iYiLyDlwj+iIcWvCNIgGAjGDQxGbcSDcqw
+5+gh5jsJZ69nbG2sIcUW4gaxDs6zKqfbck6/sKVGUGKedz4egHPuNnXvCFyOunTe+wpsjvK/1roq
+2Vr1hDv21Ng/qRAR3n3E8METCbNN4emLGV9+eZ2bt7qxhVyCPazHK4+zBeTb3HGgxd94ZJpPPrPJ
+Zz5/ljDYgqxP+HPdXPEZobfGZ1/YZGG2jiQtPBal01jd2CEhOEy9jkrqIAYfwJgUrSPHopRBgiCi
+Jyfn9vwPIqK+OVWAWTrU3Vx/h9KpUjolhFjibVx6mbPnN3jXw3vY98C7Ko+Xsv7GKwIOMTqSQGmd
+oFuQtJnsJLztZJ177zrEW++e58GDNc5e7UFvPXpKnoEdIqGgyLMYEfJAkQWGfUs2cDEUGrBZjAi+
+gGLoqoPOC4tzjiwvyvatK2VdDmvjz0YGMjGRcvpIh9N7dNWFBNgcwudfGfJnZ9a5cn2HrHBk/SJG
+psLG5xgMEBz3P3CS731oij96rs+Tz94g9NaiIY8ic7CILWJYtx7wvPjyKrOTCUweLDkIP2ZObY7N
+h3GCySQxAtRrqCTFBxWNxYPWiVbKfGByzzv2f1MwQGgeeuvOxjMHjKkTgkdGpZ4LvPrMF6k3381H
+3nmQTzdSrrz8NHmvG5kzb+MbER/DWVpHWsss7Zni8Hyde5c0P/neRdJyevfmWh9MKX7xllB4BF+B
+Rysa50oVbikcdf2A1hoyDzU9Fn+WHT7Rcdx35PXKgS+l3EopZqbrHFjs8MjxNo8eSqmbSAKlOkaW
+Jy4UPHtuk6s3uqVBhaoiCXmB4Aho7j99kB992xyfeGqdP33qBqJTgqqh3IAgSdQiiBBUCVRdbP5s
+b2/iw15W9k5xZdUTVJkukZg+vcPaHKUUohNwkDRaBOcIwZb4SlBaH1CKtwJvfEMNYPnuH546fOpt
+b2+2Jib6rovNLUoLAYUyhqw/4Pkv/DGb3cd421uWuLT33Tzx1CXyK8+W+T2gEw3GYCb2c+zYPO97
+YI53H0lJtPBd+2N0ePlmLN9Uew7fXR/nPmsQU278cDnWefLcgneVx1Tl2iDqCVQamcEAOBG8s1VJ
+CjDZaLC80GL/UpMjCzX2TxvWBo7f+uqAwjv2z9X5wHFDN4cvvrTNtfVB9PZBjBq4PEpQfU4Qxf33
+H+LDb5nmd7+yzpe+9BI+z5HJfXgzhSq2q3U0YSRRChGfYCxha40XXtniwJ4OV89O4rfWqk5nSWRH
+nWQWjUBpQ1pv4wpHcBmSJLh8AITJ1tSBd4jMfyKEWzvfMAPIulfu2rh+5cH21Ix4r+hvbeM9iFYo
+k0bQNRjyxtNfYHX1ft779v183weOc/biMi985Wlsdz2SQ+0F9h+c4WOPLvCBE4aGGbNhAJ2acGil
+w+pql25RI2S+nOnKwQWC16Bt1N65DOUjQrYqdiEjOC3JJyuYuqlYQp0KdaM5tneKUwc7rMwYOqlG
+aXj1es4nn1qlNyzIBo5aQ/NMqllqrbA8KVy61aPXzSiGMVWIz/BiEB9VSXffe4T3PzDLl17Z4YtP
+vgEhoJTF9nZImtP44ZWY74kMKdiyK+oIweOD5eq1bU4e2Au1OVBrJehTVdTwfpdc3XuSegOXO4pc
+8LaPThKCLVSjPf9Qa3bPXcAT3zADKAaDA0WWHdxaXePQo9/Puc/9W0QlmFqzKre0SSiGGd2Lz/J7
+v/kCJx55O++8b4GHT72Xq6tDPvmFN0jqCaePTfO2A4Zmom6TTwEsd4T7Dzd55VKTbj+HwsXtftYT
+SCvEYrQiCz6G33ojXlxJwA2xVggqiWxZDnv2TvLAiRmOr9SZqCs0gjFwed3y8WfWeO3CWsn07boo
+fYVzgT96sc3H7p/g1mqPrF9gg0VCbCWPxoz3HN7HDzy6wNNv9PjsF14nZAPE5YQgmPwyLm1D5xiy
+/bUYBaxFVPRspRTOKMg93e429VSRtFq4DYPPI1geEUMiAkkSNQMhNrlMo4nzLpaOQVBJANRhpdWh
+b5gBiEjt0EM/c1RE2i4vGAwzVo7fw+VzZzClNSIRoSttImK3ijNf+jxnn1/kyKkTfNc98/wfP30v
+zTosdBSTjTHAGh3+aGpntqWpJTpeAFdAiACSkuDxuh3DvjLQnEIbg041tVQzM11nZbbNgaUGe2YT
+Oqkm1TB0nl4e+OqFjBdf2eTmepetraxcLKWw1pZCkrJxY2Pf4NzFY/xYXAAAIABJREFUbfJ7J0iM
+pi95RBQqEFTM562ZWT761mXeWM35/Feughsivohe7ocElRCGa6QTK9iRHiJJCS6vgChJHF0K29e4
+sXmMQwdmOXvV4EJRTgtRRQGRSK4pDKGIcjR0BIIRD2iweXvpyLsPikj6/2e87C81gPbSQweUmPeH
+IOg05eZzn+a+D/4oO5sbZP0svimtUEbFjFXW2xpL2L7OuS/f4NUze7n8nnv54bdOs39S3TaE8ec/
+7l3WvPf+OaZbCbe2ZhkOYhdQ1zT1RNGsp8xPNSjsJI26sDSZ0mloplqxbBsMHTvDwM1Ny8vdARtb
+BTc2B1y/2WXQzTA1Q7Ah4gkRiqKInujHDR7RASXC9RtdrIWFuSbb3SEBhQ7g09gO/v53HSDVit/9
+8mW21zbLx4xhGx37Mzps4Nwifvo4euNsuXIu/o5ScaSdYLD9Lc5f3uHwvgm+VmtBkaF87JnEuYqx
+0MVHIqNyHlCxJNQejxbgfZ2Vt/4m8NqbMgARkSOP/Pd7CdwnShNcnH+7cO4VDj38Hs4/9ScUWYGu
+vIeKifPeI0VAJYYwuMHnvvAS3eEdTH9kjiMz+jbv3/3v6brwsbvqvP1wjWvbgY2+q4SihSsBnlFs
+dy3bQ89q13J1MycrHMOBZ7ufs7VdsLbViz2GXcamlMKVit7RONgor1Z1sVJ46xEBm+dsZY7lmQav
+XyDOnAWPzwve89ghDswmfOLPVrlyZQ1Ugvg8Tp6GssK2nuATQv8mSXsJJwkitpSf3X6AIQTW1nqc
+PjFbdQCtt0gIFRWsSrFsFN5oQiCC21IIq5VB64D39oGlw4/uFZHX/7IlluYv5QkCC0qZWnABMZGx
+W3vtBTrLBzj8Xe/m1cc/WzV+qqZKiN7oJYD3KOuh6HJrs8eFjVn2T8YJnD//MbTw+2cynjy3w9ZO
+EVu7PhI7WAgqpplGvcb6Wpc8zxnkDmt99OpRSiqHPGVXlFGl9EsERJvbvXXX9jEhGocYEKe5cKvg
+4FKTJ5RCa6EI8NDd+3nPnZN8+rlNzpxdjQfps5iWvEV0UlLgHtI6ym6CXsC3D6O3Xy6HF238fWMi
+41cout24MUY6y9DfjMapIJQlpy+bXN57XPCMNMY+xM6g90O0MoCva2S+5HncmzGARBlzVIlRQQlB
+TKxLQ+D6C1/kvvd+iD33vp3Lz36h4qqlRGpBjb3LhQJTRM+8slmQWUVSU5Vnjjzh+rbjibM7PP/K
+Kpu3ujGfMlb6Cg5JJ2lNdehubFe5caT3G836RxYw/n+UdO+SfaexS+cZ6xJGBz/6XgQ0gjOBV6/3
+ededk+zdM8XGxoADe1u86+5JbvYsT525WRmciOAxiNp1zRNTovkEt3mF+ux+8l6jZENLLFCqhVAQ
+tq/Rz06yb+8sr1/zFU5QIpFFFVW1wpVS8WorhZWABNC1BtgcpY1G/AEqGPn1M4E1gnrb6JBGYkof
+FIPuDl976hnuv2eF9pGH8HYkx779+WK4jZ6xudXl2de7nN8MfyH0bw89T1wsuHBth3xoK9aMUsIl
+UdyP1rFDp3YFHet81Q0cCTpHXID3UdyhlaBTweXxvZhanDhWSawqtNbxMxW0BExNMTfV5Ob6kH0z
+mve9ZY57TszwvY/MMdnS/NonXq+MV5QmqFr5Nal6+BX7ZwxCbCjZ+t7YDCrFHpURisLbITs9x/HD
+E5XzKBX1AXHqhQoMCmEsIC0NxOVFhQcQ9ShQf1MYwNRXmsak78BDQON8LH+EQAhCb+MGn/n0V/jA
+9zzCp5Vm69UnUGlaSpliZRAbQSUX313ltcvTfPblJvsmGjQSYWcYjeELb1j+5PkttrYysqyIHqki
+kAqiYtnlxzld4jIflNKl141LROs8xhhwYOoGcVK9U1Uv04kN6FQgL8O/AeWjHFvqhnotZWmhzSN3
+THByTnHnYp3hPXWGFj7+1QHTUw02NgdVk+Y2TON9TIqmRnBF6Qg1BptXaHQWybMmEqKaKUiC+Axt
+Elxe8PqVTT746J5SZTVaXhXKYC44m8ffdRZRfqQJIBQFupYiPouTT6j3mMb+BrD9dRvAoQd+bDGE
+UBetkVCqe0UqpYog9Fff4A8/4fjg93wXZ/ZP8cqX/gTrPaJ3kTxBRdDjC65d3+Lly01eO1ZnJ/O8
+dDXj5ELKU691OX9ti8GwINiRjEwqfZ7WOgq4yotsUkVwEWtIolEKxCowkKjYRk7qmmIY18Lvjhgk
+o/66kNQVNvNEFVvULydGMz/V4I79Ld53sk67rso5gThMenJPytcuthgOLEXh0FlRNcFEBK/q5Rh6
+FvFAEGA41iYkM2h3C5wq35+J+klt2docREDdnofuNcRLVQWIERQpvmyxa1VDVIHHIsZAqcJWOoC1
+k8cf/tvzwI2vOwVoSQ6K0hFgSAwtIUjV2AkqHlR/7TKf/MTjLM03uee730t9Zm4MvlT0qjhuk2N7
+2xSZ441Vy6de2OHzz67y0tUs7trrZeR5Xl3ImI9l7FmiEBNTwEjRmyQJOgjKR4pUBcNo91AIMZTr
+VKrHUUpV4XX0uEldjxdMakMtTZifbXB0KWW2KRVhBRHkH59VLM3VabcNjZpGm6R67NHripErIZQs
+5Qhw2iLHtNpAGnGAJOX7DEDKsL8dS8PGVHw/SlWtaohGqlSJxVRMA0rF31MmRSlDmtZJ0hpKmQNv
+qhsoSh+UUsOny6me0aEE76p6WkQYblzny5/6PEUeeM8H3kp9331QrlqLk5ilTKzokiaG1R3Ll796
+lStXt7hwa8BcJ41hO8+rx68OLaEa7kyIhqG1HgO4XeWkSkpJV01VfzM6lNEBxWWS+rafjw4QoN40
+dOqa+XYkksbVTfysJcJEw9ColfleU2GIUaRRqszxI7SvYpfUDrdJ09gkEtFIIpWxiNGEYY/ceyYn
+OlU1o5VUEWaEq6LcPI05X+lSbKvK3ysJIqXepAGIzMeLpiMQ0QrREi0zHQtRvY95cDjocu7Jx3nh
+1Q0+9p6jnHj0XVFrrxIkibOAJG2W52rs9B1bq2vkwy63NjJqRqinplQK6bL1WR6ij7hDa42YQFKT
+Kt+bWvxM6rry5MSMD9cksXc+GhsbGXKamKqxorXGaEWamHIsbWQQcWx8t4GNLlqqyyaNUuWswnjm
+YfQYWmuUKa+TMlW1EeVxrRhOdD0CE12P5FHRxRWBmcV2+TMI5RCL0iZGg5KPGD2sUnE72og/iNR8
+DRFZeJMGoGdGOVhUEotjZeJNGJSOcumwi861gTzrc/HpL/CpL17gobvn+NiPfAw6S3hVh3qbQycO
+8NjJNpmPOc07w1Y3Y1h42p0U06jfFnKrJRESLzJixvsBk9sJHK11jCKiSEw8aO/jrOHIKLQSjFZj
+BC/Rs0ZGMhogGbjIKNbNmEvQSrAeekW5Ii4bVxhVuiuB2+i5R1Q5oiI28Bl5NiRtt2NzCxBdxIoH
+RXAZBYGJ1ETVkCojS1yqVtLBHkmScVRVUd6uElOdEZEmnnmTBhAWSkOoQqTRCq1qID62hZUppcyR
+Pw8hemr30rP85m89QT+z/MQPvoUHHrmPQ0f28UOPLbFnQtjaKWi0p1GpYXt7yPbAcs/BqZj/TZly
+ynCdJgZTG2nkqQ5jdMGNMXEGsBzEF8b7AOrpeLvobQSH0RgVnXCEKYweL4fq9yybg3GHyJby88IF
+1vuwvm0pbGQpjVbVAkujFUmSIASMMdVrFBEkOIJpEXxBo11D6q3ydanxwYlhY7tgajKNJZ4aG6Yq
+GcOx4kmNscEIw5gYBXSaoLSZf1NloFJmVnTU7kvUJ0SxQin4VImq1Cuyu64d1avZGp/5wy/xlsce
+5scfW+DonGKl7AWslCAqhDhRu9213He4TbuZkuVuF+9QvnkPftchjvL1yFDSxNzmqSOu/bYIIbc3
+oXa3V0fPpVXkCnaGjnaiuLjlWe/HKrSZQN3Aa6sFV9YG1ayCV7Hq0QVIosgGDlNThCJE4Uwo9Yok
+5W1rCpQDTBujFbkykNahiCxit59zcJQCRKGB4B0uFCRGRzmcTmIUyHwUiVDK470DbWLaFT375noB
+SreVUWg/nu2Lau9oBAGp5v1i3ilzr74NR/DiuZs8d6jD2w83q/9/2/E6j59p0uvt4Jzj+saQEFoc
+OTDL+ctbkXMvStZLojRcSg4/cisG51zleSOkPCq1QghxTEyNw71zrkoD1nkSo6s+w4gOlnIL6cJM
+HR/gUy9l3NopEBEaqeauvSmvXMtY3xiWgLjkHIhLKlzuIwB14FRsjnkPSR1cBl4pvLNYLK3JFllv
+1FBLy9cQN4zWEolA0ZdCGGXQBlxRbjDbRbpFylgRSt4lrdVKI9DNNxkBVJs/pzGMDFTcADIKbUHF
+cS10efctyklbMQRVI+92OXO5y5XtBnsn4wkutoSPPbrAZ55P+Nq5VVbXhzRTxQfvn+Y3+3EHQK9b
+xE0c/QJTgpvERKStDBg7jgK7c3rFoO2OCJSjCrvYwpHHhwBKCbbc/jXZSji2WAMFXzqzUf2NLUCY
+ZGkypfDj5xnlepVGvUHs3IHW5YaSsgmFqLhmwiR4mzM500EJFEUW290lUMyL2J6WegN6vVhBEDed
+KRVw3iFpEgUjo1a61lH2jiCNach3EKTx5kShSplQTvgqo1BJGVpGPEDZohQv6FpCQDBprFFV0qxa
+ogDnL2zx8ecGrHY9L1x3/Nun+3RqwmMnp/joOw+wf7mNI/C+kyn/3QdX2L/UptVOSIym3kqrQ/Mh
+hmNjYm6vpUmF8HfnW8oZgESPjaKWJrdtHBulmQprlB2qpcUmi9MJn/7qNlnhGOSO7tAydJaXL/ZY
+mja06zHvJ+UsQZqYqvegVOQr0LFETnTEKRHMRf3CCIymDRMxjGnF46g16XWL6OVJM2KDMjqI0qh0
+VNXEnoKYcUfRJClJowW1iSjE1Yl+symgG/cmKULQiKYc+4r6dO8tIYz4/nG41SYprXmMEba2ezz5
+0hrLkwucuTzkqRdX+VTwLM00efDEND/41llOLWg6NeFthw1Xd1qsbw5xeaA7KLkBBC1xjk5LqHLe
+bbleIg/gvKoo4FG7R3lIxeBVnCKu3mcOksTcP9VOObpYZ6fv2OgVVRXiy/Rzc23IhVsF3/e2BX71
+k5cwajRSLrsaU/F9O6cxtShGNYAPpbRLK0wSX0dqVCVLD2WPfyReNcaQqRriPOg6oeiNS1KdIt7G
+bSgqEklKBDV9HFw/AvTbth99fURQFvf0qfJmq/HryPslts0w9bTEAGWNqtLbmz3BUuQxvK5tO16/
+0qU/tBTDgotXu/zpi2ucv1ncRrrMNQ1Tk3VqDU29YapSTquyWWPG4T81kQsYNXxGiF4lkJZ1uVKK
+YASTQqoiW1hXCu0jaSQipA3DwnydvdOGs9ez6vC1iuxjKCeJnvzaBtNNzb7lTmQjTXwNo+VWo9Si
+dRkRvIrjbWWVoEqeABt7FSaN0U1MoxKupkZRa2gkKRtMyiBJnL1UST3OVZSNMpXEsk8t3ElnqkHo
+3YqVkFH9N2cAhDWlDAqD1sm4nBkh6PKNjHJzpCXHPfYRS0ZhQfIql/aGBcMsj56shW4/54svrfMH
+L2dsDz3rfU+zBu++a4IHT0xzYLHD0nwzXhARpAyfI4MYvaZRh8+UxIwJsc5LEBKJZA+i0BKoieAk
+xLytBIOikWqOLtdZ6zlurWdRfj0CtkqR1qOh9YaOczdyHjoe5WKjSiQx8TnqqanA5m6jlEQqsmaU
+u1OjMMaMOQlMtXk0XuMUSWvlqJWvWMWgW5Ggk4AYTWP/aU6eXGJ7O04VKW0AtfEmFUH6FiKxl4Mv
+mSgXSQYTt3MikR0cz7Ob6mtQSSSQHASnqzp71JJVajTmLez0C/705S2yfIK3HKxxcd3z6o0hMy3D
+209N0hs6rm9bVjdz+tYzHPrqwo5YwarES+K9ASQVdDl6JqPbxGoqBU2aELeLmrhPYHGqxqGZhOcu
+Z2TlDgCFQoLDKan4BYLni2c2+b5H5zi4p835yztlmoxhe1RWqrJ/P+IpAEI6pnRdMdoxqKr+h05q
+VSpLExNLQW/BKAKNOGSiyv+nT605yeTBO7jz8ALPnrlO2LkSjUU5xMutN4sB1qqOXKlPrO7DW9Ke
+igjA0AahnPtTSfw6GoVKU7RJaNQSfIjbtUfijREaL6xjcz3n8XyTdnMGI4rLN4e8WngmmwnH9jQ4
+vphyZDFhWMRVcq9eH3LtRha3iwbQKJI0Rqcic2gjVQfZJGNDKayjZkoWzgQSY8iN5/hKndWe5+ZG
+HnN5GbaLXKNCnNdXwRPKnH32asaJfQ1ubQ7oDR22NOxReemcw4yGT0tqeFQuhxBvZTvYLmJDSwmm
+ZipOo1lXTE/VGGYNejtxSFRkSNA1QqgBHj13gjuPLTA9VeO5F28wvP46kg9j1A11UMP1NycKFbUu
+WqNFcF5QOq5dj94e4iqWcguI1inBhjiuPMr9UnLdwZIYTaKFQR5lzWkSewx5Ef/tikAmBXbH8vjZ
+Ln/j/kmW52qceWOb3Ho2egWpUSzNpty5r8nipDDbbmEPtlACr90qeP1qn2HhyTNPksZ0gLn9VjAh
+xPm/EfKP9bawr1Pj+JLh3E1LVgQaqR4vo0g8iVACPY3kHi+aC9cH7J+d5OBKm7MXd0gTRV74KI7N
+x9TwaKXdaJuYEBCTEnxcNtlo1+htBtIk9j8aqWaiplieb1UbyXv9qJkT28c3Fnj7g/toN2MU+dyf
+nYfNm4gbxrSsNHGY6s1GAMIlJI5mi9EEX0T0L/HWa0qbah07XiGmnP3XtagdMBENq7SNqSnSRDEY
+hl1cf8QOI7AlPgKatY0BL15tsDiRcLmZ0s+j5i/Hc/F6n2urGQvzdWYahn0zCUrDXXtT7tkXl0lu
+7DiurltWt/OK2h1VS1oCaV0z0TRMNeKdQNp1xel9mlYibAw005MJW9vxveaFjTJ1HxcLS8lBpKUQ
+9vWbQ44t1ljdyNnaKajXFHlh0XWJgyQj8UqI7zUUFusCRsfUkOd5VeqamqFRT3jo5Azff2+NBw4Y
+fv1LmmcGNo6412a488hRThyYZJhbXnljh5fO3YCt69VqmSAaXKlSCsm1N2UAAX1RREWbVXrMppUL
+FRCPEh1HwjUgscctptTtl7lqpMJNjCYPfszaqRGLt/tmToGA4uKNIQ+f6LAwW+fS1UHcLitSih6h
+2/dsbA84d7nP7FTCfCdhtqVp1hQrM4aD8wbr62wNo0F0s7hEGg0LHcPRecPipNCqCRMJTDViDr97
+WbPVr/GKg+7QosSUo+SCLkve0T0KncDNDcu+mRqHlhu8XJQVgNcUBEwrGonNoudb50kTQ5qAqRmK
+oqg4jFqthkmg00j47lMtAPZPKj58X6eaQp5pp/Qyx2bf8sLZDS5fuAy2Px4m1USdQblcSpS78OYi
+QCoXIsVVU4RynKm8z9qIB1BpRKUV+BuJH3S9FIlS3rrVYJIYsnY3XkbiiVEL1ReRW98eWNa7loPz
+Kasbce9OuktKPJrxS42i2/PsdIdcUEKrpVmeTKgZIUmE6ZZmYXHcNjQGDs8oZpvxFnC7Rakiwp4O
+3LGk2Rxo7EYEm5SlYHxOqcpgU9465sJ6wYmVGmvdgo2tAqcEE+ICqd3Us0ZTZGN2sii/Gg3tTkor
+Fd5yfJo7FsY9iwdWFIO7JnjitR7nrw3Y6GZsd+Hm5atxPtGWQlxR8bZoxN3JIdSKS89/6jL8F1+/
+Abz2zO9sHb3/R94IcDgyUgopW5ixa6erhkUY3Vo9rd/Wwh1165IRe7irOVMxd4zB00igMSw817YK
+Tu1rsDhb49pqdlv7tmaEwqmySUQs+YDhwPNaP4vlVapopJbppiZN4p2/Tu/R7J28vWm1u0GklXBk
+VugVKU2juNV1DMpdwLmNUaSw499PNKxtFlyrK04sNfhK1+N8vL9A0Bpn/ViUooRGR6ilCc2mwbo6
+2sex9FoqzDUNP3S6TjOJm8iMhm4Or9wsePnCDheubO0C2IGgTPQ5F50u6LgZLcrO1blrz//zHfi1
+r98AVs99cnj09A/8Ear501LeURthLGGq9PUmSriT9rhWHV1Qk1RTNzoIuYqTPgVqFxWrqpZqNJ6A
+eGF109Kd9dyzv87lm8OqrauNxltITOzP6zC+ZWzUso/r7EEe18aNbu+6Z1JzcCrcNv+/W8EsIkzU
+FKfmhUQJ8z1d3WxidKcQ6ylHxMvh2XLnwERDcd+hZmUwI/C5u9OoyvNJtFAU4yiWGKFuwI5uhVve
+AfW5a47nLuywtpGR5Y6pqQ473V45aBpKniVuZpNQVKBcucGngeGbHQ3LcP4pxIaAjnDWj7opMla6
+VGjfg25WDJVJ0oqa3e3d8eDHIg6VgCB4FTtrWsWbOuaF5fqGZXaixv/X3ZfGSHZd533n3vveq6Wr
+l+me4XAWShwulig5YmxZlOAYQeBAiGQjcSAkcPzHMBwYCGAkARInQAAFDuIIsJPAgq3IgRTHsmwh
+8KLVlmXRFiGKi0lZIqnhcJ/hDIezdE8v1d3Vtbx33z0nP+59SxerehkuVlJAobqra6pq7jnvLN/5
+zjl3n2rh8o2sHDOoQ+dHMRTSzxtSiGO/AVRYIFr5AZIQNJRfQ7MxYPQzwmyD9p6HAK/sbeNHtvmF
+E/575TU35Gliyk84F2BpznjBVii4x/WDEmW5Lx07K0jFL5+4vu0wcoyNzRGubc7gZ+9ropMQLnUZ
+j54fYa07grUWWgnipsFoeQDSEaJGC0msYfStfhj1loWkXVDWFwifxQGg4P0UgKHVCkEcSBtxCoQM
+TDEgWQAj4GMAzSUETFEbURTBOYcoicGBVsUSWFBhhLsnl/jlj8Yo6JARGCiI9gd6vZvizIkY77kt
+wUaPkYaVno6l2iZqFHTRai4Ek/i1clFMGFrxETsJHAPdHcFLG4J7jgqaEe3qUSzcwcgCV3uCp17J
+sDnkcgVNocCdlscFIlUNpdK6YBMxZhOF9YFDmlXrZ3ojh37flUFwNsrLlFhrjVY7hs0E568O8Ocv
+aNyxFOEvnunj0o0BstyDcHMdgztPtvCDb3s7GrHBVs/i2voA11d6GOxkkKzn6eikciizUqngzWYB
+InzPB395tbP4AxsAHwNpCCVenRHw/qJapXcTQpjZKwGLp3CH1M+Qgk40JIPvkdNAFHs41Yhvv1LG
+X23G+Jk4L1xL8f47G3j36QaeujjwbiNg7Ub76mCJCKqwNSzyV1wSFCPSBK0VeqlgeZtxpOmj7AJK
+9u5C0LeC6zuC528whjb0JFqGgYKDQHLgxlawAQ4Qle+isOUZcPfpBtgBF5fTXUswimlkMFW9wmX+
+fDyHxWGYAf3UD7U82omQqDZuPdJE7hgzzRivrg3x3ItdbPdHSAcWYvsemLOZRwydAKTWtpdfXDnI
+xLB9ZwSdf+QzlxTxVytswAFiymhfKAozfkMVTMdVcGf8gMcS/9aAiVDaUKWUp3SHR4EU4UMZD8RG
+YWMrx3pPsDBDOLEUlwJNIkJUHKaqrIuJsGu/cJG2MTNSFqzuCC5uCDZH/urvZYLVvuD8BuPsMuPZ
+FcbKtvO8P/bfxZGUI+YS46P8whWVTGNFiBLCK6spZloKtx9PEMW+HFzS5KNqqKWWivVknYeR52cN
+7joW4Z5jCh+5N8FP/u0W3r4Y49qNAZ66sIOnn1vB9taoTB9FN0ueYFl7cfjyhUd/50BjYvZVADt4
+ZX35/KPfETOXEwhMsW9tKijJOgI4926hJvyCaeuhzYrL1ow1kqYuhUURlUWTOKm4eUarMu2LNOHl
+Ve/O3nY0wuJ8VNbik5iQhF6BSFfvVQi9Ttok8rN3dlLGjR3G2oDxak9wfp3xxHXG86uMy13G6pZD
+ZqtdwmWzKRF0VPHzi6y0LDbBM4RFBBdvWByZNTg2F5cVxaJYVHAEPKPX/54Ywq1LCX7snXO455jC
+fFOV84Qvrvixso4cJAvlb1cVlaraACCmna9deOAp23+pexAF2Hc+gIjw0t0ffvWow6aQXlLIIb4D
+1VOWAu+fdFTy8LQOvXnic/+KagW0Yi+oPJA6I9IgRT59VdVBFYfkadbAMBO8subw7pMGvTmDV3Nb
+XYFF/wHvFnZENf4fhcCsDMaA7Qw4v+6w2vNX5DCwfcX5lmy9i4MYVs+E4ZbaARJXvQKOQ0TOHvnr
+7ThcNRZ33BJhe5ij33elMjvru4y9Qvns4szxBn70TIITswoLTSrX3l3uMjZ6mecGDC2iZuQXZdhq
+A1oxc8j7IKz3Vi+8KgdcC3+wMXEO5xQPnvCjWHTp+0lcmYOCc5goLk1/wYhhW4E9o5HP340xgPHZ
+QXHGcaNWElWV2Tbam+BWorA1dFgfCG5bUDjSMRUdm3xYohVVLWkQH30TQEpgIrXr70nkGyhWez5A
+G2TVEEmoCpmMg38uBqCWn2mCwopX1ML6FG4njhQ2BzmWNxnvPdPyyh5XcUoSyDqN2OAD75jD6SMR
+zt/IsZVWjbjLPcaFFYth5hAZjd6270UsSsyaQjqrkqqLSux3XZaefUPnBK5d+LOLV5/72mOslvKC
+mSOkvTIYHwdITtUYtJxAJGW3bUHaLPl4gUZFYcFibHyNvjT9oQcgijRMpMq4gAW4uukAAm5f1Ggm
+4eCNF2whXKiKQ081Sli9vevoDGFrFMbNiccTdjV5hvcoArgiY4ECGokqc3wThVZ4E7qWgtLpyFuy
+q+sWa9uMH72njUas0AhDqGOjcOZEC3/v3R2s9x0efLaH710a4tHzGS52HR6+lONPnx7huVf7cOIt
+gvLmpepoikNLWz7wbtjM5yvPfPGxjZf/7MqbMSv4G8T9fw4yJ0gJIK5C/5SGKUgQIa8X6F3duknE
+sNaVgZ3v8dBVqzdVC6IlBEuN2G/2UmFeX2wU0kxwpcs4s6RwtKNxddPVQJ0A6xYCD6PqNXkhR9oL
+qBkROg3CtS1G5sJQD6m1oRAhZ/KNVqWJFYjyz+XO5/Kx8TFqygrMAAAbcElEQVRFpIOF8McCYgWn
+fGAXxX7xJJDg/Xe2cGHVIpmPcGrRoJcKHn+pj0GAuftDiytdhXPLBk9dGGBtO8NGbwQoA5vnSOII
+XKTBYWiGbwtrQNIUpPrL5Ogbb86gSEm/R5w+LSo6gbAFHAGDrrsbHfmqnkmoXOZU9NBZ9mNe4kjB
+wC9h9Hx9KU0nKY0kBozxe1+UKaL5yh9vDBhzA8KpBYWRBXqhA7hQgtJz6SIC9zUAYh9rJMYvoC42
+h473GogSfzCakFt/lee22HxEMDoMcgyVUPa70iDw/w9WAHIf5Hnsw7uvtx3V+Il3JTjSVFjrM771
+UuaVOiCHBdI4zBxWNlP0diyECVGkMNjJwoXky9TQCs44sK0GVJAbPilueO5NGRV75YnPbo02z/8P
+kLFlU6Z2pdmvBhqEJY21hgvPY6uGNXfaGlFCJYeu3uQZGYIwhb4+7CJ7FjrnWHBtk5E74MySQqtZ
+cBZDi7ehXT430t5XF1H7kaaCE8Ewl9Jck6nWyBMHChd76+EJJSHNLALLmsspvleh8H5MfkhJQ7Yz
+N6tx91GFO45oLDQJR9uE4wsGJlZlKsview43dxg7o9wHlqaauVSUzl1gOUlQHA8BqyzdeOk3L3/3
+f2+/KQoAAGnae4A4XSaxvijEJgSgrvSxLKpq6wopThG4jCxjkDFmw2q4Oq/PN2d6ZC+KCRGqHL4Q
+HAUrociPcn25y2jGhLcd0WhGfskDsRdcHHs00EQo8Yco9u+12CaMQhRdCLbEDILSxHFtiJSrBq2U
+HUkk3nJFfu6gB6eqYLP4zuII8zMG7z5uYOAjfu/OqnhIGyrPYLZpsDFgHx+J30+Y5VyD0Kt4pOAj
+SpoCnF0d3Fh7CIe8HUoBnv/LX+kj3fxogMQ8LBYIoAWVSQvtyuULRq7LPO0rZ2CxrcvXUDCbRldX
+elTbGF7xBGhXLcFEQH/gcGWTMZcQTs77WkMj8XdFgCkeVcUGaja8cJgAFz5b6cBdCd+hkYT1s7FX
+JCJCFFeIYaT9mrkiPnBCu76jqq2w7bQ17j1tcGWT8fClHGdXGM+vMZ5ZESy2qASXAI+RLLR1uaLW
+by1RsNYiCi7VA2CBUqZFrLUCo0QNN/7V+Yd+ZXRYBTj01rDH/+Dnfvd9P/uVfwOhdwFakDORtiSS
++E5hI3COSySvODQdhkJx2KzZaUZIrSvNGsFfCZGhMg3jkN979lHF6HES4gOlcHXboRkRFmd8L8C1
+HkOFHLv0yUEJ8hzoxH5htHUCHby6hn9NYqoiT32KWbMRonADGEXIMh9IWvgto56hLaUiFIze47MK
+t8wSzi3n6A8FiSL0BnnpCh0Lztzi5yWvblucubWBH7vTM5yud1O02jE4kFMFhCgB8pQgwkJV2Crg
+/Mlv/97P/Alu4nZTa+OUZB9jbv0vcYgRKQXJyTlHWhE5rvrji+o/EUGLhhFgyH5Ny2InwsomV331
+KNg2u4c+FJVBo/yVRgYwobjkqVmEq9sOcaxxbEYhc8BGn/30tSBgVSODzLX8cwOLUqlYds/SKixP
+zr43X0IhKK44rt4yMYWpXQCFGcWaBE4BSzMKSzMKV7Y9GwkZ0CfGNlc7iKwTrGxb3HOqgfm2wg+d
+inHbnELnB2JcuJpgAGBtbQRTTF4TiFNaJHdCSnsVEklhs/+Cm7zd1Nq45x743JeI5KsKPAo7TpgF
+QkRStlhzNcIt0lQGhr2eRZoLFmd16U+N9oFYI4AuhdmOIi98CibXRF5QhWk2CuV8gmvbjIyB4zMK
+R9qqqLkgVtXdz/nxGYDLpeQJ+nkDoWyrKxxBab+nqFDS8RZzo1B+jyKOcEI4uaCxNKPwajcI3/o1
+dwWXwDpBFgq1sVHYGTDuWIxwx5L/nIUm4b13tRCTHxMXGwUyJPA9IkxEVtiN0qEbgPMvvPinv/H1
+t1QBtq9+KRPX+wQcVgAeAsiEnXMs4pzPZeooHUyVbg0yHwgutHVZYq339O1KywhlpK3Jm9vCz5Z1
+dqrcxfKOT4lOzanS1KMGl/r+P+//c6r+vaFalhEE6y1dpQgFGliPRerflcWnj8fnFE7NKVzf8kwi
+o3YXt+o6VJBFOm2NuRYh0QECdsBSR9X7IUUxhIicImQAhk6o53L7Kobbn+wtf330liqAiPBf/95H
+vy1Kfo2cbGK0MxQR65xjxyL1Dt3iCi0GM3Pux65EEeHoQuRbrlg8oSOv4NZC8EVBplCQRlIpR1E/
+cKjWzi/v+PTwtjmFduR7A2PtP2+uSeWACeNJyVXwGSyRqlmFOJA6CgthlH+sVxlz9sGjY8HRlsYd
+SxpPX/PCrzemFrS3wpoUKa4EH39Lm0oXs5UKjrYIc03tY5VYi46Iick6lqFj2XLO3XAsv3rxgY+e
+PSju/4YpgFeCl9Kr3/nc/eSGT0DFPXLDUZ7nFjnYZSIFD7/oBConZynB5iBHmgpuma34AoqAJKEy
+jy4g5yI1I+MPLXPV+xbQbFE3yB2QsuBG3499u21eoZNU+HtURO15lcuDK9PPrqg9+DuTN/GvYclI
+ZTGakc8qjs5q3HZE4ex1vwRTRz5Ggaswg3LVfYgvipRukDK6YV5id+gJK18+6zeq33myJa1YMSlt
+taIRgB4RrY/62beXH/zEQ+vnH0/xOm7q9fzj60//n8s3nv/Wx8FqRdJhn9wwcyyOjLBjkdx5mnSU
+hBatILSNzQxKAe0G7VreWAyDBqPk1BVXiWJ/mHVMoF60KQRDRBg6weWuJ2Oe6igstr15XWgSYgUM
+HJA0CHFwMWWOPbbAoggSQ2JSHZquTs46zw84OUe4uO6Q2youKLqStIhXNKXQiFQZ44gILASr2w5P
+Lzs8/qrDI5cdzl7JsLyWYWXDysp6yp1O5I7MxZmOqM8Wm1nO16489MlPXX3yd6/gdd5uWgEonNKN
+F/7wLG88/3kivcUu72c2z1wmTsJNx77xUsfVTAGlFJa3cjSMQmcmlI4Zu3zkrtFvofhRFFqgqty+
+brKLq7uTEPJgSmcS4B1HFN6xpHCyQ5hLCHMNQicixGHkSxw4e0VF0RSFJKFdQydiVcULxeklMeHE
+vMLqjkcWCzJKcS8KUkVguWtOkaba8AnG01csLq5aXFnP4FgkTIl1vR2X7fTzvohsO+fWt185+4VX
+H/vyC3U5vCUKQLVb8dSwe3XnwuNf/H2wep5y1+NsMByOUuv8ei7RisSFAA66CoZWNy2MAY7P+vm/
+0NXVrRWBCotBVfRslL9iNWiqWdaBKdwwPuKfTxSOtRXePqtwcoZwS5tw1zzh1llCO6oQO2MqP1+H
+d4tTKoNaHRDG8BVOdBRGKdDLZJfS1l0gEcGEnLvOHipAoCJW6I4cegMHZ0V0RKIVOZCyEB5aa3tb
+27bbH9nnn33gU38O3BjsIZe3xgUUlZftq39548pj//PfiWlfRzbqWWuHduQsEbGICDOLg4PiCvUa
+pIxuz3k2j8auK01EqtIuqnIry27XUD/o2FRCyZz3zbEBWmPziiJFWGwSbmkSOgntyirqNYciwjfK
+VxWV3m0VMgaOtRVAwNqgGlG/K/tBhUDWT7r4zIJMMt9UEJKCNSyiRODALLDw0EnPZtJVSl17+g8+
++t+3z9+/ijfopg5r8l/TPhjQlpVzf3Rl49wXfpH1zDpx2jOJGomIHfRzBiAkusTimX1vwNUNh5mW
+wlzbV7hK+pXx6+h0GJBI7JVEhTHueY3qGBsfsJF4H14c7NCGYEuqyZr1HUVNQ+XUrzryiIAtxLoC
+fpI4sJgDbGYh6MSEoy3CjS2ucAPaHZMU7qDEEEIxSUQq/qIA7YbGRo8DE8kL38FZRRgxcy8dua4x
+ZvX8A3/4yyvn/ujK+NkfQE6vTwH2EP6uL3LpW//tUu/ZL38CarbLzL3ccaoIVhFY2InNRIpAL7UO
+TIydAWM+qfh/WhE4dMQW0KqJqpigLogi8s+dR+yKCLvhdyliYIHuSDDKsav9S8Rz/lmAUVbBoYpC
+JmC8FSlcT/1vUF7h7l7yI+TyAvv37X/IOdQyau8ZU0my96lsKBiJCGbbCo0Y2M5YspyFc7AVsSQ6
+tdb1HMtmqx2vP/Otz3/ye3/yS5fHzh6vVwlu1gXQhEcFwF16/Pe/zte++bvaRF3k6OWO05xhWeBE
+xI8ZDMDIaMS4uG6RJIR2HAZOFHBs2c7ro+mCVFqkUCWCR8EC1FwIOw/PdlPBykBwaZtxo88Y5H7K
+5+pQsD4UNDSw0KoAqALwAVdXf8PUXEN47vScRnfgKeRA6JVRKCHrwn1wXnMJgtJC1W9HZyOs9pxI
+7iR37ESJVYLU5q6XMzbjyKx+7+Gv//4Tn/+1JwJgrWoXHU1TgjezFkBTtJAAUD683H/hrz79lfe0
+Zo8n7/g7HwIAlzrYBmCgIseiNDOYQHnuOQLDTHB8weDyWu5ZNIFwEQVyCdeCQC7caegJzMR3KKha
+8JazH+poc8HWCBgyMMiBhabPEjZT/+8U/OsMEXoW2Bq9Fk9hV7F9UhbMxgqGgFe22cccBReTvNLl
+7C0IsyeiutzHD3Ao26Bz51PUVqxgIki36yS3YMdiOUeaO+6JSLeRmLXHH3vu/rNf/eRD+fByP5yx
+1B4x5bk3zgWMmZNxsz9+VwDU4Mq57rn7f+N3uhef/AbpaCO1rscWIwdnWVBgBMICDIcOa9s5EkWY
+a4WqWzCVeQ0PyO3kb15E6yxVc6xRlQnPGBhZYOR8XLCRAT0r6I0E3ZFgZUeQC3C0STg+o8plloUl
+ULXspKkJCy3C+kAqsx8sgKrVBzhHldYGgEnp3QBWmguOzRvp7jjJR8yixGqhkWPpMXM3aURrTz39
+8jee/uNf+pOty49s7nHmEy3BQd2AuknhY4Ii1H9XvetPds995WOf2njpsT9L2s2NHPl27ngouWSA
+dwfMLIqAraHDRp9xfM4g1v7KrqOb9fJskf8Xh19chfXX1yN563yXjWNBxp5IMsqrFseUBRtDxurQ
+7wq+tUM43vHcxBJvUH6e0OKMdxVpLkjiABypKhYZryvUaxDVgfkgsJmQOBFZ7zlnnWQsGDqWbQAb
+nU6y9t0nXvrz73zmF7+w+cqjGwcQPG5WCWgvGHmCAuxlAXRFhqruOm4n9/3Mb/78bT/8wQ9bsQux
+UZ1GbJqtxERGK22MUkYrmmkbvPNkAmsFF1csZlqqRPwKcCbnCpqNxpBAQ9j9umh3Lp5owq0dwmpf
+kLqCPFoZz6Lley4hdGJPUBlZ+KtdAXMNwlIDWBsBW0MBE5BmvkPYBqdfLyuPF7UQUuCRZVgnsjCj
+eaOXu51+bocsw8xyD4zNZitaf/ivnn/wwY9/6HNuZ30U3jFHxUsK+3QhE+4Y+xn71QmmKsAE7Zmm
+AKr2WChBgXsoAEbFrcYP/5Nf/enb3/ePflLHdCQCdZqtqGkUYh2RbkaRggLdthjT7cciXFrPMRpW
+3TekQxpodtfroUKHYlE7oIrkwQTMxH4VnVFeAY62CL3Q/8dAOTw657CSqJZeHptRmI18d3AnJjQi
+jwRmzlcdL24J+plgGHj8Bb6RByUocnxTwwKShCTPIa0EPN9SrmWQPXI+Ha5u2l5iaJMVVh/8iwe/
+/tBv/bOvcTYY1gQ/TQF4PwXYTwluNgic6Pun/Kw5G/BTX/yPX9i+cWXzHR/8hY8cmWvdsjPM8nYj
+amtF8dBZ00iMutLNVJJoWpzRWMkd0pxhwvg1dlRe0SUpmUP/MwOx8WijU14gDe2FrySkb3r3lakC
+jq+Cma9jC4qAbl9g2oTTHWA2oRp8CxxpKdwYMNKsEn7ZU8JeCVQYaRsbX4TqNJWcnidebBJ3EspF
+JPvac7Z/YzvrtVtRd707XHnoC7/9pbNf/fgTnA1c7RxDgvkawfKE6F/eiizgsIpBAJQddN1LD/3W
+t/rdq9tnfvxf/9Q977rtjjSzuVbU1oqSPOeItNbX16zCoqbFGU1rPU+fikiXeXtRRi02sZQ5ei07
+QC1VRBEP1ARcZBTF84zd6F+dlFI3hIW1cE4wE0xPFAnSzCubcwL2I/p80KeARJEsdkjOLChebJGL
+NWyaS3p2mfvnLo+2lzpx95GnXn3pyS/+169e/e7nL9rhlp1whjzF779+oR3QBYx/uJpw9Y/HAGbC
+PQKgZ0780In3fPhf/IMf+fsfua83SOciULvRNC2tKWpEKmrGWh0/ElOsQas7jvxUEEIUuoDriF9R
+JDIU4kIVav1BeHEt+j41p7CVCroD8QygMbPPrqoLaPiI/5Y24dZAI7PsU8jVHcHWSJA5jxcUASqz
+V4TQKyiKIHNNkncsKV5okgVg+5kMXliT/mMXR1vOUfdLf/yVx5786q9/c/vSt7vBxNtg8ut3N+YC
+JsUCPOYCDhQHTFSAPfz/NNOvJgSAJjxGtcfiZ2M6x9qn7/3H933oF/7zh0BqwVo7k0S6ncQ6jo2K
+F2YjfWzOKGuFtoaOGrGheiag6+ma3g0M1bl9dYDn1JxC3wYFULVaQkjVMutRxHq1bqFBuHWG0M+9
+wAcp0Av9+0MrrzG+LBBm+EqegG87otx9p3UGIFvvS//cMu8s93jr2la28dlf/9j9Lz782XNp9+qw
+Juz9FKAu/L0CwgPFAa9HASYFf3qCEpiaMsS1nw0AM3Py3rff+09/7YP3feBH7hy5fBY5z0RGNxpN
+Fc9EJjp+JNYiolZ3HCWGqNPQVIeD682a5cAoquYDFPX6NBe87YhGmgtWeh6cifXuaL1QiDyvXMRi
+y2chBUgkIhhYnzVw0VnEABPE5SIskCxndiwOgJ1tqOz0oh6xYOd61/WGTja//vBLFx79zL99YO38
+o2su69ua0O2Y0PdSALdHMPh9pwB6zA3sUgzVmF24/QM/+0N/6x/+y/fecWrxKBRm8oxbSUM3Zhoq
+WpoxRkB6aEUBUI1IUUj5qDD1pjD/poqa6rm4iODEnN9mcmUjdDPVZvfUuYDF744Fdx3TuLbJGNkw
+NwheQUKUL7Xz5cGIWURcmkvOAisiI0UYRJp2IqO3n7vUXf2rr/z2E8998/fOpVtXhy7r51OEn0/J
+AP6fVIC6GzCT3EG4NxpLd9/63p/6D+9fvOu+k/f+4Kmj/aFti5Nms6kbRztRJCIm872gKtKkjFZE
+RFRw9bQi4jE8vgwUQ2rXiIArmzz2n6NSuHXsILPAXUc1Xlp1BcQsYxG3uFw4F+Y0F+dyydNcrCKM
+csZQK+onhnqPPX1tdfnCs9ee/OJ/+uud5efXxdlcnLVjZt/9/6wAe1kDXbMKiiiZnz/zvtvu+sBH
+7jr93p+47d13HF9wcK0s5VanrROjVawVacdiYqNUpEkRESWGCAAZ47kktSJMsdAccy3CUlvh4por
+A8ciby97BKoqoCjy/P6VbQciknCIfu8TC1snzIQ8t+wyh8yxpMw8IKZB0tA7Tz6/svHqd7925dlH
+/vh898JfX+N8Z7SPr58k9O9bBdgvCJykAJPiAjPBGsQ6npufOXHP8ZPv/LunfuCDP3/7e+85Pj+y
+3MozbiaGkijRMeeITAQdadKRJkWaVKz8snVtSmtAtaCOjs+q11iA8Tw6nIkkHm2Urb4XfO6YAbB1
+4gjirBObW2Qpu5QFw0ZsBnGE/ne+t7z5zP2ffvnqMw9e3145d4PTnZ0gpGlXvbsJBXjzgsADwMBq
+ihLom1QCPUEJFICmMq1OMnfLkWTulvkP/Nyn3/n+9719vqmpuTPgpjJIjCDOGZE2EhmttFaktKLC
+MigokIaPF6wInZzX6A0E/Uyo2CVVmH4miAkrHMEQTcJExMPMMQt4ZNkRkbWZWOdcxgqpUmrYTvRQ
+SIbffPTl9Uc+9fMvZv2NzXTr+hbng50JQrQTBH0Y4bspwuebgYMPowDYxw2MK4CaIvxxRdB7WIbi
+PRIALQDtxtKZhVPv+vCxH/3pf3/6zNvnO4mhJDGUDDJOrJPIsRijlRER3YiUdiyFQpAioJkQxUZR
+b+BKFE8RJGdIpAk7KUuswVkG7rTI7aTscos8B+fEZONEpYmh1Iqk1srw/OXN3sOf+9iVq+e+dmO0
+fmkTwAB+QmchQN5H8O4AP/ME8y97WAC80QqwnxvYLxbQB8gQ9lKO+t8aABpEUXv29L3zC6ffM3/6
+PT++eOKd75s7vjjbnO804lZTRYV7YIG2TrRj0SJCxKSShChNJQxVFhCTODhWonz3jYGLjXKRJicg
+O8yczXK229vZ6Pra1vDac9/evHL2ge76K09u9K59b1ucHcCj0lkQyLgAx6/k/f4+zee/oeb/jSoG
+HSQW2C8+0BPM/7TX1P8WB4WIdWOuuXjmA3NHb//h2VbnSKMxO5+gfaLRWjiRLB2db8zNNHW7Galm
+U6u5plaiiFwuRSrHQiI7g5z7fZd3t/vu6vLqMOsujzBYTtPe1qi3tTJae/mp7fULj2yx3RkBSIPA
+be2KdFMEzfsIO58gaLcPArhfRfBNUQCMwcHYwwqofRTgIMqgJrgSNeFzVC21LDKKSJk4ai7cnrSO
+3dlozByJdNQ0SdzUUWdOExEpMgrCnHPOJMTZcNOlOz2b9laz7RsvDkfdSynnWT1Pt2PC4jHBuJoF
+4H2uajel0ncQwfOYz+dplcCbVoADuoK9gsKbUYRx4et93mfc8uxXn6jXMQogWVC2ke7yq24s1ZIJ
+r+EpQnJ7KMW4wPMDCt5N+A6TFOBAgn891cC6maGx0mRtRvZrNFLGypqTDrN+L5h0dSFyjRg5zRLQ
+BOLkFPIk7/f/kwnf1+3xnd0ej+6AV/qkQG+aIk41+29VOXj8Q3mMnFj/knpM6GqCoPWUq1xPiTPU
+HsJXUxi001i04yjf+IFP+n2S8Kc9t59f30uxJgE+U+VwmG7hg4yKlQluYJyROunmagctYxZA1X4u
+lMHtYfJpisDHY49pV/9BaNTTrnxMEMC4YNwBlMJN+H2v18th6V+HFf6BYoBDBIcHTRVpiiCnxQ57
+vZb2uPoPSqKcpgS8hxuYpgj7KcBB3Mikz+Yp5v51Cf+mFOAQWcLNKkP9at/r7zTF1KsJnzft+2GP
+A52WX+8XFMoE/y0TsHueolDTUL1DgzxvqgIcUhEwRSjTIGU6wCMd8HeagGNgHz6dTAliJzFw+ACK
+IXsIfPx9ZIrw35Ar/g1XgD3454ehlB8Eaj6I0DEBowAO30o1iYCJPfJu3sdNyAEEPA3JO3Ru/5Yr
+wCEVYZIAaArv8KDKM/4ZaoIyTLNKMuHvskcqexghjgeR2Ktos1dw92YI/w1XgEMqA/aBmg/6/F5F
+q2nKdpDvU++3m9R7x/soyF6uZPxnCoJlvMW3N00BDqAMOISC0AGEt5d5p0N+3n54Bw5gpveM2Gvc
+A8Hf4I3+hj//MEpCB/ydDqgU095jGsYhB8AOcECl+BsX/PedArxJykM3aXEOYwn2/Zt8Hx/y/wUh
+VrPqnc92WwAAAABJRU5ErkJggg==
+"
+       width="48"
+       id="image2345" />
+  </g>
+</svg>
Binary files 3.4.1-6/wifi/data/misc/old/preview.jpg and 3.4.1+git20201022.a0d3415c-1/wifi/data/misc/old/preview.jpg differ
